﻿CREATE TABLE Teilnehmer(
	TNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	TName varchar(80) NOT NULL,
	TVorname varchar(80) NOT NULL,
	TPLZ INTEGER,
	TStrasse varchar(150),
	TOrt varchar(80),
	TTel varchar(30),
	TGeschl varchar(1) NOT NULL,
	TGebDat DATE NOT NULL,
	TAktiv BOOLEAN NOT NULL,
	TBehinderungsKlasse varchar(5) NOT NULL DEFAULT 'NONE',
	TGradDerBehinderung INTEGER NOT NULL DEFAULT 0,
	TMemo LONG VARCHAR,
	TEmail varchar(80),
	TSelektion varchar(100),
	TMitgliedsNr varchar(100),
	bestelltUrkunde BOOLEAN,
	bestelltAbzeichen BOOLEAN,
	bestelltZusatzabzeichen BOOLEAN,
	UNIQUE(TName, TVorname, TGebDat)
);

CREATE TABLE Familie(
	FNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	FParent INTEGER REFERENCES Teilnehmer(TNr),
	FName varchar(50) NOT NULL
);

CREATE TABLE Gruppe(
	GNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	GName varchar(100) NOT NULL
);

CREATE TABLE Disziplinengruppe(
	DGNr INTEGER NOT NULL PRIMARY KEY,
	DGName varchar(50) NOT NULL
);

CREATE TABLE TeilnehmerFamilie(
	FNr INTEGER NOT NULL REFERENCES Familie(FNr),
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	PRIMARY KEY(FNr, TNr)
);

CREATE TABLE TeilnehmerGruppe(
	GNr INTEGER NOT NULL REFERENCES Gruppe(GNr),
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	PRIMARY KEY(GNr, TNr)
);

CREATE TABLE Pruefer(
	PNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	PNummer varchar(30),
	PUnterschrift BLOB(5M),
	PAktiv BOOLEAN NOT NULL,
	PKuerzel varchar(20) NOT NULL UNIQUE,
	PName varchar(100) NOT NULL
);

CREATE TABLE Disziplin(
	DNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	DName varchar(150) NOT NULL,
	DEinheit varchar(10) NOT NULL,
	DSichtbar BOOLEAN NOT NULL,
	DInvertiert BOOLEAN NOT NULL,
	DSchwimm BOOLEAN NOT NULL,
	DGNr INTEGER NOT NULL REFERENCES DisziplinenGruppe(DGNr),
	DZusatz BOOLEAN NOT NULL
);

CREATE TABLE Punkte(
	DNr INTEGER NOT NULL REFERENCES Disziplin(DNr),
	Alter_Von INTEGER NOT NULL,
	Alter_Bis INTEGER NOT NULL,
	Geschl varchar(1) NOT NULL,
	BehinderungsKlasse varchar(5) NOT NULL DEFAULT 'NONE',
	Zusatz varchar(45),
	Sollwert1 DOUBLE,
	Sollwert2 DOUBLE,
	Sollwert3 DOUBLE,
	PRIMARY KEY(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse)
);

CREATE TABLE PruefArt(
	PruefArtNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	PruefArtName varchar(50),
	PruefArtKuerzel varchar(20)
);

CREATE TABLE AbzArt(
	AbzArtNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	AbzArtName varchar(50)
);

CREATE TABLE Pruefung(
	PNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	PruefJahr INTEGER NOT NULL,
	PruefArt INTEGER NOT NULL REFERENCES PruefArt(PruefArtNr),
	PruefAnzahl INTEGER NOT NULL,
	AbzArt INTEGER NOT NULL REFERENCES AbzArt(AbzArtNr),
	PUrkundennummer varchar(50),
	Punkte INTEGER,
	PBehinderungsKlasse varchar(5) NOT NULL DEFAULT 'NONE',
	PGradDerBehinderung INTEGER NOT NULL DEFAULT 0,
	GebuehrSoll DOUBLE,
	GebuehrIst DOUBLE,
	GebuehrDatum DATE,
	PGebucht BOOLEAN NOT NULL,
	Exportiert BOOLEAN NOT NULL,
	Importiert BOOLEAN NOT NULL,
	bestelltUrkunde BOOLEAN NOT NULL,
	bestelltAbzeichen BOOLEAN NOT NULL,
	bestelltZusatzabzeichen BOOLEAN NOT NULL,
	UrkundeGedruckt BOOLEAN NOT NULL DEFAULT FALSE
);

CREATE TABLE AbsolvierteDisziplin(
	PNr INTEGER REFERENCES Pruefer(PNr),
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	DNr INTEGER NOT NULL REFERENCES Disziplin(DNr),
	Jahr INTEGER NOT NULL,
	ADErgebnis DOUBLE,
	ADDatum DATE,
	ADOrt varchar(100),
	ADPunkte INTEGER,
	ADGeschafft BOOLEAN,
	ADZusatz varchar(45),
	Sollwert1 DOUBLE,
	Sollwert2 DOUBLE,
	Sollwert3 DOUBLE,
	SollwerteAngepasst BOOLEAN NOT NULL DEFAULT FALSE,
	Ausgleichsbedingung varchar(50),
	AusgleichsDisziplin BOOLEAN NOT NULL DEFAULT FALSE,
	Pruefung INTEGER REFERENCES Pruefung(PNr),
	PRIMARY KEY(TNr, DNr, Jahr)
);

CREATE TABLE ADZwischenErgebnis(
	ADZENr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	TNr INTEGER,
	DNr INTEGER,
	Jahr INTEGER,
	Reihenfolge INTEGER NOT NULL,
	ZwErgebnis DOUBLE,
	ZwErgebnis2 DOUBLE,
	CONSTRAINT fk1 FOREIGN KEY (TNr, DNr, Jahr) REFERENCES AbsolvierteDisziplin(TNr, DNr, Jahr),
	UNIQUE(TNr, DNr, Jahr, Reihenfolge)
);

CREATE TABLE Verbandsabzeichen(
	AName varchar(50) NOT NULL PRIMARY KEY,
	Abkuerzung varchar(50) NOT NULL,
	DGNr INTEGER NOT NULL REFERENCES Disziplinengruppe(DGNr),
	Schwimm BOOLEAN NOT NULL
);

CREATE TABLE TeilnehmerVerbandsabzeichen(
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	AName varchar(50) NOT NULL,
	Abkuerzung varchar(50) NOT NULL,
	DGNr INTEGER NOT NULL REFERENCES Disziplinengruppe(DGNr),
	Jahr INTEGER NOT NULL,
	PruefDatum DATE NOT NULL,
	EinreichDatum DATE NOT NULL,
	Schwimm BOOLEAN NOT NULL,
	Pruefung INTEGER REFERENCES Pruefung(PNr),
	PRIMARY KEY(TNr, AName, Jahr)
);

CREATE TABLE MailVorlage(
	id INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	Titel varchar(100) NOT NULL,
	Betreff varchar(100) NOT NULL,
	Nachricht LONG VARCHAR NOT NULL
);

CREATE TABLE NachweisSchwimmfertigkeit(
	NWSFNr INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
	Typ varchar(50) NOT NULL,
	TNr INTEGER NOT NULL REFERENCES Teilnehmer(TNr),
	PruefDatum DATE NOT NULL,
	EinreichDatum DATE NOT NULL,
	PNr INTEGER REFERENCES Pruefer(PNr),
	ADTNr INTEGER,
	ADDNr INTEGER,
	ADJahr INTEGER,
	TVATNr INTEGER,
	TVAAName varchar(50),
	TVAJahr INTEGER,
	CONSTRAINT fk2 FOREIGN KEY (ADTNr, ADDNr, ADJahr) REFERENCES AbsolvierteDisziplin(TNr, DNr, Jahr),
	CONSTRAINT fk3 FOREIGN KEY (TVATNr, TVAAName, TVAJahr) REFERENCES TeilnehmerVerbandsabzeichen(TNr, AName, Jahr)
);
ALTER TABLE Pruefung ADD COLUMN NWSFNr INTEGER REFERENCES NachweisSchwimmfertigkeit(NWSFNr);

CREATE TABLE tblEinstellungen(
	einst_key varchar(50) NOT NULL PRIMARY KEY,
	einst_value varchar(150) NOT NULL
);

CREATE TABLE tblFilter(
	FNr INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
	FName varchar(50) NOT NULL,
	filterType INTEGER NOT NULL DEFAULT 0,
	Alter_Von INTEGER NOT NULL,
	Alter_Bis INTEGER NOT NULL,
	Geschlecht varchar(1),
	Aktiv BOOLEAN,
	Selektion varchar(20)
);

CREATE TABLE FilterGruppe(
	FNr INTEGER NOT NULL REFERENCES tblFilter(FNr),
	GNr INTEGER NOT NULL REFERENCES Gruppe(GNr),
	PRIMARY KEY(FNr, GNr)
);

INSERT INTO Disziplinengruppe(DGNr, DGName) VALUES
	(1, 'Ausdauer'),
	(2, 'Kraft'),
	(3, 'Schnelligkeit'),
	(4, 'Koordination')
;

INSERT INTO Disziplin(DNr, DName, DEinheit, DSichtbar, DInvertiert, DSchwimm, DGNr, DZusatz) VALUES
	(1, '800 m Lauf', 'min', true, true, false, 1, false),
	(2, '1000 m Lauf', 'min', true, true, false, 1, false),
	(3, 'Dauer- / Geländelauf', 'min', true, false, false, 1, false),
	(4, 'Radfahren', 'min', true, true, false, 1, false),
	(5, '3000 m Lauf', 'min', true, true, false, 1, false),
	(6, '10 km Lauf', 'min', true, true, false, 1, false),
	(7, 'Schwimmen', 'min', true, true, true, 1, false),
	(8, 'Walking / Nordic Walking', 'min', true, true, false, 1, false),
	(9, '20 km Radfahren', 'min', true, true, false, 1, false),
	(10, 'Schlagball (80g)', 'm', true, false, false, 2, false),
	(11, 'Wurfball (200g)', 'm', true, false, false, 2, false),
	(12, 'Medizinball', 'm', true, false, false, 2, false),
	(13, 'Kugelstoßen', 'm', true, false, false, 2, false),
	(14, 'Steinstoß', 'm', true, false, false, 2, false),
	(15, 'Standweitsprung', 'm', true, false, false, 2, false),
	(16, 'Geräteturnen', 'Pkt.', true, false, false, 2, false),
	(17, 'Laufen', 'sek', true, true, false, 3, false),
	(18, '25 m Schwimmen', 'sek', true, true, true, 3, false),
	(19, '200 m Radfahren (fl. Start)', 'sek', true, true, false, 3, false),
	(20, 'Geräteturnen', 'Pkt.', true, false, false, 3, false),
	(21, 'Hochsprung', 'm', true, false, false, 4, false),
	(22, 'Zonenweitsprung', 'Pkt.', true, false, false, 4, false),
	(23, 'Weitsprung', 'm', true, false, false, 4, false),
	(24, 'Zonenweitwurf', 'Pkt.', true, false, false, 4, false),
	(25, 'Schleuderball (1 kg)', 'm', true, false, false, 4, false),
	(26, 'Seilspringen', 'Wiederh.', true, false, false, 4, false),
	(27, 'Geräteturnen', 'Pkt.', true, false, false, 4, false),
	(28, '400 m Rollstuhlfahren (Arm- oder Beinantrieb)', 'min', true, true, false, 1, false),
	(29, '800 m Rollstuhlfahren', 'min', true, true, false, 1, false),
	(30, '1000 m Rollstuhlfahren', 'min', true, true, false, 1, false),
	(31, '1500 m Rollstuhlfahren', 'min', true, true, false, 1, false),
	(32, '1500 m Lauf', 'min', true, true, false, 1, false),
	(33, 'Dauerlauf', 'min', true, false, false, 1, false),
	(34, 'Dauer-Rollstuhlfahren', 'min', true, false, false, 1, false),
	(35, 'Handbike', 'min', true, true, false, 1, false),
	(36, 'Dreiradfahren', 'min', true, true, false, 1, false),
	(37, 'Radfahren / Dreiradfahren', 'min', true, true, false, 1, false),
	(38, '4 km Walking/Nordic Walking/Wandern', 'min', true, true, false, 1, false),
	(39, 'Kegeln - Asphalt', 'Pkt.', true, false, false, 1, false),
	(40, 'Kegeln - Bohle', 'Pkt.', true, false, false, 1, false),
	(41, 'Kegeln - Bowling', 'Pkt.', true, false, false, 1, false),
	(42, 'Kegeln - Schere', 'Pkt.', true, false, false, 1, false),
	(43, 'Dauerschwimmen in Minuten', 'min', true, false, true, 1, false),
	(44, 'Kugelstoßen (rechts und links zusammen)', 'm', true, false, false, 2, false),
	(45, 'Fußballweitstoß', 'm', true, false, false, 2, false),
	(46, 'Keulenweitwurf', 'm', true, false, false, 2, false),
	(47, 'Gehen', 'sek', true, true, false, 3, false),
	(48, 'Rollstuhlfahren', 'sek', true, true, false, 3, false),
	(49, 'Rollstuhlfahren (Arm- oder Beinantrieb)', 'sek', true, true, false, 3, false),
	(50, '200 m Handbike (fl. Start)', 'min', true, true, false, 3, false),
	(51, '200 m Dreiradfahren (fl. Start)', 'sek', true, true, false, 3, false),
	(52, '200 m Rad-/Dreiradfahren (fl. Start)', 'sek', true, true, false, 3, false),
	(53, 'Zielwurf', 'Pkt.', true, false, false, 4, false),
	(54, 'Zielwurf/Fußballzielstoß', 'Pkt.', true, false, false, 4, false),
	(55, 'Geschicklichkeitsgehen ohne Pause', 'Wiederh.', true, false, false, 4, false),
	(56, 'Rollstuhl-Parcour ohne Pause', 'Wiederh.', true, false, false, 4, false),
    (57, 'Drehwurf', 'Pkt.', true, false, false, 4, false),
    (58, '400 m Rollstuhlfahren', 'min', true, true, false, 1, false),
	(59, 'Volleyballweitschlag', 'm', true, false, false, 2, false),
	(60, '25 m Schwimmen in Minuten', 'min', true, true, true, 3, false),
	(61, 'Push-Ups/Liegestützen', 'Wiederh.', true, false, false, 2, false),
	(62, 'Crunches/Curl-Up-Test/Bauchpresse', 'Wiederh.', true, false, false, 2, false),
	(63, 'Triceps-Dips/Beugestütz', 'Wiederh.', true, false, false, 2, false),
	(64, 'Pull-Ups/Klimmzüge', 'Wiederh.', true, false, false, 2, false)
;

INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'A', '', 5.95, 5.250000000000001, 4.466666666666667),
	(1, 8, 9, 'w', 'A', '', 5.866666666666666, 5.083333333333333, 4.383333333333334),
	(1, 10, 11, 'w', 'A', '', 5.6000000000000005, 4.9, 4.2),
	(1, 12, 13, 'w', 'A', '', 5.433333333333333, 4.633333333333333, 3.9333333333333336),
	(1, 14, 15, 'w', 'A', '', 5.250000000000001, 4.55, 3.7666666666666666),
	(1, 16, 17, 'w', 'A', '', 5.083333333333333, 4.283333333333333, 3.5833333333333335),
	(1, 0, 7, 'm', 'A', '', 5.95, 5.250000000000001, 4.466666666666667),
	(1, 8, 9, 'm', 'A', '', 5.683333333333334, 4.9, 4.116666666666667),
	(1, 10, 11, 'm', 'A', '', 5.333333333333334, 4.55, 3.7666666666666666),
	(1, 12, 13, 'm', 'A', '', 4.983333333333333, 4.2, 3.4166666666666665),
	(1, 14, 15, 'm', 'A', '', 4.55, 3.8499999999999996, 3.15),
	(1, 16, 17, 'm', 'A', '', 4.283333333333333, 3.5833333333333335, 2.883333333333333),
	(4, 8, 9, 'w', 'A', '5 km', 28.35, 25.200000000000003, 22.05),
	(4, 10, 11, 'w', 'A', '10 km', 53.03333333333334, 45.150000000000006, 37.26666666666666),
	(4, 12, 13, 'w', 'A', '10 km', 47.25, 41.483333333333334, 35.18333333333333),
	(4, 14, 15, 'w', 'A', '10 km', 39.9, 34.11666666666667, 29.93333333333333),
	(4, 16, 17, 'w', 'A', '10 km', 34.11666666666667, 29.93333333333333, 26.249999999999996),
	(4, 18, 19, 'w', 'A', '20 km', 60.383333333333326, 54.6, 48.833333333333336),
	(4, 20, 24, 'w', 'A', '20 km', 59.849999999999994, 54.08333333333333, 47.78333333333333),
	(4, 25, 29, 'w', 'A', '20 km', 58.8, 53.03333333333334, 47.25),
	(4, 30, 34, 'w', 'A', '20 km', 59.849999999999994, 54.08333333333333, 47.78333333333333),
	(4, 35, 39, 'w', 'A', '20 km', 63.0, 55.65, 49.35),
	(4, 40, 44, 'w', 'A', '20 km', 67.2, 58.28333333333334, 51.98333333333334),
	(4, 45, 49, 'w', 'A', '20 km', 70.35, 61.43333333333333, 54.08333333333333),
	(4, 50, 54, 'w', 'A', '20 km', 72.44999999999999, 64.05, 56.18333333333333),
	(4, 55, 59, 'w', 'A', '20 km', 75.06666666666668, 66.15, 58.28333333333334),
	(4, 60, 64, 'w', 'A', '20 km', 77.7, 68.25000000000001, 59.849999999999994),
	(4, 65, 69, 'w', 'A', '20 km', 79.28333333333333, 69.83333333333333, 61.43333333333333),
	(4, 70, 74, 'w', 'A', '20 km', 81.9, 71.93333333333334, 63.53333333333333),
	(4, 75, 79, 'w', 'A', '20 km', 85.58333333333333, 74.03333333333333, 66.15),
	(4, 80, 84, 'w', 'A', '20 km', 88.73333333333333, 78.75, 68.78333333333333),
	(4, 85, 89, 'w', 'A', '20 km', 93.96666666666667, 84.0, 72.44999999999999),
	(4, 90, 200, 'w', 'A', '20 km', 97.65, 87.15, 76.13333333333333),
	(4, 8, 9, 'm', 'A', '5 km', 27.833333333333332, 24.683333333333334, 21.516666666666666),
	(4, 10, 11, 'm', 'A', '10 km', 50.93333333333334, 43.050000000000004, 35.18333333333333),
	(4, 12, 13, 'm', 'A', '10 km', 45.150000000000006, 38.849999999999994, 33.08333333333333),
	(4, 14, 15, 'm', 'A', '10 km', 33.6, 29.4, 25.200000000000003),
	(4, 16, 17, 'm', 'A', '10 km', 28.35, 24.683333333333334, 21.516666666666666),
	(4, 18, 19, 'm', 'A', '20 km', 49.35, 44.63333333333334, 40.43333333333333),
	(4, 20, 24, 'm', 'A', '20 km', 48.833333333333336, 44.1, 39.36666666666667),
	(4, 25, 29, 'm', 'A', '20 km', 52.49999999999999, 46.73333333333333, 40.95),
	(4, 30, 34, 'm', 'A', '20 km', 56.18333333333333, 49.35, 42.51666666666667),
	(4, 35, 39, 'm', 'A', '20 km', 60.9, 52.49999999999999, 43.56666666666667),
	(4, 40, 44, 'm', 'A', '20 km', 66.15, 54.6, 45.68333333333333),
	(4, 45, 49, 'm', 'A', '20 km', 69.30000000000001, 57.75000000000001, 47.25),
	(4, 50, 54, 'm', 'A', '20 km', 71.93333333333334, 59.849999999999994, 48.833333333333336),
	(4, 55, 59, 'm', 'A', '20 km', 74.03333333333333, 61.43333333333333, 49.88333333333333),
	(4, 60, 64, 'm', 'A', '20 km', 75.06666666666668, 63.0, 50.400000000000006),
	(4, 65, 69, 'm', 'A', '20 km', 76.13333333333333, 63.53333333333333, 50.93333333333334),
	(4, 70, 74, 'm', 'A', '20 km', 77.18333333333334, 64.56666666666668, 51.98333333333334),
	(4, 75, 79, 'm', 'A', '20 km', 78.23333333333333, 66.15, 54.08333333333333),
	(4, 80, 84, 'm', 'A', '20 km', 79.80000000000001, 67.73333333333333, 55.65),
	(4, 85, 89, 'm', 'A', '20 km', 81.38333333333334, 69.83333333333333, 58.28333333333334),
	(4, 90, 200, 'm', 'A', '20 km', 82.94999999999999, 71.39999999999999, 60.9),
	(5, 18, 19, 'w', 'A', '', 21.883333333333336, 19.78333333333333, 17.683333333333334),
	(5, 20, 24, 'w', 'A', '', 21.35, 19.249999999999996, 17.15),
	(5, 25, 29, 'w', 'A', '', 21.700000000000003, 19.599999999999998, 17.5),
	(5, 30, 34, 'w', 'A', '', 22.566666666666666, 20.48333333333333, 18.383333333333333),
	(5, 35, 39, 'w', 'A', '', 23.099999999999998, 21.0, 18.9),
	(5, 40, 44, 'w', 'A', '', 23.966666666666665, 21.700000000000003, 19.433333333333337),
	(5, 45, 49, 'w', 'A', '', 25.01666666666667, 22.566666666666666, 19.78333333333333),
	(5, 50, 54, 'w', 'A', '', 26.083333333333336, 23.283333333333335, 20.13333333333333),
	(5, 55, 59, 'w', 'A', '', 27.116666666666667, 23.966666666666665, 20.816666666666663),
	(5, 60, 64, 'w', 'A', '', 27.833333333333332, 24.683333333333334, 21.516666666666666),
	(5, 65, 69, 'w', 'A', '', 28.533333333333335, 25.383333333333333, 22.233333333333334),
	(5, 70, 74, 'w', 'A', '', 29.05, 25.9, 22.75),
	(5, 75, 79, 'w', 'A', '', 29.93333333333333, 26.76666666666667, 23.616666666666667),
	(5, 80, 84, 'w', 'A', '', 31.15, 28.0, 24.85),
	(5, 85, 89, 'w', 'A', '', 32.55, 29.4, 26.249999999999996),
	(5, 90, 200, 'w', 'A', '', 34.11666666666667, 30.983333333333334, 27.833333333333332),
	(5, 18, 19, 'm', 'A', '', 18.733333333333334, 16.633333333333333, 14.516666666666667),
	(5, 20, 24, 'm', 'A', '', 18.200000000000003, 16.099999999999998, 14.0),
	(5, 25, 29, 'm', 'A', '', 18.549999999999997, 16.45, 14.350000000000001),
	(5, 30, 34, 'm', 'A', '', 19.433333333333337, 17.333333333333332, 15.233333333333334),
	(5, 35, 39, 'm', 'A', '', 20.816666666666663, 18.200000000000003, 15.749999999999998),
	(5, 40, 44, 'm', 'A', '', 22.05, 19.433333333333337, 16.633333333333333),
	(5, 45, 49, 'm', 'A', '', 23.283333333333335, 20.48333333333333, 17.333333333333332),
	(5, 50, 54, 'm', 'A', '', 24.5, 21.35, 18.200000000000003),
	(5, 55, 59, 'm', 'A', '', 25.01666666666667, 21.883333333333336, 18.733333333333334),
	(5, 60, 64, 'm', 'A', '', 25.733333333333334, 22.566666666666666, 19.433333333333337),
	(5, 65, 69, 'm', 'A', '', 26.249999999999996, 23.099999999999998, 19.95),
	(5, 70, 74, 'm', 'A', '', 26.599999999999998, 23.45, 20.3),
	(5, 75, 79, 'm', 'A', '', 27.3, 24.15, 21.0),
	(5, 80, 84, 'm', 'A', '', 27.833333333333332, 24.683333333333334, 21.516666666666666),
	(5, 85, 89, 'm', 'A', '', 28.866666666666667, 25.733333333333334, 22.566666666666666),
	(5, 90, 200, 'm', 'A', '', 31.31666666666667, 28.166666666666668, 25.01666666666667),
	(6, 18, 19, 'w', 'A', '', 88.9, 82.6, 76.30000000000001),
	(6, 20, 24, 'w', 'A', '', 87.66666666666667, 80.68333333333332, 75.06666666666668),
	(6, 25, 29, 'w', 'A', '', 87.66666666666667, 80.68333333333332, 74.55),
	(6, 30, 34, 'w', 'A', '', 88.38333333333334, 81.9, 74.9),
	(6, 35, 39, 'w', 'A', '', 92.05, 83.48333333333335, 75.06666666666668),
	(6, 40, 44, 'w', 'A', '', 95.9, 85.39999999999999, 75.25000000000001),
	(6, 45, 49, 'w', 'A', '', 100.10000000000001, 87.33333333333334, 76.48333333333335),
	(6, 50, 54, 'w', 'A', '', 102.55, 89.78333333333333, 77.7),
	(6, 55, 59, 'w', 'A', '', 105.16666666666666, 92.58333333333333, 79.98333333333333),
	(6, 60, 64, 'w', 'A', '', 107.98333333333333, 95.36666666666666, 82.78333333333333),
	(6, 65, 69, 'w', 'A', '', 110.94999999999999, 98.35, 85.75),
	(6, 70, 74, 'w', 'A', '', 114.96666666666667, 102.36666666666666, 89.78333333333333),
	(6, 75, 79, 'w', 'A', '', 121.10000000000001, 108.5, 95.9),
	(6, 80, 84, 'w', 'A', '', 128.45000000000002, 115.85000000000001, 103.25000000000001),
	(6, 85, 89, 'w', 'A', '', 135.61666666666667, 123.03333333333333, 110.41666666666667),
	(6, 90, 200, 'w', 'A', '', 143.31666666666666, 130.73333333333332, 118.11666666666666),
	(6, 18, 19, 'm', 'A', '', 66.5, 60.199999999999996, 53.9),
	(6, 20, 24, 'm', 'A', '', 65.63333333333333, 59.333333333333336, 52.49999999999999),
	(6, 25, 29, 'm', 'A', '', 69.30000000000001, 62.3, 54.6),
	(6, 30, 34, 'm', 'A', '', 73.15, 64.21666666666665, 57.583333333333336),
	(6, 35, 39, 'm', 'A', '', 77.88333333333334, 68.78333333333333, 59.68333333333333),
	(6, 40, 44, 'm', 'A', '', 82.78333333333333, 72.98333333333333, 63.18333333333333),
	(6, 45, 49, 'm', 'A', '', 87.85000000000001, 76.83333333333333, 66.68333333333332),
	(6, 50, 54, 'm', 'A', '', 92.75, 80.5, 68.78333333333333),
	(6, 55, 59, 'm', 'A', '', 96.06666666666668, 83.65, 71.05),
	(6, 60, 64, 'm', 'A', '', 99.39999999999999, 86.80000000000001, 74.2),
	(6, 65, 69, 'm', 'A', '', 102.9, 90.30000000000001, 77.7),
	(6, 70, 74, 'm', 'A', '', 107.28333333333333, 94.66666666666667, 82.08333333333333),
	(6, 75, 79, 'm', 'A', '', 112.7, 100.10000000000001, 87.5),
	(6, 80, 84, 'm', 'A', '', 118.83333333333333, 106.21666666666665, 93.63333333333333),
	(6, 85, 89, 'm', 'A', '', 126.18333333333334, 113.58333333333333, 100.98333333333333),
	(6, 90, 200, 'm', 'A', '', 134.05, 121.44999999999999, 108.85000000000001),
	(7, 0, 7, 'w', 'A', '200 m', 9.45, 8.049999999999999, 6.6499999999999995),
	(7, 8, 9, 'w', 'A', '200 m', 8.4, 7.35, 6.216666666666667),
	(7, 10, 11, 'w', 'A', '200 m', 7.7, 6.733333333333334, 5.766666666666667),
	(7, 12, 13, 'w', 'A', '400 m', 15.583333333333332, 13.566666666666666, 11.55),
	(7, 14, 15, 'w', 'A', '400 m', 13.733333333333333, 12.25, 10.500000000000002),
	(7, 16, 17, 'w', 'A', '400 m', 12.433333333333334, 11.016666666666666, 9.533333333333333),
	(7, 18, 19, 'w', 'A', '800 m', 25.200000000000003, 22.233333333333334, 19.333333333333332),
	(7, 20, 24, 'w', 'A', '800 m', 24.76666666666667, 21.883333333333336, 18.9),
	(7, 25, 29, 'w', 'A', '800 m', 26.76666666666667, 22.13333333333333, 19.599999999999998),
	(7, 30, 34, 'w', 'A', '800 m', 30.283333333333335, 24.85, 20.48333333333333),
	(7, 35, 39, 'w', 'A', '800 m', 33.6, 26.866666666666667, 21.35),
	(7, 40, 44, 'w', 'A', '800 m', 35.7, 29.05, 22.4),
	(7, 45, 49, 'w', 'A', '800 m', 37.1, 30.45, 22.566666666666666),
	(7, 50, 54, 'w', 'A', '400 m', 18.9, 15.749999999999998, 12.083333333333334),
	(7, 55, 59, 'w', 'A', '400 m', 19.516666666666666, 16.099999999999998, 12.516666666666667),
	(7, 60, 64, 'w', 'A', '400 m', 19.95, 16.366666666666664, 12.766666666666667),
	(7, 65, 69, 'w', 'A', '400 m', 20.383333333333333, 16.533333333333335, 12.866666666666665),
	(7, 70, 74, 'w', 'A', '400 m', 20.816666666666663, 16.883333333333336, 13.299999999999999),
	(7, 75, 79, 'w', 'A', '200 m', 10.766666666666667, 8.749999999999998, 6.833333333333333),
	(7, 80, 84, 'w', 'A', '200 m', 10.933333333333334, 8.916666666666668, 7.083333333333333),
	(7, 85, 89, 'w', 'A', '200 m', 11.116666666666667, 9.183333333333332, 7.433333333333333),
	(7, 90, 200, 'w', 'A', '200 m', 11.283333333333333, 9.366666666666667, 7.7),
	(7, 0, 7, 'm', 'A', '200 m', 9.45, 7.7, 6.483333333333333),
	(7, 8, 9, 'm', 'A', '200 m', 8.4, 7.083333333333333, 5.95),
	(7, 10, 11, 'm', 'A', '200 m', 7.35, 6.6499999999999995, 5.433333333333333),
	(7, 12, 13, 'm', 'A', '400 m', 14.166666666666666, 12.083333333333334, 10.233333333333334),
	(7, 14, 15, 'm', 'A', '400 m', 12.6, 10.766666666666667, 9.266666666666667),
	(7, 16, 17, 'm', 'A', '400 m', 11.55, 10.15, 8.749999999999998),
	(7, 18, 19, 'm', 'A', '800 m', 23.716666666666665, 20.816666666666663, 17.85),
	(7, 20, 24, 'm', 'A', '800 m', 23.283333333333335, 20.48333333333333, 17.233333333333334),
	(7, 25, 29, 'm', 'A', '800 m', 24.31666666666667, 21.0, 17.85),
	(7, 30, 34, 'm', 'A', '800 m', 27.03333333333333, 22.566666666666666, 18.9),
	(7, 35, 39, 'm', 'A', '800 m', 30.283333333333335, 25.200000000000003, 20.216666666666665),
	(7, 40, 44, 'm', 'A', '800 m', 34.03333333333334, 27.733333333333334, 21.433333333333337),
	(7, 45, 49, 'm', 'A', '800 m', 36.21666666666667, 29.216666666666665, 21.700000000000003),
	(7, 50, 54, 'm', 'A', '400 m', 18.283333333333335, 15.049999999999999, 11.283333333333333),
	(7, 55, 59, 'm', 'A', '400 m', 18.733333333333334, 15.316666666666666, 11.899999999999999),
	(7, 60, 64, 'm', 'A', '400 m', 19.083333333333336, 15.483333333333333, 11.983333333333333),
	(7, 65, 69, 'm', 'A', '400 m', 19.333333333333332, 15.833333333333334, 12.083333333333334),
	(7, 70, 74, 'm', 'A', '400 m', 19.333333333333332, 16.01666666666667, 12.166666666666666),
	(7, 75, 79, 'm', 'A', '200 m', 9.883333333333333, 8.049999999999999, 6.383333333333334),
	(7, 80, 84, 'm', 'A', '200 m', 9.983333333333333, 8.216666666666669, 6.483333333333333),
	(7, 85, 89, 'm', 'A', '200 m', 9.983333333333333, 8.4, 6.733333333333334),
	(7, 90, 200, 'm', 'A', '200 m', 10.233333333333334, 8.566666666666666, 7.083333333333333),
	(8, 18, 19, 'w', 'A', '7,5 km', 72.98333333333333, 69.30000000000001, 65.10000000000001),
	(8, 20, 24, 'w', 'A', '7,5 km', 69.83333333333333, 66.15, 62.483333333333334),
	(8, 25, 29, 'w', 'A', '7,5 km', 70.35, 66.68333333333332, 63.0),
	(8, 30, 34, 'w', 'A', '7,5 km', 70.88333333333334, 67.2, 63.43333333333333),
	(8, 35, 39, 'w', 'A', '7,5 km', 73.5, 68.25000000000001, 63.78333333333333),
	(8, 40, 44, 'w', 'A', '7,5 km', 76.65, 70.35, 64.05),
	(8, 45, 49, 'w', 'A', '7,5 km', 79.28333333333333, 72.44999999999999, 65.10000000000001),
	(8, 50, 54, 'w', 'A', '7,5 km', 81.9, 74.55, 67.2),
	(8, 55, 59, 'w', 'A', '7,5 km', 84.0, 76.65, 69.30000000000001),
	(8, 60, 64, 'w', 'A', '7,5 km', 86.63333333333333, 78.23333333333333, 70.88333333333334),
	(8, 65, 69, 'w', 'A', '7,5 km', 88.46666666666667, 80.33333333333334, 73.5),
	(8, 70, 74, 'w', 'A', '7,5 km', 92.66666666666667, 82.94999999999999, 75.6),
	(8, 75, 79, 'w', 'A', '7,5 km', 97.13333333333333, 85.58333333333333, 78.23333333333333),
	(8, 80, 84, 'w', 'A', '7,5 km', 103.41666666666667, 89.51666666666667, 81.38333333333334),
	(8, 85, 89, 'w', 'A', '7,5 km', 109.2, 94.85000000000001, 86.10000000000001),
	(8, 90, 200, 'w', 'A', '7,5 km', 115.85000000000001, 100.80000000000001, 91.35),
	(8, 18, 19, 'm', 'A', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 20, 24, 'm', 'A', '7,5 km', 59.849999999999994, 55.65, 51.45),
	(8, 25, 29, 'm', 'A', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 30, 34, 'm', 'A', '7,5 km', 65.63333333333333, 59.849999999999994, 53.55),
	(8, 35, 39, 'm', 'A', '7,5 km', 68.25000000000001, 61.43333333333333, 56.18333333333333),
	(8, 40, 44, 'm', 'A', '7,5 km', 69.30000000000001, 63.53333333333333, 56.7),
	(8, 45, 49, 'm', 'A', '7,5 km', 71.93333333333334, 65.63333333333333, 57.75000000000001),
	(8, 50, 54, 'm', 'A', '7,5 km', 74.55, 67.2, 60.383333333333326),
	(8, 55, 59, 'm', 'A', '7,5 km', 76.65, 68.25000000000001, 61.95),
	(8, 60, 64, 'm', 'A', '7,5 km', 79.53333333333332, 70.88333333333334, 63.53333333333333),
	(8, 65, 69, 'm', 'A', '7,5 km', 82.08333333333333, 72.98333333333333, 65.10000000000001),
	(8, 70, 74, 'm', 'A', '7,5 km', 85.58333333333333, 75.6, 68.25000000000001),
	(8, 75, 79, 'm', 'A', '7,5 km', 90.46666666666667, 79.53333333333332, 75.6),
	(8, 80, 84, 'm', 'A', '7,5 km', 96.06666666666668, 83.73333333333333, 75.6),
	(8, 85, 89, 'm', 'A', '7,5 km', 100.80000000000001, 88.46666666666667, 79.28333333333333),
	(8, 90, 200, 'm', 'A', '7,5 km', 107.88333333333334, 93.80000000000001, 84.0),
	(10, 0, 7, 'w', 'A', '', 5.7, 8.55, 11.4),
	(10, 8, 9, 'w', 'A', '', 8.55, 11.4, 14.25),
	(10, 10, 11, 'w', 'A', '', 10.45, 14.25, 17.1),
	(10, 0, 7, 'm', 'A', '', 11.4, 14.25, 16.15),
	(10, 8, 9, 'm', 'A', '', 16.15, 19.0, 21.85),
	(10, 10, 11, 'm', 'A', '', 19.95, 23.75, 26.6),
	(11, 12, 13, 'w', 'A', '', 14.25, 17.1, 20.9),
	(11, 14, 15, 'w', 'A', '', 19.0, 22.8, 25.65),
	(11, 16, 17, 'w', 'A', '', 22.8, 25.65, 29.45),
	(11, 12, 13, 'm', 'A', '', 24.7, 28.5, 31.35),
	(11, 14, 15, 'm', 'A', '', 28.5, 32.3, 35.15),
	(11, 16, 17, 'm', 'A', '', 32.3, 36.1, 39.9),
	(12, 0, 7, 'w', 'A', '1 kg', 4.13, 4.6, 5.31),
	(12, 8, 9, 'w', 'A', '1 kg', 4.63, 5.1, 5.81),
	(12, 10, 11, 'w', 'A', '1 kg', 5.13, 5.6, 6.31),
	(12, 12, 13, 'w', 'A', '1 kg', 5.63, 6.1, 6.81),
	(12, 14, 15, 'w', 'A', '1 kg', 6.13, 6.6, 7.31),
	(12, 16, 17, 'w', 'A', '1 kg', 6.63, 7.1, 7.81),
	(12, 18, 19, 'w', 'A', '2 kg', 7.13, 7.6, 8.31),
	(12, 20, 24, 'w', 'A', '2 kg', 7.13, 7.6, 8.31),
	(12, 25, 29, 'w', 'A', '2 kg', 6.65, 7.36, 8.08),
	(12, 30, 34, 'w', 'A', '2 kg', 6.18, 7.13, 8.08),
	(12, 35, 39, 'w', 'A', '2 kg', 5.7, 6.89, 7.84),
	(12, 40, 44, 'w', 'A', '2 kg', 4.99, 6.41, 7.84),
	(12, 45, 49, 'w', 'A', '2 kg', 4.51, 6.18, 7.6),
	(12, 50, 54, 'w', 'A', '2 kg', 4.04, 5.7, 7.36),
	(12, 55, 59, 'w', 'A', '2 kg', 3.8, 5.46, 7.13),
	(12, 60, 64, 'w', 'A', '2 kg', 3.56, 5.23, 6.89),
	(12, 65, 69, 'w', 'A', '2 kg', 3.33, 4.99, 6.65),
	(12, 70, 74, 'w', 'A', '2 kg', 3.09, 4.75, 6.41),
	(12, 75, 79, 'w', 'A', '2 kg', 3.09, 4.51, 6.18),
	(12, 80, 84, 'w', 'A', '2 kg', 2.85, 4.51, 5.94),
	(12, 85, 89, 'w', 'A', '2 kg', 2.85, 4.28, 5.7),
	(12, 90, 200, 'w', 'A', '2 kg', 2.61, 4.04, 5.23),
	(12, 0, 7, 'm', 'A', '1 kg', 6.74, 7.45, 8.16),
	(12, 8, 9, 'm', 'A', '1 kg', 7.24, 7.95, 8.66),
	(12, 10, 11, 'm', 'A', '1 kg', 7.74, 8.45, 9.16),
	(12, 12, 13, 'm', 'A', '1 kg', 8.24, 8.95, 9.66),
	(12, 14, 15, 'm', 'A', '1 kg', 8.74, 9.45, 10.16),
	(12, 16, 17, 'm', 'A', '1 kg', 9.24, 9.95, 10.66),
	(12, 18, 19, 'm', 'A', '2 kg', 9.74, 10.45, 11.16),
	(12, 20, 24, 'm', 'A', '2 kg', 9.74, 10.69, 11.4),
	(12, 25, 29, 'm', 'A', '2 kg', 9.26, 10.21, 11.16),
	(12, 30, 34, 'm', 'A', '2 kg', 8.55, 9.74, 10.93),
	(12, 35, 39, 'm', 'A', '2 kg', 7.84, 9.26, 10.69),
	(12, 40, 44, 'm', 'A', '2 kg', 7.36, 8.79, 10.21),
	(12, 45, 49, 'm', 'A', '2 kg', 6.65, 8.31, 9.98),
	(12, 50, 54, 'm', 'A', '2 kg', 6.18, 8.08, 9.74),
	(12, 55, 59, 'm', 'A', '2 kg', 5.7, 7.84, 9.5),
	(12, 60, 64, 'm', 'A', '2 kg', 5.46, 7.36, 9.26),
	(12, 65, 69, 'm', 'A', '2 kg', 4.99, 6.89, 8.79),
	(12, 70, 74, 'm', 'A', '2 kg', 4.75, 6.65, 8.55),
	(12, 75, 79, 'm', 'A', '2 kg', 4.28, 6.18, 8.08),
	(12, 80, 84, 'm', 'A', '2 kg', 4.04, 5.94, 7.84),
	(12, 85, 89, 'm', 'A', '2 kg', 3.8, 5.7, 7.6),
	(12, 90, 200, 'm', 'A', '2 kg', 3.33, 5.23, 7.13),
	(13, 12, 13, 'w', 'A', '2 kg', 4.51, 4.99, 5.46),
	(13, 14, 15, 'w', 'A', '3 kg', 5.23, 5.7, 6.18),
	(13, 16, 17, 'w', 'A', '3 kg', 5.46, 5.94, 6.41),
	(13, 18, 19, 'w', 'A', '4 kg', 6.18, 6.65, 7.13),
	(13, 20, 24, 'w', 'A', '4 kg', 6.18, 6.65, 7.13),
	(13, 25, 29, 'w', 'A', '4 kg', 6.18, 6.65, 7.13),
	(13, 30, 34, 'w', 'A', '4 kg', 5.94, 6.41, 6.89),
	(13, 35, 39, 'w', 'A', '4 kg', 5.7, 6.18, 6.65),
	(13, 40, 44, 'w', 'A', '4 kg', 5.23, 5.7, 6.18),
	(13, 45, 49, 'w', 'A', '4 kg', 4.99, 5.46, 5.94),
	(13, 50, 54, 'w', 'A', '3 kg', 4.99, 5.7, 6.65),
	(13, 55, 59, 'w', 'A', '3 kg', 4.75, 5.46, 6.18),
	(13, 60, 64, 'w', 'A', '3 kg', 4.51, 5.23, 5.94),
	(13, 65, 69, 'w', 'A', '3 kg', 4.28, 4.99, 5.94),
	(13, 70, 74, 'w', 'A', '3 kg', 4.04, 4.75, 5.7),
	(13, 75, 79, 'w', 'A', '2 kg', 4.04, 4.99, 5.94),
	(13, 80, 84, 'w', 'A', '2 kg', 3.8, 4.75, 5.46),
	(13, 85, 89, 'w', 'A', '2 kg', 3.56, 4.28, 5.23),
	(13, 90, 200, 'w', 'A', '2 kg', 3.09, 4.04, 4.75),
	(13, 12, 13, 'm', 'A', '3 kg', 5.94, 6.41, 6.89),
	(13, 14, 15, 'm', 'A', '4 kg', 6.65, 7.13, 7.6),
	(13, 16, 17, 'm', 'A', '5 kg', 7.13, 7.6, 8.08),
	(13, 18, 19, 'm', 'A', '6 kg', 7.36, 7.84, 8.31),
	(13, 20, 24, 'm', 'A', '6 kg', 7.36, 8.08, 8.55),
	(13, 25, 29, 'm', 'A', '6 kg', 7.13, 7.84, 8.31),
	(13, 30, 34, 'm', 'A', '6 kg', 6.65, 7.36, 7.84),
	(13, 35, 39, 'm', 'A', '6 kg', 6.41, 6.89, 7.6),
	(13, 40, 44, 'm', 'A', '6 kg', 5.94, 6.65, 7.36),
	(13, 45, 49, 'm', 'A', '6 kg', 5.7, 6.41, 7.13),
	(13, 50, 54, 'm', 'A', '5 kg', 5.94, 6.65, 7.6),
	(13, 55, 59, 'm', 'A', '5 kg', 5.7, 6.41, 7.13),
	(13, 60, 64, 'm', 'A', '4 kg', 5.7, 6.65, 7.6),
	(13, 65, 69, 'm', 'A', '4 kg', 5.46, 6.41, 7.13),
	(13, 70, 74, 'm', 'A', '4 kg', 5.4, 6.3, 7.0),
	(13, 75, 79, 'm', 'A', '4 kg', 5.3, 6.18, 6.9),
	(13, 80, 84, 'm', 'A', '3 kg', 5.23, 5.94, 6.89),
	(13, 85, 89, 'm', 'A', '3 kg', 4.75, 5.7, 6.41),
	(13, 90, 200, 'm', 'A', '3 kg', 4.28, 4.99, 5.94),
	(15, 0, 7, 'w', 'A', '', 1.0, 1.19, 1.33),
	(15, 8, 9, 'w', 'A', '', 1.09, 1.24, 1.43),
	(15, 10, 11, 'w', 'A', '', 1.24, 1.38, 1.57),
	(15, 12, 13, 'w', 'A', '', 1.33, 1.52, 1.71),
	(15, 14, 15, 'w', 'A', '', 1.47, 1.62, 1.81),
	(15, 16, 17, 'w', 'A', '', 1.57, 1.71, 1.9),
	(15, 18, 19, 'w', 'A', '', 1.57, 1.76, 1.95),
	(15, 20, 24, 'w', 'A', '', 1.52, 1.71, 1.9),
	(15, 25, 29, 'w', 'A', '', 1.43, 1.62, 1.85),
	(15, 30, 34, 'w', 'A', '', 1.28, 1.52, 1.76),
	(15, 35, 39, 'w', 'A', '', 1.19, 1.43, 1.71),
	(15, 40, 44, 'w', 'A', '', 1.09, 1.33, 1.57),
	(15, 45, 49, 'w', 'A', '', 1.05, 1.28, 1.52),
	(15, 50, 54, 'w', 'A', '', 0.95, 1.24, 1.47),
	(15, 55, 59, 'w', 'A', '', 0.9, 1.14, 1.38),
	(15, 60, 64, 'w', 'A', '', 0.9, 1.14, 1.38),
	(15, 65, 69, 'w', 'A', '', 0.86, 1.09, 1.33),
	(15, 70, 74, 'w', 'A', '', 0.86, 1.09, 1.28),
	(15, 75, 79, 'w', 'A', '', 0.86, 1.09, 1.28),
	(15, 80, 84, 'w', 'A', '', 0.86, 1.05, 1.24),
	(15, 85, 89, 'w', 'A', '', 0.81, 1.0, 1.19),
	(15, 90, 200, 'w', 'A', '', 0.76, 0.95, 1.14),
	(15, 0, 7, 'm', 'A', '', 1.09, 1.28, 1.43),
	(15, 8, 9, 'm', 'A', '', 1.24, 1.43, 1.57),
	(15, 10, 11, 'm', 'A', '', 1.43, 1.62, 1.76),
	(15, 12, 13, 'm', 'A', '', 1.62, 1.81, 1.95),
	(15, 14, 15, 'm', 'A', '', 1.81, 1.95, 2.14),
	(15, 16, 17, 'm', 'A', '', 1.95, 2.09, 2.28),
	(15, 18, 19, 'm', 'A', '', 2.0, 2.19, 2.38),
	(15, 20, 24, 'm', 'A', '', 2.0, 2.19, 2.38),
	(15, 25, 29, 'm', 'A', '', 1.95, 2.14, 2.33),
	(15, 30, 34, 'm', 'A', '', 1.76, 2.0, 2.23),
	(15, 35, 39, 'm', 'A', '', 1.57, 1.85, 2.14),
	(15, 40, 44, 'm', 'A', '', 1.47, 1.76, 2.04),
	(15, 45, 49, 'm', 'A', '', 1.38, 1.66, 1.95),
	(15, 50, 54, 'm', 'A', '', 1.33, 1.62, 1.9),
	(15, 55, 59, 'm', 'A', '', 1.28, 1.57, 1.85),
	(15, 60, 64, 'm', 'A', '', 1.24, 1.52, 1.81),
	(15, 65, 69, 'm', 'A', '', 1.24, 1.52, 1.81),
	(15, 70, 74, 'm', 'A', '', 1.19, 1.47, 1.76),
	(15, 75, 79, 'm', 'A', '', 1.14, 1.43, 1.71),
	(15, 80, 84, 'm', 'A', '', 1.09, 1.38, 1.66),
	(15, 85, 89, 'm', 'A', '', 0.95, 1.24, 1.52),
	(15, 90, 200, 'm', 'A', '', 0.86, 1.14, 1.43),
	(17, 0, 7, 'w', 'A', '30 m', 8.4, 7.5, 6.6),
	(17, 8, 9, 'w', 'A', '30 m', 7.8, 6.9, 6.0),
	(17, 10, 11, 'w', 'A', '50 m', 11.6, 10.6, 9.6),
	(17, 12, 13, 'w', 'A', '50 m', 11.1, 10.1, 8.9),
	(17, 14, 15, 'w', 'A', '100 m', 19.5, 17.9, 16.3),
	(17, 16, 17, 'w', 'A', '100 m', 18.5, 17.1, 15.8),
	(17, 18, 19, 'w', 'A', '100 m', 19.1, 17.3, 16.1),
	(17, 20, 24, 'w', 'A', '100 m', 19.4, 17.6, 16.4),
	(17, 25, 29, 'w', 'A', '100 m', 19.8, 18.1, 16.8),
	(17, 30, 34, 'w', 'A', '100 m', 20.6, 18.7, 17.2),
	(17, 35, 39, 'w', 'A', '100 m', 21.4, 19.5, 17.9),
	(17, 40, 44, 'w', 'A', '50 m', 11.6, 10.4, 9.2),
	(17, 45, 49, 'w', 'A', '50 m', 12.1, 10.8, 9.6),
	(17, 50, 54, 'w', 'A', '50 m', 12.5, 11.2, 10.0),
	(17, 55, 59, 'w', 'A', '50 m', 13.0, 11.8, 10.4),
	(17, 60, 64, 'w', 'A', '50 m', 13.2, 12.0, 10.7),
	(17, 65, 69, 'w', 'A', '50 m', 13.4, 12.2, 10.9),
	(17, 70, 74, 'w', 'A', '50 m', 13.7, 12.4, 11.1),
	(17, 75, 79, 'w', 'A', '50 m', 14.2, 12.9, 11.7),
	(17, 80, 84, 'w', 'A', '50 m', 15.0, 13.8, 12.6),
	(17, 85, 89, 'w', 'A', '50 m', 16.3, 15.0, 13.9),
	(17, 90, 200, 'w', 'A', '50 m', 18.0, 16.7, 15.5),
	(17, 0, 7, 'm', 'A', '30 m', 8.1, 7.1, 6.3),
	(17, 8, 9, 'm', 'A', '30 m', 7.6, 6.7, 6.0),
	(17, 10, 11, 'm', 'A', '50 m', 10.8, 9.8, 8.8),
	(17, 12, 13, 'm', 'A', '50 m', 10.2, 9.3, 8.5),
	(17, 14, 15, 'm', 'A', '100 m', 17.9, 16.2, 14.8),
	(17, 16, 17, 'm', 'A', '100 m', 17.1, 15.5, 14.2),
	(17, 18, 19, 'm', 'A', '100 m', 16.8, 15.3, 13.9),
	(17, 20, 24, 'm', 'A', '100 m', 16.6, 15.1, 13.7),
	(17, 25, 29, 'm', 'A', '100 m', 17.1, 15.5, 14.0),
	(17, 30, 34, 'm', 'A', '100 m', 17.6, 15.9, 14.3),
	(17, 35, 39, 'm', 'A', '100 m', 18.5, 16.7, 14.9),
	(17, 40, 44, 'm', 'A', '50 m', 10.1, 9.1, 8.1),
	(17, 45, 49, 'm', 'A', '50 m', 10.5, 9.3, 8.3),
	(17, 50, 54, 'm', 'A', '50 m', 10.8, 9.6, 8.6),
	(17, 55, 59, 'm', 'A', '50 m', 11.0, 9.9, 8.9),
	(17, 60, 64, 'm', 'A', '50 m', 11.3, 10.2, 9.2),
	(17, 65, 69, 'm', 'A', '50 m', 11.8, 10.7, 9.6),
	(17, 70, 74, 'm', 'A', '50 m', 12.3, 11.2, 10.1),
	(17, 75, 79, 'm', 'A', '50 m', 12.8, 11.8, 10.6),
	(17, 80, 84, 'm', 'A', '50 m', 13.7, 12.6, 11.4),
	(17, 85, 89, 'm', 'A', '50 m', 14.8, 13.8, 12.6),
	(17, 90, 200, 'm', 'A', '50 m', 16.3, 15.2, 14.1),
	(18, 0, 7, 'w', 'A', '', 48.8, 40.4, 32.0),
	(18, 8, 9, 'w', 'A', '', 44.1, 35.7, 29.4),
	(18, 10, 11, 'w', 'A', '', 41.0, 33.1, 26.8),
	(18, 12, 13, 'w', 'A', '', 36.8, 30.5, 24.7),
	(18, 14, 15, 'w', 'A', '', 34.7, 28.9, 22.6),
	(18, 16, 17, 'w', 'A', '', 32.0, 26.8, 21.0),
	(18, 18, 19, 'w', 'A', '', 31.0, 25.2, 19.4),
	(18, 20, 24, 'w', 'A', '', 30.5, 25.2, 19.4),
	(18, 25, 29, 'w', 'A', '', 31.5, 26.3, 20.5),
	(18, 30, 34, 'w', 'A', '', 34.1, 27.8, 22.1),
	(18, 35, 39, 'w', 'A', '', 37.8, 30.5, 23.1),
	(18, 40, 44, 'w', 'A', '', 42.0, 33.1, 24.7),
	(18, 45, 49, 'w', 'A', '', 46.2, 36.8, 26.3),
	(18, 50, 54, 'w', 'A', '', 50.4, 41.0, 29.4),
	(18, 55, 59, 'w', 'A', '', 54.1, 44.6, 32.0),
	(18, 60, 64, 'w', 'A', '', 57.2, 46.7, 34.1),
	(18, 65, 69, 'w', 'A', '', 59.3, 48.8, 36.2),
	(18, 70, 74, 'w', 'A', '', 62.0, 50.4, 37.8),
	(18, 75, 79, 'w', 'A', '', 64.1, 52.5, 39.9),
	(18, 80, 84, 'w', 'A', '', 66.7, 54.6, 42.0),
	(18, 85, 89, 'w', 'A', '', 68.8, 56.2, 43.6),
	(18, 90, 200, 'w', 'A', '', 69.8, 57.2, 44.6),
	(18, 0, 7, 'm', 'A', '', 48.3, 39.9, 31.5),
	(18, 8, 9, 'm', 'A', '', 43.1, 34.7, 27.3),
	(18, 10, 11, 'm', 'A', '', 37.8, 30.5, 23.6),
	(18, 12, 13, 'm', 'A', '', 34.7, 28.4, 22.1),
	(18, 14, 15, 'm', 'A', '', 32.6, 26.8, 21.0),
	(18, 16, 17, 'm', 'A', '', 31.0, 25.7, 20.0),
	(18, 18, 19, 'm', 'A', '', 29.4, 24.2, 18.4),
	(18, 20, 24, 'm', 'A', '', 28.4, 23.1, 16.3),
	(18, 25, 29, 'm', 'A', '', 30.5, 24.2, 17.3),
	(18, 30, 34, 'm', 'A', '', 33.1, 25.2, 17.9),
	(18, 35, 39, 'm', 'A', '', 36.8, 27.8, 19.4),
	(18, 40, 44, 'm', 'A', '', 40.4, 31.0, 20.0),
	(18, 45, 49, 'm', 'A', '', 44.1, 34.1, 21.5),
	(18, 50, 54, 'm', 'A', '', 47.3, 36.8, 24.2),
	(18, 55, 59, 'm', 'A', '', 51.5, 38.9, 26.3),
	(18, 60, 64, 'm', 'A', '', 53.6, 41.0, 28.4),
	(18, 65, 69, 'm', 'A', '', 55.1, 42.5, 29.9),
	(18, 70, 74, 'm', 'A', '', 57.8, 45.2, 32.6),
	(18, 75, 79, 'm', 'A', '', 60.4, 47.8, 35.2),
	(18, 80, 84, 'm', 'A', '', 62.0, 50.4, 37.8),
	(18, 85, 89, 'm', 'A', '', 62.5, 51.5, 39.9),
	(18, 90, 200, 'm', 'A', '', 63.0, 52.5, 42.0),
	(19, 8, 9, 'w', 'A', '', 43.1, 37.8, 32.6),
	(19, 10, 11, 'w', 'A', '', 38.9, 33.6, 28.4),
	(19, 12, 13, 'w', 'A', '', 32.6, 28.4, 24.7),
	(19, 14, 15, 'w', 'A', '', 28.4, 25.7, 22.6),
	(19, 16, 17, 'w', 'A', '', 26.3, 23.6, 21.0),
	(19, 18, 19, 'w', 'A', '', 25.2, 23.1, 20.5),
	(19, 20, 24, 'w', 'A', '', 25.7, 23.1, 20.5),
	(19, 25, 29, 'w', 'A', '', 26.3, 23.6, 21.0),
	(19, 30, 34, 'w', 'A', '', 27.3, 24.7, 22.6),
	(19, 35, 39, 'w', 'A', '', 28.9, 25.7, 23.1),
	(19, 40, 44, 'w', 'A', '', 30.5, 26.8, 23.6),
	(19, 45, 49, 'w', 'A', '', 32.0, 28.4, 24.2),
	(19, 50, 54, 'w', 'A', '', 33.6, 29.4, 24.7),
	(19, 55, 59, 'w', 'A', '', 35.2, 30.5, 25.2),
	(19, 60, 64, 'w', 'A', '', 36.8, 31.5, 26.3),
	(19, 65, 69, 'w', 'A', '', 37.8, 32.6, 26.8),
	(19, 70, 74, 'w', 'A', '', 39.9, 33.6, 27.8),
	(19, 75, 79, 'w', 'A', '', 41.0, 34.7, 28.9),
	(19, 80, 84, 'w', 'A', '', 42.5, 36.2, 29.9),
	(19, 85, 89, 'w', 'A', '', 44.1, 37.8, 31.5),
	(19, 90, 200, 'w', 'A', '', 46.7, 39.9, 33.1),
	(19, 8, 9, 'm', 'A', '', 39.9, 34.7, 29.4),
	(19, 10, 11, 'm', 'A', '', 36.8, 32.0, 27.3),
	(19, 12, 13, 'm', 'A', '', 31.0, 27.3, 23.6),
	(19, 14, 15, 'm', 'A', '', 25.2, 22.6, 20.0),
	(19, 16, 17, 'm', 'A', '', 23.1, 20.5, 17.9),
	(19, 18, 19, 'm', 'A', '', 21.5, 18.9, 16.3),
	(19, 20, 24, 'm', 'A', '', 21.0, 18.4, 15.8),
	(19, 25, 29, 'm', 'A', '', 22.1, 18.9, 15.8),
	(19, 30, 34, 'm', 'A', '', 23.6, 19.4, 15.8),
	(19, 35, 39, 'm', 'A', '', 25.2, 21.0, 16.3),
	(19, 40, 44, 'm', 'A', '', 27.8, 22.6, 17.3),
	(19, 45, 49, 'm', 'A', '', 29.9, 24.2, 17.9),
	(19, 50, 54, 'm', 'A', '', 31.5, 25.2, 18.9),
	(19, 55, 59, 'm', 'A', '', 33.6, 26.3, 19.4),
	(19, 60, 64, 'm', 'A', '', 35.2, 27.3, 20.0),
	(19, 65, 69, 'm', 'A', '', 36.8, 28.4, 20.5),
	(19, 70, 74, 'm', 'A', '', 37.8, 29.9, 21.0),
	(19, 75, 79, 'm', 'A', '', 39.4, 31.0, 22.6),
	(19, 80, 84, 'm', 'A', '', 41.0, 33.1, 24.2),
	(19, 85, 89, 'm', 'A', '', 43.1, 34.7, 25.7),
	(19, 90, 200, 'm', 'A', '', 45.7, 37.3, 28.4),
	(21, 10, 11, 'w', 'A', '', 0.76, 0.86, 0.95),
	(21, 12, 13, 'w', 'A', '', 0.86, 0.95, 1.05),
	(21, 14, 15, 'w', 'A', '', 0.9, 1.0, 1.09),
	(21, 16, 17, 'w', 'A', '', 1.0, 1.09, 1.19),
	(21, 18, 19, 'w', 'A', '', 1.05, 1.14, 1.24),
	(21, 20, 24, 'w', 'A', '', 1.05, 1.14, 1.24),
	(21, 25, 29, 'w', 'A', '', 1.0, 1.09, 1.19),
	(21, 30, 34, 'w', 'A', '', 0.95, 1.05, 1.14),
	(21, 35, 39, 'w', 'A', '', 0.9, 1.0, 1.09),
	(21, 40, 44, 'w', 'A', '', 0.86, 0.95, 1.05),
	(21, 45, 49, 'w', 'A', '', 0.86, 0.95, 1.05),
	(21, 50, 54, 'w', 'A', '', 0.81, 0.9, 1.0),
	(21, 55, 59, 'w', 'A', '', 0.76, 0.86, 0.95),
	(21, 60, 64, 'w', 'A', '', 0.71, 0.81, 0.9),
	(21, 65, 69, 'w', 'A', '', 0.71, 0.81, 0.9),
	(21, 70, 74, 'w', 'A', '', 0.67, 0.76, 0.86),
	(21, 75, 79, 'w', 'A', '', 0.62, 0.71, 0.81),
	(21, 80, 84, 'w', 'A', '', 0.62, 0.71, 0.81),
	(21, 85, 89, 'w', 'A', '', 0.57, 0.67, 0.76),
	(21, 90, 200, 'w', 'A', '', 0.52, 0.57, 0.62),
	(21, 10, 11, 'm', 'A', '', 0.81, 0.9, 1.0),
	(21, 12, 13, 'm', 'A', '', 0.9, 1.0, 1.09),
	(21, 14, 15, 'm', 'A', '', 1.05, 1.14, 1.24),
	(21, 16, 17, 'm', 'A', '', 1.14, 1.24, 1.33),
	(21, 18, 19, 'm', 'A', '', 1.24, 1.33, 1.43),
	(21, 20, 24, 'm', 'A', '', 1.28, 1.38, 1.47),
	(21, 25, 29, 'm', 'A', '', 1.24, 1.33, 1.43),
	(21, 30, 34, 'm', 'A', '', 1.24, 1.33, 1.43),
	(21, 35, 39, 'm', 'A', '', 1.19, 1.28, 1.38),
	(21, 40, 44, 'm', 'A', '', 1.14, 1.24, 1.33),
	(21, 45, 49, 'm', 'A', '', 1.09, 1.19, 1.28),
	(21, 50, 54, 'm', 'A', '', 1.0, 1.09, 1.19),
	(21, 55, 59, 'm', 'A', '', 0.95, 1.05, 1.14),
	(21, 60, 64, 'm', 'A', '', 0.9, 1.0, 1.09),
	(21, 65, 69, 'm', 'A', '', 0.81, 0.95, 1.05),
	(21, 70, 74, 'm', 'A', '', 0.76, 0.9, 1.0),
	(21, 75, 79, 'm', 'A', '', 0.71, 0.86, 0.95),
	(21, 80, 84, 'm', 'A', '', 0.71, 0.81, 0.9),
	(21, 85, 89, 'm', 'A', '', 0.67, 0.76, 0.86),
	(21, 90, 200, 'm', 'A', '', 0.62, 0.71, 0.81),
	(23, 0, 7, 'w', 'A', '', 1.79, 2.07, 2.36),
	(23, 8, 9, 'w', 'A', '', 1.99, 2.27, 2.56),
	(23, 10, 11, 'w', 'A', '', 2.19, 2.47, 2.76),
	(23, 12, 13, 'w', 'A', '', 2.66, 2.95, 3.23),
	(23, 14, 15, 'w', 'A', '', 3.04, 3.33, 3.61),
	(23, 16, 17, 'w', 'A', '', 3.23, 3.52, 3.8),
	(23, 18, 19, 'w', 'A', '', 3.23, 3.52, 3.8),
	(23, 20, 24, 'w', 'A', '', 3.23, 3.52, 3.8),
	(23, 25, 29, 'w', 'A', '', 3.14, 3.42, 3.71),
	(23, 30, 34, 'w', 'A', '', 3.04, 3.33, 3.61),
	(23, 35, 39, 'w', 'A', '', 2.95, 3.23, 3.52),
	(23, 40, 44, 'w', 'A', '', 2.85, 3.14, 3.42),
	(23, 45, 49, 'w', 'A', '', 2.66, 3.04, 3.33),
	(23, 50, 54, 'w', 'A', '', 2.47, 2.85, 3.23),
	(23, 55, 59, 'w', 'A', '', 2.38, 2.76, 3.14),
	(23, 60, 64, 'w', 'A', '', 2.28, 2.66, 3.04),
	(23, 65, 69, 'w', 'A', '', 2.19, 2.57, 2.95),
	(23, 70, 74, 'w', 'A', '', 2.0, 2.38, 2.76),
	(23, 75, 79, 'w', 'A', '', 1.71, 2.09, 2.47),
	(23, 80, 84, 'w', 'A', '', 1.52, 1.9, 2.28),
	(23, 85, 89, 'w', 'A', '', 1.24, 1.62, 2.0),
	(23, 90, 200, 'w', 'A', '', 1.05, 1.43, 1.81),
	(23, 0, 7, 'm', 'A', '', 2.07, 2.36, 2.64),
	(23, 8, 9, 'm', 'A', '', 2.27, 2.56, 2.84),
	(23, 10, 11, 'm', 'A', '', 2.47, 2.76, 3.04),
	(23, 12, 13, 'm', 'A', '', 3.04, 3.33, 3.61),
	(23, 14, 15, 'm', 'A', '', 3.61, 3.9, 4.18),
	(23, 16, 17, 'm', 'A', '', 4.09, 4.37, 4.66),
	(23, 18, 19, 'm', 'A', '', 4.28, 4.56, 4.85),
	(23, 20, 24, 'm', 'A', '', 4.18, 4.47, 4.75),
	(23, 25, 29, 'm', 'A', '', 4.09, 4.37, 4.66),
	(23, 30, 34, 'm', 'A', '', 3.99, 4.28, 4.56),
	(23, 35, 39, 'm', 'A', '', 3.9, 4.18, 4.47),
	(23, 40, 44, 'm', 'A', '', 3.71, 4.09, 4.37),
	(23, 45, 49, 'm', 'A', '', 3.52, 3.9, 4.28),
	(23, 50, 54, 'm', 'A', '', 3.42, 3.8, 4.18),
	(23, 55, 59, 'm', 'A', '', 3.23, 3.61, 3.99),
	(23, 60, 64, 'm', 'A', '', 3.04, 3.42, 3.8),
	(23, 65, 69, 'm', 'A', '', 2.76, 3.14, 3.52),
	(23, 70, 74, 'm', 'A', '', 2.57, 2.95, 3.33),
	(23, 75, 79, 'm', 'A', '', 2.28, 2.76, 3.14),
	(23, 80, 84, 'm', 'A', '', 2.0, 2.47, 2.95),
	(23, 85, 89, 'm', 'A', '', 1.81, 2.28, 2.76),
	(23, 90, 200, 'm', 'A', '', 1.52, 2.0, 2.47),
	(25, 12, 13, 'w', 'A', '', 16.15, 18.53, 20.9),
	(25, 14, 15, 'w', 'A', '', 18.53, 21.38, 24.23),
	(25, 16, 17, 'w', 'A', '', 20.9, 23.75, 26.6),
	(25, 18, 19, 'w', 'A', '', 22.33, 25.18, 27.55),
	(25, 20, 24, 'w', 'A', '', 22.8, 25.65, 28.03),
	(25, 25, 29, 'w', 'A', '', 22.8, 25.65, 28.03),
	(25, 30, 34, 'w', 'A', '', 20.9, 23.75, 26.13),
	(25, 35, 39, 'w', 'A', '', 19.95, 22.8, 25.18),
	(25, 40, 44, 'w', 'A', '', 18.53, 21.38, 23.75),
	(25, 45, 49, 'w', 'A', '', 17.58, 20.43, 22.8),
	(25, 50, 54, 'w', 'A', '', 15.68, 19.0, 21.85),
	(25, 55, 59, 'w', 'A', '', 14.73, 18.05, 20.9),
	(25, 60, 64, 'w', 'A', '', 13.78, 17.1, 19.95),
	(25, 65, 69, 'w', 'A', '', 12.83, 16.15, 19.0),
	(25, 70, 74, 'w', 'A', '', 12.35, 15.68, 18.53),
	(25, 75, 79, 'w', 'A', '', 11.4, 14.73, 17.58),
	(25, 80, 84, 'w', 'A', '', 10.45, 13.78, 16.63),
	(25, 85, 89, 'w', 'A', '', 9.03, 12.35, 15.2),
	(25, 90, 200, 'w', 'A', '', 7.13, 10.45, 13.3),
	(25, 12, 13, 'm', 'A', '', 18.53, 22.8, 26.13),
	(25, 14, 15, 'm', 'A', '', 22.33, 26.6, 30.4),
	(25, 16, 17, 'm', 'A', '', 26.13, 30.4, 34.68),
	(25, 18, 19, 'm', 'A', '', 29.93, 34.2, 38.48),
	(25, 20, 24, 'm', 'A', '', 31.35, 36.1, 39.9),
	(25, 25, 29, 'm', 'A', '', 30.88, 35.63, 39.43),
	(25, 30, 34, 'm', 'A', '', 28.5, 33.25, 38.0),
	(25, 35, 39, 'm', 'A', '', 27.08, 31.83, 36.58),
	(25, 40, 44, 'm', 'A', '', 26.6, 31.35, 36.1),
	(25, 45, 49, 'm', 'A', '', 25.65, 30.4, 35.63),
	(25, 50, 54, 'm', 'A', '', 24.23, 29.45, 34.68),
	(25, 55, 59, 'm', 'A', '', 22.33, 27.55, 33.25),
	(25, 60, 64, 'm', 'A', '', 21.38, 26.6, 32.3),
	(25, 65, 69, 'm', 'A', '', 19.0, 24.23, 28.98),
	(25, 70, 74, 'm', 'A', '', 17.58, 22.8, 27.55),
	(25, 75, 79, 'm', 'A', '', 15.2, 19.95, 24.7),
	(25, 80, 84, 'm', 'A', '', 13.3, 18.05, 22.8),
	(25, 85, 89, 'm', 'A', '', 11.4, 15.68, 19.95),
	(25, 90, 200, 'm', 'A', '', 9.98, 14.25, 18.53),
	(33, 0, 7, 'w', 'A', '', 7.6000000000000005, 11.4, 16.15),
	(33, 8, 9, 'w', 'A', '', 9.500000000000002, 14.25, 19.0),
	(33, 10, 11, 'w', 'A', '', 14.25, 19.0, 28.5),
	(33, 12, 13, 'w', 'A', '', 19.0, 28.5, 38.0),
	(33, 14, 15, 'w', 'A', '', 28.5, 38.0, 47.49999999999999),
	(33, 16, 17, 'w', 'A', '', 42.75000000000001, 57.0, 71.25000000000001),
	(33, 0, 7, 'm', 'A', '', 9.500000000000002, 14.25, 19.0),
	(33, 8, 9, 'm', 'A', '', 11.4, 16.15, 21.85),
	(33, 10, 11, 'm', 'A', '', 16.15, 23.75, 33.25),
	(33, 12, 13, 'm', 'A', '', 23.75, 33.25, 42.75000000000001),
	(33, 14, 15, 'm', 'A', '', 33.25, 42.75000000000001, 57.0),
	(33, 16, 17, 'm', 'A', '', 52.25, 66.5, 85.5),
	(39, 0, 7, 'w', 'A', '', 223.0, 248.0, 272.0),
	(39, 8, 9, 'w', 'A', '', 234.0, 260.0, 286.0),
	(39, 10, 11, 'w', 'A', '', 245.0, 273.0, 300.0),
	(39, 12, 13, 'w', 'A', '', 257.0, 285.0, 314.0),
	(39, 14, 15, 'w', 'A', '', 268.0, 298.0, 327.0),
	(39, 16, 17, 'w', 'A', '', 279.0, 310.0, 341.0),
	(39, 18, 19, 'w', 'A', '', 369.0, 410.0, 451.0),
	(39, 20, 24, 'w', 'A', '', 369.0, 410.0, 451.0),
	(39, 25, 29, 'w', 'A', '', 369.0, 410.0, 451.0),
	(39, 30, 34, 'w', 'A', '', 358.0, 398.0, 437.0),
	(39, 35, 39, 'w', 'A', '', 358.0, 398.0, 437.0),
	(39, 40, 44, 'w', 'A', '', 347.0, 385.0, 424.0),
	(39, 45, 49, 'w', 'A', '', 335.0, 373.0, 410.0),
	(39, 50, 54, 'w', 'A', '', 324.0, 360.0, 396.0),
	(39, 55, 59, 'w', 'A', '', 313.0, 348.0, 382.0),
	(39, 60, 64, 'w', 'A', '', 302.0, 335.0, 369.0),
	(39, 65, 69, 'w', 'A', '', 290.0, 323.0, 355.0),
	(39, 70, 74, 'w', 'A', '', 279.0, 310.0, 341.0),
	(39, 75, 79, 'w', 'A', '', 268.0, 298.0, 327.0),
	(39, 80, 84, 'w', 'A', '', 257.0, 285.0, 314.0),
	(39, 85, 89, 'w', 'A', '', 245.0, 273.0, 300.0),
	(39, 90, 200, 'w', 'A', '', 234.0, 260.0, 286.0),
	(39, 0, 7, 'm', 'A', '', 281.0, 313.0, 344.0),
	(39, 8, 9, 'm', 'A', '', 293.0, 325.0, 358.0),
	(39, 10, 11, 'm', 'A', '', 304.0, 338.0, 371.0),
	(39, 12, 13, 'm', 'A', '', 315.0, 350.0, 385.0),
	(39, 14, 15, 'm', 'A', '', 326.0, 363.0, 399.0),
	(39, 16, 17, 'm', 'A', '', 338.0, 375.0, 413.0),
	(39, 18, 19, 'm', 'A', '', 428.0, 475.0, 523.0),
	(39, 20, 24, 'm', 'A', '', 428.0, 475.0, 523.0),
	(39, 25, 29, 'm', 'A', '', 428.0, 475.0, 523.0),
	(39, 30, 34, 'm', 'A', '', 416.0, 463.0, 509.0),
	(39, 35, 39, 'm', 'A', '', 416.0, 463.0, 509.0),
	(39, 40, 44, 'm', 'A', '', 405.0, 450.0, 495.0),
	(39, 45, 49, 'm', 'A', '', 394.0, 438.0, 481.0),
	(39, 50, 54, 'm', 'A', '', 383.0, 425.0, 468.0),
	(39, 55, 59, 'm', 'A', '', 371.0, 413.0, 454.0),
	(39, 60, 64, 'm', 'A', '', 360.0, 400.0, 440.0),
	(39, 65, 69, 'm', 'A', '', 349.0, 388.0, 426.0),
	(39, 70, 74, 'm', 'A', '', 338.0, 375.0, 413.0),
	(39, 75, 79, 'm', 'A', '', 326.0, 363.0, 399.0),
	(39, 80, 84, 'm', 'A', '', 315.0, 350.0, 385.0),
	(39, 85, 89, 'm', 'A', '', 304.0, 338.0, 371.0),
	(39, 90, 200, 'm', 'A', '', 293.0, 325.0, 358.0),
	(40, 0, 7, 'w', 'A', '', 383.0, 425.0, 468.0),
	(40, 8, 9, 'w', 'A', '', 396.0, 440.0, 484.0),
	(40, 10, 11, 'w', 'A', '', 410.0, 455.0, 501.0),
	(40, 12, 13, 'w', 'A', '', 423.0, 470.0, 517.0),
	(40, 14, 15, 'w', 'A', '', 437.0, 485.0, 534.0),
	(40, 16, 17, 'w', 'A', '', 450.0, 500.0, 550.0),
	(40, 18, 19, 'w', 'A', '', 540.0, 600.0, 660.0),
	(40, 20, 24, 'w', 'A', '', 540.0, 600.0, 660.0),
	(40, 25, 29, 'w', 'A', '', 540.0, 600.0, 660.0),
	(40, 30, 34, 'w', 'A', '', 527.0, 585.0, 644.0),
	(40, 35, 39, 'w', 'A', '', 527.0, 585.0, 644.0),
	(40, 40, 44, 'w', 'A', '', 513.0, 570.0, 627.0),
	(40, 45, 49, 'w', 'A', '', 500.0, 555.0, 611.0),
	(40, 50, 54, 'w', 'A', '', 486.0, 540.0, 594.0),
	(40, 55, 59, 'w', 'A', '', 473.0, 525.0, 578.0),
	(40, 60, 64, 'w', 'A', '', 459.0, 510.0, 561.0),
	(40, 65, 69, 'w', 'A', '', 446.0, 495.0, 545.0),
	(40, 70, 74, 'w', 'A', '', 432.0, 480.0, 528.0),
	(40, 75, 79, 'w', 'A', '', 419.0, 465.0, 512.0),
	(40, 80, 84, 'w', 'A', '', 405.0, 450.0, 495.0),
	(40, 85, 89, 'w', 'A', '', 392.0, 435.0, 479.0),
	(40, 90, 200, 'w', 'A', '', 378.0, 420.0, 462.0),
	(40, 0, 7, 'm', 'A', '', 450.0, 500.0, 550.0),
	(40, 8, 9, 'm', 'A', '', 464.0, 515.0, 567.0),
	(40, 10, 11, 'm', 'A', '', 477.0, 530.0, 583.0),
	(40, 12, 13, 'm', 'A', '', 491.0, 545.0, 600.0),
	(40, 14, 15, 'm', 'A', '', 504.0, 560.0, 616.0),
	(40, 16, 17, 'm', 'A', '', 518.0, 575.0, 633.0),
	(40, 18, 19, 'm', 'A', '', 608.0, 675.0, 743.0),
	(40, 20, 24, 'm', 'A', '', 608.0, 675.0, 743.0),
	(40, 25, 29, 'm', 'A', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'A', '', 594.0, 660.0, 726.0),
	(40, 35, 39, 'm', 'A', '', 594.0, 660.0, 726.0),
	(40, 40, 44, 'm', 'A', '', 581.0, 645.0, 710.0),
	(40, 45, 49, 'm', 'A', '', 567.0, 630.0, 693.0),
	(40, 50, 54, 'm', 'A', '', 554.0, 615.0, 677.0),
	(40, 55, 59, 'm', 'A', '', 540.0, 600.0, 660.0),
	(40, 60, 64, 'm', 'A', '', 527.0, 585.0, 644.0),
	(40, 65, 69, 'm', 'A', '', 513.0, 570.0, 627.0),
	(40, 70, 74, 'm', 'A', '', 500.0, 555.0, 611.0),
	(40, 75, 79, 'm', 'A', '', 486.0, 540.0, 594.0),
	(40, 80, 84, 'm', 'A', '', 473.0, 525.0, 578.0),
	(40, 85, 89, 'm', 'A', '', 459.0, 510.0, 561.0),
	(40, 90, 200, 'm', 'A', '', 446.0, 495.0, 545.0),
	(41, 0, 7, 'w', 'A', '', 315.0, 350.0, 385.0),
	(41, 8, 9, 'w', 'A', '', 329.0, 365.0, 402.0),
	(41, 10, 11, 'w', 'A', '', 342.0, 380.0, 418.0),
	(41, 12, 13, 'w', 'A', '', 356.0, 395.0, 435.0),
	(41, 14, 15, 'w', 'A', '', 369.0, 410.0, 451.0),
	(41, 16, 17, 'w', 'A', '', 383.0, 425.0, 468.0),
	(41, 18, 19, 'w', 'A', '', 473.0, 525.0, 578.0),
	(41, 20, 24, 'w', 'A', '', 473.0, 525.0, 578.0),
	(41, 25, 29, 'w', 'A', '', 473.0, 525.0, 578.0),
	(41, 30, 34, 'w', 'A', '', 459.0, 510.0, 561.0),
	(41, 35, 39, 'w', 'A', '', 459.0, 510.0, 561.0),
	(41, 40, 44, 'w', 'A', '', 446.0, 495.0, 545.0),
	(41, 45, 49, 'w', 'A', '', 432.0, 480.0, 528.0),
	(41, 50, 54, 'w', 'A', '', 419.0, 465.0, 512.0),
	(41, 55, 59, 'w', 'A', '', 405.0, 450.0, 495.0),
	(41, 60, 64, 'w', 'A', '', 392.0, 435.0, 479.0),
	(41, 65, 69, 'w', 'A', '', 378.0, 420.0, 462.0),
	(41, 70, 74, 'w', 'A', '', 365.0, 405.0, 446.0),
	(41, 75, 79, 'w', 'A', '', 351.0, 390.0, 429.0),
	(41, 80, 84, 'w', 'A', '', 338.0, 375.0, 413.0),
	(41, 85, 89, 'w', 'A', '', 324.0, 360.0, 396.0),
	(41, 90, 200, 'w', 'A', '', 311.0, 345.0, 380.0),
	(41, 0, 7, 'm', 'A', '', 378.0, 420.0, 462.0),
	(41, 8, 9, 'm', 'A', '', 392.0, 435.0, 479.0),
	(41, 10, 11, 'm', 'A', '', 405.0, 450.0, 495.0),
	(41, 12, 13, 'm', 'A', '', 419.0, 465.0, 512.0),
	(41, 14, 15, 'm', 'A', '', 432.0, 480.0, 528.0),
	(41, 16, 17, 'm', 'A', '', 446.0, 495.0, 545.0),
	(41, 18, 19, 'm', 'A', '', 536.0, 595.0, 655.0),
	(41, 20, 24, 'm', 'A', '', 536.0, 595.0, 655.0),
	(41, 25, 29, 'm', 'A', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'A', '', 522.0, 580.0, 638.0),
	(41, 35, 39, 'm', 'A', '', 522.0, 580.0, 638.0),
	(41, 40, 44, 'm', 'A', '', 509.0, 565.0, 622.0),
	(41, 45, 49, 'm', 'A', '', 495.0, 550.0, 605.0),
	(41, 50, 54, 'm', 'A', '', 482.0, 535.0, 589.0),
	(41, 55, 59, 'm', 'A', '', 468.0, 520.0, 572.0),
	(41, 60, 64, 'm', 'A', '', 455.0, 505.0, 556.0),
	(41, 65, 69, 'm', 'A', '', 441.0, 490.0, 539.0),
	(41, 70, 74, 'm', 'A', '', 428.0, 475.0, 523.0),
	(41, 75, 79, 'm', 'A', '', 414.0, 460.0, 506.0),
	(41, 80, 84, 'm', 'A', '', 401.0, 445.0, 490.0),
	(41, 85, 89, 'm', 'A', '', 387.0, 430.0, 473.0),
	(41, 90, 200, 'm', 'A', '', 374.0, 415.0, 457.0),
	(42, 0, 7, 'w', 'A', '', 320.0, 355.0, 391.0),
	(42, 8, 9, 'w', 'A', '', 333.0, 370.0, 407.0),
	(42, 10, 11, 'w', 'A', '', 347.0, 385.0, 424.0),
	(42, 12, 13, 'w', 'A', '', 360.0, 400.0, 440.0),
	(42, 14, 15, 'w', 'A', '', 374.0, 415.0, 457.0),
	(42, 16, 17, 'w', 'A', '', 387.0, 430.0, 473.0),
	(42, 18, 19, 'w', 'A', '', 477.0, 530.0, 583.0),
	(42, 20, 24, 'w', 'A', '', 477.0, 530.0, 583.0),
	(42, 25, 29, 'w', 'A', '', 477.0, 530.0, 583.0),
	(42, 30, 34, 'w', 'A', '', 464.0, 515.0, 567.0),
	(42, 35, 39, 'w', 'A', '', 464.0, 515.0, 567.0),
	(42, 40, 44, 'w', 'A', '', 450.0, 500.0, 550.0),
	(42, 45, 49, 'w', 'A', '', 437.0, 485.0, 534.0),
	(42, 50, 54, 'w', 'A', '', 423.0, 470.0, 517.0),
	(42, 55, 59, 'w', 'A', '', 410.0, 455.0, 501.0),
	(42, 60, 64, 'w', 'A', '', 396.0, 440.0, 484.0),
	(42, 65, 69, 'w', 'A', '', 383.0, 425.0, 468.0),
	(42, 70, 74, 'w', 'A', '', 369.0, 410.0, 451.0),
	(42, 75, 79, 'w', 'A', '', 356.0, 395.0, 435.0),
	(42, 80, 84, 'w', 'A', '', 342.0, 380.0, 418.0),
	(42, 85, 89, 'w', 'A', '', 329.0, 365.0, 402.0),
	(42, 90, 200, 'w', 'A', '', 315.0, 350.0, 385.0),
	(42, 0, 7, 'm', 'A', '', 383.0, 425.0, 468.0),
	(42, 8, 9, 'm', 'A', '', 396.0, 440.0, 484.0),
	(42, 10, 11, 'm', 'A', '', 410.0, 455.0, 501.0),
	(42, 12, 13, 'm', 'A', '', 423.0, 470.0, 517.0),
	(42, 14, 15, 'm', 'A', '', 437.0, 485.0, 534.0),
	(42, 16, 17, 'm', 'A', '', 450.0, 500.0, 550.0),
	(42, 18, 19, 'm', 'A', '', 540.0, 600.0, 660.0),
	(42, 20, 24, 'm', 'A', '', 540.0, 600.0, 660.0),
	(42, 25, 29, 'm', 'A', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'A', '', 527.0, 585.0, 644.0),
	(42, 35, 39, 'm', 'A', '', 527.0, 585.0, 644.0),
	(42, 40, 44, 'm', 'A', '', 513.0, 570.0, 627.0),
	(42, 45, 49, 'm', 'A', '', 500.0, 555.0, 611.0),
	(42, 50, 54, 'm', 'A', '', 486.0, 540.0, 594.0),
	(42, 55, 59, 'm', 'A', '', 473.0, 525.0, 578.0),
	(42, 60, 64, 'm', 'A', '', 459.0, 510.0, 561.0),
	(42, 65, 69, 'm', 'A', '', 446.0, 495.0, 545.0),
	(42, 70, 74, 'm', 'A', '', 432.0, 480.0, 528.0),
	(42, 75, 79, 'm', 'A', '', 419.0, 465.0, 512.0),
	(42, 80, 84, 'm', 'A', '', 405.0, 450.0, 495.0),
	(42, 85, 89, 'm', 'A', '', 392.0, 435.0, 479.0),
	(42, 90, 200, 'm', 'A', '', 378.0, 420.0, 462.0),
	(44, 12, 13, 'w', 'A', '', 7.67, 8.48, 9.29),
	(44, 14, 15, 'w', 'A', '', 8.88, 9.69, 10.5),
	(44, 16, 17, 'w', 'A', '', 9.29, 10.09, 10.9),
	(44, 18, 19, 'w', 'A', '', 10.5, 11.31, 12.11),
	(44, 20, 24, 'w', 'A', '', 10.5, 11.31, 12.11),
	(44, 25, 29, 'w', 'A', '', 10.5, 11.31, 12.11),
	(44, 30, 34, 'w', 'A', '', 10.09, 10.9, 11.71),
	(44, 35, 39, 'w', 'A', '', 9.69, 10.5, 11.31),
	(44, 40, 44, 'w', 'A', '', 8.88, 9.69, 10.5),
	(44, 45, 49, 'w', 'A', '', 8.48, 9.29, 10.09),
	(44, 50, 54, 'w', 'A', '', 8.48, 9.69, 11.31),
	(44, 55, 59, 'w', 'A', '', 8.08, 9.29, 10.5),
	(44, 60, 64, 'w', 'A', '', 7.67, 8.88, 10.09),
	(44, 65, 69, 'w', 'A', '', 7.27, 8.48, 10.09),
	(44, 70, 74, 'w', 'A', '', 6.86, 8.08, 9.69),
	(44, 75, 79, 'w', 'A', '', 6.86, 8.48, 10.09),
	(44, 80, 84, 'w', 'A', '', 6.46, 8.08, 9.29),
	(44, 85, 89, 'w', 'A', '', 6.06, 7.27, 8.88),
	(44, 90, 200, 'w', 'A', '', 5.25, 6.86, 8.08),
	(44, 12, 13, 'm', 'A', '', 10.09, 10.9, 11.71),
	(44, 14, 15, 'm', 'A', '', 11.31, 12.11, 12.92),
	(44, 16, 17, 'm', 'A', '', 12.11, 12.92, 13.73),
	(44, 18, 19, 'm', 'A', '', 12.52, 13.32, 14.13),
	(44, 20, 24, 'm', 'A', '', 12.52, 13.73, 14.54),
	(44, 25, 29, 'm', 'A', '', 12.11, 13.32, 14.13),
	(44, 30, 34, 'm', 'A', '', 11.31, 12.52, 13.32),
	(44, 35, 39, 'm', 'A', '', 10.9, 11.71, 12.92),
	(44, 40, 44, 'm', 'A', '', 10.09, 11.31, 12.52),
	(44, 45, 49, 'm', 'A', '', 9.69, 10.9, 12.11),
	(44, 50, 54, 'm', 'A', '', 10.09, 11.31, 12.92),
	(44, 55, 59, 'm', 'A', '', 9.69, 10.9, 12.11),
	(44, 60, 64, 'm', 'A', '', 9.69, 11.31, 12.92),
	(44, 65, 69, 'm', 'A', '', 9.29, 10.9, 12.11),
	(44, 70, 74, 'm', 'A', '', 9.18, 10.71, 11.9),
	(44, 75, 79, 'm', 'A', '', 9.01, 10.5, 11.72),
	(44, 80, 84, 'm', 'A', '', 8.88, 10.09, 11.71),
	(44, 85, 89, 'm', 'A', '', 8.08, 9.69, 10.9),
	(44, 90, 200, 'm', 'A', '', 7.27, 8.48, 10.09),
	(53, 0, 7, 'w', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'A', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'A', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'A', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'A', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'A', '', 11.0, 14.0, 20.0),
	(57, 8, 9, 'w', 'A', '', 17.0, 20.0, 26.0),
	(57, 10, 11, 'w', 'A', '', 26.0, 29.0, 34.0),
	(57, 0, 7, 'm', 'A', '', 14.0, 17.0, 23.0),
	(57, 8, 9, 'm', 'A', '', 20.0, 26.0, 31.0),
	(57, 10, 11, 'm', 'A', '', 31.0, 37.0, 43.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'B_I', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'w', 'B_I', '', 7.250000000000001, 6.283333333333333, 5.416666666666667),
	(1, 10, 11, 'w', 'B_I', '', 6.933333333333333, 6.066666666666666, 5.2),
	(1, 12, 13, 'w', 'B_I', '', 6.716666666666666, 5.75, 4.883333333333334),
	(1, 14, 15, 'w', 'B_I', '', 6.5, 5.633333333333333, 4.666666666666667),
	(1, 16, 17, 'w', 'B_I', '', 6.283333333333333, 5.3, 4.449999999999999),
	(1, 0, 7, 'm', 'B_I', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'm', 'B_I', '', 7.033333333333332, 6.066666666666666, 5.1),
	(1, 10, 11, 'm', 'B_I', '', 6.6000000000000005, 5.633333333333333, 4.666666666666667),
	(1, 12, 13, 'm', 'B_I', '', 6.166666666666666, 5.2, 4.2333333333333325),
	(1, 14, 15, 'm', 'B_I', '', 5.633333333333333, 4.766666666666667, 3.9000000000000004),
	(1, 16, 17, 'm', 'B_I', '', 5.3, 4.449999999999999, 3.5833333333333335),
	(4, 8, 9, 'w', 'B_I', '5 km', 32.400000000000006, 28.8, 25.200000000000003),
	(4, 10, 11, 'w', 'B_I', '10 km', 60.6, 51.6, 42.6),
	(4, 12, 13, 'w', 'B_I', '10 km', 54.0, 47.400000000000006, 40.199999999999996),
	(4, 14, 15, 'w', 'B_I', '10 km', 45.6, 39.0, 34.199999999999996),
	(4, 16, 17, 'w', 'B_I', '10 km', 39.0, 34.199999999999996, 30.0),
	(4, 18, 19, 'w', 'B_I', '10 km', 31.05, 28.083333333333336, 25.116666666666667),
	(4, 20, 24, 'w', 'B_I', '10 km', 30.78333333333333, 27.816666666666663, 24.566666666666666),
	(4, 25, 29, 'w', 'B_I', '10 km', 30.233333333333334, 27.266666666666666, 24.3),
	(4, 30, 34, 'w', 'B_I', '10 km', 30.78333333333333, 27.816666666666663, 24.566666666666666),
	(4, 35, 39, 'w', 'B_I', '10 km', 32.400000000000006, 28.616666666666667, 25.383333333333333),
	(4, 40, 44, 'w', 'B_I', '10 km', 34.56666666666667, 29.966666666666665, 26.733333333333334),
	(4, 45, 49, 'w', 'B_I', '10 km', 36.18333333333333, 31.583333333333336, 27.816666666666663),
	(4, 50, 54, 'w', 'B_I', '10 km', 37.26666666666666, 32.93333333333334, 28.883333333333336),
	(4, 55, 59, 'w', 'B_I', '10 km', 38.61666666666666, 34.016666666666666, 29.966666666666665),
	(4, 60, 64, 'w', 'B_I', '10 km', 39.96666666666666, 35.1, 30.78333333333333),
	(4, 65, 69, 'w', 'B_I', '10 km', 40.766666666666666, 35.916666666666664, 31.583333333333336),
	(4, 70, 74, 'w', 'B_I', '10 km', 42.11666666666667, 36.98333333333334, 32.666666666666664),
	(4, 75, 79, 'w', 'B_I', '10 km', 44.016666666666666, 38.06666666666666, 34.016666666666666),
	(4, 80, 84, 'w', 'B_I', '10 km', 45.63333333333334, 40.49999999999999, 35.36666666666667),
	(4, 85, 89, 'w', 'B_I', '10 km', 48.333333333333336, 43.199999999999996, 37.26666666666666),
	(4, 90, 200, 'w', 'B_I', '10 km', 50.21666666666667, 44.81666666666667, 39.150000000000006),
	(4, 8, 9, 'm', 'B_I', '5 km', 31.8, 28.200000000000003, 24.599999999999998),
	(4, 10, 11, 'm', 'B_I', '10 km', 58.199999999999996, 49.199999999999996, 40.199999999999996),
	(4, 12, 13, 'm', 'B_I', '10 km', 51.6, 44.400000000000006, 37.8),
	(4, 14, 15, 'm', 'B_I', '10 km', 38.400000000000006, 33.6, 28.8),
	(4, 16, 17, 'm', 'B_I', '10 km', 32.400000000000006, 28.200000000000003, 24.599999999999998),
	(4, 18, 19, 'm', 'B_I', '10 km', 25.383333333333333, 22.95, 20.78333333333333),
	(4, 20, 24, 'm', 'B_I', '10 km', 25.116666666666667, 22.683333333333334, 20.249999999999996),
	(4, 25, 29, 'm', 'B_I', '10 km', 27.0, 24.03333333333333, 21.066666666666666),
	(4, 30, 34, 'm', 'B_I', '10 km', 28.883333333333336, 25.383333333333333, 21.866666666666667),
	(4, 35, 39, 'm', 'B_I', '10 km', 31.31666666666667, 27.0, 22.416666666666668),
	(4, 40, 44, 'm', 'B_I', '10 km', 34.016666666666666, 28.083333333333336, 23.48333333333333),
	(4, 45, 49, 'm', 'B_I', '10 km', 35.63333333333334, 29.700000000000003, 24.3),
	(4, 50, 54, 'm', 'B_I', '10 km', 36.98333333333334, 30.78333333333333, 25.116666666666667),
	(4, 55, 59, 'm', 'B_I', '10 km', 38.06666666666666, 31.583333333333336, 25.650000000000002),
	(4, 60, 64, 'm', 'B_I', '10 km', 38.61666666666666, 32.400000000000006, 25.916666666666668),
	(4, 65, 69, 'm', 'B_I', '10 km', 39.150000000000006, 32.666666666666664, 26.183333333333334),
	(4, 70, 74, 'm', 'B_I', '10 km', 39.68333333333333, 33.21666666666667, 26.733333333333334),
	(4, 75, 79, 'm', 'B_I', '10 km', 40.233333333333334, 34.016666666666666, 27.816666666666663),
	(4, 80, 84, 'm', 'B_I', '10 km', 41.03333333333334, 34.833333333333336, 28.616666666666667),
	(4, 85, 89, 'm', 'B_I', '10 km', 41.849999999999994, 35.916666666666664, 29.966666666666665),
	(4, 90, 200, 'm', 'B_I', '10 km', 42.666666666666664, 36.71666666666667, 31.31666666666667),
	(7, 0, 7, 'w', 'B_I', '200 m', 9.899999999999999, 8.433333333333334, 6.966666666666667),
	(7, 8, 9, 'w', 'B_I', '200 m', 8.8, 7.7, 6.516666666666666),
	(7, 10, 11, 'w', 'B_I', '200 m', 8.066666666666665, 7.066666666666666, 6.050000000000001),
	(7, 12, 13, 'w', 'B_I', '400 m', 16.31666666666667, 14.216666666666669, 12.100000000000001),
	(7, 14, 15, 'w', 'B_I', '400 m', 14.383333333333335, 12.833333333333334, 11.0),
	(7, 16, 17, 'w', 'B_I', '400 m', 13.016666666666666, 11.55, 10.0),
	(7, 18, 19, 'w', 'B_I', '800 m', 26.4, 23.283333333333335, 20.266666666666666),
	(7, 20, 24, 'w', 'B_I', '800 m', 25.93333333333333, 22.916666666666668, 19.8),
	(7, 25, 29, 'w', 'B_I', '800 m', 28.05, 23.183333333333334, 20.533333333333335),
	(7, 30, 34, 'w', 'B_I', '800 m', 31.716666666666665, 26.03333333333333, 21.45),
	(7, 35, 39, 'w', 'B_I', '800 m', 35.199999999999996, 28.15, 22.366666666666664),
	(7, 40, 44, 'w', 'B_I', '800 m', 37.400000000000006, 30.433333333333337, 23.46666666666667),
	(7, 45, 49, 'w', 'B_I', '800 m', 38.866666666666674, 31.9, 23.650000000000002),
	(7, 50, 54, 'w', 'B_I', '400 m', 19.8, 16.5, 12.65),
	(7, 55, 59, 'w', 'B_I', '400 m', 20.433333333333337, 16.866666666666667, 13.100000000000001),
	(7, 60, 64, 'w', 'B_I', '400 m', 20.9, 17.15, 13.383333333333335),
	(7, 65, 69, 'w', 'B_I', '400 m', 21.366666666666664, 17.333333333333332, 13.466666666666665),
	(7, 70, 74, 'w', 'B_I', '400 m', 21.816666666666663, 17.700000000000003, 13.933333333333334),
	(7, 75, 79, 'w', 'B_I', '200 m', 11.283333333333333, 9.166666666666666, 7.1499999999999995),
	(7, 80, 84, 'w', 'B_I', '200 m', 11.466666666666665, 9.350000000000001, 7.416666666666667),
	(7, 85, 89, 'w', 'B_I', '200 m', 11.633333333333335, 9.616666666666665, 7.800000000000001),
	(7, 90, 200, 'w', 'B_I', '200 m', 11.833333333333334, 9.816666666666666, 8.066666666666665),
	(7, 0, 7, 'm', 'B_I', '200 m', 9.899999999999999, 8.066666666666665, 6.783333333333333),
	(7, 8, 9, 'm', 'B_I', '200 m', 8.8, 7.416666666666667, 6.2333333333333325),
	(7, 10, 11, 'm', 'B_I', '200 m', 7.7, 6.966666666666667, 5.683333333333334),
	(7, 12, 13, 'm', 'B_I', '400 m', 14.85, 12.65, 10.733333333333333),
	(7, 14, 15, 'm', 'B_I', '400 m', 13.2, 11.283333333333333, 9.716666666666667),
	(7, 16, 17, 'm', 'B_I', '400 m', 12.100000000000001, 10.633333333333335, 9.166666666666666),
	(7, 18, 19, 'm', 'B_I', '800 m', 24.85, 21.816666666666663, 18.700000000000003),
	(7, 20, 24, 'm', 'B_I', '800 m', 24.383333333333333, 21.45, 18.066666666666666),
	(7, 25, 29, 'm', 'B_I', '800 m', 25.48333333333333, 22.0, 18.700000000000003),
	(7, 30, 34, 'm', 'B_I', '800 m', 28.31666666666667, 23.650000000000002, 19.8),
	(7, 35, 39, 'm', 'B_I', '800 m', 31.716666666666665, 26.4, 21.183333333333334),
	(7, 40, 44, 'm', 'B_I', '800 m', 35.65, 29.066666666666666, 22.46666666666667),
	(7, 45, 49, 'm', 'B_I', '800 m', 37.95, 30.616666666666667, 22.733333333333334),
	(7, 50, 54, 'm', 'B_I', '400 m', 19.166666666666668, 15.766666666666667, 11.833333333333334),
	(7, 55, 59, 'm', 'B_I', '400 m', 19.616666666666667, 16.05, 12.466666666666665),
	(7, 60, 64, 'm', 'B_I', '400 m', 19.983333333333334, 16.233333333333334, 12.55),
	(7, 65, 69, 'm', 'B_I', '400 m', 20.266666666666666, 16.599999999999998, 12.65),
	(7, 70, 74, 'm', 'B_I', '400 m', 20.266666666666666, 16.76666666666667, 12.749999999999998),
	(7, 75, 79, 'm', 'B_I', '200 m', 10.366666666666667, 8.433333333333334, 6.7),
	(7, 80, 84, 'm', 'B_I', '200 m', 10.45, 8.616666666666665, 6.783333333333333),
	(7, 85, 89, 'm', 'B_I', '200 m', 10.45, 8.8, 7.066666666666666),
	(7, 90, 200, 'm', 'B_I', '200 m', 10.733333333333333, 8.983333333333333, 7.416666666666667),
	(8, 18, 19, 'w', 'B_I', '4 km', 50.03333333333334, 47.51666666666667, 44.63333333333334),
	(8, 20, 24, 'w', 'B_I', '4 km', 47.88333333333333, 45.36666666666667, 42.833333333333336),
	(8, 25, 29, 'w', 'B_I', '4 km', 48.233333333333334, 45.71666666666667, 43.199999999999996),
	(8, 30, 34, 'w', 'B_I', '4 km', 48.6, 46.08333333333333, 43.49999999999999),
	(8, 35, 39, 'w', 'B_I', '4 km', 50.400000000000006, 46.8, 43.73333333333333),
	(8, 40, 44, 'w', 'B_I', '4 km', 52.56666666666667, 48.233333333333334, 43.916666666666664),
	(8, 45, 49, 'w', 'B_I', '4 km', 54.36666666666667, 49.68333333333333, 44.63333333333334),
	(8, 50, 54, 'w', 'B_I', '4 km', 56.16666666666667, 51.11666666666667, 46.08333333333333),
	(8, 55, 59, 'w', 'B_I', '4 km', 57.6, 52.56666666666667, 47.51666666666667),
	(8, 60, 64, 'w', 'B_I', '4 km', 59.400000000000006, 53.63333333333334, 48.6),
	(8, 65, 69, 'w', 'B_I', '4 km', 60.666666666666664, 55.08333333333333, 50.400000000000006),
	(8, 70, 74, 'w', 'B_I', '4 km', 63.53333333333333, 56.88333333333333, 51.833333333333336),
	(8, 75, 79, 'w', 'B_I', '4 km', 66.6, 58.68333333333333, 53.63333333333334),
	(8, 80, 84, 'w', 'B_I', '4 km', 70.91666666666666, 61.383333333333326, 55.8),
	(8, 85, 89, 'w', 'B_I', '4 km', 74.88333333333334, 65.03333333333333, 59.03333333333334),
	(8, 90, 200, 'w', 'B_I', '4 km', 79.43333333333334, 69.11666666666666, 62.63333333333334),
	(8, 18, 19, 'm', 'B_I', '4 km', 42.11666666666667, 39.233333333333334, 36.36666666666667),
	(8, 20, 24, 'm', 'B_I', '4 km', 41.03333333333334, 38.16666666666667, 35.28333333333334),
	(8, 25, 29, 'm', 'B_I', '4 km', 42.11666666666667, 39.233333333333334, 36.36666666666667),
	(8, 30, 34, 'm', 'B_I', '4 km', 45.0, 41.03333333333334, 36.71666666666667),
	(8, 35, 39, 'm', 'B_I', '4 km', 46.8, 42.11666666666667, 38.51666666666667),
	(8, 40, 44, 'm', 'B_I', '4 km', 47.51666666666667, 43.56666666666667, 38.88333333333333),
	(8, 45, 49, 'm', 'B_I', '4 km', 49.31666666666666, 45.0, 39.6),
	(8, 50, 54, 'm', 'B_I', '4 km', 51.11666666666667, 46.08333333333333, 41.400000000000006),
	(8, 55, 59, 'm', 'B_I', '4 km', 52.56666666666667, 46.8, 42.483333333333334),
	(8, 60, 64, 'm', 'B_I', '4 km', 54.53333333333333, 48.6, 43.56666666666667),
	(8, 65, 69, 'm', 'B_I', '4 km', 56.28333333333334, 50.03333333333334, 44.63333333333334),
	(8, 70, 74, 'm', 'B_I', '4 km', 58.68333333333333, 51.833333333333336, 46.8),
	(8, 75, 79, 'm', 'B_I', '4 km', 62.03333333333334, 54.53333333333333, 51.833333333333336),
	(8, 80, 84, 'm', 'B_I', '4 km', 65.88333333333334, 57.416666666666664, 51.833333333333336),
	(8, 85, 89, 'm', 'B_I', '4 km', 69.11666666666666, 60.666666666666664, 54.36666666666667),
	(8, 90, 200, 'm', 'B_I', '4 km', 73.98333333333333, 64.31666666666666, 57.6),
	(10, 0, 7, 'w', 'B_I', '', 5.4, 8.1, 10.8),
	(10, 8, 9, 'w', 'B_I', '', 8.1, 10.8, 13.5),
	(10, 10, 11, 'w', 'B_I', '', 9.9, 13.5, 16.2),
	(10, 0, 7, 'm', 'B_I', '', 10.8, 13.5, 15.3),
	(10, 8, 9, 'm', 'B_I', '', 15.3, 18.0, 20.7),
	(10, 10, 11, 'm', 'B_I', '', 18.9, 22.5, 25.2),
	(11, 12, 13, 'w', 'B_I', '', 13.5, 16.2, 19.8),
	(11, 14, 15, 'w', 'B_I', '', 18.0, 21.6, 24.3),
	(11, 16, 17, 'w', 'B_I', '', 21.6, 24.3, 27.9),
	(11, 12, 13, 'm', 'B_I', '', 23.4, 27.0, 29.7),
	(11, 14, 15, 'm', 'B_I', '', 27.0, 30.6, 33.3),
	(11, 16, 17, 'm', 'B_I', '', 30.6, 34.2, 37.8),
	(12, 0, 7, 'w', 'B_I', '1 kg', 3.75, 4.2, 4.88),
	(12, 8, 9, 'w', 'B_I', '1 kg', 4.25, 4.7, 5.38),
	(12, 10, 11, 'w', 'B_I', '1 kg', 4.75, 5.2, 5.88),
	(12, 12, 13, 'w', 'B_I', '1 kg', 5.25, 5.7, 6.38),
	(12, 14, 15, 'w', 'B_I', '1 kg', 5.75, 6.2, 6.88),
	(12, 16, 17, 'w', 'B_I', '1 kg', 6.25, 6.7, 7.38),
	(12, 18, 19, 'w', 'B_I', '2 kg', 6.75, 7.2, 7.88),
	(12, 20, 24, 'w', 'B_I', '2 kg', 6.75, 7.2, 7.88),
	(12, 25, 29, 'w', 'B_I', '2 kg', 6.3, 6.98, 7.65),
	(12, 30, 34, 'w', 'B_I', '2 kg', 5.85, 6.75, 7.65),
	(12, 35, 39, 'w', 'B_I', '2 kg', 5.4, 6.53, 7.43),
	(12, 40, 44, 'w', 'B_I', '2 kg', 4.73, 6.08, 7.43),
	(12, 45, 49, 'w', 'B_I', '2 kg', 4.28, 5.85, 7.2),
	(12, 50, 54, 'w', 'B_I', '2 kg', 3.83, 5.4, 6.98),
	(12, 55, 59, 'w', 'B_I', '2 kg', 3.6, 5.18, 6.75),
	(12, 60, 64, 'w', 'B_I', '2 kg', 3.38, 4.95, 6.53),
	(12, 65, 69, 'w', 'B_I', '2 kg', 3.15, 4.73, 6.3),
	(12, 70, 74, 'w', 'B_I', '2 kg', 2.93, 4.5, 6.08),
	(12, 75, 79, 'w', 'B_I', '2 kg', 2.93, 4.28, 5.85),
	(12, 80, 84, 'w', 'B_I', '2 kg', 2.7, 4.28, 5.63),
	(12, 85, 89, 'w', 'B_I', '2 kg', 2.7, 4.05, 5.4),
	(12, 90, 200, 'w', 'B_I', '2 kg', 2.48, 3.83, 4.95),
	(12, 0, 7, 'm', 'B_I', '1 kg', 6.23, 6.9, 7.58),
	(12, 8, 9, 'm', 'B_I', '1 kg', 6.73, 7.4, 8.08),
	(12, 10, 11, 'm', 'B_I', '1 kg', 7.23, 7.9, 8.58),
	(12, 12, 13, 'm', 'B_I', '1 kg', 7.73, 8.4, 9.08),
	(12, 14, 15, 'm', 'B_I', '1 kg', 8.23, 8.9, 9.58),
	(12, 16, 17, 'm', 'B_I', '1 kg', 8.73, 9.4, 10.08),
	(12, 18, 19, 'm', 'B_I', '2 kg', 9.23, 9.9, 10.58),
	(12, 20, 24, 'm', 'B_I', '2 kg', 9.23, 10.13, 10.8),
	(12, 25, 29, 'm', 'B_I', '2 kg', 8.78, 9.68, 10.58),
	(12, 30, 34, 'm', 'B_I', '2 kg', 8.1, 9.23, 10.35),
	(12, 35, 39, 'm', 'B_I', '2 kg', 7.43, 8.78, 10.13),
	(12, 40, 44, 'm', 'B_I', '2 kg', 6.98, 8.33, 9.68),
	(12, 45, 49, 'm', 'B_I', '2 kg', 6.3, 7.88, 9.45),
	(12, 50, 54, 'm', 'B_I', '2 kg', 5.85, 7.65, 9.23),
	(12, 55, 59, 'm', 'B_I', '2 kg', 5.4, 7.43, 9.0),
	(12, 60, 64, 'm', 'B_I', '2 kg', 5.18, 6.98, 8.78),
	(12, 65, 69, 'm', 'B_I', '2 kg', 4.73, 6.53, 8.33),
	(12, 70, 74, 'm', 'B_I', '2 kg', 4.5, 6.3, 8.1),
	(12, 75, 79, 'm', 'B_I', '2 kg', 4.05, 5.85, 7.65),
	(12, 80, 84, 'm', 'B_I', '2 kg', 3.83, 5.63, 7.43),
	(12, 85, 89, 'm', 'B_I', '2 kg', 3.6, 5.4, 7.2),
	(12, 90, 200, 'm', 'B_I', '2 kg', 3.15, 4.95, 6.75),
	(13, 12, 13, 'w', 'B_I', '2 kg', 4.28, 4.73, 5.18),
	(13, 14, 15, 'w', 'B_I', '3 kg', 4.95, 5.4, 5.85),
	(13, 16, 17, 'w', 'B_I', '3 kg', 5.18, 5.63, 6.08),
	(13, 18, 19, 'w', 'B_I', '4 kg', 5.85, 6.3, 6.75),
	(13, 20, 24, 'w', 'B_I', '4 kg', 5.85, 6.3, 6.75),
	(13, 25, 29, 'w', 'B_I', '4 kg', 5.85, 6.3, 6.75),
	(13, 30, 34, 'w', 'B_I', '4 kg', 5.63, 6.08, 6.53),
	(13, 35, 39, 'w', 'B_I', '4 kg', 5.4, 5.85, 6.3),
	(13, 40, 44, 'w', 'B_I', '4 kg', 4.95, 5.4, 5.85),
	(13, 45, 49, 'w', 'B_I', '4 kg', 4.73, 5.18, 5.63),
	(13, 50, 54, 'w', 'B_I', '3 kg', 4.73, 5.4, 6.3),
	(13, 55, 59, 'w', 'B_I', '3 kg', 4.5, 5.18, 5.85),
	(13, 60, 64, 'w', 'B_I', '3 kg', 4.28, 4.95, 5.63),
	(13, 65, 69, 'w', 'B_I', '3 kg', 4.05, 4.73, 5.63),
	(13, 70, 74, 'w', 'B_I', '3 kg', 3.83, 4.5, 5.4),
	(13, 75, 79, 'w', 'B_I', '2 kg', 3.83, 4.73, 5.63),
	(13, 80, 84, 'w', 'B_I', '2 kg', 3.6, 4.5, 5.18),
	(13, 85, 89, 'w', 'B_I', '2 kg', 3.38, 4.05, 4.95),
	(13, 90, 200, 'w', 'B_I', '2 kg', 2.93, 3.83, 4.5),
	(13, 12, 13, 'm', 'B_I', '3 kg', 5.63, 6.08, 6.53),
	(13, 14, 15, 'm', 'B_I', '4 kg', 6.3, 6.75, 7.2),
	(13, 16, 17, 'm', 'B_I', '5 kg', 6.75, 7.2, 7.65),
	(13, 18, 19, 'm', 'B_I', '6 kg', 6.98, 7.43, 7.88),
	(13, 20, 24, 'm', 'B_I', '6 kg', 6.98, 7.65, 8.1),
	(13, 25, 29, 'm', 'B_I', '6 kg', 6.75, 7.43, 7.88),
	(13, 30, 34, 'm', 'B_I', '6 kg', 6.3, 6.98, 7.43),
	(13, 35, 39, 'm', 'B_I', '6 kg', 6.08, 6.53, 7.2),
	(13, 40, 44, 'm', 'B_I', '6 kg', 5.63, 6.3, 6.98),
	(13, 45, 49, 'm', 'B_I', '6 kg', 5.4, 6.08, 6.75),
	(13, 50, 54, 'm', 'B_I', '5 kg', 5.63, 6.3, 7.2),
	(13, 55, 59, 'm', 'B_I', '5 kg', 5.4, 6.08, 6.75),
	(13, 60, 64, 'm', 'B_I', '4 kg', 5.4, 6.3, 7.2),
	(13, 65, 69, 'm', 'B_I', '4 kg', 5.18, 6.08, 6.75),
	(13, 70, 74, 'm', 'B_I', '4 kg', 5.1, 6.0, 6.6),
	(13, 75, 79, 'm', 'B_I', '3 kg', 5.18, 5.85, 6.75),
	(13, 80, 84, 'm', 'B_I', '3 kg', 4.95, 5.63, 6.53),
	(13, 85, 89, 'm', 'B_I', '3 kg', 4.5, 5.4, 6.08),
	(13, 90, 200, 'm', 'B_I', '3 kg', 4.05, 4.73, 5.63),
	(15, 0, 7, 'w', 'B_I', '', 0.84, 1.0, 1.12),
	(15, 8, 9, 'w', 'B_I', '', 0.92, 1.04, 1.2),
	(15, 10, 11, 'w', 'B_I', '', 1.04, 1.16, 1.32),
	(15, 12, 13, 'w', 'B_I', '', 1.12, 1.28, 1.44),
	(15, 14, 15, 'w', 'B_I', '', 1.24, 1.36, 1.52),
	(15, 16, 17, 'w', 'B_I', '', 1.32, 1.44, 1.6),
	(15, 18, 19, 'w', 'B_I', '', 1.32, 1.48, 1.64),
	(15, 20, 24, 'w', 'B_I', '', 1.28, 1.44, 1.6),
	(15, 25, 29, 'w', 'B_I', '', 1.2, 1.36, 1.56),
	(15, 30, 34, 'w', 'B_I', '', 1.08, 1.28, 1.48),
	(15, 35, 39, 'w', 'B_I', '', 1.0, 1.2, 1.44),
	(15, 40, 44, 'w', 'B_I', '', 0.92, 1.12, 1.32),
	(15, 45, 49, 'w', 'B_I', '', 0.88, 1.08, 1.28),
	(15, 50, 54, 'w', 'B_I', '', 0.8, 1.04, 1.24),
	(15, 55, 59, 'w', 'B_I', '', 0.76, 0.96, 1.16),
	(15, 60, 64, 'w', 'B_I', '', 0.76, 0.96, 1.16),
	(15, 65, 69, 'w', 'B_I', '', 0.72, 0.92, 1.12),
	(15, 70, 74, 'w', 'B_I', '', 0.72, 0.92, 1.08),
	(15, 75, 79, 'w', 'B_I', '', 0.72, 0.92, 1.08),
	(15, 80, 84, 'w', 'B_I', '', 0.72, 0.88, 1.04),
	(15, 85, 89, 'w', 'B_I', '', 0.68, 0.84, 1.0),
	(15, 90, 200, 'w', 'B_I', '', 0.64, 0.8, 0.96),
	(15, 0, 7, 'm', 'B_I', '', 0.92, 1.08, 1.2),
	(15, 8, 9, 'm', 'B_I', '', 1.04, 1.2, 1.32),
	(15, 10, 11, 'm', 'B_I', '', 1.2, 1.36, 1.48),
	(15, 12, 13, 'm', 'B_I', '', 1.36, 1.52, 1.64),
	(15, 14, 15, 'm', 'B_I', '', 1.52, 1.64, 1.8),
	(15, 16, 17, 'm', 'B_I', '', 1.64, 1.76, 1.92),
	(15, 18, 19, 'm', 'B_I', '', 1.68, 1.84, 2.0),
	(15, 20, 24, 'm', 'B_I', '', 1.68, 1.84, 2.0),
	(15, 25, 29, 'm', 'B_I', '', 1.64, 1.8, 1.96),
	(15, 30, 34, 'm', 'B_I', '', 1.48, 1.68, 1.88),
	(15, 35, 39, 'm', 'B_I', '', 1.32, 1.56, 1.8),
	(15, 40, 44, 'm', 'B_I', '', 1.24, 1.48, 1.72),
	(15, 45, 49, 'm', 'B_I', '', 1.16, 1.4, 1.64),
	(15, 50, 54, 'm', 'B_I', '', 1.12, 1.36, 1.6),
	(15, 55, 59, 'm', 'B_I', '', 1.08, 1.32, 1.56),
	(15, 60, 64, 'm', 'B_I', '', 1.04, 1.28, 1.52),
	(15, 65, 69, 'm', 'B_I', '', 1.04, 1.28, 1.52),
	(15, 70, 74, 'm', 'B_I', '', 1.0, 1.24, 1.48),
	(15, 75, 79, 'm', 'B_I', '', 0.96, 1.2, 1.44),
	(15, 80, 84, 'm', 'B_I', '', 0.92, 1.16, 1.4),
	(15, 85, 89, 'm', 'B_I', '', 0.8, 1.04, 1.28),
	(15, 90, 200, 'm', 'B_I', '', 0.72, 0.96, 1.2),
	(17, 0, 7, 'w', 'B_I', '30 m', 10.4, 9.2, 8.2),
	(17, 8, 9, 'w', 'B_I', '30 m', 9.6, 8.6, 7.4),
	(17, 10, 11, 'w', 'B_I', '50 m', 14.3, 13.1, 11.8),
	(17, 12, 13, 'w', 'B_I', '50 m', 13.8, 12.5, 11.1),
	(17, 14, 15, 'w', 'B_I', '100 m', 24.2, 22.1, 20.2),
	(17, 16, 17, 'w', 'B_I', '100 m', 22.9, 21.2, 19.5),
	(17, 18, 19, 'w', 'B_I', '100 m', 23.7, 21.5, 19.9),
	(17, 20, 24, 'w', 'B_I', '100 m', 24.1, 21.8, 20.3),
	(17, 25, 29, 'w', 'B_I', '100 m', 24.6, 22.4, 20.8),
	(17, 30, 34, 'w', 'B_I', '100 m', 25.5, 23.1, 21.3),
	(17, 35, 39, 'w', 'B_I', '100 m', 26.5, 24.2, 22.1),
	(17, 40, 44, 'w', 'B_I', '50 m', 14.3, 12.9, 11.4),
	(17, 45, 49, 'w', 'B_I', '50 m', 15.0, 13.4, 11.8),
	(17, 50, 54, 'w', 'B_I', '50 m', 15.5, 13.9, 12.4),
	(17, 55, 59, 'w', 'B_I', '50 m', 16.1, 14.6, 12.9),
	(17, 60, 64, 'w', 'B_I', '50 m', 16.4, 14.8, 13.3),
	(17, 65, 69, 'w', 'B_I', '50 m', 16.6, 15.1, 13.5),
	(17, 70, 74, 'w', 'B_I', '50 m', 16.9, 15.3, 13.8),
	(17, 75, 79, 'w', 'B_I', '50 m', 17.6, 16.0, 14.4),
	(17, 80, 84, 'w', 'B_I', '50 m', 18.6, 17.0, 15.6),
	(17, 85, 89, 'w', 'B_I', '50 m', 20.2, 18.6, 17.2),
	(17, 90, 200, 'w', 'B_I', '50 m', 22.2, 20.7, 19.2),
	(17, 0, 7, 'm', 'B_I', '30 m', 10.0, 8.8, 7.8),
	(17, 8, 9, 'm', 'B_I', '30 m', 9.4, 8.3, 7.4),
	(17, 10, 11, 'm', 'B_I', '50 m', 13.4, 12.1, 10.9),
	(17, 12, 13, 'm', 'B_I', '50 m', 12.6, 11.6, 10.5),
	(17, 14, 15, 'm', 'B_I', '100 m', 22.1, 20.0, 18.3),
	(17, 16, 17, 'm', 'B_I', '100 m', 21.2, 19.2, 17.6),
	(17, 18, 19, 'm', 'B_I', '100 m', 20.8, 19.0, 17.2),
	(17, 20, 24, 'm', 'B_I', '100 m', 20.5, 18.7, 16.9),
	(17, 25, 29, 'm', 'B_I', '100 m', 21.2, 19.2, 17.3),
	(17, 30, 34, 'm', 'B_I', '100 m', 21.8, 19.6, 17.7),
	(17, 35, 39, 'm', 'B_I', '100 m', 22.9, 20.7, 18.5),
	(17, 40, 44, 'm', 'B_I', '50 m', 12.5, 11.3, 10.0),
	(17, 45, 49, 'm', 'B_I', '50 m', 13.0, 11.6, 10.3),
	(17, 50, 54, 'm', 'B_I', '50 m', 13.4, 11.8, 10.7),
	(17, 55, 59, 'm', 'B_I', '50 m', 13.7, 12.2, 11.1),
	(17, 60, 64, 'm', 'B_I', '50 m', 14.0, 12.6, 11.4),
	(17, 65, 69, 'm', 'B_I', '50 m', 14.6, 13.3, 11.8),
	(17, 70, 74, 'm', 'B_I', '50 m', 15.2, 13.9, 12.5),
	(17, 75, 79, 'm', 'B_I', '50 m', 15.9, 14.6, 13.1),
	(17, 80, 84, 'm', 'B_I', '50 m', 16.9, 15.6, 14.2),
	(17, 85, 89, 'm', 'B_I', '50 m', 18.3, 17.0, 15.6),
	(17, 90, 200, 'm', 'B_I', '50 m', 20.2, 18.9, 17.4),
	(18, 0, 7, 'w', 'B_I', '', 51.2, 42.4, 33.6),
	(18, 8, 9, 'w', 'B_I', '', 46.2, 37.4, 30.8),
	(18, 10, 11, 'w', 'B_I', '', 42.9, 34.7, 28.1),
	(18, 12, 13, 'w', 'B_I', '', 38.5, 31.9, 25.9),
	(18, 14, 15, 'w', 'B_I', '', 36.3, 30.3, 23.7),
	(18, 16, 17, 'w', 'B_I', '', 33.6, 28.1, 22.0),
	(18, 18, 19, 'w', 'B_I', '', 32.5, 26.4, 20.4),
	(18, 20, 24, 'w', 'B_I', '', 31.9, 26.4, 20.4),
	(18, 25, 29, 'w', 'B_I', '', 33.0, 27.5, 21.5),
	(18, 30, 34, 'w', 'B_I', '', 35.8, 29.2, 23.1),
	(18, 35, 39, 'w', 'B_I', '', 39.6, 31.9, 24.2),
	(18, 40, 44, 'w', 'B_I', '', 44.0, 34.7, 25.9),
	(18, 45, 49, 'w', 'B_I', '', 48.4, 38.5, 27.5),
	(18, 50, 54, 'w', 'B_I', '', 52.8, 42.9, 30.8),
	(18, 55, 59, 'w', 'B_I', '', 56.7, 46.8, 33.6),
	(18, 60, 64, 'w', 'B_I', '', 60.0, 49.0, 35.8),
	(18, 65, 69, 'w', 'B_I', '', 62.2, 51.2, 38.0),
	(18, 70, 74, 'w', 'B_I', '', 64.9, 52.8, 39.6),
	(18, 75, 79, 'w', 'B_I', '', 67.1, 55.0, 41.8),
	(18, 80, 84, 'w', 'B_I', '', 69.9, 57.2, 44.0),
	(18, 85, 89, 'w', 'B_I', '', 72.1, 58.9, 45.7),
	(18, 90, 200, 'w', 'B_I', '', 73.2, 60.0, 46.8),
	(18, 0, 7, 'm', 'B_I', '', 50.6, 41.8, 33.0),
	(18, 8, 9, 'm', 'B_I', '', 45.1, 36.3, 28.6),
	(18, 10, 11, 'm', 'B_I', '', 39.6, 31.9, 24.8),
	(18, 12, 13, 'm', 'B_I', '', 36.3, 29.7, 23.1),
	(18, 14, 15, 'm', 'B_I', '', 34.1, 28.1, 22.0),
	(18, 16, 17, 'm', 'B_I', '', 32.5, 27.0, 20.9),
	(18, 18, 19, 'm', 'B_I', '', 30.8, 25.3, 19.3),
	(18, 20, 24, 'm', 'B_I', '', 29.7, 24.2, 17.1),
	(18, 25, 29, 'm', 'B_I', '', 31.9, 25.3, 18.2),
	(18, 30, 34, 'm', 'B_I', '', 34.7, 26.4, 18.7),
	(18, 35, 39, 'm', 'B_I', '', 38.5, 29.2, 20.4),
	(18, 40, 44, 'm', 'B_I', '', 42.4, 32.5, 20.9),
	(18, 45, 49, 'm', 'B_I', '', 46.2, 35.8, 22.6),
	(18, 50, 54, 'm', 'B_I', '', 49.5, 38.5, 25.3),
	(18, 55, 59, 'm', 'B_I', '', 53.9, 40.7, 27.5),
	(18, 60, 64, 'm', 'B_I', '', 56.1, 42.9, 29.7),
	(18, 65, 69, 'm', 'B_I', '', 57.8, 44.6, 31.4),
	(18, 70, 74, 'm', 'B_I', '', 60.5, 47.3, 34.1),
	(18, 75, 79, 'm', 'B_I', '', 63.3, 50.1, 36.9),
	(18, 80, 84, 'm', 'B_I', '', 64.9, 52.8, 39.6),
	(18, 85, 89, 'm', 'B_I', '', 65.5, 53.9, 41.8),
	(18, 90, 200, 'm', 'B_I', '', 66.0, 55.0, 44.0),
	(19, 8, 9, 'w', 'B_I', '', 49.2, 43.2, 37.2),
	(19, 10, 11, 'w', 'B_I', '', 44.4, 38.4, 32.4),
	(19, 12, 13, 'w', 'B_I', '', 37.2, 32.4, 28.2),
	(19, 14, 15, 'w', 'B_I', '', 32.4, 29.4, 25.8),
	(19, 16, 17, 'w', 'B_I', '', 30.0, 27.0, 24.0),
	(19, 18, 19, 'w', 'B_I', '', 28.8, 26.4, 23.4),
	(19, 20, 24, 'w', 'B_I', '', 29.4, 26.4, 23.4),
	(19, 25, 29, 'w', 'B_I', '', 30.0, 27.0, 24.0),
	(19, 30, 34, 'w', 'B_I', '', 31.2, 28.2, 25.8),
	(19, 35, 39, 'w', 'B_I', '', 33.0, 29.4, 26.4),
	(19, 40, 44, 'w', 'B_I', '', 34.8, 30.6, 27.0),
	(19, 45, 49, 'w', 'B_I', '', 36.6, 32.4, 27.6),
	(19, 50, 54, 'w', 'B_I', '', 38.4, 33.6, 28.2),
	(19, 55, 59, 'w', 'B_I', '', 40.2, 34.8, 28.8),
	(19, 60, 64, 'w', 'B_I', '', 42.0, 36.0, 30.0),
	(19, 65, 69, 'w', 'B_I', '', 43.2, 37.2, 30.6),
	(19, 70, 74, 'w', 'B_I', '', 45.6, 38.4, 31.8),
	(19, 75, 79, 'w', 'B_I', '', 46.8, 39.6, 33.0),
	(19, 80, 84, 'w', 'B_I', '', 48.6, 41.4, 34.2),
	(19, 85, 89, 'w', 'B_I', '', 50.4, 43.2, 36.0),
	(19, 90, 200, 'w', 'B_I', '', 53.4, 45.6, 37.8),
	(19, 8, 9, 'm', 'B_I', '', 45.6, 39.6, 33.6),
	(19, 10, 11, 'm', 'B_I', '', 42.0, 36.6, 31.2),
	(19, 12, 13, 'm', 'B_I', '', 35.4, 31.2, 27.0),
	(19, 14, 15, 'm', 'B_I', '', 28.8, 25.8, 22.8),
	(19, 16, 17, 'm', 'B_I', '', 26.4, 23.4, 20.4),
	(19, 18, 19, 'm', 'B_I', '', 24.6, 21.6, 18.6),
	(19, 20, 24, 'm', 'B_I', '', 24.0, 21.0, 18.0),
	(19, 25, 29, 'm', 'B_I', '', 25.2, 21.6, 18.0),
	(19, 30, 34, 'm', 'B_I', '', 27.0, 22.2, 18.0),
	(19, 35, 39, 'm', 'B_I', '', 28.8, 24.0, 18.6),
	(19, 40, 44, 'm', 'B_I', '', 31.8, 25.8, 19.8),
	(19, 45, 49, 'm', 'B_I', '', 34.2, 27.6, 20.4),
	(19, 50, 54, 'm', 'B_I', '', 36.0, 28.8, 21.6),
	(19, 55, 59, 'm', 'B_I', '', 38.4, 30.0, 22.2),
	(19, 60, 64, 'm', 'B_I', '', 40.2, 31.2, 22.8),
	(19, 65, 69, 'm', 'B_I', '', 42.0, 32.4, 23.4),
	(19, 70, 74, 'm', 'B_I', '', 43.2, 34.2, 24.0),
	(19, 75, 79, 'm', 'B_I', '', 45.0, 35.4, 25.8),
	(19, 80, 84, 'm', 'B_I', '', 46.8, 37.8, 27.6),
	(19, 85, 89, 'm', 'B_I', '', 49.2, 39.6, 29.4),
	(19, 90, 200, 'm', 'B_I', '', 52.2, 42.6, 32.4),
	(21, 10, 11, 'w', 'B_I', '', 0.64, 0.72, 0.8),
	(21, 12, 13, 'w', 'B_I', '', 0.72, 0.8, 0.88),
	(21, 14, 15, 'w', 'B_I', '', 0.76, 0.84, 0.92),
	(21, 16, 17, 'w', 'B_I', '', 0.84, 0.92, 1.0),
	(21, 18, 19, 'w', 'B_I', '', 0.88, 0.96, 1.04),
	(21, 20, 24, 'w', 'B_I', '', 0.88, 0.96, 1.04),
	(21, 25, 29, 'w', 'B_I', '', 0.84, 0.92, 1.0),
	(21, 30, 34, 'w', 'B_I', '', 0.8, 0.88, 0.96),
	(21, 35, 39, 'w', 'B_I', '', 0.76, 0.84, 0.92),
	(21, 40, 44, 'w', 'B_I', '', 0.72, 0.8, 0.88),
	(21, 45, 49, 'w', 'B_I', '', 0.72, 0.8, 0.88),
	(21, 50, 54, 'w', 'B_I', '', 0.68, 0.76, 0.84),
	(21, 55, 59, 'w', 'B_I', '', 0.64, 0.72, 0.8),
	(21, 60, 64, 'w', 'B_I', '', 0.6, 0.68, 0.76),
	(21, 65, 69, 'w', 'B_I', '', 0.6, 0.68, 0.76),
	(21, 70, 74, 'w', 'B_I', '', 0.56, 0.64, 0.72),
	(21, 75, 79, 'w', 'B_I', '', 0.52, 0.6, 0.68),
	(21, 80, 84, 'w', 'B_I', '', 0.52, 0.6, 0.68),
	(21, 85, 89, 'w', 'B_I', '', 0.48, 0.56, 0.64),
	(21, 90, 200, 'w', 'B_I', '', 0.44, 0.48, 0.52),
	(21, 10, 11, 'm', 'B_I', '', 0.68, 0.76, 0.84),
	(21, 12, 13, 'm', 'B_I', '', 0.76, 0.84, 0.92),
	(21, 14, 15, 'm', 'B_I', '', 0.88, 0.96, 1.04),
	(21, 16, 17, 'm', 'B_I', '', 0.96, 1.04, 1.12),
	(21, 18, 19, 'm', 'B_I', '', 1.04, 1.12, 1.2),
	(21, 20, 24, 'm', 'B_I', '', 1.08, 1.16, 1.24),
	(21, 25, 29, 'm', 'B_I', '', 1.04, 1.12, 1.2),
	(21, 30, 34, 'm', 'B_I', '', 1.04, 1.12, 1.2),
	(21, 35, 39, 'm', 'B_I', '', 1.0, 1.08, 1.16),
	(21, 40, 44, 'm', 'B_I', '', 0.96, 1.04, 1.12),
	(21, 45, 49, 'm', 'B_I', '', 0.92, 1.0, 1.08),
	(21, 50, 54, 'm', 'B_I', '', 0.84, 0.92, 1.0),
	(21, 55, 59, 'm', 'B_I', '', 0.8, 0.88, 0.96),
	(21, 60, 64, 'm', 'B_I', '', 0.76, 0.84, 0.92),
	(21, 65, 69, 'm', 'B_I', '', 0.68, 0.8, 0.88),
	(21, 70, 74, 'm', 'B_I', '', 0.64, 0.76, 0.84),
	(21, 75, 79, 'm', 'B_I', '', 0.6, 0.72, 0.8),
	(21, 80, 84, 'm', 'B_I', '', 0.6, 0.68, 0.76),
	(21, 85, 89, 'm', 'B_I', '', 0.56, 0.64, 0.72),
	(21, 90, 200, 'm', 'B_I', '', 0.52, 0.6, 0.68),
	(23, 0, 7, 'w', 'B_I', '', 1.44, 1.68, 1.92),
	(23, 8, 9, 'w', 'B_I', '', 1.64, 1.88, 2.12),
	(23, 10, 11, 'w', 'B_I', '', 1.84, 2.08, 2.32),
	(23, 12, 13, 'w', 'B_I', '', 2.24, 2.48, 2.72),
	(23, 14, 15, 'w', 'B_I', '', 2.56, 2.8, 3.04),
	(23, 16, 17, 'w', 'B_I', '', 2.72, 2.96, 3.2),
	(23, 18, 19, 'w', 'B_I', '', 2.72, 2.96, 3.2),
	(23, 20, 24, 'w', 'B_I', '', 2.72, 2.96, 3.2),
	(23, 25, 29, 'w', 'B_I', '', 2.64, 2.88, 3.12),
	(23, 30, 34, 'w', 'B_I', '', 2.56, 2.8, 3.04),
	(23, 35, 39, 'w', 'B_I', '', 2.48, 2.72, 2.96),
	(23, 40, 44, 'w', 'B_I', '', 2.4, 2.64, 2.88),
	(23, 45, 49, 'w', 'B_I', '', 2.24, 2.56, 2.8),
	(23, 50, 54, 'w', 'B_I', '', 2.08, 2.4, 2.72),
	(23, 55, 59, 'w', 'B_I', '', 2.0, 2.32, 2.64),
	(23, 60, 64, 'w', 'B_I', '', 1.92, 2.24, 2.56),
	(23, 65, 69, 'w', 'B_I', '', 1.84, 2.16, 2.48),
	(23, 70, 74, 'w', 'B_I', '', 1.68, 2.0, 2.32),
	(23, 75, 79, 'w', 'B_I', '', 1.44, 1.76, 2.08),
	(23, 80, 84, 'w', 'B_I', '', 1.28, 1.6, 1.92),
	(23, 85, 89, 'w', 'B_I', '', 1.04, 1.36, 1.68),
	(23, 90, 200, 'w', 'B_I', '', 0.88, 1.2, 1.52),
	(23, 0, 7, 'm', 'B_I', '', 1.68, 1.92, 2.16),
	(23, 8, 9, 'm', 'B_I', '', 1.88, 2.12, 2.36),
	(23, 10, 11, 'm', 'B_I', '', 2.08, 2.32, 2.56),
	(23, 12, 13, 'm', 'B_I', '', 2.56, 2.8, 3.04),
	(23, 14, 15, 'm', 'B_I', '', 3.04, 3.28, 3.52),
	(23, 16, 17, 'm', 'B_I', '', 3.44, 3.68, 3.92),
	(23, 18, 19, 'm', 'B_I', '', 3.6, 3.84, 4.08),
	(23, 20, 24, 'm', 'B_I', '', 3.52, 3.76, 4.0),
	(23, 25, 29, 'm', 'B_I', '', 3.44, 3.68, 3.92),
	(23, 30, 34, 'm', 'B_I', '', 3.36, 3.6, 3.84),
	(23, 35, 39, 'm', 'B_I', '', 3.28, 3.52, 3.76),
	(23, 40, 44, 'm', 'B_I', '', 3.12, 3.44, 3.68),
	(23, 45, 49, 'm', 'B_I', '', 2.96, 3.28, 3.6),
	(23, 50, 54, 'm', 'B_I', '', 2.88, 3.2, 3.52),
	(23, 55, 59, 'm', 'B_I', '', 2.72, 3.04, 3.36),
	(23, 60, 64, 'm', 'B_I', '', 2.56, 2.88, 3.2),
	(23, 65, 69, 'm', 'B_I', '', 2.32, 2.64, 2.96),
	(23, 70, 74, 'm', 'B_I', '', 2.16, 2.48, 2.8),
	(23, 75, 79, 'm', 'B_I', '', 1.92, 2.32, 2.64),
	(23, 80, 84, 'm', 'B_I', '', 1.68, 2.08, 2.48),
	(23, 85, 89, 'm', 'B_I', '', 1.52, 1.92, 2.32),
	(23, 90, 200, 'm', 'B_I', '', 1.28, 1.68, 2.08),
	(25, 12, 13, 'w', 'B_I', '', 15.3, 17.55, 19.8),
	(25, 14, 15, 'w', 'B_I', '', 17.55, 20.25, 22.95),
	(25, 16, 17, 'w', 'B_I', '', 19.8, 22.5, 25.2),
	(25, 18, 19, 'w', 'B_I', '', 21.15, 23.85, 26.1),
	(25, 20, 24, 'w', 'B_I', '', 21.6, 24.3, 26.55),
	(25, 25, 29, 'w', 'B_I', '', 21.6, 24.3, 26.55),
	(25, 30, 34, 'w', 'B_I', '', 19.8, 22.5, 24.75),
	(25, 35, 39, 'w', 'B_I', '', 18.9, 21.6, 23.85),
	(25, 40, 44, 'w', 'B_I', '', 17.55, 20.25, 22.5),
	(25, 45, 49, 'w', 'B_I', '', 16.65, 19.35, 21.6),
	(25, 50, 54, 'w', 'B_I', '', 14.85, 18.0, 20.7),
	(25, 55, 59, 'w', 'B_I', '', 13.95, 17.1, 19.8),
	(25, 60, 64, 'w', 'B_I', '', 13.05, 16.2, 18.9),
	(25, 65, 69, 'w', 'B_I', '', 12.15, 15.3, 18.0),
	(25, 70, 74, 'w', 'B_I', '', 11.7, 14.85, 17.55),
	(25, 75, 79, 'w', 'B_I', '', 10.8, 13.95, 16.65),
	(25, 80, 84, 'w', 'B_I', '', 9.9, 13.05, 15.75),
	(25, 85, 89, 'w', 'B_I', '', 8.55, 11.7, 14.4),
	(25, 90, 200, 'w', 'B_I', '', 6.75, 9.9, 12.6),
	(25, 12, 13, 'm', 'B_I', '', 17.55, 21.6, 24.75),
	(25, 14, 15, 'm', 'B_I', '', 21.15, 25.2, 28.8),
	(25, 16, 17, 'm', 'B_I', '', 24.75, 28.8, 32.85),
	(25, 18, 19, 'm', 'B_I', '', 28.35, 32.4, 36.45),
	(25, 20, 24, 'm', 'B_I', '', 29.7, 34.2, 37.8),
	(25, 25, 29, 'm', 'B_I', '', 29.25, 33.75, 37.35),
	(25, 30, 34, 'm', 'B_I', '', 27.0, 31.5, 36.0),
	(25, 35, 39, 'm', 'B_I', '', 25.65, 30.15, 34.65),
	(25, 40, 44, 'm', 'B_I', '', 25.2, 29.7, 34.2),
	(25, 45, 49, 'm', 'B_I', '', 24.3, 28.8, 33.75),
	(25, 50, 54, 'm', 'B_I', '', 22.95, 27.9, 32.85),
	(25, 55, 59, 'm', 'B_I', '', 21.15, 26.1, 31.5),
	(25, 60, 64, 'm', 'B_I', '', 20.25, 25.2, 30.6),
	(25, 65, 69, 'm', 'B_I', '', 18.0, 22.95, 27.45),
	(25, 70, 74, 'm', 'B_I', '', 16.65, 21.6, 26.1),
	(25, 75, 79, 'm', 'B_I', '', 14.4, 18.9, 23.4),
	(25, 80, 84, 'm', 'B_I', '', 12.6, 17.1, 21.6),
	(25, 85, 89, 'm', 'B_I', '', 10.8, 14.85, 18.9),
	(25, 90, 200, 'm', 'B_I', '', 9.45, 13.5, 17.55),
	(32, 18, 19, 'w', 'B_I', '', 12.283333333333333, 11.116666666666667, 9.933333333333334),
	(32, 20, 24, 'w', 'B_I', '', 12.0, 10.816666666666666, 9.633333333333335),
	(32, 25, 29, 'w', 'B_I', '', 12.2, 11.016666666666666, 9.833333333333334),
	(32, 30, 34, 'w', 'B_I', '', 12.683333333333334, 11.500000000000002, 10.316666666666666),
	(32, 35, 39, 'w', 'B_I', '', 12.983333333333333, 11.8, 10.616666666666665),
	(32, 40, 44, 'w', 'B_I', '', 13.466666666666665, 12.2, 10.916666666666668),
	(32, 45, 49, 'w', 'B_I', '', 14.066666666666665, 12.683333333333334, 11.116666666666667),
	(32, 50, 54, 'w', 'B_I', '', 14.65, 13.083333333333334, 11.299999999999999),
	(32, 55, 59, 'w', 'B_I', '', 15.25, 13.466666666666665, 11.7),
	(32, 60, 64, 'w', 'B_I', '', 15.633333333333335, 13.866666666666665, 12.100000000000001),
	(32, 65, 69, 'w', 'B_I', '', 16.03333333333333, 14.266666666666667, 12.483333333333333),
	(32, 70, 74, 'w', 'B_I', '', 16.31666666666667, 14.55, 12.783333333333335),
	(32, 75, 79, 'w', 'B_I', '', 16.816666666666663, 15.049999999999999, 13.266666666666667),
	(32, 80, 84, 'w', 'B_I', '', 17.5, 15.733333333333333, 13.966666666666667),
	(32, 85, 89, 'w', 'B_I', '', 18.283333333333335, 16.516666666666666, 14.749999999999998),
	(32, 90, 200, 'w', 'B_I', '', 19.183333333333334, 17.4, 15.633333333333335),
	(32, 18, 19, 'm', 'B_I', '', 10.516666666666667, 9.333333333333332, 8.166666666666666),
	(32, 20, 24, 'm', 'B_I', '', 10.233333333333334, 9.049999999999999, 7.866666666666666),
	(32, 25, 29, 'm', 'B_I', '', 10.416666666666666, 9.25, 8.066666666666665),
	(32, 30, 34, 'm', 'B_I', '', 10.916666666666668, 9.733333333333333, 8.55),
	(32, 35, 39, 'm', 'B_I', '', 11.7, 10.233333333333334, 8.85),
	(32, 40, 44, 'm', 'B_I', '', 12.383333333333335, 10.916666666666668, 9.333333333333332),
	(32, 45, 49, 'm', 'B_I', '', 13.083333333333334, 11.500000000000002, 9.733333333333333),
	(32, 50, 54, 'm', 'B_I', '', 13.766666666666667, 12.0, 10.233333333333334),
	(32, 55, 59, 'm', 'B_I', '', 14.066666666666665, 12.283333333333333, 10.516666666666667),
	(32, 60, 64, 'm', 'B_I', '', 14.45, 12.683333333333334, 10.916666666666668),
	(32, 65, 69, 'm', 'B_I', '', 14.749999999999998, 12.983333333333333, 11.216666666666669),
	(32, 70, 74, 'm', 'B_I', '', 14.950000000000001, 13.183333333333332, 11.4),
	(32, 75, 79, 'm', 'B_I', '', 15.333333333333332, 13.566666666666666, 11.8),
	(32, 80, 84, 'm', 'B_I', '', 15.633333333333335, 13.866666666666665, 12.100000000000001),
	(32, 85, 89, 'm', 'B_I', '', 16.233333333333334, 14.45, 12.683333333333334),
	(32, 90, 200, 'm', 'B_I', '', 17.599999999999998, 15.833333333333334, 14.066666666666665),
	(33, 0, 7, 'w', 'B_I', 'auch als Walking möglich', 5.6000000000000005, 8.4, 11.899999999999999),
	(33, 8, 9, 'w', 'B_I', 'auch als Walking möglich', 7.0, 10.500000000000002, 14.0),
	(33, 10, 11, 'w', 'B_I', 'auch als Walking möglich', 10.500000000000002, 14.0, 21.0),
	(33, 12, 13, 'w', 'B_I', 'auch als Walking möglich', 14.0, 21.0, 28.0),
	(33, 14, 15, 'w', 'B_I', 'auch als Walking möglich', 21.0, 28.0, 35.0),
	(33, 16, 17, 'w', 'B_I', 'auch als Walking möglich', 31.5, 42.0, 52.49999999999999),
	(33, 0, 7, 'm', 'B_I', 'auch als Walking möglich', 7.0, 10.500000000000002, 14.0),
	(33, 8, 9, 'm', 'B_I', 'auch als Walking möglich', 8.4, 11.899999999999999, 16.099999999999998),
	(33, 10, 11, 'm', 'B_I', 'auch als Walking möglich', 11.899999999999999, 17.5, 24.5),
	(33, 12, 13, 'm', 'B_I', 'auch als Walking möglich', 17.5, 24.5, 31.5),
	(33, 14, 15, 'm', 'B_I', 'auch als Walking möglich', 24.5, 31.5, 42.0),
	(33, 16, 17, 'm', 'B_I', 'auch als Walking möglich', 38.49999999999999, 49.0, 63.0),
	(39, 0, 7, 'w', 'B_I', '', 196.0, 218.0, 239.0),
	(39, 8, 9, 'w', 'B_I', '', 207.0, 230.0, 253.0),
	(39, 10, 11, 'w', 'B_I', '', 218.0, 243.0, 267.0),
	(39, 12, 13, 'w', 'B_I', '', 230.0, 255.0, 281.0),
	(39, 14, 15, 'w', 'B_I', '', 241.0, 268.0, 294.0),
	(39, 16, 17, 'w', 'B_I', '', 252.0, 280.0, 308.0),
	(39, 18, 19, 'w', 'B_I', '', 342.0, 380.0, 418.0),
	(39, 20, 24, 'w', 'B_I', '', 342.0, 380.0, 418.0),
	(39, 25, 29, 'w', 'B_I', '', 342.0, 380.0, 418.0),
	(39, 30, 34, 'w', 'B_I', '', 331.0, 368.0, 404.0),
	(39, 35, 39, 'w', 'B_I', '', 331.0, 368.0, 404.0),
	(39, 40, 44, 'w', 'B_I', '', 320.0, 355.0, 391.0),
	(39, 45, 49, 'w', 'B_I', '', 308.0, 343.0, 377.0),
	(39, 50, 54, 'w', 'B_I', '', 297.0, 330.0, 363.0),
	(39, 55, 59, 'w', 'B_I', '', 286.0, 318.0, 349.0),
	(39, 60, 64, 'w', 'B_I', '', 275.0, 305.0, 336.0),
	(39, 65, 69, 'w', 'B_I', '', 263.0, 293.0, 322.0),
	(39, 70, 74, 'w', 'B_I', '', 252.0, 280.0, 308.0),
	(39, 75, 79, 'w', 'B_I', '', 241.0, 268.0, 294.0),
	(39, 80, 84, 'w', 'B_I', '', 230.0, 255.0, 281.0),
	(39, 85, 89, 'w', 'B_I', '', 218.0, 243.0, 267.0),
	(39, 90, 200, 'w', 'B_I', '', 207.0, 230.0, 253.0),
	(39, 0, 7, 'm', 'B_I', '', 254.0, 283.0, 311.0),
	(39, 8, 9, 'm', 'B_I', '', 266.0, 295.0, 325.0),
	(39, 10, 11, 'm', 'B_I', '', 277.0, 308.0, 338.0),
	(39, 12, 13, 'm', 'B_I', '', 288.0, 320.0, 352.0),
	(39, 14, 15, 'm', 'B_I', '', 299.0, 333.0, 366.0),
	(39, 16, 17, 'm', 'B_I', '', 311.0, 345.0, 380.0),
	(39, 18, 19, 'm', 'B_I', '', 401.0, 445.0, 490.0),
	(39, 20, 24, 'm', 'B_I', '', 401.0, 445.0, 490.0),
	(39, 25, 29, 'm', 'B_I', '', 401.0, 445.0, 490.0),
	(39, 30, 34, 'm', 'B_I', '', 389.0, 433.0, 476.0),
	(39, 35, 39, 'm', 'B_I', '', 389.0, 433.0, 476.0),
	(39, 40, 44, 'm', 'B_I', '', 378.0, 420.0, 462.0),
	(39, 45, 49, 'm', 'B_I', '', 367.0, 408.0, 448.0),
	(39, 50, 54, 'm', 'B_I', '', 356.0, 395.0, 435.0),
	(39, 55, 59, 'm', 'B_I', '', 344.0, 383.0, 421.0),
	(39, 60, 64, 'm', 'B_I', '', 333.0, 370.0, 407.0),
	(39, 65, 69, 'm', 'B_I', '', 322.0, 358.0, 393.0),
	(39, 70, 74, 'm', 'B_I', '', 311.0, 345.0, 380.0),
	(39, 75, 79, 'm', 'B_I', '', 299.0, 333.0, 366.0),
	(39, 80, 84, 'm', 'B_I', '', 288.0, 320.0, 352.0),
	(39, 85, 89, 'm', 'B_I', '', 277.0, 308.0, 338.0),
	(39, 90, 200, 'm', 'B_I', '', 266.0, 295.0, 325.0),
	(40, 0, 7, 'w', 'B_I', '', 356.0, 395.0, 435.0),
	(40, 8, 9, 'w', 'B_I', '', 369.0, 410.0, 451.0),
	(40, 10, 11, 'w', 'B_I', '', 383.0, 425.0, 468.0),
	(40, 12, 13, 'w', 'B_I', '', 396.0, 440.0, 484.0),
	(40, 14, 15, 'w', 'B_I', '', 410.0, 455.0, 501.0),
	(40, 16, 17, 'w', 'B_I', '', 423.0, 470.0, 517.0),
	(40, 18, 19, 'w', 'B_I', '', 513.0, 570.0, 627.0),
	(40, 20, 24, 'w', 'B_I', '', 513.0, 570.0, 627.0),
	(40, 25, 29, 'w', 'B_I', '', 513.0, 570.0, 627.0),
	(40, 30, 34, 'w', 'B_I', '', 500.0, 555.0, 611.0),
	(40, 35, 39, 'w', 'B_I', '', 500.0, 555.0, 611.0),
	(40, 40, 44, 'w', 'B_I', '', 486.0, 540.0, 594.0),
	(40, 45, 49, 'w', 'B_I', '', 473.0, 525.0, 578.0),
	(40, 50, 54, 'w', 'B_I', '', 459.0, 510.0, 561.0),
	(40, 55, 59, 'w', 'B_I', '', 446.0, 495.0, 545.0),
	(40, 60, 64, 'w', 'B_I', '', 432.0, 480.0, 528.0),
	(40, 65, 69, 'w', 'B_I', '', 419.0, 465.0, 512.0),
	(40, 70, 74, 'w', 'B_I', '', 405.0, 450.0, 495.0),
	(40, 75, 79, 'w', 'B_I', '', 392.0, 435.0, 479.0),
	(40, 80, 84, 'w', 'B_I', '', 378.0, 420.0, 462.0),
	(40, 85, 89, 'w', 'B_I', '', 365.0, 405.0, 446.0),
	(40, 90, 200, 'w', 'B_I', '', 351.0, 390.0, 429.0),
	(40, 0, 7, 'm', 'B_I', '', 423.0, 470.0, 517.0),
	(40, 8, 9, 'm', 'B_I', '', 437.0, 485.0, 534.0),
	(40, 10, 11, 'm', 'B_I', '', 450.0, 500.0, 550.0),
	(40, 12, 13, 'm', 'B_I', '', 464.0, 515.0, 567.0),
	(40, 14, 15, 'm', 'B_I', '', 477.0, 530.0, 583.0),
	(40, 16, 17, 'm', 'B_I', '', 491.0, 545.0, 600.0),
	(40, 18, 19, 'm', 'B_I', '', 581.0, 645.0, 710.0),
	(40, 20, 24, 'm', 'B_I', '', 581.0, 645.0, 710.0),
	(40, 25, 29, 'm', 'B_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'B_I', '', 567.0, 630.0, 693.0),
	(40, 35, 39, 'm', 'B_I', '', 567.0, 630.0, 693.0),
	(40, 40, 44, 'm', 'B_I', '', 554.0, 615.0, 677.0),
	(40, 45, 49, 'm', 'B_I', '', 540.0, 600.0, 660.0),
	(40, 50, 54, 'm', 'B_I', '', 527.0, 585.0, 644.0),
	(40, 55, 59, 'm', 'B_I', '', 513.0, 570.0, 627.0),
	(40, 60, 64, 'm', 'B_I', '', 500.0, 555.0, 611.0),
	(40, 65, 69, 'm', 'B_I', '', 486.0, 540.0, 594.0),
	(40, 70, 74, 'm', 'B_I', '', 473.0, 525.0, 578.0),
	(40, 75, 79, 'm', 'B_I', '', 459.0, 510.0, 561.0),
	(40, 80, 84, 'm', 'B_I', '', 446.0, 495.0, 545.0),
	(40, 85, 89, 'm', 'B_I', '', 432.0, 480.0, 528.0),
	(40, 90, 200, 'm', 'B_I', '', 419.0, 465.0, 512.0),
	(41, 0, 7, 'w', 'B_I', '', 288.0, 320.0, 352.0),
	(41, 8, 9, 'w', 'B_I', '', 302.0, 335.0, 369.0),
	(41, 10, 11, 'w', 'B_I', '', 315.0, 350.0, 385.0),
	(41, 12, 13, 'w', 'B_I', '', 329.0, 365.0, 402.0),
	(41, 14, 15, 'w', 'B_I', '', 342.0, 380.0, 418.0),
	(41, 16, 17, 'w', 'B_I', '', 356.0, 395.0, 435.0),
	(41, 18, 19, 'w', 'B_I', '', 446.0, 495.0, 545.0),
	(41, 20, 24, 'w', 'B_I', '', 446.0, 495.0, 545.0),
	(41, 25, 29, 'w', 'B_I', '', 446.0, 495.0, 545.0),
	(41, 30, 34, 'w', 'B_I', '', 432.0, 480.0, 528.0),
	(41, 35, 39, 'w', 'B_I', '', 432.0, 480.0, 528.0),
	(41, 40, 44, 'w', 'B_I', '', 419.0, 465.0, 512.0),
	(41, 45, 49, 'w', 'B_I', '', 405.0, 450.0, 495.0),
	(41, 50, 54, 'w', 'B_I', '', 392.0, 435.0, 479.0),
	(41, 55, 59, 'w', 'B_I', '', 378.0, 420.0, 462.0),
	(41, 60, 64, 'w', 'B_I', '', 365.0, 405.0, 446.0),
	(41, 65, 69, 'w', 'B_I', '', 351.0, 390.0, 429.0),
	(41, 70, 74, 'w', 'B_I', '', 338.0, 375.0, 413.0),
	(41, 75, 79, 'w', 'B_I', '', 324.0, 360.0, 396.0),
	(41, 80, 84, 'w', 'B_I', '', 311.0, 345.0, 380.0),
	(41, 85, 89, 'w', 'B_I', '', 297.0, 330.0, 363.0),
	(41, 90, 200, 'w', 'B_I', '', 284.0, 315.0, 347.0),
	(41, 0, 7, 'm', 'B_I', '', 351.0, 390.0, 429.0),
	(41, 8, 9, 'm', 'B_I', '', 365.0, 405.0, 446.0),
	(41, 10, 11, 'm', 'B_I', '', 378.0, 420.0, 462.0),
	(41, 12, 13, 'm', 'B_I', '', 392.0, 435.0, 479.0),
	(41, 14, 15, 'm', 'B_I', '', 405.0, 450.0, 495.0),
	(41, 16, 17, 'm', 'B_I', '', 419.0, 465.0, 512.0),
	(41, 18, 19, 'm', 'B_I', '', 509.0, 565.0, 622.0),
	(41, 20, 24, 'm', 'B_I', '', 509.0, 565.0, 622.0),
	(41, 25, 29, 'm', 'B_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'B_I', '', 495.0, 550.0, 605.0),
	(41, 35, 39, 'm', 'B_I', '', 495.0, 550.0, 605.0),
	(41, 40, 44, 'm', 'B_I', '', 482.0, 535.0, 589.0),
	(41, 45, 49, 'm', 'B_I', '', 468.0, 520.0, 572.0),
	(41, 50, 54, 'm', 'B_I', '', 455.0, 505.0, 556.0),
	(41, 55, 59, 'm', 'B_I', '', 441.0, 490.0, 539.0),
	(41, 60, 64, 'm', 'B_I', '', 428.0, 475.0, 523.0),
	(41, 65, 69, 'm', 'B_I', '', 414.0, 460.0, 506.0),
	(41, 70, 74, 'm', 'B_I', '', 401.0, 445.0, 490.0),
	(41, 75, 79, 'm', 'B_I', '', 387.0, 430.0, 473.0),
	(41, 80, 84, 'm', 'B_I', '', 374.0, 415.0, 457.0),
	(41, 85, 89, 'm', 'B_I', '', 360.0, 400.0, 440.0),
	(41, 90, 200, 'm', 'B_I', '', 347.0, 385.0, 424.0),
	(42, 0, 7, 'w', 'B_I', '', 293.0, 325.0, 358.0),
	(42, 8, 9, 'w', 'B_I', '', 306.0, 340.0, 374.0),
	(42, 10, 11, 'w', 'B_I', '', 320.0, 355.0, 391.0),
	(42, 12, 13, 'w', 'B_I', '', 333.0, 370.0, 407.0),
	(42, 14, 15, 'w', 'B_I', '', 347.0, 385.0, 424.0),
	(42, 16, 17, 'w', 'B_I', '', 360.0, 400.0, 440.0),
	(42, 18, 19, 'w', 'B_I', '', 450.0, 500.0, 550.0),
	(42, 20, 24, 'w', 'B_I', '', 450.0, 500.0, 550.0),
	(42, 25, 29, 'w', 'B_I', '', 450.0, 500.0, 550.0),
	(42, 30, 34, 'w', 'B_I', '', 437.0, 485.0, 534.0),
	(42, 35, 39, 'w', 'B_I', '', 437.0, 485.0, 534.0),
	(42, 40, 44, 'w', 'B_I', '', 423.0, 470.0, 517.0),
	(42, 45, 49, 'w', 'B_I', '', 410.0, 455.0, 501.0),
	(42, 50, 54, 'w', 'B_I', '', 396.0, 440.0, 484.0),
	(42, 55, 59, 'w', 'B_I', '', 383.0, 425.0, 468.0),
	(42, 60, 64, 'w', 'B_I', '', 369.0, 410.0, 451.0),
	(42, 65, 69, 'w', 'B_I', '', 356.0, 395.0, 435.0),
	(42, 70, 74, 'w', 'B_I', '', 342.0, 380.0, 418.0),
	(42, 75, 79, 'w', 'B_I', '', 329.0, 365.0, 402.0),
	(42, 80, 84, 'w', 'B_I', '', 315.0, 350.0, 385.0),
	(42, 85, 89, 'w', 'B_I', '', 302.0, 335.0, 369.0),
	(42, 90, 200, 'w', 'B_I', '', 288.0, 320.0, 352.0),
	(42, 0, 7, 'm', 'B_I', '', 356.0, 395.0, 435.0),
	(42, 8, 9, 'm', 'B_I', '', 369.0, 410.0, 451.0),
	(42, 10, 11, 'm', 'B_I', '', 383.0, 425.0, 468.0),
	(42, 12, 13, 'm', 'B_I', '', 396.0, 440.0, 484.0),
	(42, 14, 15, 'm', 'B_I', '', 410.0, 455.0, 501.0),
	(42, 16, 17, 'm', 'B_I', '', 423.0, 470.0, 517.0),
	(42, 18, 19, 'm', 'B_I', '', 513.0, 570.0, 627.0),
	(42, 20, 24, 'm', 'B_I', '', 513.0, 570.0, 627.0),
	(42, 25, 29, 'm', 'B_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'B_I', '', 500.0, 555.0, 611.0),
	(42, 35, 39, 'm', 'B_I', '', 500.0, 555.0, 611.0),
	(42, 40, 44, 'm', 'B_I', '', 486.0, 540.0, 594.0),
	(42, 45, 49, 'm', 'B_I', '', 473.0, 525.0, 578.0),
	(42, 50, 54, 'm', 'B_I', '', 459.0, 510.0, 561.0),
	(42, 55, 59, 'm', 'B_I', '', 446.0, 495.0, 545.0),
	(42, 60, 64, 'm', 'B_I', '', 432.0, 480.0, 528.0),
	(42, 65, 69, 'm', 'B_I', '', 419.0, 465.0, 512.0),
	(42, 70, 74, 'm', 'B_I', '', 405.0, 450.0, 495.0),
	(42, 75, 79, 'm', 'B_I', '', 392.0, 435.0, 479.0),
	(42, 80, 84, 'm', 'B_I', '', 378.0, 420.0, 462.0),
	(42, 85, 89, 'm', 'B_I', '', 365.0, 405.0, 446.0),
	(42, 90, 200, 'm', 'B_I', '', 351.0, 390.0, 429.0),
	(44, 12, 13, 'w', 'B_I', '', 7.27, 8.03, 8.8),
	(44, 14, 15, 'w', 'B_I', '', 8.42, 9.18, 9.95),
	(44, 16, 17, 'w', 'B_I', '', 8.8, 9.56, 10.33),
	(44, 18, 19, 'w', 'B_I', '', 9.95, 10.71, 11.48),
	(44, 20, 24, 'w', 'B_I', '', 9.95, 10.71, 11.48),
	(44, 25, 29, 'w', 'B_I', '', 9.95, 10.71, 11.48),
	(44, 30, 34, 'w', 'B_I', '', 9.56, 10.33, 11.09),
	(44, 35, 39, 'w', 'B_I', '', 9.18, 9.95, 10.71),
	(44, 40, 44, 'w', 'B_I', '', 8.42, 9.18, 9.95),
	(44, 45, 49, 'w', 'B_I', '', 8.03, 8.8, 9.56),
	(44, 50, 54, 'w', 'B_I', '', 8.03, 9.18, 10.71),
	(44, 55, 59, 'w', 'B_I', '', 7.65, 8.8, 9.95),
	(44, 60, 64, 'w', 'B_I', '', 7.27, 8.42, 9.56),
	(44, 65, 69, 'w', 'B_I', '', 6.89, 8.03, 9.56),
	(44, 70, 74, 'w', 'B_I', '', 6.5, 7.65, 9.18),
	(44, 75, 79, 'w', 'B_I', '', 6.5, 8.03, 9.56),
	(44, 80, 84, 'w', 'B_I', '', 6.12, 7.65, 8.8),
	(44, 85, 89, 'w', 'B_I', '', 5.74, 6.89, 8.42),
	(44, 90, 200, 'w', 'B_I', '', 4.97, 6.5, 7.65),
	(44, 12, 13, 'm', 'B_I', '', 9.56, 10.33, 11.09),
	(44, 14, 15, 'm', 'B_I', '', 10.71, 11.48, 12.24),
	(44, 16, 17, 'm', 'B_I', '', 11.48, 12.24, 13.01),
	(44, 18, 19, 'm', 'B_I', '', 11.86, 12.62, 13.39),
	(44, 20, 24, 'm', 'B_I', '', 11.86, 13.01, 13.77),
	(44, 25, 29, 'm', 'B_I', '', 11.48, 12.62, 13.39),
	(44, 30, 34, 'm', 'B_I', '', 10.71, 11.86, 12.62),
	(44, 35, 39, 'm', 'B_I', '', 10.33, 11.09, 12.24),
	(44, 40, 44, 'm', 'B_I', '', 9.56, 10.71, 11.86),
	(44, 45, 49, 'm', 'B_I', '', 9.18, 10.33, 11.48),
	(44, 50, 54, 'm', 'B_I', '', 9.56, 10.71, 12.24),
	(44, 55, 59, 'm', 'B_I', '', 9.18, 10.33, 11.48),
	(44, 60, 64, 'm', 'B_I', '', 9.18, 10.71, 12.24),
	(44, 65, 69, 'm', 'B_I', '', 8.8, 10.33, 11.48),
	(44, 70, 74, 'm', 'B_I', '', 8.67, 10.19, 11.21),
	(44, 75, 79, 'm', 'B_I', '', 8.8, 9.95, 11.48),
	(44, 80, 84, 'm', 'B_I', '', 8.42, 9.56, 11.09),
	(44, 85, 89, 'm', 'B_I', '', 7.65, 9.18, 10.33),
	(44, 90, 200, 'm', 'B_I', '', 6.89, 8.03, 9.56),
	(47, 0, 7, 'w', 'B_I', '30 m', 20.8, 18.5, 16.4),
	(47, 8, 9, 'w', 'B_I', '30 m', 19.2, 17.2, 14.8),
	(47, 10, 11, 'w', 'B_I', '50 m', 28.6, 26.3, 23.7),
	(47, 12, 13, 'w', 'B_I', '50 m', 27.6, 25.0, 22.1),
	(47, 14, 15, 'w', 'B_I', '100 m', 48.4, 44.2, 40.3),
	(47, 16, 17, 'w', 'B_I', '100 m', 45.8, 42.4, 39.0),
	(47, 18, 19, 'w', 'B_I', '100 m', 47.3, 42.9, 39.8),
	(47, 20, 24, 'w', 'B_I', '100 m', 48.1, 43.7, 40.6),
	(47, 25, 29, 'w', 'B_I', '100 m', 49.1, 44.7, 41.6),
	(47, 30, 34, 'w', 'B_I', '100 m', 51.0, 46.3, 42.6),
	(47, 35, 39, 'w', 'B_I', '100 m', 53.0, 48.4, 44.2),
	(47, 40, 44, 'w', 'B_I', '50 m', 28.6, 25.7, 22.9),
	(47, 45, 49, 'w', 'B_I', '50 m', 29.9, 26.8, 23.7),
	(47, 50, 54, 'w', 'B_I', '50 m', 30.9, 27.8, 24.7),
	(47, 55, 59, 'w', 'B_I', '50 m', 32.2, 29.1, 25.7),
	(47, 60, 64, 'w', 'B_I', '50 m', 32.8, 29.6, 26.5),
	(47, 65, 69, 'w', 'B_I', '50 m', 33.3, 30.2, 27.0),
	(47, 70, 74, 'w', 'B_I', '50 m', 33.8, 30.7, 27.6),
	(47, 75, 79, 'w', 'B_I', '50 m', 35.1, 32.0, 28.9),
	(47, 80, 84, 'w', 'B_I', '50 m', 37.2, 34.1, 31.2),
	(47, 85, 89, 'w', 'B_I', '50 m', 40.3, 37.2, 34.3),
	(47, 90, 200, 'w', 'B_I', '50 m', 44.5, 41.3, 38.5),
	(47, 0, 7, 'm', 'B_I', '30 m', 20.0, 17.7, 15.6),
	(47, 8, 9, 'm', 'B_I', '30 m', 18.7, 16.6, 14.8),
	(47, 10, 11, 'm', 'B_I', '50 m', 26.8, 24.2, 21.8),
	(47, 12, 13, 'm', 'B_I', '50 m', 25.2, 23.1, 21.1),
	(47, 14, 15, 'm', 'B_I', '100 m', 44.2, 40.0, 36.7),
	(47, 16, 17, 'm', 'B_I', '100 m', 42.4, 38.5, 35.1),
	(47, 18, 19, 'm', 'B_I', '100 m', 41.6, 38.0, 34.3),
	(47, 20, 24, 'm', 'B_I', '100 m', 41.1, 37.4, 33.8),
	(47, 25, 29, 'm', 'B_I', '100 m', 42.4, 38.5, 34.6),
	(47, 30, 34, 'm', 'B_I', '100 m', 43.7, 39.3, 35.4),
	(47, 35, 39, 'm', 'B_I', '100 m', 45.8, 41.3, 36.9),
	(47, 40, 44, 'm', 'B_I', '50 m', 25.0, 22.6, 20.0),
	(47, 45, 49, 'm', 'B_I', '50 m', 26.0, 23.1, 20.5),
	(47, 50, 54, 'm', 'B_I', '50 m', 26.8, 23.7, 21.3),
	(47, 55, 59, 'm', 'B_I', '50 m', 27.3, 24.4, 22.1),
	(47, 60, 64, 'm', 'B_I', '50 m', 28.1, 25.2, 22.9),
	(47, 65, 69, 'm', 'B_I', '50 m', 29.1, 26.5, 23.7),
	(47, 70, 74, 'm', 'B_I', '50 m', 30.4, 27.8, 25.0),
	(47, 75, 79, 'm', 'B_I', '50 m', 31.7, 29.1, 26.3),
	(47, 80, 84, 'm', 'B_I', '50 m', 33.8, 31.2, 28.3),
	(47, 85, 89, 'm', 'B_I', '50 m', 36.7, 34.1, 31.2),
	(47, 90, 200, 'm', 'B_I', '50 m', 40.3, 37.7, 34.8),
	(53, 0, 7, 'w', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'B_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'B_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'B_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'B_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'B_I', '', 1.0, 2.0, 3.0),
	(57, 0, 7, 'w', 'B_I', '', 11.0, 14.0, 19.0),
	(57, 8, 9, 'w', 'B_I', '', 16.0, 19.0, 24.0),
	(57, 10, 11, 'w', 'B_I', '', 24.0, 27.0, 32.0),
	(57, 0, 7, 'm', 'B_I', '', 14.0, 16.0, 22.0),
	(57, 8, 9, 'm', 'B_I', '', 19.0, 24.0, 30.0),
	(57, 10, 11, 'm', 'B_I', '', 30.0, 35.0, 41.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'B_II', '', 8.500000000000002, 7.5, 6.366666666666666),
	(1, 8, 9, 'w', 'B_II', '', 8.366666666666667, 7.250000000000001, 6.250000000000001),
	(1, 10, 11, 'w', 'B_II', '', 8.0, 7.0, 6.0),
	(1, 12, 13, 'w', 'B_II', '', 7.75, 6.616666666666667, 5.616666666666667),
	(1, 14, 15, 'w', 'B_II', '', 7.5, 6.5, 5.383333333333334),
	(1, 16, 17, 'w', 'B_II', '', 7.250000000000001, 6.116666666666667, 5.116666666666667),
	(1, 0, 7, 'm', 'B_II', '', 8.500000000000002, 7.5, 6.366666666666666),
	(1, 8, 9, 'm', 'B_II', '', 8.116666666666667, 7.0, 5.883333333333334),
	(1, 10, 11, 'm', 'B_II', '', 7.616666666666667, 6.5, 5.383333333333334),
	(1, 12, 13, 'm', 'B_II', '', 7.116666666666667, 6.0, 4.883333333333334),
	(1, 14, 15, 'm', 'B_II', '', 6.5, 5.5, 4.5),
	(1, 16, 17, 'm', 'B_II', '', 6.116666666666667, 5.116666666666667, 4.116666666666667),
	(4, 8, 9, 'w', 'B_II', '5 km', 37.8, 33.6, 29.4),
	(4, 10, 11, 'w', 'B_II', '10 km', 70.7, 60.199999999999996, 49.7),
	(4, 12, 13, 'w', 'B_II', '10 km', 63.0, 55.3, 46.9),
	(4, 14, 15, 'w', 'B_II', '10 km', 53.199999999999996, 45.49999999999999, 39.9),
	(4, 16, 17, 'w', 'B_II', '10 km', 45.49999999999999, 39.9, 35.0),
	(4, 18, 19, 'w', 'B_II', '10 km', 36.233333333333334, 32.766666666666666, 29.3),
	(4, 20, 24, 'w', 'B_II', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 25, 29, 'w', 'B_II', '10 km', 35.28333333333334, 31.816666666666663, 28.35),
	(4, 30, 34, 'w', 'B_II', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 35, 39, 'w', 'B_II', '10 km', 37.8, 33.383333333333326, 29.616666666666667),
	(4, 40, 44, 'w', 'B_II', '10 km', 40.31666666666666, 34.96666666666666, 31.183333333333334),
	(4, 45, 49, 'w', 'B_II', '10 km', 42.21666666666667, 36.849999999999994, 32.45),
	(4, 50, 54, 'w', 'B_II', '10 km', 43.46666666666667, 38.43333333333333, 33.7),
	(4, 55, 59, 'w', 'B_II', '10 km', 45.050000000000004, 39.68333333333333, 34.96666666666666),
	(4, 60, 64, 'w', 'B_II', '10 km', 46.61666666666666, 40.95, 35.916666666666664),
	(4, 65, 69, 'w', 'B_II', '10 km', 47.56666666666667, 41.9, 36.849999999999994),
	(4, 70, 74, 'w', 'B_II', '10 km', 49.13333333333333, 43.150000000000006, 38.11666666666667),
	(4, 75, 79, 'w', 'B_II', '10 km', 51.35, 44.416666666666664, 39.68333333333333),
	(4, 80, 84, 'w', 'B_II', '10 km', 53.233333333333334, 47.25, 41.26666666666666),
	(4, 85, 89, 'w', 'B_II', '10 km', 56.383333333333326, 50.400000000000006, 43.46666666666667),
	(4, 90, 200, 'w', 'B_II', '10 km', 58.583333333333336, 52.28333333333334, 45.68333333333333),
	(4, 8, 9, 'm', 'B_II', '5 km', 37.1, 32.9, 28.700000000000003),
	(4, 10, 11, 'm', 'B_II', '10 km', 67.9, 57.400000000000006, 46.9),
	(4, 12, 13, 'm', 'B_II', '10 km', 60.199999999999996, 51.8, 44.1),
	(4, 14, 15, 'm', 'B_II', '10 km', 44.8, 39.199999999999996, 33.6),
	(4, 16, 17, 'm', 'B_II', '10 km', 37.8, 32.9, 28.700000000000003),
	(4, 18, 19, 'm', 'B_II', '10 km', 29.616666666666667, 26.78333333333333, 24.249999999999996),
	(4, 20, 24, 'm', 'B_II', '10 km', 29.3, 26.46666666666667, 23.616666666666667),
	(4, 25, 29, 'm', 'B_II', '10 km', 31.5, 28.03333333333333, 24.566666666666666),
	(4, 30, 34, 'm', 'B_II', '10 km', 33.7, 29.616666666666667, 25.516666666666666),
	(4, 35, 39, 'm', 'B_II', '10 km', 36.53333333333333, 31.5, 26.15),
	(4, 40, 44, 'm', 'B_II', '10 km', 39.68333333333333, 32.766666666666666, 27.4),
	(4, 45, 49, 'm', 'B_II', '10 km', 41.583333333333336, 34.65, 28.35),
	(4, 50, 54, 'm', 'B_II', '10 km', 43.150000000000006, 35.916666666666664, 29.3),
	(4, 55, 59, 'm', 'B_II', '10 km', 44.416666666666664, 36.849999999999994, 29.93333333333333),
	(4, 60, 64, 'm', 'B_II', '10 km', 45.050000000000004, 37.8, 30.233333333333334),
	(4, 65, 69, 'm', 'B_II', '10 km', 45.68333333333333, 38.11666666666667, 30.549999999999997),
	(4, 70, 74, 'm', 'B_II', '10 km', 46.3, 38.75000000000001, 31.183333333333334),
	(4, 75, 79, 'm', 'B_II', '10 km', 46.93333333333334, 39.68333333333333, 32.45),
	(4, 80, 84, 'm', 'B_II', '10 km', 47.88333333333333, 40.63333333333334, 33.383333333333326),
	(4, 85, 89, 'm', 'B_II', '10 km', 48.833333333333336, 41.9, 34.96666666666666),
	(4, 90, 200, 'm', 'B_II', '10 km', 49.766666666666666, 42.833333333333336, 36.53333333333333),
	(7, 0, 7, 'w', 'B_II', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'B_II', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'B_II', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'B_II', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'B_II', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'B_II', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'B_II', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'B_II', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'B_II', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'B_II', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'B_II', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'B_II', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'B_II', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'B_II', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'B_II', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'B_II', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'B_II', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'B_II', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'B_II', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'B_II', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'B_II', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'B_II', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'B_II', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'B_II', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'B_II', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'B_II', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'B_II', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'B_II', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'B_II', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'B_II', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'B_II', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'B_II', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'B_II', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'B_II', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'B_II', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'B_II', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'B_II', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'B_II', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'B_II', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'B_II', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'B_II', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'B_II', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'B_II', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'B_II', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'B_II', '4 km', 54.21666666666667, 51.483333333333334, 48.36666666666667),
	(8, 20, 24, 'w', 'B_II', '4 km', 51.866666666666674, 49.13333333333333, 46.416666666666664),
	(8, 25, 29, 'w', 'B_II', '4 km', 52.26666666666666, 49.53333333333333, 46.8),
	(8, 30, 34, 'w', 'B_II', '4 km', 52.65, 49.916666666666664, 47.13333333333333),
	(8, 35, 39, 'w', 'B_II', '4 km', 54.6, 50.7, 47.383333333333326),
	(8, 40, 44, 'w', 'B_II', '4 km', 56.93333333333334, 52.26666666666666, 47.583333333333336),
	(8, 45, 49, 'w', 'B_II', '4 km', 58.88333333333333, 53.81666666666667, 48.36666666666667),
	(8, 50, 54, 'w', 'B_II', '4 km', 60.833333333333336, 55.383333333333326, 49.916666666666664),
	(8, 55, 59, 'w', 'B_II', '4 km', 62.400000000000006, 56.93333333333334, 51.483333333333334),
	(8, 60, 64, 'w', 'B_II', '4 km', 64.35, 58.11666666666667, 52.65),
	(8, 65, 69, 'w', 'B_II', '4 km', 65.71666666666668, 59.666666666666664, 54.6),
	(8, 70, 74, 'w', 'B_II', '4 km', 68.83333333333333, 61.61666666666666, 56.16666666666667),
	(8, 75, 79, 'w', 'B_II', '4 km', 72.15, 63.56666666666667, 58.11666666666667),
	(8, 80, 84, 'w', 'B_II', '4 km', 76.83333333333333, 66.5, 60.45),
	(8, 85, 89, 'w', 'B_II', '4 km', 81.11666666666666, 70.46666666666667, 63.96666666666666),
	(8, 90, 200, 'w', 'B_II', '4 km', 86.06666666666668, 74.88333333333334, 67.86666666666666),
	(8, 18, 19, 'm', 'B_II', '4 km', 45.63333333333334, 42.51666666666667, 39.383333333333326),
	(8, 20, 24, 'm', 'B_II', '4 km', 44.46666666666667, 41.333333333333336, 38.21666666666667),
	(8, 25, 29, 'm', 'B_II', '4 km', 45.63333333333334, 42.51666666666667, 39.383333333333326),
	(8, 30, 34, 'm', 'B_II', '4 km', 48.75000000000001, 44.46666666666667, 39.78333333333333),
	(8, 35, 39, 'm', 'B_II', '4 km', 50.7, 45.63333333333334, 41.73333333333333),
	(8, 40, 44, 'm', 'B_II', '4 km', 51.483333333333334, 47.18333333333333, 42.11666666666667),
	(8, 45, 49, 'm', 'B_II', '4 km', 53.43333333333333, 48.75000000000001, 42.9),
	(8, 50, 54, 'm', 'B_II', '4 km', 55.383333333333326, 49.916666666666664, 44.849999999999994),
	(8, 55, 59, 'm', 'B_II', '4 km', 56.93333333333334, 50.7, 46.016666666666666),
	(8, 60, 64, 'm', 'B_II', '4 km', 59.08333333333333, 52.65, 47.18333333333333),
	(8, 65, 69, 'm', 'B_II', '4 km', 60.96666666666666, 54.21666666666667, 48.36666666666667),
	(8, 70, 74, 'm', 'B_II', '4 km', 63.56666666666667, 56.16666666666667, 50.7),
	(8, 75, 79, 'm', 'B_II', '4 km', 67.21666666666665, 59.08333333333333, 56.16666666666667),
	(8, 80, 84, 'm', 'B_II', '4 km', 71.36666666666666, 62.199999999999996, 56.16666666666667),
	(8, 85, 89, 'm', 'B_II', '4 km', 74.88333333333334, 65.71666666666668, 58.88333333333333),
	(8, 90, 200, 'm', 'B_II', '4 km', 80.15, 69.68333333333332, 62.400000000000006),
	(10, 0, 7, 'w', 'B_II', '', 4.8, 7.2, 9.6),
	(10, 8, 9, 'w', 'B_II', '', 7.2, 9.6, 12.0),
	(10, 10, 11, 'w', 'B_II', '', 8.8, 12.0, 14.4),
	(10, 0, 7, 'm', 'B_II', '', 9.6, 12.0, 13.6),
	(10, 8, 9, 'm', 'B_II', '', 13.6, 16.0, 18.4),
	(10, 10, 11, 'm', 'B_II', '', 16.8, 20.0, 22.4),
	(11, 12, 13, 'w', 'B_II', '', 12.0, 14.4, 17.6),
	(11, 14, 15, 'w', 'B_II', '', 16.0, 19.2, 21.6),
	(11, 16, 17, 'w', 'B_II', '', 19.2, 21.6, 24.8),
	(11, 12, 13, 'm', 'B_II', '', 20.8, 24.0, 26.4),
	(11, 14, 15, 'm', 'B_II', '', 24.0, 27.2, 29.6),
	(11, 16, 17, 'm', 'B_II', '', 27.2, 30.4, 33.6),
	(12, 0, 7, 'w', 'B_II', '1 kg', 3.0, 3.4, 4.0),
	(12, 8, 9, 'w', 'B_II', '1 kg', 3.5, 3.9, 4.5),
	(12, 10, 11, 'w', 'B_II', '1 kg', 4.0, 4.4, 5.0),
	(12, 12, 13, 'w', 'B_II', '1 kg', 4.5, 4.9, 5.5),
	(12, 14, 15, 'w', 'B_II', '1 kg', 5.0, 5.4, 6.0),
	(12, 16, 17, 'w', 'B_II', '1 kg', 5.5, 5.9, 6.5),
	(12, 18, 19, 'w', 'B_II', '2 kg', 6.0, 6.4, 7.0),
	(12, 20, 24, 'w', 'B_II', '2 kg', 6.0, 6.4, 7.0),
	(12, 25, 29, 'w', 'B_II', '2 kg', 5.6, 6.2, 6.8),
	(12, 30, 34, 'w', 'B_II', '2 kg', 5.2, 6.0, 6.8),
	(12, 35, 39, 'w', 'B_II', '2 kg', 4.8, 5.8, 6.6),
	(12, 40, 44, 'w', 'B_II', '2 kg', 4.2, 5.4, 6.6),
	(12, 45, 49, 'w', 'B_II', '2 kg', 3.8, 5.2, 6.4),
	(12, 50, 54, 'w', 'B_II', '2 kg', 3.4, 4.8, 6.2),
	(12, 55, 59, 'w', 'B_II', '2 kg', 3.2, 4.6, 6.0),
	(12, 60, 64, 'w', 'B_II', '2 kg', 3.0, 4.4, 5.8),
	(12, 65, 69, 'w', 'B_II', '2 kg', 2.8, 4.2, 5.6),
	(12, 70, 74, 'w', 'B_II', '2 kg', 2.6, 4.0, 5.4),
	(12, 75, 79, 'w', 'B_II', '2 kg', 2.6, 3.8, 5.2),
	(12, 80, 84, 'w', 'B_II', '2 kg', 2.4, 3.8, 5.0),
	(12, 85, 89, 'w', 'B_II', '2 kg', 2.4, 3.6, 4.8),
	(12, 90, 200, 'w', 'B_II', '2 kg', 2.2, 3.4, 4.4),
	(12, 0, 7, 'm', 'B_II', '1 kg', 5.2, 5.8, 6.4),
	(12, 8, 9, 'm', 'B_II', '1 kg', 5.7, 6.3, 6.9),
	(12, 10, 11, 'm', 'B_II', '1 kg', 6.2, 6.8, 7.4),
	(12, 12, 13, 'm', 'B_II', '1 kg', 6.7, 7.3, 7.9),
	(12, 14, 15, 'm', 'B_II', '1 kg', 7.2, 7.8, 8.4),
	(12, 16, 17, 'm', 'B_II', '1 kg', 7.7, 8.3, 8.9),
	(12, 18, 19, 'm', 'B_II', '2 kg', 8.2, 8.8, 9.4),
	(12, 20, 24, 'm', 'B_II', '2 kg', 8.2, 9.0, 9.6),
	(12, 25, 29, 'm', 'B_II', '2 kg', 7.8, 8.6, 9.4),
	(12, 30, 34, 'm', 'B_II', '2 kg', 7.2, 8.2, 9.2),
	(12, 35, 39, 'm', 'B_II', '2 kg', 6.6, 7.8, 9.0),
	(12, 40, 44, 'm', 'B_II', '2 kg', 6.2, 7.4, 8.6),
	(12, 45, 49, 'm', 'B_II', '2 kg', 5.6, 7.0, 8.4),
	(12, 50, 54, 'm', 'B_II', '2 kg', 5.2, 6.8, 8.2),
	(12, 55, 59, 'm', 'B_II', '2 kg', 4.8, 6.6, 8.0),
	(12, 60, 64, 'm', 'B_II', '2 kg', 4.6, 6.2, 7.8),
	(12, 65, 69, 'm', 'B_II', '2 kg', 4.2, 5.8, 7.4),
	(12, 70, 74, 'm', 'B_II', '2 kg', 4.0, 5.6, 7.2),
	(12, 75, 79, 'm', 'B_II', '2 kg', 3.6, 5.2, 6.8),
	(12, 80, 84, 'm', 'B_II', '2 kg', 3.4, 5.0, 6.6),
	(12, 85, 89, 'm', 'B_II', '2 kg', 3.2, 4.8, 6.4),
	(12, 90, 200, 'm', 'B_II', '2 kg', 2.8, 4.4, 6.0),
	(13, 12, 13, 'w', 'B_II', '2 kg', 4.04, 4.46, 4.89),
	(13, 14, 15, 'w', 'B_II', '3 kg', 4.68, 5.1, 5.53),
	(13, 16, 17, 'w', 'B_II', '3 kg', 4.89, 5.31, 5.74),
	(13, 18, 19, 'w', 'B_II', '4 kg', 5.72, 6.16, 6.6),
	(13, 20, 24, 'w', 'B_II', '4 kg', 5.72, 6.16, 6.6),
	(13, 25, 29, 'w', 'B_II', '4 kg', 5.72, 6.16, 6.6),
	(13, 30, 34, 'w', 'B_II', '4 kg', 5.5, 5.94, 6.38),
	(13, 35, 39, 'w', 'B_II', '4 kg', 5.28, 5.72, 6.16),
	(13, 40, 44, 'w', 'B_II', '4 kg', 4.84, 5.28, 5.72),
	(13, 45, 49, 'w', 'B_II', '4 kg', 4.62, 5.06, 5.5),
	(13, 50, 54, 'w', 'B_II', '3 kg', 4.62, 5.28, 6.16),
	(13, 55, 59, 'w', 'B_II', '3 kg', 4.4, 5.06, 5.72),
	(13, 60, 64, 'w', 'B_II', '3 kg', 4.18, 4.84, 5.5),
	(13, 65, 69, 'w', 'B_II', '3 kg', 3.96, 4.62, 5.5),
	(13, 70, 74, 'w', 'B_II', '3 kg', 3.74, 4.4, 5.28),
	(13, 75, 79, 'w', 'B_II', '2 kg', 3.74, 4.62, 5.5),
	(13, 80, 84, 'w', 'B_II', '2 kg', 3.52, 4.4, 5.06),
	(13, 85, 89, 'w', 'B_II', '2 kg', 3.3, 3.96, 4.84),
	(13, 90, 200, 'w', 'B_II', '2 kg', 2.86, 3.74, 4.4),
	(13, 12, 13, 'm', 'B_II', '3 kg', 5.31, 5.74, 6.16),
	(13, 14, 15, 'm', 'B_II', '4 kg', 5.95, 6.38, 6.8),
	(13, 16, 17, 'm', 'B_II', '5 kg', 6.38, 6.8, 7.23),
	(13, 18, 19, 'm', 'B_II', '6 kg', 6.82, 7.26, 7.7),
	(13, 20, 24, 'm', 'B_II', '6 kg', 6.82, 7.48, 7.92),
	(13, 25, 29, 'm', 'B_II', '6 kg', 6.6, 7.26, 7.7),
	(13, 30, 34, 'm', 'B_II', '6 kg', 6.16, 6.82, 7.26),
	(13, 35, 39, 'm', 'B_II', '6 kg', 5.94, 6.38, 7.04),
	(13, 40, 44, 'm', 'B_II', '6 kg', 5.5, 6.16, 6.82),
	(13, 45, 49, 'm', 'B_II', '6 kg', 5.28, 5.94, 6.6),
	(13, 50, 54, 'm', 'B_II', '5 kg', 5.5, 6.16, 7.04),
	(13, 55, 59, 'm', 'B_II', '5 kg', 5.28, 5.94, 6.6),
	(13, 60, 64, 'm', 'B_II', '4 kg', 5.28, 6.16, 7.04),
	(13, 65, 69, 'm', 'B_II', '4 kg', 5.06, 5.94, 6.6),
	(13, 70, 74, 'm', 'B_II', '4 kg', 5.0, 5.8, 6.4),
	(13, 75, 79, 'm', 'B_II', '3 kg', 5.06, 5.72, 6.6),
	(13, 80, 84, 'm', 'B_II', '3 kg', 4.84, 5.5, 6.38),
	(13, 85, 89, 'm', 'B_II', '3 kg', 4.4, 5.28, 5.94),
	(13, 90, 200, 'm', 'B_II', '3 kg', 3.96, 4.62, 5.5),
	(15, 0, 7, 'w', 'B_II', '', 0.74, 0.88, 0.98),
	(15, 8, 9, 'w', 'B_II', '', 0.81, 0.91, 1.05),
	(15, 10, 11, 'w', 'B_II', '', 0.91, 1.02, 1.16),
	(15, 12, 13, 'w', 'B_II', '', 0.98, 1.12, 1.26),
	(15, 14, 15, 'w', 'B_II', '', 1.09, 1.19, 1.33),
	(15, 16, 17, 'w', 'B_II', '', 1.16, 1.26, 1.4),
	(15, 18, 19, 'w', 'B_II', '', 1.16, 1.3, 1.44),
	(15, 20, 24, 'w', 'B_II', '', 1.12, 1.26, 1.4),
	(15, 25, 29, 'w', 'B_II', '', 1.05, 1.19, 1.37),
	(15, 30, 34, 'w', 'B_II', '', 0.95, 1.12, 1.3),
	(15, 35, 39, 'w', 'B_II', '', 0.88, 1.05, 1.26),
	(15, 40, 44, 'w', 'B_II', '', 0.81, 0.98, 1.16),
	(15, 45, 49, 'w', 'B_II', '', 0.77, 0.95, 1.12),
	(15, 50, 54, 'w', 'B_II', '', 0.7, 0.91, 1.09),
	(15, 55, 59, 'w', 'B_II', '', 0.67, 0.84, 1.02),
	(15, 60, 64, 'w', 'B_II', '', 0.67, 0.84, 1.02),
	(15, 65, 69, 'w', 'B_II', '', 0.63, 0.81, 0.98),
	(15, 70, 74, 'w', 'B_II', '', 0.63, 0.81, 0.95),
	(15, 75, 79, 'w', 'B_II', '', 0.63, 0.81, 0.95),
	(15, 80, 84, 'w', 'B_II', '', 0.63, 0.77, 0.91),
	(15, 85, 89, 'w', 'B_II', '', 0.6, 0.74, 0.88),
	(15, 90, 200, 'w', 'B_II', '', 0.56, 0.7, 0.84),
	(15, 0, 7, 'm', 'B_II', '', 0.81, 0.95, 1.05),
	(15, 8, 9, 'm', 'B_II', '', 0.91, 1.05, 1.16),
	(15, 10, 11, 'm', 'B_II', '', 1.05, 1.19, 1.3),
	(15, 12, 13, 'm', 'B_II', '', 1.19, 1.33, 1.44),
	(15, 14, 15, 'm', 'B_II', '', 1.33, 1.44, 1.58),
	(15, 16, 17, 'm', 'B_II', '', 1.44, 1.54, 1.68),
	(15, 18, 19, 'm', 'B_II', '', 1.47, 1.61, 1.75),
	(15, 20, 24, 'm', 'B_II', '', 1.47, 1.61, 1.75),
	(15, 25, 29, 'm', 'B_II', '', 1.44, 1.58, 1.72),
	(15, 30, 34, 'm', 'B_II', '', 1.3, 1.47, 1.65),
	(15, 35, 39, 'm', 'B_II', '', 1.16, 1.37, 1.58),
	(15, 40, 44, 'm', 'B_II', '', 1.09, 1.3, 1.51),
	(15, 45, 49, 'm', 'B_II', '', 1.02, 1.23, 1.44),
	(15, 50, 54, 'm', 'B_II', '', 0.98, 1.19, 1.4),
	(15, 55, 59, 'm', 'B_II', '', 0.95, 1.16, 1.37),
	(15, 60, 64, 'm', 'B_II', '', 0.91, 1.12, 1.33),
	(15, 65, 69, 'm', 'B_II', '', 0.91, 1.12, 1.33),
	(15, 70, 74, 'm', 'B_II', '', 0.88, 1.09, 1.3),
	(15, 75, 79, 'm', 'B_II', '', 0.84, 1.05, 1.26),
	(15, 80, 84, 'm', 'B_II', '', 0.81, 1.02, 1.23),
	(15, 85, 89, 'm', 'B_II', '', 0.7, 0.91, 1.12),
	(15, 90, 200, 'm', 'B_II', '', 0.63, 0.84, 1.05),
	(17, 0, 7, 'w', 'B_II', '30 m', 12.0, 10.7, 9.5),
	(17, 8, 9, 'w', 'B_II', '30 m', 11.1, 9.9, 8.6),
	(17, 10, 11, 'w', 'B_II', '50 m', 16.5, 15.2, 13.7),
	(17, 12, 13, 'w', 'B_II', '50 m', 15.9, 14.4, 12.8),
	(17, 14, 15, 'w', 'B_II', '100 m', 27.9, 25.5, 23.3),
	(17, 16, 17, 'w', 'B_II', '100 m', 26.4, 24.5, 22.5),
	(17, 18, 19, 'w', 'B_II', '100 m', 27.3, 24.8, 23.0),
	(17, 20, 24, 'w', 'B_II', '100 m', 27.8, 25.2, 23.4),
	(17, 25, 29, 'w', 'B_II', '100 m', 28.4, 25.8, 24.0),
	(17, 30, 34, 'w', 'B_II', '100 m', 29.4, 26.7, 24.6),
	(17, 35, 39, 'w', 'B_II', '100 m', 30.6, 27.9, 25.5),
	(17, 40, 44, 'w', 'B_II', '50 m', 16.5, 14.9, 13.2),
	(17, 45, 49, 'w', 'B_II', '50 m', 17.3, 15.5, 13.7),
	(17, 50, 54, 'w', 'B_II', '50 m', 17.9, 16.1, 14.3),
	(17, 55, 59, 'w', 'B_II', '50 m', 18.6, 16.8, 14.9),
	(17, 60, 64, 'w', 'B_II', '50 m', 18.9, 17.1, 15.3),
	(17, 65, 69, 'w', 'B_II', '50 m', 19.2, 17.4, 15.6),
	(17, 70, 74, 'w', 'B_II', '50 m', 19.5, 17.7, 15.9),
	(17, 75, 79, 'w', 'B_II', '50 m', 20.3, 18.5, 16.7),
	(17, 80, 84, 'w', 'B_II', '50 m', 21.5, 19.7, 18.0),
	(17, 85, 89, 'w', 'B_II', '50 m', 23.3, 21.5, 19.8),
	(17, 90, 200, 'w', 'B_II', '50 m', 25.7, 23.9, 22.2),
	(17, 0, 7, 'm', 'B_II', '30 m', 11.6, 10.2, 9.0),
	(17, 8, 9, 'm', 'B_II', '30 m', 10.8, 9.6, 8.6),
	(17, 10, 11, 'm', 'B_II', '50 m', 15.5, 14.0, 12.6),
	(17, 12, 13, 'm', 'B_II', '50 m', 14.6, 13.4, 12.2),
	(17, 14, 15, 'm', 'B_II', '100 m', 25.5, 23.1, 21.2),
	(17, 16, 17, 'm', 'B_II', '100 m', 24.5, 22.2, 20.3),
	(17, 18, 19, 'm', 'B_II', '100 m', 24.0, 21.9, 19.8),
	(17, 20, 24, 'm', 'B_II', '100 m', 23.7, 21.6, 19.5),
	(17, 25, 29, 'm', 'B_II', '100 m', 24.5, 22.2, 20.0),
	(17, 30, 34, 'm', 'B_II', '100 m', 25.2, 22.7, 20.4),
	(17, 35, 39, 'm', 'B_II', '100 m', 26.4, 23.9, 21.3),
	(17, 40, 44, 'm', 'B_II', '50 m', 14.4, 13.1, 11.6),
	(17, 45, 49, 'm', 'B_II', '50 m', 15.0, 13.4, 11.9),
	(17, 50, 54, 'm', 'B_II', '50 m', 15.5, 13.7, 12.3),
	(17, 55, 59, 'm', 'B_II', '50 m', 15.8, 14.1, 12.8),
	(17, 60, 64, 'm', 'B_II', '50 m', 16.2, 14.6, 13.2),
	(17, 65, 69, 'm', 'B_II', '50 m', 16.8, 15.3, 13.7),
	(17, 70, 74, 'm', 'B_II', '50 m', 17.6, 16.1, 14.4),
	(17, 75, 79, 'm', 'B_II', '50 m', 18.3, 16.8, 15.2),
	(17, 80, 84, 'm', 'B_II', '50 m', 19.5, 18.0, 16.4),
	(17, 85, 89, 'm', 'B_II', '50 m', 21.2, 19.7, 18.0),
	(17, 90, 200, 'm', 'B_II', '50 m', 23.3, 21.8, 20.1),
	(18, 0, 7, 'w', 'B_II', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'B_II', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'B_II', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'B_II', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'B_II', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'B_II', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'B_II', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'B_II', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'B_II', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'B_II', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'B_II', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'B_II', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'B_II', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'B_II', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'B_II', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'B_II', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'B_II', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'B_II', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'B_II', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'B_II', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'B_II', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'B_II', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'B_II', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'B_II', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'B_II', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'B_II', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'B_II', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'B_II', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'B_II', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'B_II', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'B_II', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'B_II', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'B_II', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'B_II', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'B_II', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'B_II', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'B_II', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'B_II', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'B_II', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'B_II', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'B_II', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'B_II', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'B_II', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'B_II', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'B_II', '', 57.4, 50.4, 43.4),
	(19, 10, 11, 'w', 'B_II', '', 51.8, 44.8, 37.8),
	(19, 12, 13, 'w', 'B_II', '', 43.4, 37.8, 32.9),
	(19, 14, 15, 'w', 'B_II', '', 37.8, 34.3, 30.1),
	(19, 16, 17, 'w', 'B_II', '', 35.0, 31.5, 28.0),
	(19, 18, 19, 'w', 'B_II', '', 33.6, 30.8, 27.3),
	(19, 20, 24, 'w', 'B_II', '', 34.3, 30.8, 27.3),
	(19, 25, 29, 'w', 'B_II', '', 35.0, 31.5, 28.0),
	(19, 30, 34, 'w', 'B_II', '', 36.4, 32.9, 30.1),
	(19, 35, 39, 'w', 'B_II', '', 38.5, 34.3, 30.8),
	(19, 40, 44, 'w', 'B_II', '', 40.6, 35.7, 31.5),
	(19, 45, 49, 'w', 'B_II', '', 42.7, 37.8, 32.2),
	(19, 50, 54, 'w', 'B_II', '', 44.8, 39.2, 32.9),
	(19, 55, 59, 'w', 'B_II', '', 46.9, 40.6, 33.6),
	(19, 60, 64, 'w', 'B_II', '', 49.0, 42.0, 35.0),
	(19, 65, 69, 'w', 'B_II', '', 50.4, 43.4, 35.7),
	(19, 70, 74, 'w', 'B_II', '', 53.2, 44.8, 37.1),
	(19, 75, 79, 'w', 'B_II', '', 54.6, 46.2, 38.5),
	(19, 80, 84, 'w', 'B_II', '', 56.7, 48.3, 39.9),
	(19, 85, 89, 'w', 'B_II', '', 58.8, 50.4, 42.0),
	(19, 90, 200, 'w', 'B_II', '', 62.3, 53.2, 44.1),
	(19, 8, 9, 'm', 'B_II', '', 53.2, 46.2, 39.2),
	(19, 10, 11, 'm', 'B_II', '', 49.0, 42.7, 36.4),
	(19, 12, 13, 'm', 'B_II', '', 41.3, 36.4, 31.5),
	(19, 14, 15, 'm', 'B_II', '', 33.6, 30.1, 26.6),
	(19, 16, 17, 'm', 'B_II', '', 30.8, 27.3, 23.8),
	(19, 18, 19, 'm', 'B_II', '', 28.7, 25.2, 21.7),
	(19, 20, 24, 'm', 'B_II', '', 28.0, 24.5, 21.0),
	(19, 25, 29, 'm', 'B_II', '', 29.4, 25.2, 21.0),
	(19, 30, 34, 'm', 'B_II', '', 31.5, 25.9, 21.0),
	(19, 35, 39, 'm', 'B_II', '', 33.6, 28.0, 21.7),
	(19, 40, 44, 'm', 'B_II', '', 37.1, 30.1, 23.1),
	(19, 45, 49, 'm', 'B_II', '', 39.9, 32.2, 23.8),
	(19, 50, 54, 'm', 'B_II', '', 42.0, 33.6, 25.2),
	(19, 55, 59, 'm', 'B_II', '', 44.8, 35.0, 25.9),
	(19, 60, 64, 'm', 'B_II', '', 46.9, 36.4, 26.6),
	(19, 65, 69, 'm', 'B_II', '', 49.0, 37.8, 27.3),
	(19, 70, 74, 'm', 'B_II', '', 50.4, 39.9, 28.0),
	(19, 75, 79, 'm', 'B_II', '', 52.5, 41.3, 30.1),
	(19, 80, 84, 'm', 'B_II', '', 54.6, 44.1, 32.2),
	(19, 85, 89, 'm', 'B_II', '', 57.4, 46.2, 34.3),
	(19, 90, 200, 'm', 'B_II', '', 60.9, 49.7, 37.8),
	(21, 10, 11, 'w', 'B_II', '', 0.56, 0.63, 0.7),
	(21, 12, 13, 'w', 'B_II', '', 0.63, 0.7, 0.77),
	(21, 14, 15, 'w', 'B_II', '', 0.67, 0.74, 0.81),
	(21, 16, 17, 'w', 'B_II', '', 0.74, 0.81, 0.88),
	(21, 18, 19, 'w', 'B_II', '', 0.77, 0.84, 0.91),
	(21, 20, 24, 'w', 'B_II', '', 0.77, 0.84, 0.91),
	(21, 25, 29, 'w', 'B_II', '', 0.74, 0.81, 0.88),
	(21, 30, 34, 'w', 'B_II', '', 0.7, 0.77, 0.84),
	(21, 35, 39, 'w', 'B_II', '', 0.67, 0.74, 0.81),
	(21, 40, 44, 'w', 'B_II', '', 0.63, 0.7, 0.77),
	(21, 45, 49, 'w', 'B_II', '', 0.63, 0.7, 0.77),
	(21, 50, 54, 'w', 'B_II', '', 0.6, 0.67, 0.74),
	(21, 55, 59, 'w', 'B_II', '', 0.56, 0.63, 0.7),
	(21, 60, 64, 'w', 'B_II', '', 0.53, 0.6, 0.67),
	(21, 65, 69, 'w', 'B_II', '', 0.53, 0.6, 0.67),
	(21, 70, 74, 'w', 'B_II', '', 0.49, 0.56, 0.63),
	(21, 75, 79, 'w', 'B_II', '', 0.46, 0.53, 0.6),
	(21, 80, 84, 'w', 'B_II', '', 0.46, 0.53, 0.6),
	(21, 85, 89, 'w', 'B_II', '', 0.42, 0.49, 0.56),
	(21, 90, 200, 'w', 'B_II', '', 0.39, 0.42, 0.46),
	(21, 10, 11, 'm', 'B_II', '', 0.6, 0.67, 0.74),
	(21, 12, 13, 'm', 'B_II', '', 0.67, 0.74, 0.81),
	(21, 14, 15, 'm', 'B_II', '', 0.77, 0.84, 0.91),
	(21, 16, 17, 'm', 'B_II', '', 0.84, 0.91, 0.98),
	(21, 18, 19, 'm', 'B_II', '', 0.91, 0.98, 1.05),
	(21, 20, 24, 'm', 'B_II', '', 0.95, 1.02, 1.09),
	(21, 25, 29, 'm', 'B_II', '', 0.91, 0.98, 1.05),
	(21, 30, 34, 'm', 'B_II', '', 0.91, 0.98, 1.05),
	(21, 35, 39, 'm', 'B_II', '', 0.88, 0.95, 1.02),
	(21, 40, 44, 'm', 'B_II', '', 0.84, 0.91, 0.98),
	(21, 45, 49, 'm', 'B_II', '', 0.81, 0.88, 0.95),
	(21, 50, 54, 'm', 'B_II', '', 0.74, 0.81, 0.88),
	(21, 55, 59, 'm', 'B_II', '', 0.7, 0.77, 0.84),
	(21, 60, 64, 'm', 'B_II', '', 0.67, 0.74, 0.81),
	(21, 65, 69, 'm', 'B_II', '', 0.6, 0.7, 0.77),
	(21, 70, 74, 'm', 'B_II', '', 0.56, 0.67, 0.74),
	(21, 75, 79, 'm', 'B_II', '', 0.53, 0.63, 0.7),
	(21, 80, 84, 'm', 'B_II', '', 0.53, 0.6, 0.67),
	(21, 85, 89, 'm', 'B_II', '', 0.49, 0.56, 0.63),
	(21, 90, 200, 'm', 'B_II', '', 0.46, 0.53, 0.6),
	(23, 0, 7, 'w', 'B_II', '', 1.41, 1.62, 1.83),
	(23, 8, 9, 'w', 'B_II', '', 1.51, 1.72, 1.93),
	(23, 10, 11, 'w', 'B_II', '', 1.61, 1.82, 2.03),
	(23, 12, 13, 'w', 'B_II', '', 1.96, 2.17, 2.38),
	(23, 14, 15, 'w', 'B_II', '', 2.24, 2.45, 2.66),
	(23, 16, 17, 'w', 'B_II', '', 2.38, 2.59, 2.8),
	(23, 18, 19, 'w', 'B_II', '', 2.38, 2.59, 2.8),
	(23, 20, 24, 'w', 'B_II', '', 2.38, 2.59, 2.8),
	(23, 25, 29, 'w', 'B_II', '', 2.31, 2.52, 2.73),
	(23, 30, 34, 'w', 'B_II', '', 2.24, 2.45, 2.66),
	(23, 35, 39, 'w', 'B_II', '', 2.17, 2.38, 2.59),
	(23, 40, 44, 'w', 'B_II', '', 2.1, 2.31, 2.52),
	(23, 45, 49, 'w', 'B_II', '', 1.96, 2.24, 2.45),
	(23, 50, 54, 'w', 'B_II', '', 1.82, 2.1, 2.38),
	(23, 55, 59, 'w', 'B_II', '', 1.75, 2.03, 2.31),
	(23, 60, 64, 'w', 'B_II', '', 1.68, 1.96, 2.24),
	(23, 65, 69, 'w', 'B_II', '', 1.61, 1.89, 2.17),
	(23, 70, 74, 'w', 'B_II', '', 1.47, 1.75, 2.03),
	(23, 75, 79, 'w', 'B_II', '', 1.26, 1.54, 1.82),
	(23, 80, 84, 'w', 'B_II', '', 1.12, 1.4, 1.68),
	(23, 85, 89, 'w', 'B_II', '', 0.91, 1.19, 1.47),
	(23, 90, 200, 'w', 'B_II', '', 0.77, 1.05, 1.33),
	(23, 0, 7, 'm', 'B_II', '', 1.62, 1.83, 2.04),
	(23, 8, 9, 'm', 'B_II', '', 1.72, 1.93, 2.14),
	(23, 10, 11, 'm', 'B_II', '', 1.82, 2.03, 2.24),
	(23, 12, 13, 'm', 'B_II', '', 2.24, 2.45, 2.66),
	(23, 14, 15, 'm', 'B_II', '', 2.66, 2.87, 3.08),
	(23, 16, 17, 'm', 'B_II', '', 3.01, 3.22, 3.43),
	(23, 18, 19, 'm', 'B_II', '', 3.15, 3.36, 3.57),
	(23, 20, 24, 'm', 'B_II', '', 3.08, 3.29, 3.5),
	(23, 25, 29, 'm', 'B_II', '', 3.01, 3.22, 3.43),
	(23, 30, 34, 'm', 'B_II', '', 2.94, 3.15, 3.36),
	(23, 35, 39, 'm', 'B_II', '', 2.87, 3.08, 3.29),
	(23, 40, 44, 'm', 'B_II', '', 2.73, 3.01, 3.22),
	(23, 45, 49, 'm', 'B_II', '', 2.59, 2.87, 3.15),
	(23, 50, 54, 'm', 'B_II', '', 2.52, 2.8, 3.08),
	(23, 55, 59, 'm', 'B_II', '', 2.38, 2.66, 2.94),
	(23, 60, 64, 'm', 'B_II', '', 2.24, 2.52, 2.8),
	(23, 65, 69, 'm', 'B_II', '', 2.03, 2.31, 2.59),
	(23, 70, 74, 'm', 'B_II', '', 1.89, 2.17, 2.45),
	(23, 75, 79, 'm', 'B_II', '', 1.68, 2.03, 2.31),
	(23, 80, 84, 'm', 'B_II', '', 1.47, 1.82, 2.17),
	(23, 85, 89, 'm', 'B_II', '', 1.33, 1.68, 2.03),
	(23, 90, 200, 'm', 'B_II', '', 1.12, 1.47, 1.82),
	(25, 12, 13, 'w', 'B_II', '', 13.6, 15.6, 17.6),
	(25, 14, 15, 'w', 'B_II', '', 15.6, 18.0, 20.4),
	(25, 16, 17, 'w', 'B_II', '', 17.6, 20.0, 22.4),
	(25, 18, 19, 'w', 'B_II', '', 18.8, 21.2, 23.2),
	(25, 20, 24, 'w', 'B_II', '', 19.2, 21.6, 23.6),
	(25, 25, 29, 'w', 'B_II', '', 19.2, 21.6, 23.6),
	(25, 30, 34, 'w', 'B_II', '', 17.6, 20.0, 22.0),
	(25, 35, 39, 'w', 'B_II', '', 16.8, 19.2, 21.2),
	(25, 40, 44, 'w', 'B_II', '', 15.6, 18.0, 20.0),
	(25, 45, 49, 'w', 'B_II', '', 14.8, 17.2, 19.2),
	(25, 50, 54, 'w', 'B_II', '', 13.2, 16.0, 18.4),
	(25, 55, 59, 'w', 'B_II', '', 12.4, 15.2, 17.6),
	(25, 60, 64, 'w', 'B_II', '', 11.6, 14.4, 16.8),
	(25, 65, 69, 'w', 'B_II', '', 10.8, 13.6, 16.0),
	(25, 70, 74, 'w', 'B_II', '', 10.4, 13.2, 15.6),
	(25, 75, 79, 'w', 'B_II', '', 9.6, 12.4, 14.8),
	(25, 80, 84, 'w', 'B_II', '', 8.8, 11.6, 14.0),
	(25, 85, 89, 'w', 'B_II', '', 7.6, 10.4, 12.8),
	(25, 90, 200, 'w', 'B_II', '', 6.0, 8.8, 11.2),
	(25, 12, 13, 'm', 'B_II', '', 15.6, 19.2, 22.0),
	(25, 14, 15, 'm', 'B_II', '', 18.8, 22.4, 25.6),
	(25, 16, 17, 'm', 'B_II', '', 22.0, 25.6, 29.2),
	(25, 18, 19, 'm', 'B_II', '', 25.2, 28.8, 32.4),
	(25, 20, 24, 'm', 'B_II', '', 26.4, 30.4, 33.6),
	(25, 25, 29, 'm', 'B_II', '', 26.0, 30.0, 33.2),
	(25, 30, 34, 'm', 'B_II', '', 24.0, 28.0, 32.0),
	(25, 35, 39, 'm', 'B_II', '', 22.8, 26.8, 30.8),
	(25, 40, 44, 'm', 'B_II', '', 22.4, 26.4, 30.4),
	(25, 45, 49, 'm', 'B_II', '', 21.6, 25.6, 30.0),
	(25, 50, 54, 'm', 'B_II', '', 20.4, 24.8, 29.2),
	(25, 55, 59, 'm', 'B_II', '', 18.8, 23.2, 28.0),
	(25, 60, 64, 'm', 'B_II', '', 18.0, 22.4, 27.2),
	(25, 65, 69, 'm', 'B_II', '', 16.0, 20.4, 24.4),
	(25, 70, 74, 'm', 'B_II', '', 14.8, 19.2, 23.2),
	(25, 75, 79, 'm', 'B_II', '', 12.8, 16.8, 20.8),
	(25, 80, 84, 'm', 'B_II', '', 11.2, 15.2, 19.2),
	(25, 85, 89, 'm', 'B_II', '', 9.6, 13.2, 16.8),
	(25, 90, 200, 'm', 'B_II', '', 8.4, 12.0, 15.6),
	(32, 18, 19, 'w', 'B_II', '', 14.166666666666666, 12.8, 11.45),
	(32, 20, 24, 'w', 'B_II', '', 13.833333333333334, 12.466666666666665, 11.100000000000001),
	(32, 25, 29, 'w', 'B_II', '', 14.049999999999999, 12.7, 11.333333333333332),
	(32, 30, 34, 'w', 'B_II', '', 14.616666666666665, 13.266666666666667, 11.899999999999999),
	(32, 35, 39, 'w', 'B_II', '', 14.966666666666667, 13.6, 12.233333333333334),
	(32, 40, 44, 'w', 'B_II', '', 15.533333333333333, 14.049999999999999, 12.583333333333332),
	(32, 45, 49, 'w', 'B_II', '', 16.200000000000003, 14.616666666666665, 12.8),
	(32, 50, 54, 'w', 'B_II', '', 16.883333333333336, 15.066666666666665, 13.033333333333333),
	(32, 55, 59, 'w', 'B_II', '', 17.566666666666666, 15.533333333333333, 13.483333333333333),
	(32, 60, 64, 'w', 'B_II', '', 18.01666666666667, 15.983333333333333, 13.933333333333334),
	(32, 65, 69, 'w', 'B_II', '', 18.46666666666667, 16.433333333333337, 14.4),
	(32, 70, 74, 'w', 'B_II', '', 18.816666666666663, 16.76666666666667, 14.733333333333333),
	(32, 75, 79, 'w', 'B_II', '', 19.383333333333333, 17.333333333333332, 15.299999999999999),
	(32, 80, 84, 'w', 'B_II', '', 20.166666666666668, 18.13333333333333, 16.099999999999998),
	(32, 85, 89, 'w', 'B_II', '', 21.083333333333336, 19.03333333333333, 17.0),
	(32, 90, 200, 'w', 'B_II', '', 22.099999999999998, 20.066666666666666, 18.01666666666667),
	(32, 18, 19, 'm', 'B_II', '', 12.133333333333333, 10.766666666666667, 9.4),
	(32, 20, 24, 'm', 'B_II', '', 11.783333333333335, 10.433333333333334, 9.066666666666665),
	(32, 25, 29, 'm', 'B_II', '', 12.016666666666666, 10.65, 9.299999999999999),
	(32, 30, 34, 'm', 'B_II', '', 12.583333333333332, 11.216666666666669, 9.866666666666665),
	(32, 35, 39, 'm', 'B_II', '', 13.483333333333333, 11.783333333333335, 10.2),
	(32, 40, 44, 'm', 'B_II', '', 14.283333333333333, 12.583333333333332, 10.766666666666667),
	(32, 45, 49, 'm', 'B_II', '', 15.066666666666665, 13.266666666666667, 11.216666666666669),
	(32, 50, 54, 'm', 'B_II', '', 15.866666666666665, 13.833333333333334, 11.783333333333335),
	(32, 55, 59, 'm', 'B_II', '', 16.200000000000003, 14.166666666666666, 12.133333333333333),
	(32, 60, 64, 'm', 'B_II', '', 16.666666666666664, 14.616666666666665, 12.583333333333332),
	(32, 65, 69, 'm', 'B_II', '', 17.0, 14.966666666666667, 12.916666666666668),
	(32, 70, 74, 'm', 'B_II', '', 17.233333333333334, 15.183333333333332, 13.15),
	(32, 75, 79, 'm', 'B_II', '', 17.683333333333334, 15.633333333333335, 13.6),
	(32, 80, 84, 'm', 'B_II', '', 18.01666666666667, 15.983333333333333, 13.933333333333334),
	(32, 85, 89, 'm', 'B_II', '', 18.700000000000003, 16.666666666666664, 14.616666666666665),
	(32, 90, 200, 'm', 'B_II', '', 20.283333333333335, 18.249999999999996, 16.200000000000003),
	(33, 0, 7, 'w', 'B_II', 'auch als Walking möglich', 4.0, 6.0, 8.500000000000002),
	(33, 8, 9, 'w', 'B_II', 'auch als Walking möglich', 5.0, 7.5, 10.0),
	(33, 10, 11, 'w', 'B_II', 'auch als Walking möglich', 7.5, 10.0, 15.0),
	(33, 12, 13, 'w', 'B_II', 'auch als Walking möglich', 10.0, 15.0, 20.0),
	(33, 14, 15, 'w', 'B_II', 'auch als Walking möglich', 15.0, 20.0, 25.0),
	(33, 16, 17, 'w', 'B_II', 'auch als Walking möglich', 22.5, 30.0, 37.49999999999999),
	(33, 0, 7, 'm', 'B_II', 'auch als Walking möglich', 5.0, 7.5, 10.0),
	(33, 8, 9, 'm', 'B_II', 'auch als Walking möglich', 6.0, 8.500000000000002, 11.500000000000002),
	(33, 10, 11, 'm', 'B_II', 'auch als Walking möglich', 8.500000000000002, 12.500000000000002, 17.5),
	(33, 12, 13, 'm', 'B_II', 'auch als Walking möglich', 12.500000000000002, 17.5, 22.5),
	(33, 14, 15, 'm', 'B_II', 'auch als Walking möglich', 17.5, 22.5, 30.0),
	(33, 16, 17, 'm', 'B_II', 'auch als Walking möglich', 27.5, 35.0, 45.0),
	(39, 0, 7, 'w', 'B_II', '', 182.0, 203.0, 223.0),
	(39, 8, 9, 'w', 'B_II', '', 194.0, 215.0, 237.0),
	(39, 10, 11, 'w', 'B_II', '', 205.0, 228.0, 250.0),
	(39, 12, 13, 'w', 'B_II', '', 216.0, 240.0, 264.0),
	(39, 14, 15, 'w', 'B_II', '', 227.0, 253.0, 278.0),
	(39, 16, 17, 'w', 'B_II', '', 239.0, 265.0, 292.0),
	(39, 18, 19, 'w', 'B_II', '', 329.0, 365.0, 402.0),
	(39, 20, 24, 'w', 'B_II', '', 329.0, 365.0, 402.0),
	(39, 25, 29, 'w', 'B_II', '', 329.0, 365.0, 402.0),
	(39, 30, 34, 'w', 'B_II', '', 317.0, 353.0, 388.0),
	(39, 35, 39, 'w', 'B_II', '', 317.0, 353.0, 388.0),
	(39, 40, 44, 'w', 'B_II', '', 306.0, 340.0, 374.0),
	(39, 45, 49, 'w', 'B_II', '', 295.0, 328.0, 360.0),
	(39, 50, 54, 'w', 'B_II', '', 284.0, 315.0, 347.0),
	(39, 55, 59, 'w', 'B_II', '', 272.0, 303.0, 333.0),
	(39, 60, 64, 'w', 'B_II', '', 261.0, 290.0, 319.0),
	(39, 65, 69, 'w', 'B_II', '', 250.0, 278.0, 305.0),
	(39, 70, 74, 'w', 'B_II', '', 239.0, 265.0, 292.0),
	(39, 75, 79, 'w', 'B_II', '', 227.0, 253.0, 278.0),
	(39, 80, 84, 'w', 'B_II', '', 216.0, 240.0, 264.0),
	(39, 85, 89, 'w', 'B_II', '', 205.0, 228.0, 250.0),
	(39, 90, 200, 'w', 'B_II', '', 194.0, 215.0, 237.0),
	(39, 0, 7, 'm', 'B_II', '', 241.0, 268.0, 294.0),
	(39, 8, 9, 'm', 'B_II', '', 252.0, 280.0, 308.0),
	(39, 10, 11, 'm', 'B_II', '', 263.0, 293.0, 322.0),
	(39, 12, 13, 'm', 'B_II', '', 275.0, 305.0, 336.0),
	(39, 14, 15, 'm', 'B_II', '', 286.0, 318.0, 349.0),
	(39, 16, 17, 'm', 'B_II', '', 297.0, 330.0, 363.0),
	(39, 18, 19, 'm', 'B_II', '', 387.0, 430.0, 473.0),
	(39, 20, 24, 'm', 'B_II', '', 387.0, 430.0, 473.0),
	(39, 25, 29, 'm', 'B_II', '', 387.0, 430.0, 473.0),
	(39, 30, 34, 'm', 'B_II', '', 376.0, 418.0, 459.0),
	(39, 35, 39, 'm', 'B_II', '', 376.0, 418.0, 459.0),
	(39, 40, 44, 'm', 'B_II', '', 365.0, 405.0, 446.0),
	(39, 45, 49, 'm', 'B_II', '', 353.0, 393.0, 432.0),
	(39, 50, 54, 'm', 'B_II', '', 342.0, 380.0, 418.0),
	(39, 55, 59, 'm', 'B_II', '', 331.0, 368.0, 404.0),
	(39, 60, 64, 'm', 'B_II', '', 320.0, 355.0, 391.0),
	(39, 65, 69, 'm', 'B_II', '', 308.0, 343.0, 377.0),
	(39, 70, 74, 'm', 'B_II', '', 297.0, 330.0, 363.0),
	(39, 75, 79, 'm', 'B_II', '', 286.0, 318.0, 349.0),
	(39, 80, 84, 'm', 'B_II', '', 275.0, 305.0, 336.0),
	(39, 85, 89, 'm', 'B_II', '', 263.0, 293.0, 322.0),
	(39, 90, 200, 'm', 'B_II', '', 252.0, 280.0, 308.0),
	(40, 0, 7, 'w', 'B_II', '', 342.0, 380.0, 418.0),
	(40, 8, 9, 'w', 'B_II', '', 356.0, 395.0, 435.0),
	(40, 10, 11, 'w', 'B_II', '', 369.0, 410.0, 451.0),
	(40, 12, 13, 'w', 'B_II', '', 383.0, 425.0, 468.0),
	(40, 14, 15, 'w', 'B_II', '', 396.0, 440.0, 484.0),
	(40, 16, 17, 'w', 'B_II', '', 410.0, 455.0, 501.0),
	(40, 18, 19, 'w', 'B_II', '', 500.0, 555.0, 611.0),
	(40, 20, 24, 'w', 'B_II', '', 500.0, 555.0, 611.0),
	(40, 25, 29, 'w', 'B_II', '', 500.0, 555.0, 611.0),
	(40, 30, 34, 'w', 'B_II', '', 486.0, 540.0, 594.0),
	(40, 35, 39, 'w', 'B_II', '', 486.0, 540.0, 594.0),
	(40, 40, 44, 'w', 'B_II', '', 473.0, 525.0, 578.0),
	(40, 45, 49, 'w', 'B_II', '', 459.0, 510.0, 561.0),
	(40, 50, 54, 'w', 'B_II', '', 446.0, 495.0, 545.0),
	(40, 55, 59, 'w', 'B_II', '', 432.0, 480.0, 528.0),
	(40, 60, 64, 'w', 'B_II', '', 419.0, 465.0, 512.0),
	(40, 65, 69, 'w', 'B_II', '', 405.0, 450.0, 495.0),
	(40, 70, 74, 'w', 'B_II', '', 392.0, 435.0, 479.0),
	(40, 75, 79, 'w', 'B_II', '', 378.0, 420.0, 462.0),
	(40, 80, 84, 'w', 'B_II', '', 365.0, 405.0, 446.0),
	(40, 85, 89, 'w', 'B_II', '', 351.0, 390.0, 429.0),
	(40, 90, 200, 'w', 'B_II', '', 338.0, 375.0, 413.0),
	(40, 0, 7, 'm', 'B_II', '', 410.0, 455.0, 501.0),
	(40, 8, 9, 'm', 'B_II', '', 423.0, 470.0, 517.0),
	(40, 10, 11, 'm', 'B_II', '', 437.0, 485.0, 534.0),
	(40, 12, 13, 'm', 'B_II', '', 450.0, 500.0, 550.0),
	(40, 14, 15, 'm', 'B_II', '', 464.0, 515.0, 567.0),
	(40, 16, 17, 'm', 'B_II', '', 477.0, 530.0, 583.0),
	(40, 18, 19, 'm', 'B_II', '', 567.0, 630.0, 693.0),
	(40, 20, 24, 'm', 'B_II', '', 567.0, 630.0, 693.0),
	(40, 25, 29, 'm', 'B_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'B_II', '', 554.0, 615.0, 677.0),
	(40, 35, 39, 'm', 'B_II', '', 554.0, 615.0, 677.0),
	(40, 40, 44, 'm', 'B_II', '', 540.0, 600.0, 660.0),
	(40, 45, 49, 'm', 'B_II', '', 527.0, 585.0, 644.0),
	(40, 50, 54, 'm', 'B_II', '', 513.0, 570.0, 627.0),
	(40, 55, 59, 'm', 'B_II', '', 500.0, 555.0, 611.0),
	(40, 60, 64, 'm', 'B_II', '', 486.0, 540.0, 594.0),
	(40, 65, 69, 'm', 'B_II', '', 473.0, 525.0, 578.0),
	(40, 70, 74, 'm', 'B_II', '', 459.0, 510.0, 561.0),
	(40, 75, 79, 'm', 'B_II', '', 446.0, 495.0, 545.0),
	(40, 80, 84, 'm', 'B_II', '', 432.0, 480.0, 528.0),
	(40, 85, 89, 'm', 'B_II', '', 419.0, 465.0, 512.0),
	(40, 90, 200, 'm', 'B_II', '', 405.0, 450.0, 495.0),
	(41, 0, 7, 'w', 'B_II', '', 275.0, 305.0, 336.0),
	(41, 8, 9, 'w', 'B_II', '', 288.0, 320.0, 352.0),
	(41, 10, 11, 'w', 'B_II', '', 302.0, 335.0, 369.0),
	(41, 12, 13, 'w', 'B_II', '', 315.0, 350.0, 385.0),
	(41, 14, 15, 'w', 'B_II', '', 329.0, 365.0, 402.0),
	(41, 16, 17, 'w', 'B_II', '', 342.0, 380.0, 418.0),
	(41, 18, 19, 'w', 'B_II', '', 432.0, 480.0, 528.0),
	(41, 20, 24, 'w', 'B_II', '', 432.0, 480.0, 528.0),
	(41, 25, 29, 'w', 'B_II', '', 432.0, 480.0, 528.0),
	(41, 30, 34, 'w', 'B_II', '', 419.0, 465.0, 512.0),
	(41, 35, 39, 'w', 'B_II', '', 419.0, 465.0, 512.0),
	(41, 40, 44, 'w', 'B_II', '', 405.0, 450.0, 495.0),
	(41, 45, 49, 'w', 'B_II', '', 392.0, 435.0, 479.0),
	(41, 50, 54, 'w', 'B_II', '', 378.0, 420.0, 462.0),
	(41, 55, 59, 'w', 'B_II', '', 365.0, 405.0, 446.0),
	(41, 60, 64, 'w', 'B_II', '', 351.0, 390.0, 429.0),
	(41, 65, 69, 'w', 'B_II', '', 338.0, 375.0, 413.0),
	(41, 70, 74, 'w', 'B_II', '', 324.0, 360.0, 396.0),
	(41, 75, 79, 'w', 'B_II', '', 311.0, 345.0, 380.0),
	(41, 80, 84, 'w', 'B_II', '', 297.0, 330.0, 363.0),
	(41, 85, 89, 'w', 'B_II', '', 284.0, 315.0, 347.0),
	(41, 90, 200, 'w', 'B_II', '', 270.0, 300.0, 330.0),
	(41, 0, 7, 'm', 'B_II', '', 338.0, 375.0, 413.0),
	(41, 8, 9, 'm', 'B_II', '', 351.0, 390.0, 429.0),
	(41, 10, 11, 'm', 'B_II', '', 365.0, 405.0, 446.0),
	(41, 12, 13, 'm', 'B_II', '', 378.0, 420.0, 462.0),
	(41, 14, 15, 'm', 'B_II', '', 392.0, 435.0, 479.0),
	(41, 16, 17, 'm', 'B_II', '', 405.0, 450.0, 495.0),
	(41, 18, 19, 'm', 'B_II', '', 495.0, 550.0, 605.0),
	(41, 20, 24, 'm', 'B_II', '', 495.0, 550.0, 605.0),
	(41, 25, 29, 'm', 'B_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'B_II', '', 482.0, 535.0, 589.0),
	(41, 35, 39, 'm', 'B_II', '', 482.0, 535.0, 589.0),
	(41, 40, 44, 'm', 'B_II', '', 468.0, 520.0, 572.0),
	(41, 45, 49, 'm', 'B_II', '', 455.0, 505.0, 556.0),
	(41, 50, 54, 'm', 'B_II', '', 441.0, 490.0, 539.0),
	(41, 55, 59, 'm', 'B_II', '', 428.0, 475.0, 523.0),
	(41, 60, 64, 'm', 'B_II', '', 414.0, 460.0, 506.0),
	(41, 65, 69, 'm', 'B_II', '', 401.0, 445.0, 490.0),
	(41, 70, 74, 'm', 'B_II', '', 387.0, 430.0, 473.0),
	(41, 75, 79, 'm', 'B_II', '', 374.0, 415.0, 457.0),
	(41, 80, 84, 'm', 'B_II', '', 360.0, 400.0, 440.0),
	(41, 85, 89, 'm', 'B_II', '', 347.0, 385.0, 424.0),
	(41, 90, 200, 'm', 'B_II', '', 333.0, 370.0, 407.0),
	(42, 0, 7, 'w', 'B_II', '', 279.0, 310.0, 341.0),
	(42, 8, 9, 'w', 'B_II', '', 293.0, 325.0, 358.0),
	(42, 10, 11, 'w', 'B_II', '', 306.0, 340.0, 374.0),
	(42, 12, 13, 'w', 'B_II', '', 320.0, 355.0, 391.0),
	(42, 14, 15, 'w', 'B_II', '', 333.0, 370.0, 407.0),
	(42, 16, 17, 'w', 'B_II', '', 347.0, 385.0, 424.0),
	(42, 18, 19, 'w', 'B_II', '', 437.0, 485.0, 534.0),
	(42, 20, 24, 'w', 'B_II', '', 437.0, 485.0, 534.0),
	(42, 25, 29, 'w', 'B_II', '', 437.0, 485.0, 534.0),
	(42, 30, 34, 'w', 'B_II', '', 423.0, 470.0, 517.0),
	(42, 35, 39, 'w', 'B_II', '', 423.0, 470.0, 517.0),
	(42, 40, 44, 'w', 'B_II', '', 410.0, 455.0, 501.0),
	(42, 45, 49, 'w', 'B_II', '', 396.0, 440.0, 484.0),
	(42, 50, 54, 'w', 'B_II', '', 383.0, 425.0, 468.0),
	(42, 55, 59, 'w', 'B_II', '', 369.0, 410.0, 451.0),
	(42, 60, 64, 'w', 'B_II', '', 356.0, 395.0, 435.0),
	(42, 65, 69, 'w', 'B_II', '', 342.0, 380.0, 418.0),
	(42, 70, 74, 'w', 'B_II', '', 329.0, 365.0, 402.0),
	(42, 75, 79, 'w', 'B_II', '', 315.0, 350.0, 385.0),
	(42, 80, 84, 'w', 'B_II', '', 302.0, 335.0, 369.0),
	(42, 85, 89, 'w', 'B_II', '', 288.0, 320.0, 352.0),
	(42, 90, 200, 'w', 'B_II', '', 275.0, 305.0, 336.0),
	(42, 0, 7, 'm', 'B_II', '', 342.0, 380.0, 418.0),
	(42, 8, 9, 'm', 'B_II', '', 356.0, 395.0, 435.0),
	(42, 10, 11, 'm', 'B_II', '', 369.0, 410.0, 451.0),
	(42, 12, 13, 'm', 'B_II', '', 383.0, 425.0, 468.0),
	(42, 14, 15, 'm', 'B_II', '', 396.0, 440.0, 484.0),
	(42, 16, 17, 'm', 'B_II', '', 410.0, 455.0, 501.0),
	(42, 18, 19, 'm', 'B_II', '', 500.0, 555.0, 611.0),
	(42, 20, 24, 'm', 'B_II', '', 500.0, 555.0, 611.0),
	(42, 25, 29, 'm', 'B_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'B_II', '', 486.0, 540.0, 594.0),
	(42, 35, 39, 'm', 'B_II', '', 486.0, 540.0, 594.0),
	(42, 40, 44, 'm', 'B_II', '', 473.0, 525.0, 578.0),
	(42, 45, 49, 'm', 'B_II', '', 459.0, 510.0, 561.0),
	(42, 50, 54, 'm', 'B_II', '', 446.0, 495.0, 545.0),
	(42, 55, 59, 'm', 'B_II', '', 432.0, 480.0, 528.0),
	(42, 60, 64, 'm', 'B_II', '', 419.0, 465.0, 512.0),
	(42, 65, 69, 'm', 'B_II', '', 405.0, 450.0, 495.0),
	(42, 70, 74, 'm', 'B_II', '', 392.0, 435.0, 479.0),
	(42, 75, 79, 'm', 'B_II', '', 378.0, 420.0, 462.0),
	(42, 80, 84, 'm', 'B_II', '', 365.0, 405.0, 446.0),
	(42, 85, 89, 'm', 'B_II', '', 351.0, 390.0, 429.0),
	(42, 90, 200, 'm', 'B_II', '', 338.0, 375.0, 413.0),
	(44, 12, 13, 'w', 'B_II', '', 6.86, 7.59, 8.31),
	(44, 14, 15, 'w', 'B_II', '', 7.95, 8.67, 9.39),
	(44, 16, 17, 'w', 'B_II', '', 8.31, 9.03, 9.75),
	(44, 18, 19, 'w', 'B_II', '', 9.72, 10.47, 11.22),
	(44, 20, 24, 'w', 'B_II', '', 9.72, 10.47, 11.22),
	(44, 25, 29, 'w', 'B_II', '', 9.72, 10.47, 11.22),
	(44, 30, 34, 'w', 'B_II', '', 9.35, 10.1, 10.85),
	(44, 35, 39, 'w', 'B_II', '', 8.98, 9.72, 10.47),
	(44, 40, 44, 'w', 'B_II', '', 8.23, 8.98, 9.72),
	(44, 45, 49, 'w', 'B_II', '', 7.85, 8.6, 9.35),
	(44, 50, 54, 'w', 'B_II', '', 7.85, 8.98, 10.47),
	(44, 55, 59, 'w', 'B_II', '', 7.48, 8.6, 9.72),
	(44, 60, 64, 'w', 'B_II', '', 7.11, 8.23, 9.35),
	(44, 65, 69, 'w', 'B_II', '', 6.73, 7.85, 9.35),
	(44, 70, 74, 'w', 'B_II', '', 6.36, 7.48, 8.98),
	(44, 75, 79, 'w', 'B_II', '', 6.36, 7.85, 9.35),
	(44, 80, 84, 'w', 'B_II', '', 5.98, 7.48, 8.6),
	(44, 85, 89, 'w', 'B_II', '', 5.61, 6.73, 8.23),
	(44, 90, 200, 'w', 'B_II', '', 4.86, 6.36, 7.48),
	(44, 12, 13, 'm', 'B_II', '', 9.03, 9.75, 10.48),
	(44, 14, 15, 'm', 'B_II', '', 10.12, 10.84, 11.56),
	(44, 16, 17, 'm', 'B_II', '', 10.84, 11.56, 12.28),
	(44, 18, 19, 'm', 'B_II', '', 11.59, 12.34, 13.09),
	(44, 20, 24, 'm', 'B_II', '', 11.59, 12.72, 13.46),
	(44, 25, 29, 'm', 'B_II', '', 11.22, 12.34, 13.09),
	(44, 30, 34, 'm', 'B_II', '', 10.47, 11.59, 12.34),
	(44, 35, 39, 'm', 'B_II', '', 10.1, 10.85, 11.97),
	(44, 40, 44, 'm', 'B_II', '', 9.35, 10.47, 11.59),
	(44, 45, 49, 'm', 'B_II', '', 8.98, 10.1, 11.22),
	(44, 50, 54, 'm', 'B_II', '', 9.35, 10.47, 11.97),
	(44, 55, 59, 'm', 'B_II', '', 8.98, 10.1, 11.22),
	(44, 60, 64, 'm', 'B_II', '', 8.98, 10.47, 11.97),
	(44, 65, 69, 'm', 'B_II', '', 8.6, 10.1, 11.22),
	(44, 70, 74, 'm', 'B_II', '', 8.5, 9.86, 10.88),
	(44, 75, 79, 'm', 'B_II', '', 8.6, 9.72, 11.22),
	(44, 80, 84, 'm', 'B_II', '', 8.23, 9.35, 10.85),
	(44, 85, 89, 'm', 'B_II', '', 7.48, 8.98, 10.1),
	(44, 90, 200, 'm', 'B_II', '', 6.73, 7.85, 9.35),
	(47, 0, 7, 'w', 'B_II', '30 m', 24.0, 21.3, 18.9),
	(47, 8, 9, 'w', 'B_II', '30 m', 22.2, 19.8, 17.1),
	(47, 10, 11, 'w', 'B_II', '50 m', 33.0, 30.3, 27.3),
	(47, 12, 13, 'w', 'B_II', '50 m', 31.8, 28.8, 25.5),
	(47, 14, 15, 'w', 'B_II', '100 m', 55.8, 51.0, 46.5),
	(47, 16, 17, 'w', 'B_II', '100 m', 52.8, 48.9, 45.0),
	(47, 18, 19, 'w', 'B_II', '100 m', 54.6, 49.5, 45.9),
	(47, 20, 24, 'w', 'B_II', '100 m', 55.5, 50.4, 46.8),
	(47, 25, 29, 'w', 'B_II', '100 m', 56.7, 51.6, 48.0),
	(47, 30, 34, 'w', 'B_II', '100 m', 58.8, 53.4, 49.2),
	(47, 35, 39, 'w', 'B_II', '100 m', 61.2, 55.8, 51.0),
	(47, 40, 44, 'w', 'B_II', '50 m', 33.0, 29.7, 26.4),
	(47, 45, 49, 'w', 'B_II', '50 m', 34.5, 30.9, 27.3),
	(47, 50, 54, 'w', 'B_II', '50 m', 35.7, 32.1, 28.5),
	(47, 55, 59, 'w', 'B_II', '50 m', 37.2, 33.6, 29.7),
	(47, 60, 64, 'w', 'B_II', '50 m', 37.8, 34.2, 30.6),
	(47, 65, 69, 'w', 'B_II', '50 m', 38.4, 34.8, 31.2),
	(47, 70, 74, 'w', 'B_II', '50 m', 39.0, 35.4, 31.8),
	(47, 75, 79, 'w', 'B_II', '50 m', 40.5, 36.9, 33.3),
	(47, 80, 84, 'w', 'B_II', '50 m', 42.9, 39.3, 36.0),
	(47, 85, 89, 'w', 'B_II', '50 m', 46.5, 42.9, 39.6),
	(47, 90, 200, 'w', 'B_II', '50 m', 51.3, 47.7, 44.4),
	(47, 0, 7, 'm', 'B_II', '30 m', 23.1, 20.4, 18.0),
	(47, 8, 9, 'm', 'B_II', '30 m', 21.6, 19.2, 17.1),
	(47, 10, 11, 'm', 'B_II', '50 m', 30.9, 27.9, 25.2),
	(47, 12, 13, 'm', 'B_II', '50 m', 29.1, 26.7, 24.3),
	(47, 14, 15, 'm', 'B_II', '100 m', 51.0, 46.2, 42.3),
	(47, 16, 17, 'm', 'B_II', '100 m', 48.9, 44.4, 40.5),
	(47, 18, 19, 'm', 'B_II', '100 m', 48.0, 43.8, 39.6),
	(47, 20, 24, 'm', 'B_II', '100 m', 47.4, 43.2, 39.0),
	(47, 25, 29, 'm', 'B_II', '100 m', 48.9, 44.4, 39.9),
	(47, 30, 34, 'm', 'B_II', '100 m', 50.4, 45.3, 40.8),
	(47, 35, 39, 'm', 'B_II', '100 m', 52.8, 47.7, 42.6),
	(47, 40, 44, 'm', 'B_II', '50 m', 28.8, 26.1, 23.1),
	(47, 45, 49, 'm', 'B_II', '50 m', 30.0, 26.7, 23.7),
	(47, 50, 54, 'm', 'B_II', '50 m', 30.9, 27.3, 24.6),
	(47, 55, 59, 'm', 'B_II', '50 m', 31.5, 28.2, 25.5),
	(47, 60, 64, 'm', 'B_II', '50 m', 32.4, 29.1, 26.4),
	(47, 65, 69, 'm', 'B_II', '50 m', 33.6, 30.6, 27.3),
	(47, 70, 74, 'm', 'B_II', '50 m', 35.1, 32.1, 28.8),
	(47, 75, 79, 'm', 'B_II', '50 m', 36.6, 33.6, 30.3),
	(47, 80, 84, 'm', 'B_II', '50 m', 39.0, 36.0, 32.7),
	(47, 85, 89, 'm', 'B_II', '50 m', 42.3, 39.3, 36.0),
	(47, 90, 200, 'm', 'B_II', '50 m', 46.5, 43.5, 40.2),
	(53, 0, 7, 'w', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'B_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'B_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'B_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'B_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'B_II', '', 1.0, 2.0, 3.0),
	(57, 0, 7, 'w', 'B_II', '', 10.0, 12.0, 17.0),
	(57, 8, 9, 'w', 'B_II', '', 14.0, 17.0, 22.0),
	(57, 10, 11, 'w', 'B_II', '', 22.0, 24.0, 29.0),
	(57, 0, 7, 'm', 'B_II', '', 12.0, 14.0, 19.0),
	(57, 8, 9, 'm', 'B_II', '', 17.0, 22.0, 26.0),
	(57, 10, 11, 'm', 'B_II', '', 26.0, 31.0, 36.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(4, 8, 9, 'w', 'C_I', '5 km', 37.8, 33.6, 29.4),
	(4, 10, 11, 'w', 'C_I', '10 km', 70.7, 60.199999999999996, 49.7),
	(4, 12, 13, 'w', 'C_I', '10 km', 63.0, 55.3, 46.9),
	(4, 14, 15, 'w', 'C_I', '10 km', 53.199999999999996, 45.49999999999999, 39.9),
	(4, 16, 17, 'w', 'C_I', '10 km', 45.49999999999999, 39.9, 35.0),
	(4, 18, 19, 'w', 'C_I', '10 km', 36.233333333333334, 32.766666666666666, 29.3),
	(4, 20, 24, 'w', 'C_I', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 25, 29, 'w', 'C_I', '10 km', 35.28333333333334, 31.816666666666663, 28.35),
	(4, 30, 34, 'w', 'C_I', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 35, 39, 'w', 'C_I', '10 km', 37.8, 33.383333333333326, 29.616666666666667),
	(4, 40, 44, 'w', 'C_I', '10 km', 40.31666666666666, 34.96666666666666, 31.183333333333334),
	(4, 45, 49, 'w', 'C_I', '10 km', 42.21666666666667, 36.849999999999994, 32.45),
	(4, 50, 54, 'w', 'C_I', '10 km', 43.46666666666667, 38.43333333333333, 33.7),
	(4, 55, 59, 'w', 'C_I', '10 km', 45.050000000000004, 39.68333333333333, 34.96666666666666),
	(4, 60, 64, 'w', 'C_I', '10 km', 46.61666666666666, 40.95, 35.916666666666664),
	(4, 65, 69, 'w', 'C_I', '10 km', 47.56666666666667, 41.9, 36.849999999999994),
	(4, 70, 74, 'w', 'C_I', '10 km', 49.13333333333333, 43.150000000000006, 38.11666666666667),
	(4, 75, 79, 'w', 'C_I', '10 km', 51.35, 44.416666666666664, 39.68333333333333),
	(4, 80, 84, 'w', 'C_I', '10 km', 53.233333333333334, 47.25, 41.26666666666666),
	(4, 85, 89, 'w', 'C_I', '10 km', 56.383333333333326, 50.400000000000006, 43.46666666666667),
	(4, 90, 200, 'w', 'C_I', '10 km', 58.583333333333336, 52.28333333333334, 45.68333333333333),
	(4, 8, 9, 'm', 'C_I', '5 km', 37.1, 32.9, 28.700000000000003),
	(4, 10, 11, 'm', 'C_I', '10 km', 67.9, 57.400000000000006, 46.9),
	(4, 12, 13, 'm', 'C_I', '10 km', 60.199999999999996, 51.8, 44.1),
	(4, 14, 15, 'm', 'C_I', '10 km', 44.8, 39.199999999999996, 33.6),
	(4, 16, 17, 'm', 'C_I', '10 km', 37.8, 32.9, 28.700000000000003),
	(4, 18, 19, 'm', 'C_I', '10 km', 29.616666666666667, 26.78333333333333, 24.249999999999996),
	(4, 20, 24, 'm', 'C_I', '10 km', 29.3, 26.46666666666667, 23.616666666666667),
	(4, 25, 29, 'm', 'C_I', '10 km', 31.5, 28.03333333333333, 24.566666666666666),
	(4, 30, 34, 'm', 'C_I', '10 km', 33.7, 29.616666666666667, 25.516666666666666),
	(4, 35, 39, 'm', 'C_I', '10 km', 36.53333333333333, 31.5, 26.15),
	(4, 40, 44, 'm', 'C_I', '10 km', 39.68333333333333, 32.766666666666666, 27.4),
	(4, 45, 49, 'm', 'C_I', '10 km', 41.583333333333336, 34.65, 28.35),
	(4, 50, 54, 'm', 'C_I', '10 km', 43.150000000000006, 35.916666666666664, 29.3),
	(4, 55, 59, 'm', 'C_I', '10 km', 44.416666666666664, 36.849999999999994, 29.93333333333333),
	(4, 60, 64, 'm', 'C_I', '10 km', 45.050000000000004, 37.8, 30.233333333333334),
	(4, 65, 69, 'm', 'C_I', '10 km', 45.68333333333333, 38.11666666666667, 30.549999999999997),
	(4, 70, 74, 'm', 'C_I', '10 km', 46.3, 38.75000000000001, 31.183333333333334),
	(4, 75, 79, 'm', 'C_I', '10 km', 46.93333333333334, 39.68333333333333, 32.45),
	(4, 80, 84, 'm', 'C_I', '10 km', 47.88333333333333, 40.63333333333334, 33.383333333333326),
	(4, 85, 89, 'm', 'C_I', '10 km', 48.833333333333336, 41.9, 34.96666666666666),
	(4, 90, 200, 'm', 'C_I', '10 km', 49.766666666666666, 42.833333333333336, 36.53333333333333),
	(7, 0, 7, 'w', 'C_I', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'C_I', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'C_I', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'C_I', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'C_I', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'C_I', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'C_I', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'C_I', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'C_I', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'C_I', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'C_I', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'C_I', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'C_I', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'C_I', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'C_I', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'C_I', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'C_I', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'C_I', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'C_I', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'C_I', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'C_I', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'C_I', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'C_I', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'C_I', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'C_I', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'C_I', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'C_I', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'C_I', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'C_I', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'C_I', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'C_I', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'C_I', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'C_I', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'C_I', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'C_I', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'C_I', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'C_I', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'C_I', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'C_I', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'C_I', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'C_I', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'C_I', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'C_I', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'C_I', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'C_I', '4 km', 54.21666666666667, 51.483333333333334, 48.36666666666667),
	(8, 20, 24, 'w', 'C_I', '4 km', 51.866666666666674, 49.13333333333333, 46.416666666666664),
	(8, 25, 29, 'w', 'C_I', '4 km', 52.26666666666666, 49.53333333333333, 46.8),
	(8, 30, 34, 'w', 'C_I', '4 km', 52.65, 49.916666666666664, 47.13333333333333),
	(8, 35, 39, 'w', 'C_I', '4 km', 54.6, 50.7, 47.383333333333326),
	(8, 40, 44, 'w', 'C_I', '4 km', 56.93333333333334, 52.26666666666666, 47.583333333333336),
	(8, 45, 49, 'w', 'C_I', '4 km', 58.88333333333333, 53.81666666666667, 48.36666666666667),
	(8, 50, 54, 'w', 'C_I', '4 km', 60.833333333333336, 55.383333333333326, 49.916666666666664),
	(8, 55, 59, 'w', 'C_I', '4 km', 62.400000000000006, 56.93333333333334, 51.483333333333334),
	(8, 60, 64, 'w', 'C_I', '4 km', 64.35, 58.11666666666667, 52.65),
	(8, 65, 69, 'w', 'C_I', '4 km', 65.71666666666668, 59.666666666666664, 54.6),
	(8, 70, 74, 'w', 'C_I', '4 km', 68.83333333333333, 61.61666666666666, 56.16666666666667),
	(8, 75, 79, 'w', 'C_I', '4 km', 72.15, 63.56666666666667, 58.11666666666667),
	(8, 80, 84, 'w', 'C_I', '4 km', 76.83333333333333, 66.5, 60.45),
	(8, 85, 89, 'w', 'C_I', '4 km', 81.11666666666666, 70.46666666666667, 63.96666666666666),
	(8, 90, 200, 'w', 'C_I', '4 km', 86.06666666666668, 74.88333333333334, 67.86666666666666),
	(8, 18, 19, 'm', 'C_I', '4 km', 45.63333333333334, 42.51666666666667, 39.383333333333326),
	(8, 20, 24, 'm', 'C_I', '4 km', 44.46666666666667, 41.333333333333336, 38.21666666666667),
	(8, 25, 29, 'm', 'C_I', '4 km', 45.63333333333334, 42.51666666666667, 39.383333333333326),
	(8, 30, 34, 'm', 'C_I', '4 km', 48.75000000000001, 44.46666666666667, 39.78333333333333),
	(8, 35, 39, 'm', 'C_I', '4 km', 50.7, 45.63333333333334, 41.73333333333333),
	(8, 40, 44, 'm', 'C_I', '4 km', 51.483333333333334, 47.18333333333333, 42.11666666666667),
	(8, 45, 49, 'm', 'C_I', '4 km', 53.43333333333333, 48.75000000000001, 42.9),
	(8, 50, 54, 'm', 'C_I', '4 km', 55.383333333333326, 49.916666666666664, 44.849999999999994),
	(8, 55, 59, 'm', 'C_I', '4 km', 56.93333333333334, 50.7, 46.016666666666666),
	(8, 60, 64, 'm', 'C_I', '4 km', 59.08333333333333, 52.65, 47.18333333333333),
	(8, 65, 69, 'm', 'C_I', '4 km', 60.96666666666666, 54.21666666666667, 48.36666666666667),
	(8, 70, 74, 'm', 'C_I', '4 km', 63.56666666666667, 56.16666666666667, 50.7),
	(8, 75, 79, 'm', 'C_I', '4 km', 67.21666666666665, 59.08333333333333, 56.16666666666667),
	(8, 80, 84, 'm', 'C_I', '4 km', 71.36666666666666, 62.199999999999996, 56.16666666666667),
	(8, 85, 89, 'm', 'C_I', '4 km', 74.88333333333334, 65.71666666666668, 58.88333333333333),
	(8, 90, 200, 'm', 'C_I', '4 km', 80.15, 69.68333333333332, 62.400000000000006),
	(10, 0, 7, 'w', 'C_I', '', 4.8, 7.2, 9.6),
	(10, 8, 9, 'w', 'C_I', '', 7.2, 9.6, 12.0),
	(10, 10, 11, 'w', 'C_I', '', 8.8, 12.0, 14.4),
	(10, 0, 7, 'm', 'C_I', '', 9.6, 12.0, 13.6),
	(10, 8, 9, 'm', 'C_I', '', 13.6, 16.0, 18.4),
	(10, 10, 11, 'm', 'C_I', '', 16.8, 20.0, 22.4),
	(11, 12, 13, 'w', 'C_I', '', 12.0, 14.4, 17.6),
	(11, 14, 15, 'w', 'C_I', '', 16.0, 19.2, 21.6),
	(11, 16, 17, 'w', 'C_I', '', 19.2, 21.6, 24.8),
	(11, 12, 13, 'm', 'C_I', '', 20.8, 24.0, 26.4),
	(11, 14, 15, 'm', 'C_I', '', 24.0, 27.2, 29.6),
	(11, 16, 17, 'm', 'C_I', '', 27.2, 30.4, 33.6),
	(12, 0, 7, 'w', 'C_I', '1 kg', 3.0, 3.4, 4.0),
	(12, 8, 9, 'w', 'C_I', '1 kg', 3.5, 3.9, 4.5),
	(12, 10, 11, 'w', 'C_I', '1 kg', 4.0, 4.4, 5.0),
	(12, 12, 13, 'w', 'C_I', '1 kg', 4.5, 4.9, 5.5),
	(12, 14, 15, 'w', 'C_I', '1 kg', 5.0, 5.4, 6.0),
	(12, 16, 17, 'w', 'C_I', '1 kg', 5.5, 5.9, 6.5),
	(12, 18, 19, 'w', 'C_I', '2 kg', 6.0, 6.4, 7.0),
	(12, 20, 24, 'w', 'C_I', '2 kg', 6.0, 6.4, 7.0),
	(12, 25, 29, 'w', 'C_I', '2 kg', 5.6, 6.2, 6.8),
	(12, 30, 34, 'w', 'C_I', '2 kg', 5.2, 6.0, 6.8),
	(12, 35, 39, 'w', 'C_I', '2 kg', 4.8, 5.8, 6.6),
	(12, 40, 44, 'w', 'C_I', '2 kg', 4.2, 5.4, 6.6),
	(12, 45, 49, 'w', 'C_I', '2 kg', 3.8, 5.2, 6.4),
	(12, 50, 54, 'w', 'C_I', '2 kg', 3.4, 4.8, 6.2),
	(12, 55, 59, 'w', 'C_I', '2 kg', 3.2, 4.6, 6.0),
	(12, 60, 64, 'w', 'C_I', '2 kg', 3.0, 4.4, 5.8),
	(12, 65, 69, 'w', 'C_I', '2 kg', 2.8, 4.2, 5.6),
	(12, 70, 74, 'w', 'C_I', '2 kg', 2.6, 4.0, 5.4),
	(12, 75, 79, 'w', 'C_I', '2 kg', 2.6, 3.8, 5.2),
	(12, 80, 84, 'w', 'C_I', '2 kg', 2.4, 3.8, 5.0),
	(12, 85, 89, 'w', 'C_I', '2 kg', 2.4, 3.6, 4.8),
	(12, 90, 200, 'w', 'C_I', '2 kg', 2.2, 3.4, 4.4),
	(12, 0, 7, 'm', 'C_I', '1 kg', 5.2, 5.8, 6.4),
	(12, 8, 9, 'm', 'C_I', '1 kg', 5.7, 6.3, 6.9),
	(12, 10, 11, 'm', 'C_I', '1 kg', 6.2, 6.8, 7.4),
	(12, 12, 13, 'm', 'C_I', '1 kg', 6.7, 7.3, 7.9),
	(12, 14, 15, 'm', 'C_I', '1 kg', 7.2, 7.8, 8.4),
	(12, 16, 17, 'm', 'C_I', '1 kg', 7.7, 8.3, 8.9),
	(12, 18, 19, 'm', 'C_I', '2 kg', 8.2, 8.8, 9.4),
	(12, 20, 24, 'm', 'C_I', '2 kg', 8.2, 9.0, 9.6),
	(12, 25, 29, 'm', 'C_I', '2 kg', 7.8, 8.6, 9.4),
	(12, 30, 34, 'm', 'C_I', '2 kg', 7.2, 8.2, 9.2),
	(12, 35, 39, 'm', 'C_I', '2 kg', 6.6, 7.8, 9.0),
	(12, 40, 44, 'm', 'C_I', '2 kg', 6.2, 7.4, 8.6),
	(12, 45, 49, 'm', 'C_I', '2 kg', 5.6, 7.0, 8.4),
	(12, 50, 54, 'm', 'C_I', '2 kg', 5.2, 6.8, 8.2),
	(12, 55, 59, 'm', 'C_I', '2 kg', 4.8, 6.6, 8.0),
	(12, 60, 64, 'm', 'C_I', '2 kg', 4.6, 6.2, 7.8),
	(12, 65, 69, 'm', 'C_I', '2 kg', 4.2, 5.8, 7.4),
	(12, 70, 74, 'm', 'C_I', '2 kg', 4.0, 5.6, 7.2),
	(12, 75, 79, 'm', 'C_I', '2 kg', 3.6, 5.2, 6.8),
	(12, 80, 84, 'm', 'C_I', '2 kg', 3.4, 5.0, 6.6),
	(12, 85, 89, 'm', 'C_I', '2 kg', 3.2, 4.8, 6.4),
	(12, 90, 200, 'm', 'C_I', '2 kg', 2.8, 4.4, 6.0),
	(13, 12, 13, 'w', 'C_I', '2 kg', 3.56, 3.94, 4.31),
	(13, 14, 15, 'w', 'C_I', '3 kg', 4.13, 4.5, 4.88),
	(13, 16, 17, 'w', 'C_I', '3 kg', 4.31, 4.69, 5.06),
	(13, 18, 19, 'w', 'C_I', '4 kg', 5.53, 5.95, 6.38),
	(13, 20, 24, 'w', 'C_I', '4 kg', 5.53, 5.95, 6.38),
	(13, 25, 29, 'w', 'C_I', '4 kg', 5.53, 5.95, 6.38),
	(13, 30, 34, 'w', 'C_I', '4 kg', 5.31, 5.74, 6.16),
	(13, 35, 39, 'w', 'C_I', '4 kg', 5.1, 5.53, 5.95),
	(13, 40, 44, 'w', 'C_I', '4 kg', 4.68, 5.1, 5.53),
	(13, 45, 49, 'w', 'C_I', '4 kg', 4.46, 4.89, 5.31),
	(13, 50, 54, 'w', 'C_I', '3 kg', 4.46, 5.1, 5.95),
	(13, 55, 59, 'w', 'C_I', '3 kg', 4.25, 4.89, 5.53),
	(13, 60, 64, 'w', 'C_I', '3 kg', 4.04, 4.68, 5.31),
	(13, 65, 69, 'w', 'C_I', '3 kg', 3.83, 4.46, 5.31),
	(13, 70, 74, 'w', 'C_I', '3 kg', 3.61, 4.25, 5.1),
	(13, 75, 79, 'w', 'C_I', '2 kg', 3.61, 4.46, 5.31),
	(13, 80, 84, 'w', 'C_I', '2 kg', 3.4, 4.25, 4.89),
	(13, 85, 89, 'w', 'C_I', '2 kg', 3.19, 3.83, 4.68),
	(13, 90, 200, 'w', 'C_I', '2 kg', 2.76, 3.61, 4.25),
	(13, 12, 13, 'm', 'C_I', '3 kg', 4.69, 5.06, 5.44),
	(13, 14, 15, 'm', 'C_I', '4 kg', 5.25, 5.63, 6.0),
	(13, 16, 17, 'm', 'C_I', '5 kg', 5.63, 6.0, 6.38),
	(13, 18, 19, 'm', 'C_I', '6 kg', 6.59, 7.01, 7.44),
	(13, 20, 24, 'm', 'C_I', '6 kg', 6.59, 7.23, 7.65),
	(13, 25, 29, 'm', 'C_I', '6 kg', 6.38, 7.01, 7.44),
	(13, 30, 34, 'm', 'C_I', '6 kg', 5.95, 6.59, 7.01),
	(13, 35, 39, 'm', 'C_I', '6 kg', 5.74, 6.16, 6.8),
	(13, 40, 44, 'm', 'C_I', '6 kg', 5.31, 5.95, 6.59),
	(13, 45, 49, 'm', 'C_I', '6 kg', 5.1, 5.74, 6.38),
	(13, 50, 54, 'm', 'C_I', '5 kg', 5.31, 5.95, 6.8),
	(13, 55, 59, 'm', 'C_I', '5 kg', 5.1, 5.74, 6.38),
	(13, 60, 64, 'm', 'C_I', '4 kg', 5.1, 5.95, 6.8),
	(13, 65, 69, 'm', 'C_I', '4 kg', 4.89, 5.74, 6.38),
	(13, 70, 74, 'm', 'C_I', '4 kg', 4.8, 5.6, 6.2),
	(13, 75, 79, 'm', 'C_I', '3 kg', 4.89, 5.53, 6.38),
	(13, 80, 84, 'm', 'C_I', '3 kg', 4.68, 5.31, 6.16),
	(13, 85, 89, 'm', 'C_I', '3 kg', 4.25, 5.1, 5.74),
	(13, 90, 200, 'm', 'C_I', '3 kg', 3.83, 4.46, 5.31),
	(15, 0, 7, 'w', 'C_I', '', 0.74, 0.88, 0.98),
	(15, 8, 9, 'w', 'C_I', '', 0.81, 0.91, 1.05),
	(15, 10, 11, 'w', 'C_I', '', 0.91, 1.02, 1.16),
	(15, 12, 13, 'w', 'C_I', '', 0.98, 1.12, 1.26),
	(15, 14, 15, 'w', 'C_I', '', 1.09, 1.19, 1.33),
	(15, 16, 17, 'w', 'C_I', '', 1.16, 1.26, 1.4),
	(15, 18, 19, 'w', 'C_I', '', 1.16, 1.3, 1.44),
	(15, 20, 24, 'w', 'C_I', '', 1.12, 1.26, 1.4),
	(15, 25, 29, 'w', 'C_I', '', 1.05, 1.19, 1.37),
	(15, 30, 34, 'w', 'C_I', '', 0.95, 1.12, 1.3),
	(15, 35, 39, 'w', 'C_I', '', 0.88, 1.05, 1.26),
	(15, 40, 44, 'w', 'C_I', '', 0.81, 0.98, 1.16),
	(15, 45, 49, 'w', 'C_I', '', 0.77, 0.95, 1.12),
	(15, 50, 54, 'w', 'C_I', '', 0.7, 0.91, 1.09),
	(15, 55, 59, 'w', 'C_I', '', 0.67, 0.84, 1.02),
	(15, 60, 64, 'w', 'C_I', '', 0.67, 0.84, 1.02),
	(15, 65, 69, 'w', 'C_I', '', 0.63, 0.81, 0.98),
	(15, 70, 74, 'w', 'C_I', '', 0.63, 0.81, 0.95),
	(15, 75, 79, 'w', 'C_I', '', 0.63, 0.81, 0.95),
	(15, 80, 84, 'w', 'C_I', '', 0.63, 0.77, 0.91),
	(15, 85, 89, 'w', 'C_I', '', 0.6, 0.74, 0.88),
	(15, 90, 200, 'w', 'C_I', '', 0.56, 0.7, 0.84),
	(15, 0, 7, 'm', 'C_I', '', 0.81, 0.95, 1.05),
	(15, 8, 9, 'm', 'C_I', '', 0.91, 1.05, 1.16),
	(15, 10, 11, 'm', 'C_I', '', 1.05, 1.19, 1.3),
	(15, 12, 13, 'm', 'C_I', '', 1.19, 1.33, 1.44),
	(15, 14, 15, 'm', 'C_I', '', 1.33, 1.44, 1.58),
	(15, 16, 17, 'm', 'C_I', '', 1.44, 1.54, 1.68),
	(15, 18, 19, 'm', 'C_I', '', 1.47, 1.61, 1.75),
	(15, 20, 24, 'm', 'C_I', '', 1.47, 1.61, 1.75),
	(15, 25, 29, 'm', 'C_I', '', 1.44, 1.58, 1.72),
	(15, 30, 34, 'm', 'C_I', '', 1.3, 1.47, 1.65),
	(15, 35, 39, 'm', 'C_I', '', 1.16, 1.37, 1.58),
	(15, 40, 44, 'm', 'C_I', '', 1.09, 1.3, 1.51),
	(15, 45, 49, 'm', 'C_I', '', 1.02, 1.23, 1.44),
	(15, 50, 54, 'm', 'C_I', '', 0.98, 1.19, 1.4),
	(15, 55, 59, 'm', 'C_I', '', 0.95, 1.16, 1.37),
	(15, 60, 64, 'm', 'C_I', '', 0.91, 1.12, 1.33),
	(15, 65, 69, 'm', 'C_I', '', 0.91, 1.12, 1.33),
	(15, 70, 74, 'm', 'C_I', '', 0.88, 1.09, 1.3),
	(15, 75, 79, 'm', 'C_I', '', 0.84, 1.05, 1.26),
	(15, 80, 84, 'm', 'C_I', '', 0.81, 1.02, 1.23),
	(15, 85, 89, 'm', 'C_I', '', 0.7, 0.91, 1.12),
	(15, 90, 200, 'm', 'C_I', '', 0.63, 0.84, 1.05),
	(17, 0, 7, 'w', 'C_I', '30 m', 12.0, 10.7, 9.5),
	(17, 8, 9, 'w', 'C_I', '30 m', 11.1, 9.9, 8.6),
	(17, 10, 11, 'w', 'C_I', '50 m', 16.5, 15.2, 13.7),
	(17, 12, 13, 'w', 'C_I', '50 m', 15.9, 14.4, 12.8),
	(17, 14, 15, 'w', 'C_I', '100 m', 27.9, 25.5, 23.3),
	(17, 16, 17, 'w', 'C_I', '100 m', 26.4, 24.5, 22.5),
	(17, 18, 19, 'w', 'C_I', '100 m', 27.3, 24.8, 23.0),
	(17, 20, 24, 'w', 'C_I', '100 m', 27.8, 25.2, 23.4),
	(17, 25, 29, 'w', 'C_I', '100 m', 28.4, 25.8, 24.0),
	(17, 30, 34, 'w', 'C_I', '100 m', 29.4, 26.7, 24.6),
	(17, 35, 39, 'w', 'C_I', '100 m', 30.6, 27.9, 25.5),
	(17, 40, 44, 'w', 'C_I', '50 m', 16.5, 14.9, 13.2),
	(17, 45, 49, 'w', 'C_I', '50 m', 17.3, 15.5, 13.7),
	(17, 50, 54, 'w', 'C_I', '50 m', 17.9, 16.1, 14.3),
	(17, 55, 59, 'w', 'C_I', '50 m', 18.6, 16.8, 14.9),
	(17, 60, 64, 'w', 'C_I', '50 m', 18.9, 17.1, 15.3),
	(17, 65, 69, 'w', 'C_I', '50 m', 19.2, 17.4, 15.6),
	(17, 70, 74, 'w', 'C_I', '50 m', 19.5, 17.7, 15.9),
	(17, 75, 79, 'w', 'C_I', '50 m', 20.3, 18.5, 16.7),
	(17, 80, 84, 'w', 'C_I', '50 m', 21.5, 19.7, 18.0),
	(17, 85, 89, 'w', 'C_I', '50 m', 23.3, 21.5, 19.8),
	(17, 90, 200, 'w', 'C_I', '50 m', 25.7, 23.9, 22.2),
	(17, 0, 7, 'm', 'C_I', '30 m', 11.6, 10.2, 9.0),
	(17, 8, 9, 'm', 'C_I', '30 m', 10.8, 9.6, 8.6),
	(17, 10, 11, 'm', 'C_I', '50 m', 15.5, 14.0, 12.6),
	(17, 12, 13, 'm', 'C_I', '50 m', 14.6, 13.4, 12.2),
	(17, 14, 15, 'm', 'C_I', '100 m', 25.5, 23.1, 21.2),
	(17, 16, 17, 'm', 'C_I', '100 m', 24.5, 22.2, 20.3),
	(17, 18, 19, 'm', 'C_I', '100 m', 24.0, 21.9, 19.8),
	(17, 20, 24, 'm', 'C_I', '100 m', 23.7, 21.6, 19.5),
	(17, 25, 29, 'm', 'C_I', '100 m', 24.5, 22.2, 20.0),
	(17, 30, 34, 'm', 'C_I', '100 m', 25.2, 22.7, 20.4),
	(17, 35, 39, 'm', 'C_I', '100 m', 26.4, 23.9, 21.3),
	(17, 40, 44, 'm', 'C_I', '50 m', 14.4, 13.1, 11.6),
	(17, 45, 49, 'm', 'C_I', '50 m', 15.0, 13.4, 11.9),
	(17, 50, 54, 'm', 'C_I', '50 m', 15.5, 13.7, 12.3),
	(17, 55, 59, 'm', 'C_I', '50 m', 15.8, 14.1, 12.8),
	(17, 60, 64, 'm', 'C_I', '50 m', 16.2, 14.6, 13.2),
	(17, 65, 69, 'm', 'C_I', '50 m', 16.8, 15.3, 13.7),
	(17, 70, 74, 'm', 'C_I', '50 m', 17.6, 16.1, 14.4),
	(17, 75, 79, 'm', 'C_I', '50 m', 18.3, 16.8, 15.2),
	(17, 80, 84, 'm', 'C_I', '50 m', 19.5, 18.0, 16.4),
	(17, 85, 89, 'm', 'C_I', '50 m', 21.2, 19.7, 18.0),
	(17, 90, 200, 'm', 'C_I', '50 m', 23.3, 21.8, 20.1),
	(18, 0, 7, 'w', 'C_I', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'C_I', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'C_I', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'C_I', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'C_I', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'C_I', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'C_I', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'C_I', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'C_I', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'C_I', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'C_I', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'C_I', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'C_I', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'C_I', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'C_I', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'C_I', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'C_I', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'C_I', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'C_I', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'C_I', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'C_I', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'C_I', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'C_I', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'C_I', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'C_I', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'C_I', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'C_I', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'C_I', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'C_I', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'C_I', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'C_I', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'C_I', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'C_I', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'C_I', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'C_I', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'C_I', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'C_I', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'C_I', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'C_I', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'C_I', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'C_I', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'C_I', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'C_I', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'C_I', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'C_I', '', 57.4, 50.4, 43.4),
	(19, 10, 11, 'w', 'C_I', '', 51.8, 44.8, 37.8),
	(19, 12, 13, 'w', 'C_I', '', 43.4, 37.8, 32.9),
	(19, 14, 15, 'w', 'C_I', '', 37.8, 34.3, 30.1),
	(19, 16, 17, 'w', 'C_I', '', 35.0, 31.5, 28.0),
	(19, 18, 19, 'w', 'C_I', '', 33.6, 30.8, 27.3),
	(19, 20, 24, 'w', 'C_I', '', 34.3, 30.8, 27.3),
	(19, 25, 29, 'w', 'C_I', '', 35.0, 31.5, 28.0),
	(19, 30, 34, 'w', 'C_I', '', 36.4, 32.9, 30.1),
	(19, 35, 39, 'w', 'C_I', '', 38.5, 34.3, 30.8),
	(19, 40, 44, 'w', 'C_I', '', 40.6, 35.7, 31.5),
	(19, 45, 49, 'w', 'C_I', '', 42.7, 37.8, 32.2),
	(19, 50, 54, 'w', 'C_I', '', 44.8, 39.2, 32.9),
	(19, 55, 59, 'w', 'C_I', '', 46.9, 40.6, 33.6),
	(19, 60, 64, 'w', 'C_I', '', 49.0, 42.0, 35.0),
	(19, 65, 69, 'w', 'C_I', '', 50.4, 43.4, 35.7),
	(19, 70, 74, 'w', 'C_I', '', 53.2, 44.8, 37.1),
	(19, 75, 79, 'w', 'C_I', '', 54.6, 46.2, 38.5),
	(19, 80, 84, 'w', 'C_I', '', 56.7, 48.3, 39.9),
	(19, 85, 89, 'w', 'C_I', '', 58.8, 50.4, 42.0),
	(19, 90, 200, 'w', 'C_I', '', 62.3, 53.2, 44.1),
	(19, 8, 9, 'm', 'C_I', '', 53.2, 46.2, 39.2),
	(19, 10, 11, 'm', 'C_I', '', 49.0, 42.7, 36.4),
	(19, 12, 13, 'm', 'C_I', '', 41.3, 36.4, 31.5),
	(19, 14, 15, 'm', 'C_I', '', 33.6, 30.1, 26.6),
	(19, 16, 17, 'm', 'C_I', '', 30.8, 27.3, 23.8),
	(19, 18, 19, 'm', 'C_I', '', 28.7, 25.2, 21.7),
	(19, 20, 24, 'm', 'C_I', '', 28.0, 24.5, 21.0),
	(19, 25, 29, 'm', 'C_I', '', 29.4, 25.2, 21.0),
	(19, 30, 34, 'm', 'C_I', '', 31.5, 25.9, 21.0),
	(19, 35, 39, 'm', 'C_I', '', 33.6, 28.0, 21.7),
	(19, 40, 44, 'm', 'C_I', '', 37.1, 30.1, 23.1),
	(19, 45, 49, 'm', 'C_I', '', 39.9, 32.2, 23.8),
	(19, 50, 54, 'm', 'C_I', '', 42.0, 33.6, 25.2),
	(19, 55, 59, 'm', 'C_I', '', 44.8, 35.0, 25.9),
	(19, 60, 64, 'm', 'C_I', '', 46.9, 36.4, 26.6),
	(19, 65, 69, 'm', 'C_I', '', 49.0, 37.8, 27.3),
	(19, 70, 74, 'm', 'C_I', '', 50.4, 39.9, 28.0),
	(19, 75, 79, 'm', 'C_I', '', 52.5, 41.3, 30.1),
	(19, 80, 84, 'm', 'C_I', '', 54.6, 44.1, 32.2),
	(19, 85, 89, 'm', 'C_I', '', 57.4, 46.2, 34.3),
	(19, 90, 200, 'm', 'C_I', '', 60.9, 49.7, 37.8),
	(21, 10, 11, 'w', 'C_I', '', 0.56, 0.63, 0.7),
	(21, 12, 13, 'w', 'C_I', '', 0.63, 0.7, 0.77),
	(21, 14, 15, 'w', 'C_I', '', 0.67, 0.74, 0.81),
	(21, 16, 17, 'w', 'C_I', '', 0.74, 0.81, 0.88),
	(21, 18, 19, 'w', 'C_I', '', 0.77, 0.84, 0.91),
	(21, 20, 24, 'w', 'C_I', '', 0.77, 0.84, 0.91),
	(21, 25, 29, 'w', 'C_I', '', 0.74, 0.81, 0.88),
	(21, 30, 34, 'w', 'C_I', '', 0.7, 0.77, 0.84),
	(21, 35, 39, 'w', 'C_I', '', 0.67, 0.74, 0.81),
	(21, 40, 44, 'w', 'C_I', '', 0.63, 0.7, 0.77),
	(21, 45, 49, 'w', 'C_I', '', 0.63, 0.7, 0.77),
	(21, 50, 54, 'w', 'C_I', '', 0.6, 0.67, 0.74),
	(21, 55, 59, 'w', 'C_I', '', 0.56, 0.63, 0.7),
	(21, 60, 64, 'w', 'C_I', '', 0.53, 0.6, 0.67),
	(21, 65, 69, 'w', 'C_I', '', 0.53, 0.6, 0.67),
	(21, 70, 74, 'w', 'C_I', '', 0.49, 0.56, 0.63),
	(21, 75, 79, 'w', 'C_I', '', 0.46, 0.53, 0.6),
	(21, 80, 84, 'w', 'C_I', '', 0.46, 0.53, 0.6),
	(21, 85, 89, 'w', 'C_I', '', 0.42, 0.49, 0.56),
	(21, 90, 200, 'w', 'C_I', '', 0.39, 0.42, 0.46),
	(21, 10, 11, 'm', 'C_I', '', 0.6, 0.67, 0.74),
	(21, 12, 13, 'm', 'C_I', '', 0.67, 0.74, 0.81),
	(21, 14, 15, 'm', 'C_I', '', 0.77, 0.84, 0.91),
	(21, 16, 17, 'm', 'C_I', '', 0.84, 0.91, 0.98),
	(21, 18, 19, 'm', 'C_I', '', 0.91, 0.98, 1.05),
	(21, 20, 24, 'm', 'C_I', '', 0.95, 1.02, 1.09),
	(21, 25, 29, 'm', 'C_I', '', 0.91, 0.98, 1.05),
	(21, 30, 34, 'm', 'C_I', '', 0.91, 0.98, 1.05),
	(21, 35, 39, 'm', 'C_I', '', 0.88, 0.95, 1.02),
	(21, 40, 44, 'm', 'C_I', '', 0.84, 0.91, 0.98),
	(21, 45, 49, 'm', 'C_I', '', 0.81, 0.88, 0.95),
	(21, 50, 54, 'm', 'C_I', '', 0.74, 0.81, 0.88),
	(21, 55, 59, 'm', 'C_I', '', 0.7, 0.77, 0.84),
	(21, 60, 64, 'm', 'C_I', '', 0.67, 0.74, 0.81),
	(21, 65, 69, 'm', 'C_I', '', 0.6, 0.7, 0.77),
	(21, 70, 74, 'm', 'C_I', '', 0.56, 0.67, 0.74),
	(21, 75, 79, 'm', 'C_I', '', 0.53, 0.63, 0.7),
	(21, 80, 84, 'm', 'C_I', '', 0.53, 0.6, 0.67),
	(21, 85, 89, 'm', 'C_I', '', 0.49, 0.56, 0.63),
	(21, 90, 200, 'm', 'C_I', '', 0.46, 0.53, 0.6),
	(25, 12, 13, 'w', 'C_I', '', 13.6, 15.6, 17.6),
	(25, 14, 15, 'w', 'C_I', '', 15.6, 18.0, 20.4),
	(25, 16, 17, 'w', 'C_I', '', 17.6, 20.0, 22.4),
	(25, 18, 19, 'w', 'C_I', '', 18.8, 21.2, 23.2),
	(25, 20, 24, 'w', 'C_I', '', 19.2, 21.6, 23.6),
	(25, 25, 29, 'w', 'C_I', '', 19.2, 21.6, 23.6),
	(25, 30, 34, 'w', 'C_I', '', 17.6, 20.0, 22.0),
	(25, 35, 39, 'w', 'C_I', '', 16.8, 19.2, 21.2),
	(25, 40, 44, 'w', 'C_I', '', 15.6, 18.0, 20.0),
	(25, 45, 49, 'w', 'C_I', '', 14.8, 17.2, 19.2),
	(25, 50, 54, 'w', 'C_I', '', 13.2, 16.0, 18.4),
	(25, 55, 59, 'w', 'C_I', '', 12.4, 15.2, 17.6),
	(25, 60, 64, 'w', 'C_I', '', 11.6, 14.4, 16.8),
	(25, 65, 69, 'w', 'C_I', '', 10.8, 13.6, 16.0),
	(25, 70, 74, 'w', 'C_I', '', 10.4, 13.2, 15.6),
	(25, 75, 79, 'w', 'C_I', '', 9.6, 12.4, 14.8),
	(25, 80, 84, 'w', 'C_I', '', 8.8, 11.6, 14.0),
	(25, 85, 89, 'w', 'C_I', '', 7.6, 10.4, 12.8),
	(25, 90, 200, 'w', 'C_I', '', 6.0, 8.8, 11.2),
	(25, 12, 13, 'm', 'C_I', '', 15.6, 19.2, 22.0),
	(25, 14, 15, 'm', 'C_I', '', 18.8, 22.4, 25.6),
	(25, 16, 17, 'm', 'C_I', '', 22.0, 25.6, 29.2),
	(25, 18, 19, 'm', 'C_I', '', 25.2, 28.8, 32.4),
	(25, 20, 24, 'm', 'C_I', '', 26.4, 30.4, 33.6),
	(25, 25, 29, 'm', 'C_I', '', 26.0, 30.0, 33.2),
	(25, 30, 34, 'm', 'C_I', '', 24.0, 28.0, 32.0),
	(25, 35, 39, 'm', 'C_I', '', 22.8, 26.8, 30.8),
	(25, 40, 44, 'm', 'C_I', '', 22.4, 26.4, 30.4),
	(25, 45, 49, 'm', 'C_I', '', 21.6, 25.6, 30.0),
	(25, 50, 54, 'm', 'C_I', '', 20.4, 24.8, 29.2),
	(25, 55, 59, 'm', 'C_I', '', 18.8, 23.2, 28.0),
	(25, 60, 64, 'm', 'C_I', '', 18.0, 22.4, 27.2),
	(25, 65, 69, 'm', 'C_I', '', 16.0, 20.4, 24.4),
	(25, 70, 74, 'm', 'C_I', '', 14.8, 19.2, 23.2),
	(25, 75, 79, 'm', 'C_I', '', 12.8, 16.8, 20.8),
	(25, 80, 84, 'm', 'C_I', '', 11.2, 15.2, 19.2),
	(25, 85, 89, 'm', 'C_I', '', 9.6, 13.2, 16.8),
	(25, 90, 200, 'm', 'C_I', '', 8.4, 12.0, 15.6),
	(33, 0, 7, 'w', 'C_I', 'auch als Walking möglich', 4.0, 6.0, 8.500000000000002),
	(33, 8, 9, 'w', 'C_I', 'auch als Walking möglich', 5.0, 7.5, 10.0),
	(33, 10, 11, 'w', 'C_I', 'auch als Walking möglich', 7.5, 10.0, 15.0),
	(33, 12, 13, 'w', 'C_I', 'auch als Walking möglich', 10.0, 15.0, 20.0),
	(33, 14, 15, 'w', 'C_I', 'auch als Walking möglich', 15.0, 20.0, 25.0),
	(33, 16, 17, 'w', 'C_I', 'auch als Walking möglich', 22.5, 30.0, 37.49999999999999),
	(33, 0, 7, 'm', 'C_I', 'auch als Walking möglich', 5.0, 7.5, 10.0),
	(33, 8, 9, 'm', 'C_I', 'auch als Walking möglich', 6.0, 8.500000000000002, 11.500000000000002),
	(33, 10, 11, 'm', 'C_I', 'auch als Walking möglich', 8.500000000000002, 12.500000000000002, 17.5),
	(33, 12, 13, 'm', 'C_I', 'auch als Walking möglich', 12.500000000000002, 17.5, 22.5),
	(33, 14, 15, 'm', 'C_I', 'auch als Walking möglich', 17.5, 22.5, 30.0),
	(33, 16, 17, 'm', 'C_I', 'auch als Walking möglich', 27.5, 35.0, 45.0),
	(39, 0, 7, 'w', 'C_I', '', 169.0, 188.0, 206.0),
	(39, 8, 9, 'w', 'C_I', '', 180.0, 200.0, 220.0),
	(39, 10, 11, 'w', 'C_I', '', 191.0, 213.0, 234.0),
	(39, 12, 13, 'w', 'C_I', '', 203.0, 225.0, 248.0),
	(39, 14, 15, 'w', 'C_I', '', 214.0, 238.0, 261.0),
	(39, 16, 17, 'w', 'C_I', '', 225.0, 250.0, 275.0),
	(39, 18, 19, 'w', 'C_I', '', 315.0, 350.0, 385.0),
	(39, 20, 24, 'w', 'C_I', '', 315.0, 350.0, 385.0),
	(39, 25, 29, 'w', 'C_I', '', 315.0, 350.0, 385.0),
	(39, 30, 34, 'w', 'C_I', '', 304.0, 338.0, 371.0),
	(39, 35, 39, 'w', 'C_I', '', 304.0, 338.0, 371.0),
	(39, 40, 44, 'w', 'C_I', '', 293.0, 325.0, 358.0),
	(39, 45, 49, 'w', 'C_I', '', 281.0, 313.0, 344.0),
	(39, 50, 54, 'w', 'C_I', '', 270.0, 300.0, 330.0),
	(39, 55, 59, 'w', 'C_I', '', 259.0, 288.0, 316.0),
	(39, 60, 64, 'w', 'C_I', '', 248.0, 275.0, 303.0),
	(39, 65, 69, 'w', 'C_I', '', 236.0, 263.0, 289.0),
	(39, 70, 74, 'w', 'C_I', '', 225.0, 250.0, 275.0),
	(39, 75, 79, 'w', 'C_I', '', 214.0, 238.0, 261.0),
	(39, 80, 84, 'w', 'C_I', '', 203.0, 225.0, 248.0),
	(39, 85, 89, 'w', 'C_I', '', 191.0, 213.0, 234.0),
	(39, 90, 200, 'w', 'C_I', '', 180.0, 200.0, 220.0),
	(39, 0, 7, 'm', 'C_I', '', 227.0, 253.0, 278.0),
	(39, 8, 9, 'm', 'C_I', '', 239.0, 265.0, 292.0),
	(39, 10, 11, 'm', 'C_I', '', 250.0, 278.0, 305.0),
	(39, 12, 13, 'm', 'C_I', '', 261.0, 290.0, 319.0),
	(39, 14, 15, 'm', 'C_I', '', 272.0, 303.0, 333.0),
	(39, 16, 17, 'm', 'C_I', '', 284.0, 315.0, 347.0),
	(39, 18, 19, 'm', 'C_I', '', 374.0, 415.0, 457.0),
	(39, 20, 24, 'm', 'C_I', '', 374.0, 415.0, 457.0),
	(39, 25, 29, 'm', 'C_I', '', 374.0, 415.0, 457.0),
	(39, 30, 34, 'm', 'C_I', '', 362.0, 403.0, 443.0),
	(39, 35, 39, 'm', 'C_I', '', 362.0, 403.0, 443.0),
	(39, 40, 44, 'm', 'C_I', '', 351.0, 390.0, 429.0),
	(39, 45, 49, 'm', 'C_I', '', 340.0, 378.0, 415.0),
	(39, 50, 54, 'm', 'C_I', '', 329.0, 365.0, 402.0),
	(39, 55, 59, 'm', 'C_I', '', 317.0, 353.0, 388.0),
	(39, 60, 64, 'm', 'C_I', '', 306.0, 340.0, 374.0),
	(39, 65, 69, 'm', 'C_I', '', 295.0, 328.0, 360.0),
	(39, 70, 74, 'm', 'C_I', '', 284.0, 315.0, 347.0),
	(39, 75, 79, 'm', 'C_I', '', 272.0, 303.0, 333.0),
	(39, 80, 84, 'm', 'C_I', '', 261.0, 290.0, 319.0),
	(39, 85, 89, 'm', 'C_I', '', 250.0, 278.0, 305.0),
	(39, 90, 200, 'm', 'C_I', '', 239.0, 265.0, 292.0),
	(40, 0, 7, 'w', 'C_I', '', 329.0, 365.0, 402.0),
	(40, 8, 9, 'w', 'C_I', '', 342.0, 380.0, 418.0),
	(40, 10, 11, 'w', 'C_I', '', 356.0, 395.0, 435.0),
	(40, 12, 13, 'w', 'C_I', '', 369.0, 410.0, 451.0),
	(40, 14, 15, 'w', 'C_I', '', 383.0, 425.0, 468.0),
	(40, 16, 17, 'w', 'C_I', '', 396.0, 440.0, 484.0),
	(40, 18, 19, 'w', 'C_I', '', 486.0, 540.0, 594.0),
	(40, 20, 24, 'w', 'C_I', '', 486.0, 540.0, 594.0),
	(40, 25, 29, 'w', 'C_I', '', 486.0, 540.0, 594.0),
	(40, 30, 34, 'w', 'C_I', '', 473.0, 525.0, 578.0),
	(40, 35, 39, 'w', 'C_I', '', 473.0, 525.0, 578.0),
	(40, 40, 44, 'w', 'C_I', '', 459.0, 510.0, 561.0),
	(40, 45, 49, 'w', 'C_I', '', 446.0, 495.0, 545.0),
	(40, 50, 54, 'w', 'C_I', '', 432.0, 480.0, 528.0),
	(40, 55, 59, 'w', 'C_I', '', 419.0, 465.0, 512.0),
	(40, 60, 64, 'w', 'C_I', '', 405.0, 450.0, 495.0),
	(40, 65, 69, 'w', 'C_I', '', 392.0, 435.0, 479.0),
	(40, 70, 74, 'w', 'C_I', '', 378.0, 420.0, 462.0),
	(40, 75, 79, 'w', 'C_I', '', 365.0, 405.0, 446.0),
	(40, 80, 84, 'w', 'C_I', '', 351.0, 390.0, 429.0),
	(40, 85, 89, 'w', 'C_I', '', 338.0, 375.0, 413.0),
	(40, 90, 200, 'w', 'C_I', '', 324.0, 360.0, 396.0),
	(40, 0, 7, 'm', 'C_I', '', 396.0, 440.0, 484.0),
	(40, 8, 9, 'm', 'C_I', '', 410.0, 455.0, 501.0),
	(40, 10, 11, 'm', 'C_I', '', 423.0, 470.0, 517.0),
	(40, 12, 13, 'm', 'C_I', '', 437.0, 485.0, 534.0),
	(40, 14, 15, 'm', 'C_I', '', 450.0, 500.0, 550.0),
	(40, 16, 17, 'm', 'C_I', '', 464.0, 515.0, 567.0),
	(40, 18, 19, 'm', 'C_I', '', 554.0, 615.0, 677.0),
	(40, 20, 24, 'm', 'C_I', '', 554.0, 615.0, 677.0),
	(40, 25, 29, 'm', 'C_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'C_I', '', 540.0, 600.0, 660.0),
	(40, 35, 39, 'm', 'C_I', '', 540.0, 600.0, 660.0),
	(40, 40, 44, 'm', 'C_I', '', 527.0, 585.0, 644.0),
	(40, 45, 49, 'm', 'C_I', '', 513.0, 570.0, 627.0),
	(40, 50, 54, 'm', 'C_I', '', 500.0, 555.0, 611.0),
	(40, 55, 59, 'm', 'C_I', '', 486.0, 540.0, 594.0),
	(40, 60, 64, 'm', 'C_I', '', 473.0, 525.0, 578.0),
	(40, 65, 69, 'm', 'C_I', '', 459.0, 510.0, 561.0),
	(40, 70, 74, 'm', 'C_I', '', 446.0, 495.0, 545.0),
	(40, 75, 79, 'm', 'C_I', '', 432.0, 480.0, 528.0),
	(40, 80, 84, 'm', 'C_I', '', 419.0, 465.0, 512.0),
	(40, 85, 89, 'm', 'C_I', '', 405.0, 450.0, 495.0),
	(40, 90, 200, 'm', 'C_I', '', 392.0, 435.0, 479.0),
	(41, 0, 7, 'w', 'C_I', '', 261.0, 290.0, 319.0),
	(41, 8, 9, 'w', 'C_I', '', 275.0, 305.0, 336.0),
	(41, 10, 11, 'w', 'C_I', '', 288.0, 320.0, 352.0),
	(41, 12, 13, 'w', 'C_I', '', 302.0, 335.0, 369.0),
	(41, 14, 15, 'w', 'C_I', '', 315.0, 350.0, 385.0),
	(41, 16, 17, 'w', 'C_I', '', 329.0, 365.0, 402.0),
	(41, 18, 19, 'w', 'C_I', '', 419.0, 465.0, 512.0),
	(41, 20, 24, 'w', 'C_I', '', 419.0, 465.0, 512.0),
	(41, 25, 29, 'w', 'C_I', '', 419.0, 465.0, 512.0),
	(41, 30, 34, 'w', 'C_I', '', 405.0, 450.0, 495.0),
	(41, 35, 39, 'w', 'C_I', '', 405.0, 450.0, 495.0),
	(41, 40, 44, 'w', 'C_I', '', 392.0, 435.0, 479.0),
	(41, 45, 49, 'w', 'C_I', '', 378.0, 420.0, 462.0),
	(41, 50, 54, 'w', 'C_I', '', 365.0, 405.0, 446.0),
	(41, 55, 59, 'w', 'C_I', '', 351.0, 390.0, 429.0),
	(41, 60, 64, 'w', 'C_I', '', 338.0, 375.0, 413.0),
	(41, 65, 69, 'w', 'C_I', '', 324.0, 360.0, 396.0),
	(41, 70, 74, 'w', 'C_I', '', 311.0, 345.0, 380.0),
	(41, 75, 79, 'w', 'C_I', '', 297.0, 330.0, 363.0),
	(41, 80, 84, 'w', 'C_I', '', 284.0, 315.0, 347.0),
	(41, 85, 89, 'w', 'C_I', '', 270.0, 300.0, 330.0),
	(41, 90, 200, 'w', 'C_I', '', 257.0, 285.0, 314.0),
	(41, 0, 7, 'm', 'C_I', '', 324.0, 360.0, 396.0),
	(41, 8, 9, 'm', 'C_I', '', 338.0, 375.0, 413.0),
	(41, 10, 11, 'm', 'C_I', '', 351.0, 390.0, 429.0),
	(41, 12, 13, 'm', 'C_I', '', 365.0, 405.0, 446.0),
	(41, 14, 15, 'm', 'C_I', '', 378.0, 420.0, 462.0),
	(41, 16, 17, 'm', 'C_I', '', 392.0, 435.0, 479.0),
	(41, 18, 19, 'm', 'C_I', '', 482.0, 535.0, 589.0),
	(41, 20, 24, 'm', 'C_I', '', 482.0, 535.0, 589.0),
	(41, 25, 29, 'm', 'C_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'C_I', '', 468.0, 520.0, 572.0),
	(41, 35, 39, 'm', 'C_I', '', 468.0, 520.0, 572.0),
	(41, 40, 44, 'm', 'C_I', '', 455.0, 505.0, 556.0),
	(41, 45, 49, 'm', 'C_I', '', 441.0, 490.0, 539.0),
	(41, 50, 54, 'm', 'C_I', '', 428.0, 475.0, 523.0),
	(41, 55, 59, 'm', 'C_I', '', 414.0, 460.0, 506.0),
	(41, 60, 64, 'm', 'C_I', '', 401.0, 445.0, 490.0),
	(41, 65, 69, 'm', 'C_I', '', 387.0, 430.0, 473.0),
	(41, 70, 74, 'm', 'C_I', '', 374.0, 415.0, 457.0),
	(41, 75, 79, 'm', 'C_I', '', 360.0, 400.0, 440.0),
	(41, 80, 84, 'm', 'C_I', '', 347.0, 385.0, 424.0),
	(41, 85, 89, 'm', 'C_I', '', 333.0, 370.0, 407.0),
	(41, 90, 200, 'm', 'C_I', '', 320.0, 355.0, 391.0),
	(42, 0, 7, 'w', 'C_I', '', 266.0, 295.0, 325.0),
	(42, 8, 9, 'w', 'C_I', '', 279.0, 310.0, 341.0),
	(42, 10, 11, 'w', 'C_I', '', 293.0, 325.0, 358.0),
	(42, 12, 13, 'w', 'C_I', '', 306.0, 340.0, 374.0),
	(42, 14, 15, 'w', 'C_I', '', 320.0, 355.0, 391.0),
	(42, 16, 17, 'w', 'C_I', '', 333.0, 370.0, 407.0),
	(42, 18, 19, 'w', 'C_I', '', 423.0, 470.0, 517.0),
	(42, 20, 24, 'w', 'C_I', '', 423.0, 470.0, 517.0),
	(42, 25, 29, 'w', 'C_I', '', 423.0, 470.0, 517.0),
	(42, 30, 34, 'w', 'C_I', '', 410.0, 455.0, 501.0),
	(42, 35, 39, 'w', 'C_I', '', 410.0, 455.0, 501.0),
	(42, 40, 44, 'w', 'C_I', '', 396.0, 440.0, 484.0),
	(42, 45, 49, 'w', 'C_I', '', 383.0, 425.0, 468.0),
	(42, 50, 54, 'w', 'C_I', '', 369.0, 410.0, 451.0),
	(42, 55, 59, 'w', 'C_I', '', 356.0, 395.0, 435.0),
	(42, 60, 64, 'w', 'C_I', '', 342.0, 380.0, 418.0),
	(42, 65, 69, 'w', 'C_I', '', 329.0, 365.0, 402.0),
	(42, 70, 74, 'w', 'C_I', '', 315.0, 350.0, 385.0),
	(42, 75, 79, 'w', 'C_I', '', 302.0, 335.0, 369.0),
	(42, 80, 84, 'w', 'C_I', '', 288.0, 320.0, 352.0),
	(42, 85, 89, 'w', 'C_I', '', 275.0, 305.0, 336.0),
	(42, 90, 200, 'w', 'C_I', '', 261.0, 290.0, 319.0),
	(42, 0, 7, 'm', 'C_I', '', 329.0, 365.0, 402.0),
	(42, 8, 9, 'm', 'C_I', '', 342.0, 380.0, 418.0),
	(42, 10, 11, 'm', 'C_I', '', 356.0, 395.0, 435.0),
	(42, 12, 13, 'm', 'C_I', '', 369.0, 410.0, 451.0),
	(42, 14, 15, 'm', 'C_I', '', 383.0, 425.0, 468.0),
	(42, 16, 17, 'm', 'C_I', '', 396.0, 440.0, 484.0),
	(42, 18, 19, 'm', 'C_I', '', 486.0, 540.0, 594.0),
	(42, 20, 24, 'm', 'C_I', '', 486.0, 540.0, 594.0),
	(42, 25, 29, 'm', 'C_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'C_I', '', 473.0, 525.0, 578.0),
	(42, 35, 39, 'm', 'C_I', '', 473.0, 525.0, 578.0),
	(42, 40, 44, 'm', 'C_I', '', 459.0, 510.0, 561.0),
	(42, 45, 49, 'm', 'C_I', '', 446.0, 495.0, 545.0),
	(42, 50, 54, 'm', 'C_I', '', 432.0, 480.0, 528.0),
	(42, 55, 59, 'm', 'C_I', '', 419.0, 465.0, 512.0),
	(42, 60, 64, 'm', 'C_I', '', 405.0, 450.0, 495.0),
	(42, 65, 69, 'm', 'C_I', '', 392.0, 435.0, 479.0),
	(42, 70, 74, 'm', 'C_I', '', 378.0, 420.0, 462.0),
	(42, 75, 79, 'm', 'C_I', '', 365.0, 405.0, 446.0),
	(42, 80, 84, 'm', 'C_I', '', 351.0, 390.0, 429.0),
	(42, 85, 89, 'm', 'C_I', '', 338.0, 375.0, 413.0),
	(42, 90, 200, 'm', 'C_I', '', 324.0, 360.0, 396.0),
	(44, 12, 13, 'w', 'C_I', '', 6.06, 6.69, 7.33),
	(44, 14, 15, 'w', 'C_I', '', 7.01, 7.65, 8.29),
	(44, 16, 17, 'w', 'C_I', '', 7.33, 7.97, 8.61),
	(44, 18, 19, 'w', 'C_I', '', 9.39, 10.12, 10.84),
	(44, 20, 24, 'w', 'C_I', '', 9.39, 10.12, 10.84),
	(44, 25, 29, 'w', 'C_I', '', 9.39, 10.12, 10.84),
	(44, 30, 34, 'w', 'C_I', '', 9.03, 9.75, 10.48),
	(44, 35, 39, 'w', 'C_I', '', 8.67, 9.39, 10.12),
	(44, 40, 44, 'w', 'C_I', '', 7.95, 8.67, 9.39),
	(44, 45, 49, 'w', 'C_I', '', 7.59, 8.31, 9.03),
	(44, 50, 54, 'w', 'C_I', '', 7.59, 8.67, 10.12),
	(44, 55, 59, 'w', 'C_I', '', 7.23, 8.31, 9.39),
	(44, 60, 64, 'w', 'C_I', '', 6.86, 7.95, 9.03),
	(44, 65, 69, 'w', 'C_I', '', 6.5, 7.59, 9.03),
	(44, 70, 74, 'w', 'C_I', '', 6.14, 7.23, 8.67),
	(44, 75, 79, 'w', 'C_I', '', 6.14, 7.59, 9.03),
	(44, 80, 84, 'w', 'C_I', '', 5.78, 7.23, 8.31),
	(44, 85, 89, 'w', 'C_I', '', 5.42, 6.5, 7.95),
	(44, 90, 200, 'w', 'C_I', '', 4.7, 6.14, 7.23),
	(44, 12, 13, 'm', 'C_I', '', 7.97, 8.61, 9.24),
	(44, 14, 15, 'm', 'C_I', '', 8.93, 9.56, 10.2),
	(44, 16, 17, 'm', 'C_I', '', 9.56, 10.2, 10.84),
	(44, 18, 19, 'm', 'C_I', '', 11.2, 11.92, 12.64),
	(44, 20, 24, 'm', 'C_I', '', 11.2, 12.28, 13.01),
	(44, 25, 29, 'm', 'C_I', '', 10.84, 11.92, 12.64),
	(44, 30, 34, 'm', 'C_I', '', 10.12, 11.2, 11.92),
	(44, 35, 39, 'm', 'C_I', '', 9.75, 10.48, 11.56),
	(44, 40, 44, 'm', 'C_I', '', 9.03, 10.12, 11.2),
	(44, 45, 49, 'm', 'C_I', '', 8.67, 9.75, 10.84),
	(44, 50, 54, 'm', 'C_I', '', 9.03, 10.12, 11.56),
	(44, 55, 59, 'm', 'C_I', '', 8.67, 9.75, 10.84),
	(44, 60, 64, 'm', 'C_I', '', 8.67, 10.12, 11.56),
	(44, 65, 69, 'm', 'C_I', '', 8.31, 9.75, 10.84),
	(44, 70, 74, 'm', 'C_I', '', 8.16, 9.52, 10.54),
	(44, 75, 79, 'm', 'C_I', '', 8.31, 9.39, 10.84),
	(44, 80, 84, 'm', 'C_I', '', 7.95, 9.03, 10.48),
	(44, 85, 89, 'm', 'C_I', '', 7.23, 8.67, 9.75),
	(44, 90, 200, 'm', 'C_I', '', 6.5, 7.59, 9.03),
	(47, 0, 7, 'w', 'C_I', '30 m', 24.0, 21.3, 18.9),
	(47, 8, 9, 'w', 'C_I', '30 m', 22.2, 19.8, 17.1),
	(47, 10, 11, 'w', 'C_I', '50 m', 33.0, 30.3, 27.3),
	(47, 12, 13, 'w', 'C_I', '50 m', 31.8, 28.8, 25.5),
	(47, 14, 15, 'w', 'C_I', '100 m', 55.8, 51.0, 46.5),
	(47, 16, 17, 'w', 'C_I', '100 m', 52.8, 48.9, 45.0),
	(47, 18, 19, 'w', 'C_I', '100 m', 54.6, 49.5, 45.9),
	(47, 20, 24, 'w', 'C_I', '100 m', 55.5, 50.4, 46.8),
	(47, 25, 29, 'w', 'C_I', '100 m', 56.7, 51.6, 48.0),
	(47, 30, 34, 'w', 'C_I', '100 m', 58.8, 53.4, 49.2),
	(47, 35, 39, 'w', 'C_I', '100 m', 61.2, 55.8, 51.0),
	(47, 40, 44, 'w', 'C_I', '50 m', 33.0, 29.7, 26.4),
	(47, 45, 49, 'w', 'C_I', '50 m', 34.5, 30.9, 27.3),
	(47, 50, 54, 'w', 'C_I', '50 m', 35.7, 32.1, 28.5),
	(47, 55, 59, 'w', 'C_I', '50 m', 37.2, 33.6, 29.7),
	(47, 60, 64, 'w', 'C_I', '50 m', 37.8, 34.2, 30.6),
	(47, 65, 69, 'w', 'C_I', '50 m', 38.4, 34.8, 31.2),
	(47, 70, 74, 'w', 'C_I', '50 m', 39.0, 35.4, 31.8),
	(47, 75, 79, 'w', 'C_I', '50 m', 40.5, 36.9, 33.3),
	(47, 80, 84, 'w', 'C_I', '50 m', 42.9, 39.3, 36.0),
	(47, 85, 89, 'w', 'C_I', '50 m', 46.5, 42.9, 39.6),
	(47, 90, 200, 'w', 'C_I', '50 m', 51.3, 47.7, 44.4),
	(47, 0, 7, 'm', 'C_I', '30 m', 23.1, 20.4, 18.0),
	(47, 8, 9, 'm', 'C_I', '30 m', 21.6, 19.2, 17.1),
	(47, 10, 11, 'm', 'C_I', '50 m', 30.9, 27.9, 25.2),
	(47, 12, 13, 'm', 'C_I', '50 m', 29.1, 26.7, 24.3),
	(47, 14, 15, 'm', 'C_I', '100 m', 51.0, 46.2, 42.3),
	(47, 16, 17, 'm', 'C_I', '100 m', 48.9, 44.4, 40.5),
	(47, 18, 19, 'm', 'C_I', '100 m', 48.0, 43.8, 39.6),
	(47, 20, 24, 'm', 'C_I', '100 m', 47.4, 43.2, 39.0),
	(47, 25, 29, 'm', 'C_I', '100 m', 48.9, 44.4, 39.9),
	(47, 30, 34, 'm', 'C_I', '100 m', 50.4, 45.3, 40.8),
	(47, 35, 39, 'm', 'C_I', '100 m', 52.8, 47.7, 42.6),
	(47, 40, 44, 'm', 'C_I', '50 m', 28.8, 26.1, 23.1),
	(47, 45, 49, 'm', 'C_I', '50 m', 30.0, 26.7, 23.7),
	(47, 50, 54, 'm', 'C_I', '50 m', 30.9, 27.3, 24.6),
	(47, 55, 59, 'm', 'C_I', '50 m', 31.5, 28.2, 25.5),
	(47, 60, 64, 'm', 'C_I', '50 m', 32.4, 29.1, 26.4),
	(47, 65, 69, 'm', 'C_I', '50 m', 33.6, 30.6, 27.3),
	(47, 70, 74, 'm', 'C_I', '50 m', 35.1, 32.1, 28.8),
	(47, 75, 79, 'm', 'C_I', '50 m', 36.6, 33.6, 30.3),
	(47, 80, 84, 'm', 'C_I', '50 m', 39.0, 36.0, 32.7),
	(47, 85, 89, 'm', 'C_I', '50 m', 42.3, 39.3, 36.0),
	(47, 90, 200, 'm', 'C_I', '50 m', 46.5, 43.5, 40.2),
	(53, 0, 7, 'w', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'C_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'C_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'C_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'C_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'C_I', '', 1.0, 2.0, 3.0),
	(57, 0, 7, 'w', 'C_I', '', 10.0, 12.0, 17.0),
	(57, 8, 9, 'w', 'C_I', '', 14.0, 17.0, 22.0),
	(57, 10, 11, 'w', 'C_I', '', 22.0, 24.0, 29.0),
	(57, 0, 7, 'm', 'C_I', '', 12.0, 14.0, 19.0),
	(57, 8, 9, 'm', 'C_I', '', 17.0, 22.0, 26.0),
	(57, 10, 11, 'm', 'C_I', '', 26.0, 31.0, 36.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(4, 8, 9, 'w', 'C_II', '5 km', 35.1, 31.200000000000003, 27.3),
	(4, 10, 11, 'w', 'C_II', '10 km', 65.65, 55.9, 46.150000000000006),
	(4, 12, 13, 'w', 'C_II', '10 km', 58.49999999999999, 51.35, 43.55),
	(4, 14, 15, 'w', 'C_II', '10 km', 49.400000000000006, 42.25, 37.050000000000004),
	(4, 16, 17, 'w', 'C_II', '10 km', 42.25, 37.050000000000004, 32.49999999999999),
	(4, 18, 19, 'w', 'C_II', '10 km', 41.400000000000006, 37.43333333333333, 33.483333333333334),
	(4, 20, 24, 'w', 'C_II', '10 km', 41.03333333333334, 37.08333333333333, 32.766666666666666),
	(4, 25, 29, 'w', 'C_II', '10 km', 40.31666666666666, 36.36666666666667, 32.400000000000006),
	(4, 30, 34, 'w', 'C_II', '10 km', 41.03333333333334, 37.08333333333333, 32.766666666666666),
	(4, 35, 39, 'w', 'C_II', '10 km', 43.199999999999996, 38.16666666666667, 33.833333333333336),
	(4, 40, 44, 'w', 'C_II', '10 km', 46.08333333333333, 39.96666666666666, 35.63333333333334),
	(4, 45, 49, 'w', 'C_II', '10 km', 48.233333333333334, 42.11666666666667, 37.08333333333333),
	(4, 50, 54, 'w', 'C_II', '10 km', 49.68333333333333, 43.916666666666664, 38.51666666666667),
	(4, 55, 59, 'w', 'C_II', '10 km', 51.483333333333334, 45.36666666666667, 39.96666666666666),
	(4, 60, 64, 'w', 'C_II', '10 km', 53.28333333333334, 46.8, 41.03333333333334),
	(4, 65, 69, 'w', 'C_II', '10 km', 54.36666666666667, 47.88333333333333, 42.11666666666667),
	(4, 70, 74, 'w', 'C_II', '10 km', 56.16666666666667, 49.31666666666666, 43.56666666666667),
	(4, 75, 79, 'w', 'C_II', '10 km', 58.68333333333333, 50.766666666666666, 45.36666666666667),
	(4, 80, 84, 'w', 'C_II', '10 km', 60.833333333333336, 54.0, 47.16666666666667),
	(4, 85, 89, 'w', 'C_II', '10 km', 64.43333333333334, 57.6, 49.68333333333333),
	(4, 90, 200, 'w', 'C_II', '10 km', 66.96666666666667, 59.766666666666666, 52.199999999999996),
	(4, 8, 9, 'm', 'C_II', '5 km', 34.45, 30.549999999999997, 26.650000000000002),
	(4, 10, 11, 'm', 'C_II', '10 km', 63.050000000000004, 53.3, 43.55),
	(4, 12, 13, 'm', 'C_II', '10 km', 55.9, 48.1, 40.95),
	(4, 14, 15, 'm', 'C_II', '10 km', 41.6, 36.400000000000006, 31.200000000000003),
	(4, 16, 17, 'm', 'C_II', '10 km', 35.1, 30.549999999999997, 26.650000000000002),
	(4, 18, 19, 'm', 'C_II', '10 km', 33.833333333333336, 30.599999999999998, 27.716666666666665),
	(4, 20, 24, 'm', 'C_II', '10 km', 33.483333333333334, 30.233333333333334, 27.0),
	(4, 25, 29, 'm', 'C_II', '10 km', 36.0, 32.03333333333334, 28.083333333333336),
	(4, 30, 34, 'm', 'C_II', '10 km', 38.51666666666667, 33.833333333333336, 29.166666666666668),
	(4, 35, 39, 'm', 'C_II', '10 km', 41.766666666666666, 36.0, 29.883333333333336),
	(4, 40, 44, 'm', 'C_II', '10 km', 45.36666666666667, 37.43333333333333, 31.31666666666667),
	(4, 45, 49, 'm', 'C_II', '10 km', 47.51666666666667, 39.6, 32.400000000000006),
	(4, 50, 54, 'm', 'C_II', '10 km', 49.31666666666666, 41.03333333333334, 33.483333333333334),
	(4, 55, 59, 'm', 'C_II', '10 km', 50.766666666666666, 42.11666666666667, 34.199999999999996),
	(4, 60, 64, 'm', 'C_II', '10 km', 51.483333333333334, 43.199999999999996, 34.56666666666667),
	(4, 65, 69, 'm', 'C_II', '10 km', 52.199999999999996, 43.56666666666667, 34.916666666666664),
	(4, 70, 74, 'm', 'C_II', '10 km', 52.916666666666664, 44.28333333333334, 35.63333333333334),
	(4, 75, 79, 'm', 'C_II', '10 km', 53.63333333333334, 45.36666666666667, 37.08333333333333),
	(4, 80, 84, 'm', 'C_II', '10 km', 54.71666666666667, 46.43333333333333, 38.16666666666667),
	(4, 85, 89, 'm', 'C_II', '10 km', 55.8, 47.88333333333333, 39.96666666666666),
	(4, 90, 200, 'm', 'C_II', '10 km', 56.88333333333333, 48.96666666666666, 41.766666666666666),
	(7, 0, 7, 'w', 'C_II', '200 m', 11.7, 9.966666666666667, 8.233333333333334),
	(7, 8, 9, 'w', 'C_II', '200 m', 10.4, 9.100000000000001, 7.7),
	(7, 10, 11, 'w', 'C_II', '200 m', 9.533333333333333, 8.333333333333332, 7.1499999999999995),
	(7, 12, 13, 'w', 'C_II', '400 m', 19.283333333333335, 16.8, 14.299999999999999),
	(7, 14, 15, 'w', 'C_II', '400 m', 17.01666666666667, 15.166666666666666, 13.0),
	(7, 16, 17, 'w', 'C_II', '400 m', 15.383333333333335, 13.65, 11.8),
	(7, 18, 19, 'w', 'C_II', '800 m', 31.200000000000003, 27.516666666666666, 23.93333333333333),
	(7, 20, 24, 'w', 'C_II', '800 m', 30.650000000000002, 27.083333333333336, 23.4),
	(7, 25, 29, 'w', 'C_II', '800 m', 33.150000000000006, 27.416666666666668, 24.266666666666666),
	(7, 30, 34, 'w', 'C_II', '800 m', 37.483333333333334, 30.76666666666667, 25.35),
	(7, 35, 39, 'w', 'C_II', '800 m', 41.6, 33.26666666666666, 26.433333333333337),
	(7, 40, 44, 'w', 'C_II', '800 m', 44.199999999999996, 35.96666666666666, 27.733333333333334),
	(7, 45, 49, 'w', 'C_II', '800 m', 45.93333333333334, 37.7, 27.95),
	(7, 50, 54, 'w', 'C_II', '400 m', 23.4, 19.5, 14.950000000000001),
	(7, 55, 59, 'w', 'C_II', '400 m', 24.15, 19.93333333333333, 15.483333333333333),
	(7, 60, 64, 'w', 'C_II', '400 m', 24.700000000000003, 20.266666666666666, 15.816666666666666),
	(7, 65, 69, 'w', 'C_II', '400 m', 25.249999999999996, 20.48333333333333, 15.933333333333334),
	(7, 70, 74, 'w', 'C_II', '400 m', 25.78333333333333, 20.9, 16.46666666666667),
	(7, 75, 79, 'w', 'C_II', '200 m', 13.316666666666666, 10.833333333333334, 8.45),
	(7, 80, 84, 'w', 'C_II', '200 m', 13.55, 11.049999999999999, 8.783333333333335),
	(7, 85, 89, 'w', 'C_II', '200 m', 13.766666666666667, 11.366666666666667, 9.216666666666669),
	(7, 90, 200, 'w', 'C_II', '200 m', 13.983333333333333, 11.583333333333332, 9.533333333333333),
	(7, 0, 7, 'm', 'C_II', '200 m', 11.7, 9.533333333333333, 8.016666666666666),
	(7, 8, 9, 'm', 'C_II', '200 m', 10.4, 8.783333333333335, 7.366666666666666),
	(7, 10, 11, 'm', 'C_II', '200 m', 9.100000000000001, 8.233333333333334, 6.716666666666666),
	(7, 12, 13, 'm', 'C_II', '400 m', 17.549999999999997, 14.950000000000001, 12.683333333333334),
	(7, 14, 15, 'm', 'C_II', '400 m', 15.6, 13.316666666666666, 11.483333333333333),
	(7, 16, 17, 'm', 'C_II', '400 m', 14.299999999999999, 12.566666666666666, 10.833333333333334),
	(7, 18, 19, 'm', 'C_II', '800 m', 29.366666666666664, 25.78333333333333, 22.099999999999998),
	(7, 20, 24, 'm', 'C_II', '800 m', 28.816666666666663, 25.35, 21.35),
	(7, 25, 29, 'm', 'C_II', '800 m', 30.116666666666667, 26.0, 22.099999999999998),
	(7, 30, 34, 'm', 'C_II', '800 m', 33.483333333333334, 27.95, 23.4),
	(7, 35, 39, 'm', 'C_II', '800 m', 37.483333333333334, 31.200000000000003, 25.03333333333333),
	(7, 40, 44, 'm', 'C_II', '800 m', 42.13333333333333, 34.35, 26.549999999999997),
	(7, 45, 49, 'm', 'C_II', '800 m', 44.849999999999994, 36.18333333333333, 26.866666666666667),
	(7, 50, 54, 'm', 'C_II', '400 m', 22.650000000000002, 18.633333333333333, 13.983333333333333),
	(7, 55, 59, 'm', 'C_II', '400 m', 23.183333333333334, 18.966666666666665, 14.733333333333333),
	(7, 60, 64, 'm', 'C_II', '400 m', 23.616666666666667, 19.183333333333334, 14.833333333333334),
	(7, 65, 69, 'm', 'C_II', '400 m', 23.93333333333333, 19.616666666666667, 14.950000000000001),
	(7, 70, 74, 'm', 'C_II', '400 m', 23.93333333333333, 19.816666666666663, 15.049999999999999),
	(7, 75, 79, 'm', 'C_II', '200 m', 12.25, 9.966666666666667, 7.916666666666666),
	(7, 80, 84, 'm', 'C_II', '200 m', 12.350000000000001, 10.183333333333332, 8.016666666666666),
	(7, 85, 89, 'm', 'C_II', '200 m', 12.350000000000001, 10.4, 8.333333333333332),
	(7, 90, 200, 'm', 'C_II', '200 m', 12.683333333333334, 10.616666666666665, 8.783333333333335),
	(8, 18, 19, 'w', 'C_II', '4 km', 58.383333333333326, 55.43333333333333, 52.08333333333333),
	(8, 20, 24, 'w', 'C_II', '4 km', 55.866666666666674, 52.916666666666664, 49.98333333333334),
	(8, 25, 29, 'w', 'C_II', '4 km', 56.28333333333334, 53.333333333333336, 50.400000000000006),
	(8, 30, 34, 'w', 'C_II', '4 km', 56.7, 53.766666666666666, 50.75000000000001),
	(8, 35, 39, 'w', 'C_II', '4 km', 58.8, 54.6, 51.03333333333334),
	(8, 40, 44, 'w', 'C_II', '4 km', 61.31666666666666, 56.28333333333334, 51.233333333333334),
	(8, 45, 49, 'w', 'C_II', '4 km', 63.416666666666664, 57.96666666666666, 52.08333333333333),
	(8, 50, 54, 'w', 'C_II', '4 km', 65.51666666666667, 59.63333333333334, 53.766666666666666),
	(8, 55, 59, 'w', 'C_II', '4 km', 67.2, 61.31666666666666, 55.43333333333333),
	(8, 60, 64, 'w', 'C_II', '4 km', 69.30000000000001, 62.583333333333336, 56.7),
	(8, 65, 69, 'w', 'C_II', '4 km', 70.76666666666665, 64.26666666666667, 58.8),
	(8, 70, 74, 'w', 'C_II', '4 km', 74.13333333333333, 66.36666666666666, 60.483333333333334),
	(8, 75, 79, 'w', 'C_II', '4 km', 77.7, 68.46666666666667, 62.583333333333336),
	(8, 80, 84, 'w', 'C_II', '4 km', 82.73333333333333, 71.61666666666667, 65.10000000000001),
	(8, 85, 89, 'w', 'C_II', '4 km', 87.36666666666666, 75.88333333333334, 68.88333333333334),
	(8, 90, 200, 'w', 'C_II', '4 km', 92.68333333333332, 80.63333333333333, 73.08333333333333),
	(8, 18, 19, 'm', 'C_II', '4 km', 49.13333333333333, 45.78333333333333, 42.416666666666664),
	(8, 20, 24, 'm', 'C_II', '4 km', 47.88333333333333, 44.51666666666667, 41.16666666666667),
	(8, 25, 29, 'm', 'C_II', '4 km', 49.13333333333333, 45.78333333333333, 42.416666666666664),
	(8, 30, 34, 'm', 'C_II', '4 km', 52.49999999999999, 47.88333333333333, 42.833333333333336),
	(8, 35, 39, 'm', 'C_II', '4 km', 54.6, 49.13333333333333, 44.93333333333334),
	(8, 40, 44, 'm', 'C_II', '4 km', 55.43333333333333, 50.81666666666667, 45.36666666666667),
	(8, 45, 49, 'm', 'C_II', '4 km', 57.53333333333333, 52.49999999999999, 46.199999999999996),
	(8, 50, 54, 'm', 'C_II', '4 km', 59.63333333333334, 53.766666666666666, 48.3),
	(8, 55, 59, 'm', 'C_II', '4 km', 61.31666666666666, 54.6, 49.56666666666667),
	(8, 60, 64, 'm', 'C_II', '4 km', 63.63333333333334, 56.7, 50.81666666666667),
	(8, 65, 69, 'm', 'C_II', '4 km', 65.66666666666667, 58.383333333333326, 52.08333333333333),
	(8, 70, 74, 'm', 'C_II', '4 km', 68.46666666666667, 60.483333333333334, 54.6),
	(8, 75, 79, 'm', 'C_II', '4 km', 72.38333333333334, 63.63333333333334, 60.483333333333334),
	(8, 80, 84, 'm', 'C_II', '4 km', 76.86666666666666, 66.98333333333333, 60.483333333333334),
	(8, 85, 89, 'm', 'C_II', '4 km', 80.63333333333333, 70.76666666666665, 63.416666666666664),
	(8, 90, 200, 'm', 'C_II', '4 km', 86.31666666666666, 75.03333333333333, 67.2),
	(10, 0, 7, 'w', 'C_II', '', 4.2, 6.3, 8.4),
	(10, 8, 9, 'w', 'C_II', '', 6.3, 8.4, 10.5),
	(10, 10, 11, 'w', 'C_II', '', 7.7, 10.5, 12.6),
	(10, 0, 7, 'm', 'C_II', '', 8.4, 10.5, 11.9),
	(10, 8, 9, 'm', 'C_II', '', 11.9, 14.0, 16.1),
	(10, 10, 11, 'm', 'C_II', '', 14.7, 17.5, 19.6),
	(11, 12, 13, 'w', 'C_II', '', 10.5, 12.6, 15.4),
	(11, 14, 15, 'w', 'C_II', '', 14.0, 16.8, 18.9),
	(11, 16, 17, 'w', 'C_II', '', 16.8, 18.9, 21.7),
	(11, 12, 13, 'm', 'C_II', '', 18.2, 21.0, 23.1),
	(11, 14, 15, 'm', 'C_II', '', 21.0, 23.8, 25.9),
	(11, 16, 17, 'm', 'C_II', '', 23.8, 26.6, 29.4),
	(12, 0, 7, 'w', 'C_II', '1 kg', 2.25, 2.6, 3.13),
	(12, 8, 9, 'w', 'C_II', '1 kg', 2.75, 3.1, 3.63),
	(12, 10, 11, 'w', 'C_II', '1 kg', 3.25, 3.6, 4.13),
	(12, 12, 13, 'w', 'C_II', '1 kg', 3.75, 4.1, 4.63),
	(12, 14, 15, 'w', 'C_II', '1 kg', 4.25, 4.6, 5.13),
	(12, 16, 17, 'w', 'C_II', '1 kg', 4.75, 5.1, 5.63),
	(12, 18, 19, 'w', 'C_II', '2 kg', 5.25, 5.6, 6.13),
	(12, 20, 24, 'w', 'C_II', '2 kg', 5.25, 5.6, 6.13),
	(12, 25, 29, 'w', 'C_II', '2 kg', 4.9, 5.43, 5.95),
	(12, 30, 34, 'w', 'C_II', '2 kg', 4.55, 5.25, 5.95),
	(12, 35, 39, 'w', 'C_II', '2 kg', 4.2, 5.08, 5.78),
	(12, 40, 44, 'w', 'C_II', '2 kg', 3.68, 4.73, 5.78),
	(12, 45, 49, 'w', 'C_II', '2 kg', 3.33, 4.55, 5.6),
	(12, 50, 54, 'w', 'C_II', '2 kg', 2.98, 4.2, 5.43),
	(12, 55, 59, 'w', 'C_II', '2 kg', 2.8, 4.03, 5.25),
	(12, 60, 64, 'w', 'C_II', '2 kg', 2.63, 3.85, 5.08),
	(12, 65, 69, 'w', 'C_II', '2 kg', 2.45, 3.68, 4.9),
	(12, 70, 74, 'w', 'C_II', '2 kg', 2.28, 3.5, 4.73),
	(12, 75, 79, 'w', 'C_II', '2 kg', 2.28, 3.33, 4.55),
	(12, 80, 84, 'w', 'C_II', '2 kg', 2.1, 3.33, 4.38),
	(12, 85, 89, 'w', 'C_II', '2 kg', 2.1, 3.15, 4.2),
	(12, 90, 200, 'w', 'C_II', '2 kg', 1.93, 2.98, 3.85),
	(12, 0, 7, 'm', 'C_II', '1 kg', 4.18, 4.7, 5.23),
	(12, 8, 9, 'm', 'C_II', '1 kg', 4.68, 5.2, 5.73),
	(12, 10, 11, 'm', 'C_II', '1 kg', 5.18, 5.7, 6.23),
	(12, 12, 13, 'm', 'C_II', '1 kg', 5.68, 6.2, 6.73),
	(12, 14, 15, 'm', 'C_II', '1 kg', 6.18, 6.7, 7.23),
	(12, 16, 17, 'm', 'C_II', '1 kg', 6.68, 7.2, 7.73),
	(12, 18, 19, 'm', 'C_II', '2 kg', 7.18, 7.7, 8.23),
	(12, 20, 24, 'm', 'C_II', '2 kg', 7.18, 7.88, 8.4),
	(12, 25, 29, 'm', 'C_II', '2 kg', 6.83, 7.53, 8.23),
	(12, 30, 34, 'm', 'C_II', '2 kg', 6.3, 7.18, 8.05),
	(12, 35, 39, 'm', 'C_II', '2 kg', 5.78, 6.83, 7.88),
	(12, 40, 44, 'm', 'C_II', '2 kg', 5.43, 6.48, 7.53),
	(12, 45, 49, 'm', 'C_II', '2 kg', 4.9, 6.13, 7.35),
	(12, 50, 54, 'm', 'C_II', '2 kg', 4.55, 5.95, 7.18),
	(12, 55, 59, 'm', 'C_II', '2 kg', 4.2, 5.78, 7.0),
	(12, 60, 64, 'm', 'C_II', '2 kg', 4.03, 5.43, 6.83),
	(12, 65, 69, 'm', 'C_II', '2 kg', 3.68, 5.08, 6.48),
	(12, 70, 74, 'm', 'C_II', '2 kg', 3.5, 4.9, 6.3),
	(12, 75, 79, 'm', 'C_II', '2 kg', 3.15, 4.55, 5.95),
	(12, 80, 84, 'm', 'C_II', '2 kg', 2.98, 4.38, 5.78),
	(12, 85, 89, 'm', 'C_II', '2 kg', 2.8, 4.2, 5.6),
	(12, 90, 200, 'm', 'C_II', '2 kg', 2.45, 3.85, 5.25),
	(13, 12, 13, 'w', 'C_II', '2 kg', 3.33, 3.68, 4.03),
	(13, 14, 15, 'w', 'C_II', '3 kg', 3.85, 4.2, 4.55),
	(13, 16, 17, 'w', 'C_II', '3 kg', 4.03, 4.38, 4.73),
	(13, 18, 19, 'w', 'C_II', '4 kg', 5.2, 5.6, 6.0),
	(13, 20, 24, 'w', 'C_II', '4 kg', 5.2, 5.6, 6.0),
	(13, 25, 29, 'w', 'C_II', '4 kg', 5.2, 5.6, 6.0),
	(13, 30, 34, 'w', 'C_II', '4 kg', 5.0, 5.4, 5.8),
	(13, 35, 39, 'w', 'C_II', '4 kg', 4.8, 5.2, 5.6),
	(13, 40, 44, 'w', 'C_II', '4 kg', 4.4, 4.8, 5.2),
	(13, 45, 49, 'w', 'C_II', '4 kg', 4.2, 4.6, 5.0),
	(13, 50, 54, 'w', 'C_II', '3 kg', 4.2, 4.8, 5.6),
	(13, 55, 59, 'w', 'C_II', '3 kg', 4.0, 4.6, 5.2),
	(13, 60, 64, 'w', 'C_II', '3 kg', 3.8, 4.4, 5.0),
	(13, 65, 69, 'w', 'C_II', '3 kg', 3.6, 4.2, 5.0),
	(13, 70, 74, 'w', 'C_II', '3 kg', 3.4, 4.0, 4.8),
	(13, 75, 79, 'w', 'C_II', '2 kg', 3.4, 4.2, 5.0),
	(13, 80, 84, 'w', 'C_II', '2 kg', 3.2, 4.0, 4.6),
	(13, 85, 89, 'w', 'C_II', '2 kg', 3.0, 3.6, 4.4),
	(13, 90, 200, 'w', 'C_II', '2 kg', 2.6, 3.4, 4.0),
	(13, 12, 13, 'm', 'C_II', '3 kg', 4.38, 4.73, 5.08),
	(13, 14, 15, 'm', 'C_II', '4 kg', 4.9, 5.25, 5.6),
	(13, 16, 17, 'm', 'C_II', '5 kg', 5.25, 5.6, 5.95),
	(13, 18, 19, 'm', 'C_II', '6 kg', 6.2, 6.6, 7.0),
	(13, 20, 24, 'm', 'C_II', '6 kg', 6.2, 6.8, 7.2),
	(13, 25, 29, 'm', 'C_II', '6 kg', 6.0, 6.6, 7.0),
	(13, 30, 34, 'm', 'C_II', '6 kg', 5.6, 6.2, 6.6),
	(13, 35, 39, 'm', 'C_II', '6 kg', 5.4, 5.8, 6.4),
	(13, 40, 44, 'm', 'C_II', '6 kg', 5.0, 5.6, 6.2),
	(13, 45, 49, 'm', 'C_II', '6 kg', 4.8, 5.4, 6.0),
	(13, 50, 54, 'm', 'C_II', '5 kg', 5.0, 5.6, 6.4),
	(13, 55, 59, 'm', 'C_II', '5 kg', 4.8, 5.4, 6.0),
	(13, 60, 64, 'm', 'C_II', '4 kg', 4.8, 5.6, 6.4),
	(13, 65, 69, 'm', 'C_II', '4 kg', 4.6, 5.4, 6.0),
	(13, 70, 74, 'm', 'C_II', '4 kg', 4.5, 5.3, 5.9),
	(13, 75, 79, 'm', 'C_II', '3 kg', 4.6, 5.2, 6.0),
	(13, 80, 84, 'm', 'C_II', '3 kg', 4.4, 5.0, 5.8),
	(13, 85, 89, 'm', 'C_II', '3 kg', 4.0, 4.8, 5.4),
	(13, 90, 200, 'm', 'C_II', '3 kg', 3.6, 4.2, 5.0),
	(18, 0, 7, 'w', 'C_II', '', 60.5, 50.1, 39.7),
	(18, 8, 9, 'w', 'C_II', '', 54.6, 44.2, 36.4),
	(18, 10, 11, 'w', 'C_II', '', 50.7, 41.0, 33.2),
	(18, 12, 13, 'w', 'C_II', '', 45.5, 37.7, 30.6),
	(18, 14, 15, 'w', 'C_II', '', 42.9, 35.8, 28.0),
	(18, 16, 17, 'w', 'C_II', '', 39.7, 33.2, 26.0),
	(18, 18, 19, 'w', 'C_II', '', 38.4, 31.2, 24.1),
	(18, 20, 24, 'w', 'C_II', '', 37.7, 31.2, 24.1),
	(18, 25, 29, 'w', 'C_II', '', 39.0, 32.5, 25.4),
	(18, 30, 34, 'w', 'C_II', '', 42.3, 34.5, 27.3),
	(18, 35, 39, 'w', 'C_II', '', 46.8, 37.7, 28.6),
	(18, 40, 44, 'w', 'C_II', '', 52.0, 41.0, 30.6),
	(18, 45, 49, 'w', 'C_II', '', 57.2, 45.5, 32.5),
	(18, 50, 54, 'w', 'C_II', '', 62.4, 50.7, 36.4),
	(18, 55, 59, 'w', 'C_II', '', 67.0, 55.3, 39.7),
	(18, 60, 64, 'w', 'C_II', '', 70.9, 57.9, 42.3),
	(18, 65, 69, 'w', 'C_II', '', 73.5, 60.5, 44.9),
	(18, 70, 74, 'w', 'C_II', '', 76.7, 62.4, 46.8),
	(18, 75, 79, 'w', 'C_II', '', 79.3, 65.0, 49.4),
	(18, 80, 84, 'w', 'C_II', '', 82.6, 67.6, 52.0),
	(18, 85, 89, 'w', 'C_II', '', 85.2, 69.6, 54.0),
	(18, 90, 200, 'w', 'C_II', '', 86.5, 70.9, 55.3),
	(18, 0, 7, 'm', 'C_II', '', 59.8, 49.4, 39.0),
	(18, 8, 9, 'm', 'C_II', '', 53.3, 42.9, 33.8),
	(18, 10, 11, 'm', 'C_II', '', 46.8, 37.7, 29.3),
	(18, 12, 13, 'm', 'C_II', '', 42.9, 35.1, 27.3),
	(18, 14, 15, 'm', 'C_II', '', 40.3, 33.2, 26.0),
	(18, 16, 17, 'm', 'C_II', '', 38.4, 31.9, 24.7),
	(18, 18, 19, 'm', 'C_II', '', 36.4, 29.9, 22.8),
	(18, 20, 24, 'm', 'C_II', '', 35.1, 28.6, 20.2),
	(18, 25, 29, 'm', 'C_II', '', 37.7, 29.9, 21.5),
	(18, 30, 34, 'm', 'C_II', '', 41.0, 31.2, 22.1),
	(18, 35, 39, 'm', 'C_II', '', 45.5, 34.5, 24.1),
	(18, 40, 44, 'm', 'C_II', '', 50.1, 38.4, 24.7),
	(18, 45, 49, 'm', 'C_II', '', 54.6, 42.3, 26.7),
	(18, 50, 54, 'm', 'C_II', '', 58.5, 45.5, 29.9),
	(18, 55, 59, 'm', 'C_II', '', 63.7, 48.1, 32.5),
	(18, 60, 64, 'm', 'C_II', '', 66.3, 50.7, 35.1),
	(18, 65, 69, 'm', 'C_II', '', 68.3, 52.7, 37.1),
	(18, 70, 74, 'm', 'C_II', '', 71.5, 55.9, 40.3),
	(18, 75, 79, 'm', 'C_II', '', 74.8, 59.2, 43.6),
	(18, 80, 84, 'm', 'C_II', '', 76.7, 62.4, 46.8),
	(18, 85, 89, 'm', 'C_II', '', 77.4, 63.7, 49.4),
	(18, 90, 200, 'm', 'C_II', '', 78.0, 65.0, 52.0),
	(19, 8, 9, 'w', 'C_II', '', 65.6, 57.6, 49.6),
	(19, 10, 11, 'w', 'C_II', '', 59.2, 51.2, 43.2),
	(19, 12, 13, 'w', 'C_II', '', 49.6, 43.2, 37.6),
	(19, 14, 15, 'w', 'C_II', '', 43.2, 39.2, 34.4),
	(19, 16, 17, 'w', 'C_II', '', 40.0, 36.0, 32.0),
	(19, 18, 19, 'w', 'C_II', '', 38.4, 35.2, 31.2),
	(19, 20, 24, 'w', 'C_II', '', 39.2, 35.2, 31.2),
	(19, 25, 29, 'w', 'C_II', '', 40.0, 36.0, 32.0),
	(19, 30, 34, 'w', 'C_II', '', 41.6, 37.6, 34.4),
	(19, 35, 39, 'w', 'C_II', '', 44.0, 39.2, 35.2),
	(19, 40, 44, 'w', 'C_II', '', 46.4, 40.8, 36.0),
	(19, 45, 49, 'w', 'C_II', '', 48.8, 43.2, 36.8),
	(19, 50, 54, 'w', 'C_II', '', 51.2, 44.8, 37.6),
	(19, 55, 59, 'w', 'C_II', '', 53.6, 46.4, 38.4),
	(19, 60, 64, 'w', 'C_II', '', 56.0, 48.0, 40.0),
	(19, 65, 69, 'w', 'C_II', '', 57.6, 49.6, 40.8),
	(19, 70, 74, 'w', 'C_II', '', 60.8, 51.2, 42.4),
	(19, 75, 79, 'w', 'C_II', '', 62.4, 52.8, 44.0),
	(19, 80, 84, 'w', 'C_II', '', 64.8, 55.2, 45.6),
	(19, 85, 89, 'w', 'C_II', '', 67.2, 57.6, 48.0),
	(19, 90, 200, 'w', 'C_II', '', 71.2, 60.8, 50.4),
	(19, 8, 9, 'm', 'C_II', '', 60.8, 52.8, 44.8),
	(19, 10, 11, 'm', 'C_II', '', 56.0, 48.8, 41.6),
	(19, 12, 13, 'm', 'C_II', '', 47.2, 41.6, 36.0),
	(19, 14, 15, 'm', 'C_II', '', 38.4, 34.4, 30.4),
	(19, 16, 17, 'm', 'C_II', '', 35.2, 31.2, 27.2),
	(19, 18, 19, 'm', 'C_II', '', 32.8, 28.8, 24.8),
	(19, 20, 24, 'm', 'C_II', '', 32.0, 28.0, 24.0),
	(19, 25, 29, 'm', 'C_II', '', 33.6, 28.8, 24.0),
	(19, 30, 34, 'm', 'C_II', '', 36.0, 29.6, 24.0),
	(19, 35, 39, 'm', 'C_II', '', 38.4, 32.0, 24.8),
	(19, 40, 44, 'm', 'C_II', '', 42.4, 34.4, 26.4),
	(19, 45, 49, 'm', 'C_II', '', 45.6, 36.8, 27.2),
	(19, 50, 54, 'm', 'C_II', '', 48.0, 38.4, 28.8),
	(19, 55, 59, 'm', 'C_II', '', 51.2, 40.0, 29.6),
	(19, 60, 64, 'm', 'C_II', '', 53.6, 41.6, 30.4),
	(19, 65, 69, 'm', 'C_II', '', 56.0, 43.2, 31.2),
	(19, 70, 74, 'm', 'C_II', '', 57.6, 45.6, 32.0),
	(19, 75, 79, 'm', 'C_II', '', 60.0, 47.2, 34.4),
	(19, 80, 84, 'm', 'C_II', '', 62.4, 50.4, 36.8),
	(19, 85, 89, 'm', 'C_II', '', 65.6, 52.8, 39.2),
	(19, 90, 200, 'm', 'C_II', '', 69.6, 56.8, 43.2),
	(25, 12, 13, 'w', 'C_II', '', 11.9, 13.65, 15.4),
	(25, 14, 15, 'w', 'C_II', '', 13.65, 15.75, 17.85),
	(25, 16, 17, 'w', 'C_II', '', 15.4, 17.5, 19.6),
	(25, 18, 19, 'w', 'C_II', '', 16.45, 18.55, 20.3),
	(25, 20, 24, 'w', 'C_II', '', 16.8, 18.9, 20.65),
	(25, 25, 29, 'w', 'C_II', '', 16.8, 18.9, 20.65),
	(25, 30, 34, 'w', 'C_II', '', 15.4, 17.5, 19.25),
	(25, 35, 39, 'w', 'C_II', '', 14.7, 16.8, 18.55),
	(25, 40, 44, 'w', 'C_II', '', 13.65, 15.75, 17.5),
	(25, 45, 49, 'w', 'C_II', '', 12.95, 15.05, 16.8),
	(25, 50, 54, 'w', 'C_II', '', 11.55, 14.0, 16.1),
	(25, 55, 59, 'w', 'C_II', '', 10.85, 13.3, 15.4),
	(25, 60, 64, 'w', 'C_II', '', 10.15, 12.6, 14.7),
	(25, 65, 69, 'w', 'C_II', '', 9.45, 11.9, 14.0),
	(25, 70, 74, 'w', 'C_II', '', 9.1, 11.55, 13.65),
	(25, 75, 79, 'w', 'C_II', '', 8.4, 10.85, 12.95),
	(25, 80, 84, 'w', 'C_II', '', 7.7, 10.15, 12.25),
	(25, 85, 89, 'w', 'C_II', '', 6.65, 9.1, 11.2),
	(25, 90, 200, 'w', 'C_II', '', 5.25, 7.7, 9.8),
	(25, 12, 13, 'm', 'C_II', '', 13.65, 16.8, 19.25),
	(25, 14, 15, 'm', 'C_II', '', 16.45, 19.6, 22.4),
	(25, 16, 17, 'm', 'C_II', '', 19.25, 22.4, 25.55),
	(25, 18, 19, 'm', 'C_II', '', 22.05, 25.2, 28.35),
	(25, 20, 24, 'm', 'C_II', '', 23.1, 26.6, 29.4),
	(25, 25, 29, 'm', 'C_II', '', 22.75, 26.25, 29.05),
	(25, 30, 34, 'm', 'C_II', '', 21.0, 24.5, 28.0),
	(25, 35, 39, 'm', 'C_II', '', 19.95, 23.45, 26.95),
	(25, 40, 44, 'm', 'C_II', '', 19.6, 23.1, 26.6),
	(25, 45, 49, 'm', 'C_II', '', 18.9, 22.4, 26.25),
	(25, 50, 54, 'm', 'C_II', '', 17.85, 21.7, 25.55),
	(25, 55, 59, 'm', 'C_II', '', 16.45, 20.3, 24.5),
	(25, 60, 64, 'm', 'C_II', '', 15.75, 19.6, 23.8),
	(25, 65, 69, 'm', 'C_II', '', 14.0, 17.85, 21.35),
	(25, 70, 74, 'm', 'C_II', '', 12.95, 16.8, 20.3),
	(25, 75, 79, 'm', 'C_II', '', 11.2, 14.7, 18.2),
	(25, 80, 84, 'm', 'C_II', '', 9.8, 13.3, 16.8),
	(25, 85, 89, 'm', 'C_II', '', 8.4, 11.55, 14.7),
	(25, 90, 200, 'm', 'C_II', '', 7.35, 10.5, 13.65),
	(33, 0, 7, 'w', 'C_II', 'auch als Walking möglich', 2.4000000000000004, 3.5999999999999996, 5.1),
	(33, 8, 9, 'w', 'C_II', 'auch als Walking möglich', 3.0, 4.5, 6.0),
	(33, 10, 11, 'w', 'C_II', 'auch als Walking möglich', 4.5, 6.0, 9.0),
	(33, 12, 13, 'w', 'C_II', 'auch als Walking möglich', 6.0, 9.0, 12.0),
	(33, 14, 15, 'w', 'C_II', 'auch als Walking möglich', 9.0, 12.0, 15.0),
	(33, 16, 17, 'w', 'C_II', 'auch als Walking möglich', 13.500000000000002, 18.0, 22.5),
	(33, 0, 7, 'm', 'C_II', 'auch als Walking möglich', 3.0, 4.5, 6.0),
	(33, 8, 9, 'm', 'C_II', 'auch als Walking möglich', 3.5999999999999996, 5.1, 6.9),
	(33, 10, 11, 'm', 'C_II', 'auch als Walking möglich', 5.1, 7.5, 10.500000000000002),
	(33, 12, 13, 'm', 'C_II', 'auch als Walking möglich', 7.5, 10.500000000000002, 13.500000000000002),
	(33, 14, 15, 'm', 'C_II', 'auch als Walking möglich', 10.500000000000002, 13.500000000000002, 18.0),
	(33, 16, 17, 'm', 'C_II', 'auch als Walking möglich', 16.5, 21.0, 27.0),
	(39, 0, 7, 'w', 'C_II', '', 182.0, 203.0, 223.0),
	(39, 8, 9, 'w', 'C_II', '', 194.0, 215.0, 237.0),
	(39, 10, 11, 'w', 'C_II', '', 205.0, 228.0, 250.0),
	(39, 12, 13, 'w', 'C_II', '', 216.0, 240.0, 264.0),
	(39, 14, 15, 'w', 'C_II', '', 227.0, 253.0, 278.0),
	(39, 16, 17, 'w', 'C_II', '', 239.0, 265.0, 292.0),
	(39, 18, 19, 'w', 'C_II', '', 329.0, 365.0, 402.0),
	(39, 20, 24, 'w', 'C_II', '', 329.0, 365.0, 402.0),
	(39, 25, 29, 'w', 'C_II', '', 329.0, 365.0, 402.0),
	(39, 30, 34, 'w', 'C_II', '', 317.0, 353.0, 388.0),
	(39, 35, 39, 'w', 'C_II', '', 317.0, 353.0, 388.0),
	(39, 40, 44, 'w', 'C_II', '', 306.0, 340.0, 374.0),
	(39, 45, 49, 'w', 'C_II', '', 295.0, 328.0, 360.0),
	(39, 50, 54, 'w', 'C_II', '', 284.0, 315.0, 347.0),
	(39, 55, 59, 'w', 'C_II', '', 272.0, 303.0, 333.0),
	(39, 60, 64, 'w', 'C_II', '', 261.0, 290.0, 319.0),
	(39, 65, 69, 'w', 'C_II', '', 250.0, 278.0, 305.0),
	(39, 70, 74, 'w', 'C_II', '', 239.0, 265.0, 292.0),
	(39, 75, 79, 'w', 'C_II', '', 227.0, 253.0, 278.0),
	(39, 80, 84, 'w', 'C_II', '', 216.0, 240.0, 264.0),
	(39, 85, 89, 'w', 'C_II', '', 205.0, 228.0, 250.0),
	(39, 90, 200, 'w', 'C_II', '', 194.0, 215.0, 237.0),
	(39, 0, 7, 'm', 'C_II', '', 241.0, 268.0, 294.0),
	(39, 8, 9, 'm', 'C_II', '', 252.0, 280.0, 308.0),
	(39, 10, 11, 'm', 'C_II', '', 263.0, 293.0, 322.0),
	(39, 12, 13, 'm', 'C_II', '', 275.0, 305.0, 336.0),
	(39, 14, 15, 'm', 'C_II', '', 286.0, 318.0, 349.0),
	(39, 16, 17, 'm', 'C_II', '', 297.0, 330.0, 363.0),
	(39, 18, 19, 'm', 'C_II', '', 387.0, 430.0, 473.0),
	(39, 20, 24, 'm', 'C_II', '', 387.0, 430.0, 473.0),
	(39, 25, 29, 'm', 'C_II', '', 387.0, 430.0, 473.0),
	(39, 30, 34, 'm', 'C_II', '', 376.0, 418.0, 459.0),
	(39, 35, 39, 'm', 'C_II', '', 376.0, 418.0, 459.0),
	(39, 40, 44, 'm', 'C_II', '', 365.0, 405.0, 446.0),
	(39, 45, 49, 'm', 'C_II', '', 353.0, 393.0, 432.0),
	(39, 50, 54, 'm', 'C_II', '', 342.0, 380.0, 418.0),
	(39, 55, 59, 'm', 'C_II', '', 331.0, 368.0, 404.0),
	(39, 60, 64, 'm', 'C_II', '', 320.0, 355.0, 391.0),
	(39, 65, 69, 'm', 'C_II', '', 308.0, 343.0, 377.0),
	(39, 70, 74, 'm', 'C_II', '', 297.0, 330.0, 363.0),
	(39, 75, 79, 'm', 'C_II', '', 286.0, 318.0, 349.0),
	(39, 80, 84, 'm', 'C_II', '', 275.0, 305.0, 336.0),
	(39, 85, 89, 'm', 'C_II', '', 263.0, 293.0, 322.0),
	(39, 90, 200, 'm', 'C_II', '', 252.0, 280.0, 308.0),
	(40, 0, 7, 'w', 'C_II', '', 342.0, 380.0, 418.0),
	(40, 8, 9, 'w', 'C_II', '', 356.0, 395.0, 435.0),
	(40, 10, 11, 'w', 'C_II', '', 369.0, 410.0, 451.0),
	(40, 12, 13, 'w', 'C_II', '', 383.0, 425.0, 468.0),
	(40, 14, 15, 'w', 'C_II', '', 396.0, 440.0, 484.0),
	(40, 16, 17, 'w', 'C_II', '', 410.0, 455.0, 501.0),
	(40, 18, 19, 'w', 'C_II', '', 500.0, 555.0, 611.0),
	(40, 20, 24, 'w', 'C_II', '', 500.0, 555.0, 611.0),
	(40, 25, 29, 'w', 'C_II', '', 500.0, 555.0, 611.0),
	(40, 30, 34, 'w', 'C_II', '', 486.0, 540.0, 594.0),
	(40, 35, 39, 'w', 'C_II', '', 486.0, 540.0, 594.0),
	(40, 40, 44, 'w', 'C_II', '', 473.0, 525.0, 578.0),
	(40, 45, 49, 'w', 'C_II', '', 459.0, 510.0, 561.0),
	(40, 50, 54, 'w', 'C_II', '', 446.0, 495.0, 545.0),
	(40, 55, 59, 'w', 'C_II', '', 432.0, 480.0, 528.0),
	(40, 60, 64, 'w', 'C_II', '', 419.0, 465.0, 512.0),
	(40, 65, 69, 'w', 'C_II', '', 405.0, 450.0, 495.0),
	(40, 70, 74, 'w', 'C_II', '', 392.0, 435.0, 479.0),
	(40, 75, 79, 'w', 'C_II', '', 378.0, 420.0, 462.0),
	(40, 80, 84, 'w', 'C_II', '', 365.0, 405.0, 446.0),
	(40, 85, 89, 'w', 'C_II', '', 351.0, 390.0, 429.0),
	(40, 90, 200, 'w', 'C_II', '', 338.0, 375.0, 413.0),
	(40, 0, 7, 'm', 'C_II', '', 410.0, 455.0, 501.0),
	(40, 8, 9, 'm', 'C_II', '', 423.0, 470.0, 517.0),
	(40, 10, 11, 'm', 'C_II', '', 437.0, 485.0, 534.0),
	(40, 12, 13, 'm', 'C_II', '', 450.0, 500.0, 550.0),
	(40, 14, 15, 'm', 'C_II', '', 464.0, 515.0, 567.0),
	(40, 16, 17, 'm', 'C_II', '', 477.0, 530.0, 583.0),
	(40, 18, 19, 'm', 'C_II', '', 567.0, 630.0, 693.0),
	(40, 20, 24, 'm', 'C_II', '', 567.0, 630.0, 693.0),
	(40, 25, 29, 'm', 'C_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'C_II', '', 554.0, 615.0, 677.0),
	(40, 35, 39, 'm', 'C_II', '', 554.0, 615.0, 677.0),
	(40, 40, 44, 'm', 'C_II', '', 540.0, 600.0, 660.0),
	(40, 45, 49, 'm', 'C_II', '', 527.0, 585.0, 644.0),
	(40, 50, 54, 'm', 'C_II', '', 513.0, 570.0, 627.0),
	(40, 55, 59, 'm', 'C_II', '', 500.0, 555.0, 611.0),
	(40, 60, 64, 'm', 'C_II', '', 486.0, 540.0, 594.0),
	(40, 65, 69, 'm', 'C_II', '', 473.0, 525.0, 578.0),
	(40, 70, 74, 'm', 'C_II', '', 459.0, 510.0, 561.0),
	(40, 75, 79, 'm', 'C_II', '', 446.0, 495.0, 545.0),
	(40, 80, 84, 'm', 'C_II', '', 432.0, 480.0, 528.0),
	(40, 85, 89, 'm', 'C_II', '', 419.0, 465.0, 512.0),
	(40, 90, 200, 'm', 'C_II', '', 405.0, 450.0, 495.0),
	(41, 0, 7, 'w', 'C_II', '', 275.0, 305.0, 336.0),
	(41, 8, 9, 'w', 'C_II', '', 288.0, 320.0, 352.0),
	(41, 10, 11, 'w', 'C_II', '', 302.0, 335.0, 369.0),
	(41, 12, 13, 'w', 'C_II', '', 315.0, 350.0, 385.0),
	(41, 14, 15, 'w', 'C_II', '', 329.0, 365.0, 402.0),
	(41, 16, 17, 'w', 'C_II', '', 342.0, 380.0, 418.0),
	(41, 18, 19, 'w', 'C_II', '', 432.0, 480.0, 528.0),
	(41, 20, 24, 'w', 'C_II', '', 432.0, 480.0, 528.0),
	(41, 25, 29, 'w', 'C_II', '', 432.0, 480.0, 528.0),
	(41, 30, 34, 'w', 'C_II', '', 419.0, 465.0, 512.0),
	(41, 35, 39, 'w', 'C_II', '', 419.0, 465.0, 512.0),
	(41, 40, 44, 'w', 'C_II', '', 405.0, 450.0, 495.0),
	(41, 45, 49, 'w', 'C_II', '', 392.0, 435.0, 479.0),
	(41, 50, 54, 'w', 'C_II', '', 378.0, 420.0, 462.0),
	(41, 55, 59, 'w', 'C_II', '', 365.0, 405.0, 446.0),
	(41, 60, 64, 'w', 'C_II', '', 351.0, 390.0, 429.0),
	(41, 65, 69, 'w', 'C_II', '', 338.0, 375.0, 413.0),
	(41, 70, 74, 'w', 'C_II', '', 324.0, 360.0, 396.0),
	(41, 75, 79, 'w', 'C_II', '', 311.0, 345.0, 380.0),
	(41, 80, 84, 'w', 'C_II', '', 297.0, 330.0, 363.0),
	(41, 85, 89, 'w', 'C_II', '', 284.0, 315.0, 347.0),
	(41, 90, 200, 'w', 'C_II', '', 270.0, 300.0, 330.0),
	(41, 0, 7, 'm', 'C_II', '', 338.0, 375.0, 413.0),
	(41, 8, 9, 'm', 'C_II', '', 351.0, 390.0, 429.0),
	(41, 10, 11, 'm', 'C_II', '', 365.0, 405.0, 446.0),
	(41, 12, 13, 'm', 'C_II', '', 378.0, 420.0, 462.0),
	(41, 14, 15, 'm', 'C_II', '', 392.0, 435.0, 479.0),
	(41, 16, 17, 'm', 'C_II', '', 405.0, 450.0, 495.0),
	(41, 18, 19, 'm', 'C_II', '', 495.0, 550.0, 605.0),
	(41, 20, 24, 'm', 'C_II', '', 495.0, 550.0, 605.0),
	(41, 25, 29, 'm', 'C_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'C_II', '', 482.0, 535.0, 589.0),
	(41, 35, 39, 'm', 'C_II', '', 482.0, 535.0, 589.0),
	(41, 40, 44, 'm', 'C_II', '', 468.0, 520.0, 572.0),
	(41, 45, 49, 'm', 'C_II', '', 455.0, 505.0, 556.0),
	(41, 50, 54, 'm', 'C_II', '', 441.0, 490.0, 539.0),
	(41, 55, 59, 'm', 'C_II', '', 428.0, 475.0, 523.0),
	(41, 60, 64, 'm', 'C_II', '', 414.0, 460.0, 506.0),
	(41, 65, 69, 'm', 'C_II', '', 401.0, 445.0, 490.0),
	(41, 70, 74, 'm', 'C_II', '', 387.0, 430.0, 473.0),
	(41, 75, 79, 'm', 'C_II', '', 374.0, 415.0, 457.0),
	(41, 80, 84, 'm', 'C_II', '', 360.0, 400.0, 440.0),
	(41, 85, 89, 'm', 'C_II', '', 347.0, 385.0, 424.0),
	(41, 90, 200, 'm', 'C_II', '', 333.0, 370.0, 407.0),
	(42, 0, 7, 'w', 'C_II', '', 279.0, 310.0, 341.0),
	(42, 8, 9, 'w', 'C_II', '', 293.0, 325.0, 358.0),
	(42, 10, 11, 'w', 'C_II', '', 306.0, 340.0, 374.0),
	(42, 12, 13, 'w', 'C_II', '', 320.0, 355.0, 391.0),
	(42, 14, 15, 'w', 'C_II', '', 333.0, 370.0, 407.0),
	(42, 16, 17, 'w', 'C_II', '', 347.0, 385.0, 424.0),
	(42, 18, 19, 'w', 'C_II', '', 437.0, 485.0, 534.0),
	(42, 20, 24, 'w', 'C_II', '', 437.0, 485.0, 534.0),
	(42, 25, 29, 'w', 'C_II', '', 437.0, 485.0, 534.0),
	(42, 30, 34, 'w', 'C_II', '', 423.0, 470.0, 517.0),
	(42, 35, 39, 'w', 'C_II', '', 423.0, 470.0, 517.0),
	(42, 40, 44, 'w', 'C_II', '', 410.0, 455.0, 501.0),
	(42, 45, 49, 'w', 'C_II', '', 396.0, 440.0, 484.0),
	(42, 50, 54, 'w', 'C_II', '', 383.0, 425.0, 468.0),
	(42, 55, 59, 'w', 'C_II', '', 369.0, 410.0, 451.0),
	(42, 60, 64, 'w', 'C_II', '', 356.0, 395.0, 435.0),
	(42, 65, 69, 'w', 'C_II', '', 342.0, 380.0, 418.0),
	(42, 70, 74, 'w', 'C_II', '', 329.0, 365.0, 402.0),
	(42, 75, 79, 'w', 'C_II', '', 315.0, 350.0, 385.0),
	(42, 80, 84, 'w', 'C_II', '', 302.0, 335.0, 369.0),
	(42, 85, 89, 'w', 'C_II', '', 288.0, 320.0, 352.0),
	(42, 90, 200, 'w', 'C_II', '', 275.0, 305.0, 336.0),
	(42, 0, 7, 'm', 'C_II', '', 342.0, 380.0, 418.0),
	(42, 8, 9, 'm', 'C_II', '', 356.0, 395.0, 435.0),
	(42, 10, 11, 'm', 'C_II', '', 369.0, 410.0, 451.0),
	(42, 12, 13, 'm', 'C_II', '', 383.0, 425.0, 468.0),
	(42, 14, 15, 'm', 'C_II', '', 396.0, 440.0, 484.0),
	(42, 16, 17, 'm', 'C_II', '', 410.0, 455.0, 501.0),
	(42, 18, 19, 'm', 'C_II', '', 500.0, 555.0, 611.0),
	(42, 20, 24, 'm', 'C_II', '', 500.0, 555.0, 611.0),
	(42, 25, 29, 'm', 'C_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'C_II', '', 486.0, 540.0, 594.0),
	(42, 35, 39, 'm', 'C_II', '', 486.0, 540.0, 594.0),
	(42, 40, 44, 'm', 'C_II', '', 473.0, 525.0, 578.0),
	(42, 45, 49, 'm', 'C_II', '', 459.0, 510.0, 561.0),
	(42, 50, 54, 'm', 'C_II', '', 446.0, 495.0, 545.0),
	(42, 55, 59, 'm', 'C_II', '', 432.0, 480.0, 528.0),
	(42, 60, 64, 'm', 'C_II', '', 419.0, 465.0, 512.0),
	(42, 65, 69, 'm', 'C_II', '', 405.0, 450.0, 495.0),
	(42, 70, 74, 'm', 'C_II', '', 392.0, 435.0, 479.0),
	(42, 75, 79, 'm', 'C_II', '', 378.0, 420.0, 462.0),
	(42, 80, 84, 'm', 'C_II', '', 365.0, 405.0, 446.0),
	(42, 85, 89, 'm', 'C_II', '', 351.0, 390.0, 429.0),
	(42, 90, 200, 'm', 'C_II', '', 338.0, 375.0, 413.0),
	(44, 12, 13, 'w', 'C_II', '', 5.65, 6.25, 6.84),
	(44, 14, 15, 'w', 'C_II', '', 6.55, 7.14, 7.74),
	(44, 16, 17, 'w', 'C_II', '', 6.84, 7.44, 8.03),
	(44, 18, 19, 'w', 'C_II', '', 8.84, 9.52, 10.2),
	(44, 20, 24, 'w', 'C_II', '', 8.84, 9.52, 10.2),
	(44, 25, 29, 'w', 'C_II', '', 8.84, 9.52, 10.2),
	(44, 30, 34, 'w', 'C_II', '', 8.5, 9.18, 9.86),
	(44, 35, 39, 'w', 'C_II', '', 8.16, 8.84, 9.52),
	(44, 40, 44, 'w', 'C_II', '', 7.48, 8.16, 8.84),
	(44, 45, 49, 'w', 'C_II', '', 7.14, 7.82, 8.5),
	(44, 50, 54, 'w', 'C_II', '', 7.14, 8.16, 9.52),
	(44, 55, 59, 'w', 'C_II', '', 6.8, 7.82, 8.84),
	(44, 60, 64, 'w', 'C_II', '', 6.46, 7.48, 8.5),
	(44, 65, 69, 'w', 'C_II', '', 6.12, 7.14, 8.5),
	(44, 70, 74, 'w', 'C_II', '', 5.78, 6.8, 8.16),
	(44, 75, 79, 'w', 'C_II', '', 5.78, 7.14, 8.5),
	(44, 80, 84, 'w', 'C_II', '', 5.44, 6.8, 7.82),
	(44, 85, 89, 'w', 'C_II', '', 5.1, 6.12, 7.48),
	(44, 90, 200, 'w', 'C_II', '', 4.42, 5.78, 6.8),
	(44, 12, 13, 'm', 'C_II', '', 7.44, 8.03, 8.63),
	(44, 14, 15, 'm', 'C_II', '', 8.33, 8.93, 9.52),
	(44, 16, 17, 'm', 'C_II', '', 8.93, 9.52, 10.12),
	(44, 18, 19, 'm', 'C_II', '', 10.54, 11.22, 11.9),
	(44, 20, 24, 'm', 'C_II', '', 10.54, 11.56, 12.24),
	(44, 25, 29, 'm', 'C_II', '', 10.2, 11.22, 11.9),
	(44, 30, 34, 'm', 'C_II', '', 9.52, 10.54, 11.22),
	(44, 35, 39, 'm', 'C_II', '', 9.18, 9.86, 10.88),
	(44, 40, 44, 'm', 'C_II', '', 8.5, 9.52, 10.54),
	(44, 45, 49, 'm', 'C_II', '', 8.16, 9.18, 10.2),
	(44, 50, 54, 'm', 'C_II', '', 8.5, 9.52, 10.88),
	(44, 55, 59, 'm', 'C_II', '', 8.16, 9.18, 10.2),
	(44, 60, 64, 'm', 'C_II', '', 8.16, 9.52, 10.88),
	(44, 65, 69, 'm', 'C_II', '', 7.82, 9.18, 10.2),
	(44, 70, 74, 'm', 'C_II', '', 7.65, 9.01, 10.03),
	(44, 75, 79, 'm', 'C_II', '', 7.82, 8.84, 10.2),
	(44, 80, 84, 'm', 'C_II', '', 7.48, 8.5, 9.86),
	(44, 85, 89, 'm', 'C_II', '', 6.8, 8.16, 9.18),
	(44, 90, 200, 'm', 'C_II', '', 6.12, 7.14, 8.5),
	(47, 0, 7, 'w', 'C_II', '30 m', 25.6, 22.7, 20.2),
	(47, 8, 9, 'w', 'C_II', '30 m', 23.7, 21.1, 18.2),
	(47, 10, 11, 'w', 'C_II', '50 m', 35.2, 32.3, 29.1),
	(47, 12, 13, 'w', 'C_II', '50 m', 33.9, 30.7, 27.2),
	(47, 14, 15, 'w', 'C_II', '100 m', 59.5, 54.4, 49.6),
	(47, 16, 17, 'w', 'C_II', '100 m', 56.3, 52.2, 48.0),
	(47, 18, 19, 'w', 'C_II', '100 m', 54.6, 49.5, 45.9),
	(47, 20, 24, 'w', 'C_II', '100 m', 55.5, 50.4, 46.8),
	(47, 25, 29, 'w', 'C_II', '100 m', 56.7, 51.6, 48.0),
	(47, 30, 34, 'w', 'C_II', '100 m', 58.8, 53.4, 49.2),
	(47, 35, 39, 'w', 'C_II', '100 m', 61.2, 55.8, 51.0),
	(47, 40, 44, 'w', 'C_II', '50 m', 33.0, 29.7, 26.4),
	(47, 45, 49, 'w', 'C_II', '50 m', 34.5, 30.9, 27.3),
	(47, 50, 54, 'w', 'C_II', '50 m', 35.7, 32.1, 28.5),
	(47, 55, 59, 'w', 'C_II', '50 m', 37.2, 33.6, 29.7),
	(47, 60, 64, 'w', 'C_II', '50 m', 37.8, 34.2, 30.6),
	(47, 65, 69, 'w', 'C_II', '50 m', 38.4, 34.8, 31.2),
	(47, 70, 74, 'w', 'C_II', '50 m', 39.0, 35.4, 31.8),
	(47, 75, 79, 'w', 'C_II', '50 m', 40.5, 36.9, 33.3),
	(47, 80, 84, 'w', 'C_II', '50 m', 42.9, 39.3, 36.0),
	(47, 85, 89, 'w', 'C_II', '50 m', 46.5, 42.9, 39.6),
	(47, 90, 200, 'w', 'C_II', '50 m', 51.3, 47.7, 44.4),
	(47, 0, 7, 'm', 'C_II', '30 m', 24.6, 21.8, 19.2),
	(47, 8, 9, 'm', 'C_II', '30 m', 23.0, 20.5, 18.2),
	(47, 10, 11, 'm', 'C_II', '50 m', 33.0, 29.8, 26.9),
	(47, 12, 13, 'm', 'C_II', '50 m', 31.0, 28.5, 25.9),
	(47, 14, 15, 'm', 'C_II', '100 m', 54.4, 49.3, 45.1),
	(47, 16, 17, 'm', 'C_II', '100 m', 52.2, 47.4, 43.2),
	(47, 18, 19, 'm', 'C_II', '100 m', 48.0, 43.8, 39.6),
	(47, 20, 24, 'm', 'C_II', '100 m', 47.4, 43.2, 39.0),
	(47, 25, 29, 'm', 'C_II', '100 m', 48.9, 44.4, 39.9),
	(47, 30, 34, 'm', 'C_II', '100 m', 50.4, 45.3, 40.8),
	(47, 35, 39, 'm', 'C_II', '100 m', 52.8, 47.7, 42.6),
	(47, 40, 44, 'm', 'C_II', '50 m', 28.8, 26.1, 23.1),
	(47, 45, 49, 'm', 'C_II', '50 m', 30.0, 26.7, 23.7),
	(47, 50, 54, 'm', 'C_II', '50 m', 30.9, 27.3, 24.6),
	(47, 55, 59, 'm', 'C_II', '50 m', 31.5, 28.2, 25.5),
	(47, 60, 64, 'm', 'C_II', '50 m', 32.4, 29.1, 26.4),
	(47, 65, 69, 'm', 'C_II', '50 m', 33.6, 30.6, 27.3),
	(47, 70, 74, 'm', 'C_II', '50 m', 35.1, 32.1, 28.8),
	(47, 75, 79, 'm', 'C_II', '50 m', 36.6, 33.6, 30.3),
	(47, 80, 84, 'm', 'C_II', '50 m', 39.0, 36.0, 32.7),
	(47, 85, 89, 'm', 'C_II', '50 m', 42.3, 39.3, 36.0),
	(47, 90, 200, 'm', 'C_II', '50 m', 46.5, 43.5, 40.2),
	(53, 0, 7, 'w', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'C_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'C_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'C_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'C_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'C_II', '', 1.0, 2.0, 3.0),
	(57, 0, 7, 'w', 'C_II', '', 8.0, 11.0, 15.0),
	(57, 8, 9, 'w', 'C_II', '', 13.0, 15.0, 19.0),
	(57, 10, 11, 'w', 'C_II', '', 19.0, 21.0, 25.0),
	(57, 0, 7, 'm', 'C_II', '', 11.0, 13.0, 17.0),
	(57, 8, 9, 'm', 'C_II', '', 15.0, 19.0, 23.0),
	(57, 10, 11, 'm', 'C_II', '', 23.0, 27.0, 32.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'D_I', '', 6.2333333333333325, 5.5, 4.683333333333334),
	(1, 8, 9, 'w', 'D_I', '', 6.133333333333334, 5.316666666666667, 4.583333333333333),
	(1, 10, 11, 'w', 'D_I', '', 5.866666666666666, 5.133333333333334, 4.4),
	(1, 12, 13, 'w', 'D_I', '', 5.683333333333334, 4.866666666666666, 4.133333333333334),
	(1, 14, 15, 'w', 'D_I', '', 5.5, 4.766666666666667, 3.9499999999999997),
	(1, 16, 17, 'w', 'D_I', '', 5.316666666666667, 4.5, 3.7666666666666666),
	(1, 0, 7, 'm', 'D_I', '', 6.2333333333333325, 5.5, 4.683333333333334),
	(1, 8, 9, 'm', 'D_I', '', 5.966666666666667, 5.133333333333334, 4.316666666666667),
	(1, 10, 11, 'm', 'D_I', '', 5.583333333333333, 4.766666666666667, 3.9499999999999997),
	(1, 12, 13, 'm', 'D_I', '', 5.2333333333333325, 4.4, 3.5833333333333335),
	(1, 14, 15, 'm', 'D_I', '', 4.766666666666667, 4.033333333333332, 3.3000000000000003),
	(1, 16, 17, 'm', 'D_I', '', 4.5, 3.7666666666666666, 3.033333333333333),
	(4, 8, 9, 'w', 'D_I', '5 km', 29.700000000000003, 26.4, 23.099999999999998),
	(4, 10, 11, 'w', 'D_I', '10 km', 55.55, 47.3, 39.050000000000004),
	(4, 12, 13, 'w', 'D_I', '10 km', 49.49999999999999, 43.45, 36.849999999999994),
	(4, 14, 15, 'w', 'D_I', '10 km', 41.8, 35.75000000000001, 31.35),
	(4, 16, 17, 'w', 'D_I', '10 km', 35.75000000000001, 31.35, 27.5),
	(4, 18, 19, 'w', 'D_I', '20 km', 63.25, 57.199999999999996, 51.150000000000006),
	(4, 20, 24, 'w', 'D_I', '20 km', 62.7, 56.65, 50.050000000000004),
	(4, 25, 29, 'w', 'D_I', '20 km', 61.6, 55.55, 49.49999999999999),
	(4, 30, 34, 'w', 'D_I', '20 km', 62.7, 56.65, 50.050000000000004),
	(4, 35, 39, 'w', 'D_I', '20 km', 66.0, 58.3, 51.7),
	(4, 40, 44, 'w', 'D_I', '20 km', 70.39999999999999, 61.050000000000004, 54.45),
	(4, 45, 49, 'w', 'D_I', '20 km', 73.7, 64.35, 56.65),
	(4, 50, 54, 'w', 'D_I', '20 km', 75.9, 67.10000000000001, 58.849999999999994),
	(4, 55, 59, 'w', 'D_I', '20 km', 78.65, 69.30000000000001, 61.050000000000004),
	(4, 60, 64, 'w', 'D_I', '20 km', 81.39999999999999, 71.5, 62.7),
	(4, 65, 69, 'w', 'D_I', '20 km', 83.05, 73.15, 64.35),
	(4, 70, 74, 'w', 'D_I', '20 km', 85.80000000000001, 75.35, 66.55),
	(4, 75, 79, 'w', 'D_I', '20 km', 89.65, 77.55, 69.30000000000001),
	(4, 80, 84, 'w', 'D_I', '20 km', 92.94999999999999, 82.5, 72.05),
	(4, 85, 89, 'w', 'D_I', '20 km', 98.44999999999999, 88.0, 75.9),
	(4, 90, 200, 'w', 'D_I', '20 km', 102.30000000000001, 91.30000000000001, 79.75),
	(4, 8, 9, 'm', 'D_I', '5 km', 29.15, 25.85, 22.549999999999997),
	(4, 10, 11, 'm', 'D_I', '10 km', 53.35, 45.1, 36.849999999999994),
	(4, 12, 13, 'm', 'D_I', '10 km', 47.3, 40.7, 34.65),
	(4, 14, 15, 'm', 'D_I', '10 km', 35.199999999999996, 30.8, 26.4),
	(4, 16, 17, 'm', 'D_I', '10 km', 29.700000000000003, 25.85, 22.549999999999997),
	(4, 18, 19, 'm', 'D_I', '20 km', 51.7, 46.75000000000001, 42.35),
	(4, 20, 24, 'm', 'D_I', '20 km', 51.150000000000006, 46.199999999999996, 41.25),
	(4, 25, 29, 'm', 'D_I', '20 km', 55.0, 48.95, 42.9),
	(4, 30, 34, 'm', 'D_I', '20 km', 58.849999999999994, 51.7, 44.55),
	(4, 35, 39, 'm', 'D_I', '20 km', 63.8, 55.0, 45.65),
	(4, 40, 44, 'm', 'D_I', '20 km', 69.30000000000001, 57.199999999999996, 47.849999999999994),
	(4, 45, 49, 'm', 'D_I', '20 km', 72.6, 60.49999999999999, 49.49999999999999),
	(4, 50, 54, 'm', 'D_I', '20 km', 75.35, 62.7, 51.150000000000006),
	(4, 55, 59, 'm', 'D_I', '20 km', 77.55, 64.35, 52.25),
	(4, 60, 64, 'm', 'D_I', '20 km', 78.65, 66.0, 52.8),
	(4, 65, 69, 'm', 'D_I', '20 km', 79.75, 66.55, 53.35),
	(4, 70, 74, 'm', 'D_I', '20 km', 80.85000000000001, 67.65, 54.45),
	(4, 75, 79, 'm', 'D_I', '20 km', 81.94999999999999, 69.30000000000001, 56.65),
	(4, 80, 84, 'm', 'D_I', '20 km', 83.6, 70.94999999999999, 58.3),
	(4, 85, 89, 'm', 'D_I', '20 km', 85.25000000000001, 73.15, 61.050000000000004),
	(4, 90, 200, 'm', 'D_I', '20 km', 86.9, 74.80000000000001, 63.8),
	(5, 18, 19, 'w', 'D_I', '', 22.916666666666668, 20.716666666666665, 18.516666666666666),
	(5, 20, 24, 'w', 'D_I', '', 22.366666666666664, 20.166666666666668, 17.966666666666665),
	(5, 25, 29, 'w', 'D_I', '', 22.733333333333334, 20.533333333333335, 18.333333333333332),
	(5, 30, 34, 'w', 'D_I', '', 23.650000000000002, 21.45, 19.249999999999996),
	(5, 35, 39, 'w', 'D_I', '', 24.200000000000003, 22.0, 19.8),
	(5, 40, 44, 'w', 'D_I', '', 25.116666666666667, 22.733333333333334, 20.35),
	(5, 45, 49, 'w', 'D_I', '', 26.216666666666665, 23.650000000000002, 20.716666666666665),
	(5, 50, 54, 'w', 'D_I', '', 27.31666666666667, 24.383333333333333, 21.083333333333336),
	(5, 55, 59, 'w', 'D_I', '', 28.416666666666668, 25.116666666666667, 21.816666666666663),
	(5, 60, 64, 'w', 'D_I', '', 29.15, 25.85, 22.549999999999997),
	(5, 65, 69, 'w', 'D_I', '', 29.883333333333336, 26.583333333333336, 23.283333333333335),
	(5, 70, 74, 'w', 'D_I', '', 30.433333333333337, 27.13333333333333, 23.833333333333332),
	(5, 75, 79, 'w', 'D_I', '', 31.35, 28.05, 24.75),
	(5, 80, 84, 'w', 'D_I', '', 32.63333333333334, 29.333333333333332, 26.03333333333333),
	(5, 85, 89, 'w', 'D_I', '', 34.1, 30.8, 27.5),
	(5, 90, 200, 'w', 'D_I', '', 35.75000000000001, 32.45, 29.15),
	(5, 18, 19, 'm', 'D_I', '', 19.616666666666667, 17.416666666666668, 15.216666666666669),
	(5, 20, 24, 'm', 'D_I', '', 19.066666666666666, 16.866666666666667, 14.666666666666668),
	(5, 25, 29, 'm', 'D_I', '', 19.433333333333337, 17.233333333333334, 15.033333333333333),
	(5, 30, 34, 'm', 'D_I', '', 20.35, 18.15, 15.950000000000001),
	(5, 35, 39, 'm', 'D_I', '', 21.816666666666663, 19.066666666666666, 16.5),
	(5, 40, 44, 'm', 'D_I', '', 23.099999999999998, 20.35, 17.416666666666668),
	(5, 45, 49, 'm', 'D_I', '', 24.383333333333333, 21.45, 18.15),
	(5, 50, 54, 'm', 'D_I', '', 25.666666666666664, 22.366666666666664, 19.066666666666666),
	(5, 55, 59, 'm', 'D_I', '', 26.216666666666665, 22.916666666666668, 19.616666666666667),
	(5, 60, 64, 'm', 'D_I', '', 26.95, 23.650000000000002, 20.35),
	(5, 65, 69, 'm', 'D_I', '', 27.5, 24.200000000000003, 20.9),
	(5, 70, 74, 'm', 'D_I', '', 27.866666666666667, 24.566666666666666, 21.266666666666666),
	(5, 75, 79, 'm', 'D_I', '', 28.599999999999998, 25.3, 22.0),
	(5, 80, 84, 'm', 'D_I', '', 29.15, 25.85, 22.549999999999997),
	(5, 85, 89, 'm', 'D_I', '', 30.249999999999996, 26.95, 23.650000000000002),
	(5, 90, 200, 'm', 'D_I', '', 32.81666666666667, 29.516666666666666, 26.216666666666665),
	(6, 18, 19, 'w', 'D_I', '', 93.13333333333333, 86.53333333333332, 79.93333333333334),
	(6, 20, 24, 'w', 'D_I', '', 91.85000000000001, 84.51666666666667, 78.65),
	(6, 25, 29, 'w', 'D_I', '', 91.85000000000001, 84.51666666666667, 78.10000000000001),
	(6, 30, 34, 'w', 'D_I', '', 92.58333333333333, 85.80000000000001, 78.46666666666667),
	(6, 35, 39, 'w', 'D_I', '', 96.43333333333334, 87.44999999999999, 78.65),
	(6, 40, 44, 'w', 'D_I', '', 100.46666666666667, 89.46666666666667, 78.83333333333333),
	(6, 45, 49, 'w', 'D_I', '', 104.86666666666666, 91.48333333333335, 80.11666666666666),
	(6, 50, 54, 'w', 'D_I', '', 107.43333333333334, 94.05, 81.39999999999999),
	(6, 55, 59, 'w', 'D_I', '', 110.18333333333334, 96.98333333333333, 83.78333333333333),
	(6, 60, 64, 'w', 'D_I', '', 113.11666666666666, 99.91666666666666, 86.71666666666668),
	(6, 65, 69, 'w', 'D_I', '', 116.23333333333333, 103.03333333333333, 89.83333333333333),
	(6, 70, 74, 'w', 'D_I', '', 120.44999999999999, 107.25000000000001, 94.05),
	(6, 75, 79, 'w', 'D_I', '', 126.86666666666666, 113.66666666666667, 100.46666666666667),
	(6, 80, 84, 'w', 'D_I', '', 134.56666666666666, 121.36666666666666, 108.16666666666666),
	(6, 85, 89, 'w', 'D_I', '', 142.08333333333334, 128.88333333333333, 115.68333333333332),
	(6, 90, 200, 'w', 'D_I', '', 150.15, 136.95, 123.75),
	(6, 18, 19, 'm', 'D_I', '', 69.66666666666667, 63.06666666666666, 56.46666666666667),
	(6, 20, 24, 'm', 'D_I', '', 68.75, 62.150000000000006, 55.0),
	(6, 25, 29, 'm', 'D_I', '', 72.6, 65.26666666666667, 57.199999999999996),
	(6, 30, 34, 'm', 'D_I', '', 76.63333333333333, 67.28333333333333, 60.31666666666666),
	(6, 35, 39, 'm', 'D_I', '', 81.58333333333333, 72.05, 62.51666666666667),
	(6, 40, 44, 'm', 'D_I', '', 86.71666666666668, 76.44999999999999, 66.18333333333334),
	(6, 45, 49, 'm', 'D_I', '', 92.03333333333333, 80.48333333333335, 69.85000000000001),
	(6, 50, 54, 'm', 'D_I', '', 97.16666666666666, 84.33333333333334, 72.05),
	(6, 55, 59, 'm', 'D_I', '', 100.65, 87.63333333333333, 74.43333333333334),
	(6, 60, 64, 'm', 'D_I', '', 104.13333333333333, 90.93333333333334, 77.73333333333333),
	(6, 65, 69, 'm', 'D_I', '', 107.80000000000001, 94.6, 81.39999999999999),
	(6, 70, 74, 'm', 'D_I', '', 112.38333333333334, 99.18333333333334, 85.98333333333333),
	(6, 75, 79, 'm', 'D_I', '', 118.06666666666668, 104.86666666666666, 91.66666666666667),
	(6, 80, 84, 'm', 'D_I', '', 124.48333333333335, 111.28333333333333, 98.08333333333333),
	(6, 85, 89, 'm', 'D_I', '', 132.18333333333337, 118.98333333333333, 105.78333333333333),
	(6, 90, 200, 'm', 'D_I', '', 140.4333333333333, 127.23333333333333, 114.03333333333333),
	(7, 0, 7, 'w', 'D_I', '200 m', 9.899999999999999, 8.433333333333334, 6.966666666666667),
	(7, 8, 9, 'w', 'D_I', '200 m', 8.8, 7.7, 6.516666666666666),
	(7, 10, 11, 'w', 'D_I', '200 m', 8.066666666666665, 7.066666666666666, 6.050000000000001),
	(7, 12, 13, 'w', 'D_I', '400 m', 16.31666666666667, 14.216666666666669, 12.100000000000001),
	(7, 14, 15, 'w', 'D_I', '400 m', 14.383333333333335, 12.833333333333334, 11.0),
	(7, 16, 17, 'w', 'D_I', '400 m', 13.016666666666666, 11.55, 10.0),
	(7, 18, 19, 'w', 'D_I', '800 m', 26.4, 23.283333333333335, 20.266666666666666),
	(7, 20, 24, 'w', 'D_I', '800 m', 25.93333333333333, 22.916666666666668, 19.8),
	(7, 25, 29, 'w', 'D_I', '800 m', 28.05, 23.183333333333334, 20.533333333333335),
	(7, 30, 34, 'w', 'D_I', '800 m', 31.716666666666665, 26.03333333333333, 21.45),
	(7, 35, 39, 'w', 'D_I', '800 m', 35.199999999999996, 28.15, 22.366666666666664),
	(7, 40, 44, 'w', 'D_I', '800 m', 37.400000000000006, 30.433333333333337, 23.46666666666667),
	(7, 45, 49, 'w', 'D_I', '800 m', 38.866666666666674, 31.9, 23.650000000000002),
	(7, 50, 54, 'w', 'D_I', '400 m', 19.8, 16.5, 12.65),
	(7, 55, 59, 'w', 'D_I', '400 m', 20.433333333333337, 16.866666666666667, 13.100000000000001),
	(7, 60, 64, 'w', 'D_I', '400 m', 20.9, 17.15, 13.383333333333335),
	(7, 65, 69, 'w', 'D_I', '400 m', 21.366666666666664, 17.333333333333332, 13.466666666666665),
	(7, 70, 74, 'w', 'D_I', '400 m', 21.816666666666663, 17.700000000000003, 13.933333333333334),
	(7, 75, 79, 'w', 'D_I', '200 m', 11.283333333333333, 9.166666666666666, 7.1499999999999995),
	(7, 80, 84, 'w', 'D_I', '200 m', 11.466666666666665, 9.350000000000001, 7.416666666666667),
	(7, 85, 89, 'w', 'D_I', '200 m', 11.633333333333335, 9.616666666666665, 7.800000000000001),
	(7, 90, 200, 'w', 'D_I', '200 m', 11.833333333333334, 9.816666666666666, 8.066666666666665),
	(7, 0, 7, 'm', 'D_I', '200 m', 9.899999999999999, 8.066666666666665, 6.783333333333333),
	(7, 8, 9, 'm', 'D_I', '200 m', 8.8, 7.416666666666667, 6.2333333333333325),
	(7, 10, 11, 'm', 'D_I', '200 m', 7.7, 6.966666666666667, 5.683333333333334),
	(7, 12, 13, 'm', 'D_I', '400 m', 14.85, 12.65, 10.733333333333333),
	(7, 14, 15, 'm', 'D_I', '400 m', 13.2, 11.283333333333333, 9.716666666666667),
	(7, 16, 17, 'm', 'D_I', '400 m', 12.100000000000001, 10.633333333333335, 9.166666666666666),
	(7, 18, 19, 'm', 'D_I', '800 m', 24.85, 21.816666666666663, 18.700000000000003),
	(7, 20, 24, 'm', 'D_I', '800 m', 24.383333333333333, 21.45, 18.066666666666666),
	(7, 25, 29, 'm', 'D_I', '800 m', 25.48333333333333, 22.0, 18.700000000000003),
	(7, 30, 34, 'm', 'D_I', '800 m', 28.31666666666667, 23.650000000000002, 19.8),
	(7, 35, 39, 'm', 'D_I', '800 m', 31.716666666666665, 26.4, 21.183333333333334),
	(7, 40, 44, 'm', 'D_I', '800 m', 35.65, 29.066666666666666, 22.46666666666667),
	(7, 45, 49, 'm', 'D_I', '800 m', 37.95, 30.616666666666667, 22.733333333333334),
	(7, 50, 54, 'm', 'D_I', '400 m', 19.166666666666668, 15.766666666666667, 11.833333333333334),
	(7, 55, 59, 'm', 'D_I', '400 m', 19.616666666666667, 16.05, 12.466666666666665),
	(7, 60, 64, 'm', 'D_I', '400 m', 19.983333333333334, 16.233333333333334, 12.55),
	(7, 65, 69, 'm', 'D_I', '400 m', 20.266666666666666, 16.599999999999998, 12.65),
	(7, 70, 74, 'm', 'D_I', '400 m', 20.266666666666666, 16.76666666666667, 12.749999999999998),
	(7, 75, 79, 'm', 'D_I', '200 m', 10.366666666666667, 8.433333333333334, 6.7),
	(7, 80, 84, 'm', 'D_I', '200 m', 10.45, 8.616666666666665, 6.783333333333333),
	(7, 85, 89, 'm', 'D_I', '200 m', 10.45, 8.8, 7.066666666666666),
	(7, 90, 200, 'm', 'D_I', '200 m', 10.733333333333333, 8.983333333333333, 7.416666666666667),
	(8, 18, 19, 'w', 'D_I', '7,5 km', 72.98333333333333, 69.30000000000001, 65.10000000000001),
	(8, 20, 24, 'w', 'D_I', '7,5 km', 69.83333333333333, 66.15, 62.483333333333334),
	(8, 25, 29, 'w', 'D_I', '7,5 km', 70.35, 66.68333333333332, 63.0),
	(8, 30, 34, 'w', 'D_I', '7,5 km', 70.88333333333334, 67.2, 63.43333333333333),
	(8, 35, 39, 'w', 'D_I', '7,5 km', 73.5, 68.25000000000001, 63.78333333333333),
	(8, 40, 44, 'w', 'D_I', '7,5 km', 76.65, 70.35, 64.05),
	(8, 45, 49, 'w', 'D_I', '7,5 km', 79.28333333333333, 72.44999999999999, 65.10000000000001),
	(8, 50, 54, 'w', 'D_I', '7,5 km', 81.9, 74.55, 67.2),
	(8, 55, 59, 'w', 'D_I', '7,5 km', 84.0, 76.65, 69.30000000000001),
	(8, 60, 64, 'w', 'D_I', '7,5 km', 86.63333333333333, 78.23333333333333, 70.88333333333334),
	(8, 65, 69, 'w', 'D_I', '7,5 km', 88.46666666666667, 80.33333333333334, 73.5),
	(8, 70, 74, 'w', 'D_I', '7,5 km', 92.66666666666667, 82.94999999999999, 75.6),
	(8, 75, 79, 'w', 'D_I', '7,5 km', 97.13333333333333, 85.58333333333333, 78.23333333333333),
	(8, 80, 84, 'w', 'D_I', '7,5 km', 103.41666666666667, 89.51666666666667, 81.38333333333334),
	(8, 85, 89, 'w', 'D_I', '7,5 km', 109.2, 94.85000000000001, 86.10000000000001),
	(8, 90, 200, 'w', 'D_I', '7,5 km', 115.85000000000001, 100.80000000000001, 91.35),
	(8, 18, 19, 'm', 'D_I', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 20, 24, 'm', 'D_I', '7,5 km', 59.849999999999994, 55.65, 51.45),
	(8, 25, 29, 'm', 'D_I', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 30, 34, 'm', 'D_I', '7,5 km', 65.63333333333333, 59.849999999999994, 53.55),
	(8, 35, 39, 'm', 'D_I', '7,5 km', 68.25000000000001, 61.43333333333333, 56.18333333333333),
	(8, 40, 44, 'm', 'D_I', '7,5 km', 69.30000000000001, 63.53333333333333, 56.7),
	(8, 45, 49, 'm', 'D_I', '7,5 km', 71.93333333333334, 65.63333333333333, 57.75000000000001),
	(8, 50, 54, 'm', 'D_I', '7,5 km', 74.55, 67.2, 60.383333333333326),
	(8, 55, 59, 'm', 'D_I', '7,5 km', 76.65, 68.25000000000001, 61.95),
	(8, 60, 64, 'm', 'D_I', '7,5 km', 79.53333333333332, 70.88333333333334, 63.53333333333333),
	(8, 65, 69, 'm', 'D_I', '7,5 km', 82.08333333333333, 72.98333333333333, 65.10000000000001),
	(8, 70, 74, 'm', 'D_I', '7,5 km', 85.58333333333333, 75.6, 68.25000000000001),
	(8, 75, 79, 'm', 'D_I', '7,5 km', 90.46666666666667, 79.53333333333332, 75.6),
	(8, 80, 84, 'm', 'D_I', '7,5 km', 96.06666666666668, 83.73333333333333, 75.6),
	(8, 85, 89, 'm', 'D_I', '7,5 km', 100.80000000000001, 88.46666666666667, 79.28333333333333),
	(8, 90, 200, 'm', 'D_I', '7,5 km', 107.88333333333334, 93.80000000000001, 84.0),
	(10, 0, 7, 'w', 'D_I', '', 4.8, 7.2, 9.6),
	(10, 8, 9, 'w', 'D_I', '', 7.2, 9.6, 12.0),
	(10, 10, 11, 'w', 'D_I', '', 8.8, 12.0, 14.4),
	(10, 0, 7, 'm', 'D_I', '', 9.6, 12.0, 13.6),
	(10, 8, 9, 'm', 'D_I', '', 13.6, 16.0, 18.4),
	(10, 10, 11, 'm', 'D_I', '', 16.8, 20.0, 22.4),
	(11, 12, 13, 'w', 'D_I', '', 12.0, 14.4, 17.6),
	(11, 14, 15, 'w', 'D_I', '', 16.0, 19.2, 21.6),
	(11, 16, 17, 'w', 'D_I', '', 19.2, 21.6, 24.8),
	(11, 18, 19, 'w', 'D_I', '', 24.2, 26.6, 29.8),
	(11, 20, 24, 'w', 'D_I', '', 24.2, 26.6, 29.8),
	(11, 25, 29, 'w', 'D_I', '', 24.2, 26.6, 29.8),
	(11, 30, 34, 'w', 'D_I', '', 22.7, 25.1, 28.3),
	(11, 35, 39, 'w', 'D_I', '', 21.2, 23.6, 26.8),
	(11, 40, 44, 'w', 'D_I', '', 19.7, 22.1, 25.3),
	(11, 45, 49, 'w', 'D_I', '', 18.2, 20.6, 23.8),
	(11, 50, 54, 'w', 'D_I', '', 17.2, 19.6, 22.8),
	(11, 55, 59, 'w', 'D_I', '', 16.2, 18.6, 21.8),
	(11, 60, 64, 'w', 'D_I', '', 15.2, 17.6, 20.8),
	(11, 65, 69, 'w', 'D_I', '', 14.2, 16.6, 19.8),
	(11, 70, 74, 'w', 'D_I', '', 13.2, 15.6, 18.8),
	(11, 75, 79, 'w', 'D_I', '', 12.2, 14.6, 17.3),
	(11, 80, 84, 'w', 'D_I', '', 11.2, 13.6, 16.3),
	(11, 85, 89, 'w', 'D_I', '', 8.2, 10.6, 14.1),
	(11, 90, 200, 'w', 'D_I', '', 8.2, 10.6, 14.1),
	(11, 12, 13, 'm', 'D_I', '', 20.8, 24.0, 26.4),
	(11, 14, 15, 'm', 'D_I', '', 24.0, 27.2, 29.6),
	(11, 16, 17, 'm', 'D_I', '', 27.2, 30.4, 33.6),
	(11, 18, 19, 'm', 'D_I', '', 32.2, 35.4, 38.6),
	(11, 20, 24, 'm', 'D_I', '', 30.7, 33.9, 37.1),
	(11, 25, 29, 'm', 'D_I', '', 29.2, 32.4, 35.6),
	(11, 30, 34, 'm', 'D_I', '', 27.7, 30.9, 34.1),
	(11, 35, 39, 'm', 'D_I', '', 26.2, 29.4, 32.6),
	(11, 40, 44, 'm', 'D_I', '', 24.7, 27.9, 31.1),
	(11, 45, 49, 'm', 'D_I', '', 23.2, 26.4, 29.6),
	(11, 50, 54, 'm', 'D_I', '', 22.2, 25.4, 28.6),
	(11, 55, 59, 'm', 'D_I', '', 21.2, 24.4, 27.6),
	(11, 60, 64, 'm', 'D_I', '', 20.2, 23.4, 26.6),
	(11, 65, 69, 'm', 'D_I', '', 19.2, 22.4, 25.6),
	(11, 70, 74, 'm', 'D_I', '', 18.2, 21.4, 24.6),
	(11, 75, 79, 'm', 'D_I', '', 17.2, 20.4, 23.1),
	(11, 80, 84, 'm', 'D_I', '', 16.2, 19.4, 22.1),
	(11, 85, 89, 'm', 'D_I', '', 8.2, 10.6, 14.1),
	(11, 90, 200, 'm', 'D_I', '', 8.2, 10.6, 14.1),
	(13, 12, 13, 'w', 'D_I', '2 kg', 4.04, 4.46, 4.89),
	(13, 14, 15, 'w', 'D_I', '3 kg', 4.68, 5.1, 5.53),
	(13, 16, 17, 'w', 'D_I', '3 kg', 4.89, 5.31, 5.74),
	(13, 18, 19, 'w', 'D_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 20, 24, 'w', 'D_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 25, 29, 'w', 'D_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 30, 34, 'w', 'D_I', '4 kg', 5.94, 6.41, 6.89),
	(13, 35, 39, 'w', 'D_I', '4 kg', 5.7, 6.18, 6.65),
	(13, 40, 44, 'w', 'D_I', '4 kg', 5.23, 5.7, 6.18),
	(13, 45, 49, 'w', 'D_I', '4 kg', 4.99, 5.46, 5.94),
	(13, 50, 54, 'w', 'D_I', '3 kg', 4.99, 5.7, 6.65),
	(13, 55, 59, 'w', 'D_I', '3 kg', 4.75, 5.46, 6.18),
	(13, 60, 64, 'w', 'D_I', '3 kg', 4.51, 5.23, 5.94),
	(13, 65, 69, 'w', 'D_I', '3 kg', 4.28, 4.99, 5.94),
	(13, 70, 74, 'w', 'D_I', '3 kg', 4.04, 4.75, 5.7),
	(13, 75, 79, 'w', 'D_I', '2 kg', 4.04, 4.99, 5.94),
	(13, 80, 84, 'w', 'D_I', '2 kg', 3.8, 4.75, 5.46),
	(13, 85, 89, 'w', 'D_I', '2 kg', 3.56, 4.28, 5.23),
	(13, 90, 200, 'w', 'D_I', '2 kg', 3.09, 4.04, 4.75),
	(13, 12, 13, 'm', 'D_I', '3 kg', 5.31, 5.74, 6.16),
	(13, 14, 15, 'm', 'D_I', '4 kg', 5.95, 6.38, 6.8),
	(13, 16, 17, 'm', 'D_I', '5 kg', 6.38, 6.8, 7.23),
	(13, 18, 19, 'm', 'D_I', '6 kg', 7.36, 7.84, 8.31),
	(13, 20, 24, 'm', 'D_I', '6 kg', 7.36, 8.08, 8.55),
	(13, 25, 29, 'm', 'D_I', '6 kg', 7.13, 7.84, 8.31),
	(13, 30, 34, 'm', 'D_I', '6 kg', 6.65, 7.36, 7.84),
	(13, 35, 39, 'm', 'D_I', '6 kg', 6.41, 6.89, 7.6),
	(13, 40, 44, 'm', 'D_I', '6 kg', 5.94, 6.65, 7.36),
	(13, 45, 49, 'm', 'D_I', '6 kg', 5.7, 6.41, 7.13),
	(13, 50, 54, 'm', 'D_I', '5 kg', 5.94, 6.65, 7.6),
	(13, 55, 59, 'm', 'D_I', '5 kg', 5.7, 6.41, 7.13),
	(13, 60, 64, 'm', 'D_I', '4 kg', 5.7, 6.65, 7.6),
	(13, 65, 69, 'm', 'D_I', '4 kg', 5.46, 6.41, 7.13),
	(13, 70, 74, 'm', 'D_I', '4 kg', 5.3, 6.3, 7.0),
	(13, 75, 79, 'm', 'D_I', '3 kg', 5.46, 6.18, 7.13),
	(13, 80, 84, 'm', 'D_I', '3 kg', 5.23, 5.94, 6.89),
	(13, 85, 89, 'm', 'D_I', '3 kg', 4.75, 5.7, 6.41),
	(13, 90, 200, 'm', 'D_I', '3 kg', 4.28, 4.99, 5.94),
	(15, 0, 7, 'w', 'D_I', '', 0.95, 1.13, 1.26),
	(15, 8, 9, 'w', 'D_I', '', 1.04, 1.17, 1.35),
	(15, 10, 11, 'w', 'D_I', '', 1.17, 1.31, 1.49),
	(15, 12, 13, 'w', 'D_I', '', 1.26, 1.44, 1.62),
	(15, 14, 15, 'w', 'D_I', '', 1.4, 1.53, 1.71),
	(15, 16, 17, 'w', 'D_I', '', 1.49, 1.62, 1.8),
	(15, 18, 19, 'w', 'D_I', '', 1.49, 1.67, 1.85),
	(15, 20, 24, 'w', 'D_I', '', 1.44, 1.62, 1.8),
	(15, 25, 29, 'w', 'D_I', '', 1.35, 1.53, 1.76),
	(15, 30, 34, 'w', 'D_I', '', 1.22, 1.44, 1.67),
	(15, 35, 39, 'w', 'D_I', '', 1.13, 1.35, 1.62),
	(15, 40, 44, 'w', 'D_I', '', 1.04, 1.26, 1.49),
	(15, 45, 49, 'w', 'D_I', '', 0.99, 1.22, 1.44),
	(15, 50, 54, 'w', 'D_I', '', 0.9, 1.17, 1.4),
	(15, 55, 59, 'w', 'D_I', '', 0.86, 1.08, 1.31),
	(15, 60, 64, 'w', 'D_I', '', 0.86, 1.08, 1.31),
	(15, 65, 69, 'w', 'D_I', '', 0.81, 1.04, 1.26),
	(15, 70, 74, 'w', 'D_I', '', 0.81, 1.04, 1.22),
	(15, 75, 79, 'w', 'D_I', '', 0.81, 1.04, 1.22),
	(15, 80, 84, 'w', 'D_I', '', 0.81, 0.99, 1.17),
	(15, 85, 89, 'w', 'D_I', '', 0.77, 0.95, 1.13),
	(15, 90, 200, 'w', 'D_I', '', 0.72, 0.9, 1.08),
	(15, 0, 7, 'm', 'D_I', '', 1.04, 1.22, 1.35),
	(15, 8, 9, 'm', 'D_I', '', 1.17, 1.35, 1.49),
	(15, 10, 11, 'm', 'D_I', '', 1.35, 1.53, 1.67),
	(15, 12, 13, 'm', 'D_I', '', 1.53, 1.71, 1.85),
	(15, 14, 15, 'm', 'D_I', '', 1.71, 1.85, 2.03),
	(15, 16, 17, 'm', 'D_I', '', 1.85, 1.98, 2.16),
	(15, 18, 19, 'm', 'D_I', '', 1.89, 2.07, 2.25),
	(15, 20, 24, 'm', 'D_I', '', 1.89, 2.07, 2.25),
	(15, 25, 29, 'm', 'D_I', '', 1.85, 2.03, 2.21),
	(15, 30, 34, 'm', 'D_I', '', 1.67, 1.89, 2.12),
	(15, 35, 39, 'm', 'D_I', '', 1.49, 1.76, 2.03),
	(15, 40, 44, 'm', 'D_I', '', 1.4, 1.67, 1.94),
	(15, 45, 49, 'm', 'D_I', '', 1.31, 1.58, 1.85),
	(15, 50, 54, 'm', 'D_I', '', 1.26, 1.53, 1.8),
	(15, 55, 59, 'm', 'D_I', '', 1.22, 1.49, 1.76),
	(15, 60, 64, 'm', 'D_I', '', 1.17, 1.44, 1.71),
	(15, 65, 69, 'm', 'D_I', '', 1.17, 1.44, 1.71),
	(15, 70, 74, 'm', 'D_I', '', 1.13, 1.4, 1.67),
	(15, 75, 79, 'm', 'D_I', '', 1.08, 1.35, 1.62),
	(15, 80, 84, 'm', 'D_I', '', 1.04, 1.31, 1.58),
	(15, 85, 89, 'm', 'D_I', '', 0.9, 1.17, 1.44),
	(15, 90, 200, 'm', 'D_I', '', 0.81, 1.08, 1.35),
	(17, 0, 7, 'w', 'D_I', '30 m', 8.8, 7.8, 6.9),
	(17, 8, 9, 'w', 'D_I', '30 m', 8.1, 7.3, 6.3),
	(17, 10, 11, 'w', 'D_I', '50 m', 12.1, 11.1, 10.0),
	(17, 12, 13, 'w', 'D_I', '50 m', 11.7, 10.6, 9.4),
	(17, 14, 15, 'w', 'D_I', '100 m', 20.5, 18.7, 17.1),
	(17, 16, 17, 'w', 'D_I', '100 m', 19.4, 17.9, 16.5),
	(17, 18, 19, 'w', 'D_I', '100 m', 20.0, 18.2, 16.8),
	(17, 20, 24, 'w', 'D_I', '100 m', 20.4, 18.5, 17.2),
	(17, 25, 29, 'w', 'D_I', '100 m', 20.8, 18.9, 17.6),
	(17, 30, 34, 'w', 'D_I', '100 m', 21.6, 19.6, 18.0),
	(17, 35, 39, 'w', 'D_I', '100 m', 22.4, 20.5, 18.7),
	(17, 40, 44, 'w', 'D_I', '50 m', 12.1, 10.9, 9.7),
	(17, 45, 49, 'w', 'D_I', '50 m', 12.7, 11.3, 10.0),
	(17, 50, 54, 'w', 'D_I', '50 m', 13.1, 11.8, 10.5),
	(17, 55, 59, 'w', 'D_I', '50 m', 13.6, 12.3, 10.9),
	(17, 60, 64, 'w', 'D_I', '50 m', 13.9, 12.5, 11.2),
	(17, 65, 69, 'w', 'D_I', '50 m', 14.1, 12.8, 11.4),
	(17, 70, 74, 'w', 'D_I', '50 m', 14.3, 13.0, 11.7),
	(17, 75, 79, 'w', 'D_I', '50 m', 14.9, 13.5, 12.2),
	(17, 80, 84, 'w', 'D_I', '50 m', 15.7, 14.4, 13.2),
	(17, 85, 89, 'w', 'D_I', '50 m', 17.1, 15.7, 14.5),
	(17, 90, 200, 'w', 'D_I', '50 m', 18.8, 17.5, 16.3),
	(17, 0, 7, 'm', 'D_I', '30 m', 8.5, 7.5, 6.6),
	(17, 8, 9, 'm', 'D_I', '30 m', 7.9, 7.0, 6.3),
	(17, 10, 11, 'm', 'D_I', '50 m', 11.3, 10.2, 9.2),
	(17, 12, 13, 'm', 'D_I', '50 m', 10.7, 9.8, 8.9),
	(17, 14, 15, 'm', 'D_I', '100 m', 18.7, 16.9, 15.5),
	(17, 16, 17, 'm', 'D_I', '100 m', 17.9, 16.3, 14.9),
	(17, 18, 19, 'm', 'D_I', '100 m', 17.6, 16.1, 14.5),
	(17, 20, 24, 'm', 'D_I', '100 m', 17.4, 15.8, 14.3),
	(17, 25, 29, 'm', 'D_I', '100 m', 17.9, 16.3, 14.6),
	(17, 30, 34, 'm', 'D_I', '100 m', 18.5, 16.6, 15.0),
	(17, 35, 39, 'm', 'D_I', '100 m', 19.4, 17.5, 15.6),
	(17, 40, 44, 'm', 'D_I', '50 m', 10.6, 9.6, 8.5),
	(17, 45, 49, 'm', 'D_I', '50 m', 11.0, 9.8, 8.7),
	(17, 50, 54, 'm', 'D_I', '50 m', 11.3, 10.0, 9.0),
	(17, 55, 59, 'm', 'D_I', '50 m', 11.6, 10.3, 9.4),
	(17, 60, 64, 'm', 'D_I', '50 m', 11.9, 10.7, 9.7),
	(17, 65, 69, 'm', 'D_I', '50 m', 12.3, 11.2, 10.0),
	(17, 70, 74, 'm', 'D_I', '50 m', 12.9, 11.8, 10.6),
	(17, 75, 79, 'm', 'D_I', '50 m', 13.4, 12.3, 11.1),
	(17, 80, 84, 'm', 'D_I', '50 m', 14.3, 13.2, 12.0),
	(17, 85, 89, 'm', 'D_I', '50 m', 15.5, 14.4, 13.2),
	(17, 90, 200, 'm', 'D_I', '50 m', 17.1, 16.0, 14.7),
	(18, 0, 7, 'w', 'D_I', '', 51.2, 42.4, 33.6),
	(18, 8, 9, 'w', 'D_I', '', 46.2, 37.4, 30.8),
	(18, 10, 11, 'w', 'D_I', '', 42.9, 34.7, 28.1),
	(18, 12, 13, 'w', 'D_I', '', 38.5, 31.9, 25.9),
	(18, 14, 15, 'w', 'D_I', '', 36.3, 30.3, 23.7),
	(18, 16, 17, 'w', 'D_I', '', 33.6, 28.1, 22.0),
	(18, 18, 19, 'w', 'D_I', '', 32.5, 26.4, 20.4),
	(18, 20, 24, 'w', 'D_I', '', 31.9, 26.4, 20.4),
	(18, 25, 29, 'w', 'D_I', '', 33.0, 27.5, 21.5),
	(18, 30, 34, 'w', 'D_I', '', 35.8, 29.2, 23.1),
	(18, 35, 39, 'w', 'D_I', '', 39.6, 31.9, 24.2),
	(18, 40, 44, 'w', 'D_I', '', 44.0, 34.7, 25.9),
	(18, 45, 49, 'w', 'D_I', '', 48.4, 38.5, 27.5),
	(18, 50, 54, 'w', 'D_I', '', 52.8, 42.9, 30.8),
	(18, 55, 59, 'w', 'D_I', '', 56.7, 46.8, 33.6),
	(18, 60, 64, 'w', 'D_I', '', 60.0, 49.0, 35.8),
	(18, 65, 69, 'w', 'D_I', '', 62.2, 51.2, 38.0),
	(18, 70, 74, 'w', 'D_I', '', 64.9, 52.8, 39.6),
	(18, 75, 79, 'w', 'D_I', '', 67.1, 55.0, 41.8),
	(18, 80, 84, 'w', 'D_I', '', 69.9, 57.2, 44.0),
	(18, 85, 89, 'w', 'D_I', '', 72.1, 58.9, 45.7),
	(18, 90, 200, 'w', 'D_I', '', 73.2, 60.0, 46.8),
	(18, 0, 7, 'm', 'D_I', '', 50.6, 41.8, 33.0),
	(18, 8, 9, 'm', 'D_I', '', 45.1, 36.3, 28.6),
	(18, 10, 11, 'm', 'D_I', '', 39.6, 31.9, 24.8),
	(18, 12, 13, 'm', 'D_I', '', 36.3, 29.7, 23.1),
	(18, 14, 15, 'm', 'D_I', '', 34.1, 28.1, 22.0),
	(18, 16, 17, 'm', 'D_I', '', 32.5, 27.0, 20.9),
	(18, 18, 19, 'm', 'D_I', '', 30.8, 25.3, 19.3),
	(18, 20, 24, 'm', 'D_I', '', 29.7, 24.2, 17.1),
	(18, 25, 29, 'm', 'D_I', '', 31.9, 25.3, 18.2),
	(18, 30, 34, 'm', 'D_I', '', 34.7, 26.4, 18.7),
	(18, 35, 39, 'm', 'D_I', '', 38.5, 29.2, 20.4),
	(18, 40, 44, 'm', 'D_I', '', 42.4, 32.5, 20.9),
	(18, 45, 49, 'm', 'D_I', '', 46.2, 35.8, 22.6),
	(18, 50, 54, 'm', 'D_I', '', 49.5, 38.5, 25.3),
	(18, 55, 59, 'm', 'D_I', '', 53.9, 40.7, 27.5),
	(18, 60, 64, 'm', 'D_I', '', 56.1, 42.9, 29.7),
	(18, 65, 69, 'm', 'D_I', '', 57.8, 44.6, 31.4),
	(18, 70, 74, 'm', 'D_I', '', 60.5, 47.3, 34.1),
	(18, 75, 79, 'm', 'D_I', '', 63.3, 50.1, 36.9),
	(18, 80, 84, 'm', 'D_I', '', 64.9, 52.8, 39.6),
	(18, 85, 89, 'm', 'D_I', '', 65.5, 53.9, 41.8),
	(18, 90, 200, 'm', 'D_I', '', 66.0, 55.0, 44.0),
	(19, 8, 9, 'w', 'D_I', '', 45.1, 39.6, 34.1),
	(19, 10, 11, 'w', 'D_I', '', 40.7, 35.2, 29.7),
	(19, 12, 13, 'w', 'D_I', '', 34.1, 29.7, 25.9),
	(19, 14, 15, 'w', 'D_I', '', 29.7, 27.0, 23.7),
	(19, 16, 17, 'w', 'D_I', '', 27.5, 24.8, 22.0),
	(19, 18, 19, 'w', 'D_I', '', 26.4, 24.2, 21.5),
	(19, 20, 24, 'w', 'D_I', '', 27.0, 24.2, 21.5),
	(19, 25, 29, 'w', 'D_I', '', 27.5, 24.8, 22.0),
	(19, 30, 34, 'w', 'D_I', '', 28.6, 25.9, 23.7),
	(19, 35, 39, 'w', 'D_I', '', 30.3, 27.0, 24.2),
	(19, 40, 44, 'w', 'D_I', '', 31.9, 28.1, 24.8),
	(19, 45, 49, 'w', 'D_I', '', 33.6, 29.7, 25.3),
	(19, 50, 54, 'w', 'D_I', '', 35.2, 30.8, 25.9),
	(19, 55, 59, 'w', 'D_I', '', 36.9, 31.9, 26.4),
	(19, 60, 64, 'w', 'D_I', '', 38.5, 33.0, 27.5),
	(19, 65, 69, 'w', 'D_I', '', 39.6, 34.1, 28.1),
	(19, 70, 74, 'w', 'D_I', '', 41.8, 35.2, 29.2),
	(19, 75, 79, 'w', 'D_I', '', 42.9, 36.3, 30.3),
	(19, 80, 84, 'w', 'D_I', '', 44.6, 38.0, 31.4),
	(19, 85, 89, 'w', 'D_I', '', 46.2, 39.6, 33.0),
	(19, 90, 200, 'w', 'D_I', '', 49.0, 41.8, 34.7),
	(19, 8, 9, 'm', 'D_I', '', 41.8, 36.3, 30.8),
	(19, 10, 11, 'm', 'D_I', '', 38.5, 33.6, 28.6),
	(19, 12, 13, 'm', 'D_I', '', 32.5, 28.6, 24.8),
	(19, 14, 15, 'm', 'D_I', '', 26.4, 23.7, 20.9),
	(19, 16, 17, 'm', 'D_I', '', 24.2, 21.5, 18.7),
	(19, 18, 19, 'm', 'D_I', '', 22.6, 19.8, 17.1),
	(19, 20, 24, 'm', 'D_I', '', 22.0, 19.3, 16.5),
	(19, 25, 29, 'm', 'D_I', '', 23.1, 19.8, 16.5),
	(19, 30, 34, 'm', 'D_I', '', 24.8, 20.4, 16.5),
	(19, 35, 39, 'm', 'D_I', '', 26.4, 22.0, 17.1),
	(19, 40, 44, 'm', 'D_I', '', 29.2, 23.7, 18.2),
	(19, 45, 49, 'm', 'D_I', '', 31.4, 25.3, 18.7),
	(19, 50, 54, 'm', 'D_I', '', 33.0, 26.4, 19.8),
	(19, 55, 59, 'm', 'D_I', '', 35.2, 27.5, 20.4),
	(19, 60, 64, 'm', 'D_I', '', 36.9, 28.6, 20.9),
	(19, 65, 69, 'm', 'D_I', '', 38.5, 29.7, 21.5),
	(19, 70, 74, 'm', 'D_I', '', 39.6, 31.4, 22.0),
	(19, 75, 79, 'm', 'D_I', '', 41.3, 32.5, 23.7),
	(19, 80, 84, 'm', 'D_I', '', 42.9, 34.7, 25.3),
	(19, 85, 89, 'm', 'D_I', '', 45.1, 36.3, 27.0),
	(19, 90, 200, 'm', 'D_I', '', 47.9, 39.1, 29.7),
	(21, 10, 11, 'w', 'D_I', '', 0.72, 0.81, 0.9),
	(21, 12, 13, 'w', 'D_I', '', 0.81, 0.9, 0.99),
	(21, 14, 15, 'w', 'D_I', '', 0.86, 0.95, 1.04),
	(21, 16, 17, 'w', 'D_I', '', 0.95, 1.04, 1.13),
	(21, 18, 19, 'w', 'D_I', '', 0.99, 1.08, 1.17),
	(21, 20, 24, 'w', 'D_I', '', 0.99, 1.08, 1.17),
	(21, 25, 29, 'w', 'D_I', '', 0.95, 1.04, 1.13),
	(21, 30, 34, 'w', 'D_I', '', 0.9, 0.99, 1.08),
	(21, 35, 39, 'w', 'D_I', '', 0.86, 0.95, 1.04),
	(21, 40, 44, 'w', 'D_I', '', 0.81, 0.9, 0.99),
	(21, 45, 49, 'w', 'D_I', '', 0.81, 0.9, 0.99),
	(21, 50, 54, 'w', 'D_I', '', 0.77, 0.86, 0.95),
	(21, 55, 59, 'w', 'D_I', '', 0.72, 0.81, 0.9),
	(21, 60, 64, 'w', 'D_I', '', 0.68, 0.77, 0.86),
	(21, 65, 69, 'w', 'D_I', '', 0.68, 0.77, 0.86),
	(21, 70, 74, 'w', 'D_I', '', 0.63, 0.72, 0.81),
	(21, 75, 79, 'w', 'D_I', '', 0.59, 0.68, 0.77),
	(21, 80, 84, 'w', 'D_I', '', 0.59, 0.68, 0.77),
	(21, 85, 89, 'w', 'D_I', '', 0.54, 0.63, 0.72),
	(21, 90, 200, 'w', 'D_I', '', 0.5, 0.54, 0.59),
	(21, 10, 11, 'm', 'D_I', '', 0.77, 0.86, 0.95),
	(21, 12, 13, 'm', 'D_I', '', 0.86, 0.95, 1.04),
	(21, 14, 15, 'm', 'D_I', '', 0.99, 1.08, 1.17),
	(21, 16, 17, 'm', 'D_I', '', 1.08, 1.17, 1.26),
	(21, 18, 19, 'm', 'D_I', '', 1.17, 1.26, 1.35),
	(21, 20, 24, 'm', 'D_I', '', 1.22, 1.31, 1.4),
	(21, 25, 29, 'm', 'D_I', '', 1.17, 1.26, 1.35),
	(21, 30, 34, 'm', 'D_I', '', 1.17, 1.26, 1.35),
	(21, 35, 39, 'm', 'D_I', '', 1.13, 1.22, 1.31),
	(21, 40, 44, 'm', 'D_I', '', 1.08, 1.17, 1.26),
	(21, 45, 49, 'm', 'D_I', '', 1.04, 1.13, 1.22),
	(21, 50, 54, 'm', 'D_I', '', 0.95, 1.04, 1.13),
	(21, 55, 59, 'm', 'D_I', '', 0.9, 0.99, 1.08),
	(21, 60, 64, 'm', 'D_I', '', 0.86, 0.95, 1.04),
	(21, 65, 69, 'm', 'D_I', '', 0.77, 0.9, 0.99),
	(21, 70, 74, 'm', 'D_I', '', 0.72, 0.86, 0.95),
	(21, 75, 79, 'm', 'D_I', '', 0.68, 0.81, 0.9),
	(21, 80, 84, 'm', 'D_I', '', 0.68, 0.77, 0.86),
	(21, 85, 89, 'm', 'D_I', '', 0.63, 0.72, 0.81),
	(21, 90, 200, 'm', 'D_I', '', 0.59, 0.68, 0.77),
	(23, 0, 7, 'w', 'D_I', '', 1.67, 1.94, 2.21),
	(23, 8, 9, 'w', 'D_I', '', 1.87, 2.14, 2.41),
	(23, 10, 11, 'w', 'D_I', '', 2.07, 2.34, 2.61),
	(23, 12, 13, 'w', 'D_I', '', 2.52, 2.79, 3.06),
	(23, 14, 15, 'w', 'D_I', '', 2.88, 3.15, 3.42),
	(23, 16, 17, 'w', 'D_I', '', 3.06, 3.33, 3.6),
	(23, 18, 19, 'w', 'D_I', '', 3.06, 3.33, 3.6),
	(23, 20, 24, 'w', 'D_I', '', 3.06, 3.33, 3.6),
	(23, 25, 29, 'w', 'D_I', '', 2.97, 3.24, 3.51),
	(23, 30, 34, 'w', 'D_I', '', 2.88, 3.15, 3.42),
	(23, 35, 39, 'w', 'D_I', '', 2.79, 3.06, 3.33),
	(23, 40, 44, 'w', 'D_I', '', 2.7, 2.97, 3.24),
	(23, 45, 49, 'w', 'D_I', '', 2.52, 2.88, 3.15),
	(23, 50, 54, 'w', 'D_I', '', 2.34, 2.7, 3.06),
	(23, 55, 59, 'w', 'D_I', '', 2.25, 2.61, 2.97),
	(23, 60, 64, 'w', 'D_I', '', 2.16, 2.52, 2.88),
	(23, 65, 69, 'w', 'D_I', '', 2.07, 2.43, 2.79),
	(23, 70, 74, 'w', 'D_I', '', 1.89, 2.25, 2.61),
	(23, 75, 79, 'w', 'D_I', '', 1.62, 1.98, 2.34),
	(23, 80, 84, 'w', 'D_I', '', 1.44, 1.8, 2.16),
	(23, 85, 89, 'w', 'D_I', '', 1.17, 1.53, 1.89),
	(23, 90, 200, 'w', 'D_I', '', 0.99, 1.35, 1.71),
	(23, 0, 7, 'm', 'D_I', '', 1.94, 2.21, 2.48),
	(23, 8, 9, 'm', 'D_I', '', 2.14, 2.41, 2.68),
	(23, 10, 11, 'm', 'D_I', '', 2.34, 2.61, 2.88),
	(23, 12, 13, 'm', 'D_I', '', 2.88, 3.15, 3.42),
	(23, 14, 15, 'm', 'D_I', '', 3.42, 3.69, 3.96),
	(23, 16, 17, 'm', 'D_I', '', 3.87, 4.14, 4.41),
	(23, 18, 19, 'm', 'D_I', '', 4.05, 4.32, 4.59),
	(23, 20, 24, 'm', 'D_I', '', 3.96, 4.23, 4.5),
	(23, 25, 29, 'm', 'D_I', '', 3.87, 4.14, 4.41),
	(23, 30, 34, 'm', 'D_I', '', 3.78, 4.05, 4.32),
	(23, 35, 39, 'm', 'D_I', '', 3.69, 3.96, 4.23),
	(23, 40, 44, 'm', 'D_I', '', 3.51, 3.87, 4.14),
	(23, 45, 49, 'm', 'D_I', '', 3.33, 3.69, 4.05),
	(23, 50, 54, 'm', 'D_I', '', 3.24, 3.6, 3.96),
	(23, 55, 59, 'm', 'D_I', '', 3.06, 3.42, 3.78),
	(23, 60, 64, 'm', 'D_I', '', 2.88, 3.24, 3.6),
	(23, 65, 69, 'm', 'D_I', '', 2.61, 2.97, 3.33),
	(23, 70, 74, 'm', 'D_I', '', 2.43, 2.79, 3.15),
	(23, 75, 79, 'm', 'D_I', '', 2.16, 2.61, 2.97),
	(23, 80, 84, 'm', 'D_I', '', 1.89, 2.34, 2.79),
	(23, 85, 89, 'm', 'D_I', '', 1.71, 2.16, 2.61),
	(23, 90, 200, 'm', 'D_I', '', 1.44, 1.89, 2.34),
	(25, 12, 13, 'w', 'D_I', '', 13.6, 15.6, 17.6),
	(25, 14, 15, 'w', 'D_I', '', 15.6, 18.0, 20.4),
	(25, 16, 17, 'w', 'D_I', '', 17.6, 20.0, 22.4),
	(25, 18, 19, 'w', 'D_I', '', 18.8, 21.2, 23.2),
	(25, 20, 24, 'w', 'D_I', '', 19.2, 21.6, 23.6),
	(25, 25, 29, 'w', 'D_I', '', 19.2, 21.6, 23.6),
	(25, 30, 34, 'w', 'D_I', '', 17.6, 20.0, 22.0),
	(25, 35, 39, 'w', 'D_I', '', 16.8, 19.2, 21.2),
	(25, 40, 44, 'w', 'D_I', '', 15.6, 18.0, 20.0),
	(25, 45, 49, 'w', 'D_I', '', 14.8, 17.2, 19.2),
	(25, 50, 54, 'w', 'D_I', '', 13.2, 16.0, 18.4),
	(25, 55, 59, 'w', 'D_I', '', 12.4, 15.2, 17.6),
	(25, 60, 64, 'w', 'D_I', '', 11.6, 14.4, 16.8),
	(25, 65, 69, 'w', 'D_I', '', 10.8, 13.6, 16.0),
	(25, 70, 74, 'w', 'D_I', '', 10.4, 13.2, 15.6),
	(25, 75, 79, 'w', 'D_I', '', 9.6, 12.4, 14.8),
	(25, 80, 84, 'w', 'D_I', '', 8.8, 11.6, 14.0),
	(25, 85, 89, 'w', 'D_I', '', 7.6, 10.4, 12.8),
	(25, 90, 200, 'w', 'D_I', '', 6.0, 8.8, 11.2),
	(25, 12, 13, 'm', 'D_I', '', 15.6, 19.2, 22.0),
	(25, 14, 15, 'm', 'D_I', '', 18.8, 22.4, 25.6),
	(25, 16, 17, 'm', 'D_I', '', 22.0, 25.6, 29.2),
	(25, 18, 19, 'm', 'D_I', '', 25.2, 28.8, 32.4),
	(25, 20, 24, 'm', 'D_I', '', 26.4, 30.4, 33.6),
	(25, 25, 29, 'm', 'D_I', '', 26.0, 30.0, 33.2),
	(25, 30, 34, 'm', 'D_I', '', 24.0, 28.0, 32.0),
	(25, 35, 39, 'm', 'D_I', '', 22.8, 26.8, 30.8),
	(25, 40, 44, 'm', 'D_I', '', 22.4, 26.4, 30.4),
	(25, 45, 49, 'm', 'D_I', '', 21.6, 25.6, 30.0),
	(25, 50, 54, 'm', 'D_I', '', 20.4, 24.8, 29.2),
	(25, 55, 59, 'm', 'D_I', '', 18.8, 23.2, 28.0),
	(25, 60, 64, 'm', 'D_I', '', 18.0, 22.4, 27.2),
	(25, 65, 69, 'm', 'D_I', '', 16.0, 20.4, 24.4),
	(25, 70, 74, 'm', 'D_I', '', 14.8, 19.2, 23.2),
	(25, 75, 79, 'm', 'D_I', '', 12.8, 16.8, 20.8),
	(25, 80, 84, 'm', 'D_I', '', 11.2, 15.2, 19.2),
	(25, 85, 89, 'm', 'D_I', '', 9.6, 13.2, 16.8),
	(25, 90, 200, 'm', 'D_I', '', 8.4, 12.0, 15.6),
	(33, 0, 7, 'w', 'D_I', '', 7.2, 10.8, 15.299999999999999),
	(33, 8, 9, 'w', 'D_I', '', 9.0, 13.500000000000002, 18.0),
	(33, 10, 11, 'w', 'D_I', '', 13.500000000000002, 18.0, 27.0),
	(33, 12, 13, 'w', 'D_I', '', 18.0, 27.0, 36.0),
	(33, 14, 15, 'w', 'D_I', '', 27.0, 36.0, 45.0),
	(33, 16, 17, 'w', 'D_I', '', 40.49999999999999, 54.0, 67.5),
	(33, 0, 7, 'm', 'D_I', '', 9.0, 13.500000000000002, 18.0),
	(33, 8, 9, 'm', 'D_I', '', 10.8, 15.299999999999999, 20.700000000000003),
	(33, 10, 11, 'm', 'D_I', '', 15.299999999999999, 22.5, 31.5),
	(33, 12, 13, 'm', 'D_I', '', 22.5, 31.5, 40.49999999999999),
	(33, 14, 15, 'm', 'D_I', '', 31.5, 40.49999999999999, 54.0),
	(33, 16, 17, 'm', 'D_I', '', 49.49999999999999, 63.0, 81.0),
	(39, 0, 7, 'w', 'D_I', '', 196.0, 218.0, 239.0),
	(39, 8, 9, 'w', 'D_I', '', 207.0, 230.0, 253.0),
	(39, 10, 11, 'w', 'D_I', '', 218.0, 243.0, 267.0),
	(39, 12, 13, 'w', 'D_I', '', 230.0, 255.0, 281.0),
	(39, 14, 15, 'w', 'D_I', '', 241.0, 268.0, 294.0),
	(39, 16, 17, 'w', 'D_I', '', 252.0, 280.0, 308.0),
	(39, 18, 19, 'w', 'D_I', '', 342.0, 380.0, 418.0),
	(39, 20, 24, 'w', 'D_I', '', 342.0, 380.0, 418.0),
	(39, 25, 29, 'w', 'D_I', '', 342.0, 380.0, 418.0),
	(39, 30, 34, 'w', 'D_I', '', 331.0, 368.0, 404.0),
	(39, 35, 39, 'w', 'D_I', '', 331.0, 368.0, 404.0),
	(39, 40, 44, 'w', 'D_I', '', 320.0, 355.0, 391.0),
	(39, 45, 49, 'w', 'D_I', '', 308.0, 343.0, 377.0),
	(39, 50, 54, 'w', 'D_I', '', 297.0, 330.0, 363.0),
	(39, 55, 59, 'w', 'D_I', '', 286.0, 318.0, 349.0),
	(39, 60, 64, 'w', 'D_I', '', 275.0, 305.0, 336.0),
	(39, 65, 69, 'w', 'D_I', '', 263.0, 293.0, 322.0),
	(39, 70, 74, 'w', 'D_I', '', 252.0, 280.0, 308.0),
	(39, 75, 79, 'w', 'D_I', '', 241.0, 268.0, 294.0),
	(39, 80, 84, 'w', 'D_I', '', 230.0, 255.0, 281.0),
	(39, 85, 89, 'w', 'D_I', '', 218.0, 243.0, 267.0),
	(39, 90, 200, 'w', 'D_I', '', 207.0, 230.0, 253.0),
	(39, 0, 7, 'm', 'D_I', '', 254.0, 283.0, 311.0),
	(39, 8, 9, 'm', 'D_I', '', 266.0, 295.0, 325.0),
	(39, 10, 11, 'm', 'D_I', '', 277.0, 308.0, 338.0),
	(39, 12, 13, 'm', 'D_I', '', 288.0, 320.0, 352.0),
	(39, 14, 15, 'm', 'D_I', '', 299.0, 333.0, 366.0),
	(39, 16, 17, 'm', 'D_I', '', 311.0, 345.0, 380.0),
	(39, 18, 19, 'm', 'D_I', '', 401.0, 445.0, 490.0),
	(39, 20, 24, 'm', 'D_I', '', 401.0, 445.0, 490.0),
	(39, 25, 29, 'm', 'D_I', '', 401.0, 445.0, 490.0),
	(39, 30, 34, 'm', 'D_I', '', 389.0, 433.0, 476.0),
	(39, 35, 39, 'm', 'D_I', '', 389.0, 433.0, 476.0),
	(39, 40, 44, 'm', 'D_I', '', 378.0, 420.0, 462.0),
	(39, 45, 49, 'm', 'D_I', '', 367.0, 408.0, 448.0),
	(39, 50, 54, 'm', 'D_I', '', 356.0, 395.0, 435.0),
	(39, 55, 59, 'm', 'D_I', '', 344.0, 383.0, 421.0),
	(39, 60, 64, 'm', 'D_I', '', 333.0, 370.0, 407.0),
	(39, 65, 69, 'm', 'D_I', '', 322.0, 358.0, 393.0),
	(39, 70, 74, 'm', 'D_I', '', 311.0, 345.0, 380.0),
	(39, 75, 79, 'm', 'D_I', '', 299.0, 333.0, 366.0),
	(39, 80, 84, 'm', 'D_I', '', 288.0, 320.0, 352.0),
	(39, 85, 89, 'm', 'D_I', '', 277.0, 308.0, 338.0),
	(39, 90, 200, 'm', 'D_I', '', 266.0, 295.0, 325.0),
	(40, 0, 7, 'w', 'D_I', '', 356.0, 395.0, 435.0),
	(40, 8, 9, 'w', 'D_I', '', 369.0, 410.0, 451.0),
	(40, 10, 11, 'w', 'D_I', '', 383.0, 425.0, 468.0),
	(40, 12, 13, 'w', 'D_I', '', 396.0, 440.0, 484.0),
	(40, 14, 15, 'w', 'D_I', '', 410.0, 455.0, 501.0),
	(40, 16, 17, 'w', 'D_I', '', 423.0, 470.0, 517.0),
	(40, 18, 19, 'w', 'D_I', '', 513.0, 570.0, 627.0),
	(40, 20, 24, 'w', 'D_I', '', 513.0, 570.0, 627.0),
	(40, 25, 29, 'w', 'D_I', '', 513.0, 570.0, 627.0),
	(40, 30, 34, 'w', 'D_I', '', 500.0, 555.0, 611.0),
	(40, 35, 39, 'w', 'D_I', '', 500.0, 555.0, 611.0),
	(40, 40, 44, 'w', 'D_I', '', 486.0, 540.0, 594.0),
	(40, 45, 49, 'w', 'D_I', '', 473.0, 525.0, 578.0),
	(40, 50, 54, 'w', 'D_I', '', 459.0, 510.0, 561.0),
	(40, 55, 59, 'w', 'D_I', '', 446.0, 495.0, 545.0),
	(40, 60, 64, 'w', 'D_I', '', 432.0, 480.0, 528.0),
	(40, 65, 69, 'w', 'D_I', '', 419.0, 465.0, 512.0),
	(40, 70, 74, 'w', 'D_I', '', 405.0, 450.0, 495.0),
	(40, 75, 79, 'w', 'D_I', '', 392.0, 435.0, 479.0),
	(40, 80, 84, 'w', 'D_I', '', 378.0, 420.0, 462.0),
	(40, 85, 89, 'w', 'D_I', '', 365.0, 405.0, 446.0),
	(40, 90, 200, 'w', 'D_I', '', 351.0, 390.0, 429.0),
	(40, 0, 7, 'm', 'D_I', '', 423.0, 470.0, 517.0),
	(40, 8, 9, 'm', 'D_I', '', 437.0, 485.0, 534.0),
	(40, 10, 11, 'm', 'D_I', '', 450.0, 500.0, 550.0),
	(40, 12, 13, 'm', 'D_I', '', 464.0, 515.0, 567.0),
	(40, 14, 15, 'm', 'D_I', '', 477.0, 530.0, 583.0),
	(40, 16, 17, 'm', 'D_I', '', 491.0, 545.0, 600.0),
	(40, 18, 19, 'm', 'D_I', '', 581.0, 645.0, 710.0),
	(40, 20, 24, 'm', 'D_I', '', 581.0, 645.0, 710.0),
	(40, 25, 29, 'm', 'D_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'D_I', '', 567.0, 630.0, 693.0),
	(40, 35, 39, 'm', 'D_I', '', 567.0, 630.0, 693.0),
	(40, 40, 44, 'm', 'D_I', '', 554.0, 615.0, 677.0),
	(40, 45, 49, 'm', 'D_I', '', 540.0, 600.0, 660.0),
	(40, 50, 54, 'm', 'D_I', '', 527.0, 585.0, 644.0),
	(40, 55, 59, 'm', 'D_I', '', 513.0, 570.0, 627.0),
	(40, 60, 64, 'm', 'D_I', '', 500.0, 555.0, 611.0),
	(40, 65, 69, 'm', 'D_I', '', 486.0, 540.0, 594.0),
	(40, 70, 74, 'm', 'D_I', '', 473.0, 525.0, 578.0),
	(40, 75, 79, 'm', 'D_I', '', 459.0, 510.0, 561.0),
	(40, 80, 84, 'm', 'D_I', '', 446.0, 495.0, 545.0),
	(40, 85, 89, 'm', 'D_I', '', 432.0, 480.0, 528.0),
	(40, 90, 200, 'm', 'D_I', '', 419.0, 465.0, 512.0),
	(41, 0, 7, 'w', 'D_I', '', 288.0, 320.0, 352.0),
	(41, 8, 9, 'w', 'D_I', '', 302.0, 335.0, 369.0),
	(41, 10, 11, 'w', 'D_I', '', 315.0, 350.0, 385.0),
	(41, 12, 13, 'w', 'D_I', '', 329.0, 365.0, 402.0),
	(41, 14, 15, 'w', 'D_I', '', 342.0, 380.0, 418.0),
	(41, 16, 17, 'w', 'D_I', '', 356.0, 395.0, 435.0),
	(41, 18, 19, 'w', 'D_I', '', 446.0, 495.0, 545.0),
	(41, 20, 24, 'w', 'D_I', '', 446.0, 495.0, 545.0),
	(41, 25, 29, 'w', 'D_I', '', 446.0, 495.0, 545.0),
	(41, 30, 34, 'w', 'D_I', '', 432.0, 480.0, 528.0),
	(41, 35, 39, 'w', 'D_I', '', 432.0, 480.0, 528.0),
	(41, 40, 44, 'w', 'D_I', '', 419.0, 465.0, 512.0),
	(41, 45, 49, 'w', 'D_I', '', 405.0, 450.0, 495.0),
	(41, 50, 54, 'w', 'D_I', '', 392.0, 435.0, 479.0),
	(41, 55, 59, 'w', 'D_I', '', 378.0, 420.0, 462.0),
	(41, 60, 64, 'w', 'D_I', '', 365.0, 405.0, 446.0),
	(41, 65, 69, 'w', 'D_I', '', 351.0, 390.0, 429.0),
	(41, 70, 74, 'w', 'D_I', '', 338.0, 375.0, 413.0),
	(41, 75, 79, 'w', 'D_I', '', 324.0, 360.0, 396.0),
	(41, 80, 84, 'w', 'D_I', '', 311.0, 345.0, 380.0),
	(41, 85, 89, 'w', 'D_I', '', 297.0, 330.0, 363.0),
	(41, 90, 200, 'w', 'D_I', '', 284.0, 315.0, 347.0),
	(41, 0, 7, 'm', 'D_I', '', 351.0, 390.0, 429.0),
	(41, 8, 9, 'm', 'D_I', '', 365.0, 405.0, 446.0),
	(41, 10, 11, 'm', 'D_I', '', 378.0, 420.0, 462.0),
	(41, 12, 13, 'm', 'D_I', '', 392.0, 435.0, 479.0),
	(41, 14, 15, 'm', 'D_I', '', 405.0, 450.0, 495.0),
	(41, 16, 17, 'm', 'D_I', '', 419.0, 465.0, 512.0),
	(41, 18, 19, 'm', 'D_I', '', 509.0, 565.0, 622.0),
	(41, 20, 24, 'm', 'D_I', '', 509.0, 565.0, 622.0),
	(41, 25, 29, 'm', 'D_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'D_I', '', 495.0, 550.0, 605.0),
	(41, 35, 39, 'm', 'D_I', '', 495.0, 550.0, 605.0),
	(41, 40, 44, 'm', 'D_I', '', 482.0, 535.0, 589.0),
	(41, 45, 49, 'm', 'D_I', '', 468.0, 520.0, 572.0),
	(41, 50, 54, 'm', 'D_I', '', 455.0, 505.0, 556.0),
	(41, 55, 59, 'm', 'D_I', '', 441.0, 490.0, 539.0),
	(41, 60, 64, 'm', 'D_I', '', 428.0, 475.0, 523.0),
	(41, 65, 69, 'm', 'D_I', '', 414.0, 460.0, 506.0),
	(41, 70, 74, 'm', 'D_I', '', 401.0, 445.0, 490.0),
	(41, 75, 79, 'm', 'D_I', '', 387.0, 430.0, 473.0),
	(41, 80, 84, 'm', 'D_I', '', 374.0, 415.0, 457.0),
	(41, 85, 89, 'm', 'D_I', '', 360.0, 400.0, 440.0),
	(41, 90, 200, 'm', 'D_I', '', 347.0, 385.0, 424.0),
	(42, 0, 7, 'w', 'D_I', '', 293.0, 325.0, 358.0),
	(42, 8, 9, 'w', 'D_I', '', 306.0, 340.0, 374.0),
	(42, 10, 11, 'w', 'D_I', '', 320.0, 355.0, 391.0),
	(42, 12, 13, 'w', 'D_I', '', 333.0, 370.0, 407.0),
	(42, 14, 15, 'w', 'D_I', '', 347.0, 385.0, 424.0),
	(42, 16, 17, 'w', 'D_I', '', 360.0, 400.0, 440.0),
	(42, 18, 19, 'w', 'D_I', '', 450.0, 500.0, 550.0),
	(42, 20, 24, 'w', 'D_I', '', 450.0, 500.0, 550.0),
	(42, 25, 29, 'w', 'D_I', '', 450.0, 500.0, 550.0),
	(42, 30, 34, 'w', 'D_I', '', 437.0, 485.0, 534.0),
	(42, 35, 39, 'w', 'D_I', '', 437.0, 485.0, 534.0),
	(42, 40, 44, 'w', 'D_I', '', 423.0, 470.0, 517.0),
	(42, 45, 49, 'w', 'D_I', '', 410.0, 455.0, 501.0),
	(42, 50, 54, 'w', 'D_I', '', 396.0, 440.0, 484.0),
	(42, 55, 59, 'w', 'D_I', '', 383.0, 425.0, 468.0),
	(42, 60, 64, 'w', 'D_I', '', 369.0, 410.0, 451.0),
	(42, 65, 69, 'w', 'D_I', '', 356.0, 395.0, 435.0),
	(42, 70, 74, 'w', 'D_I', '', 342.0, 380.0, 418.0),
	(42, 75, 79, 'w', 'D_I', '', 329.0, 365.0, 402.0),
	(42, 80, 84, 'w', 'D_I', '', 315.0, 350.0, 385.0),
	(42, 85, 89, 'w', 'D_I', '', 302.0, 335.0, 369.0),
	(42, 90, 200, 'w', 'D_I', '', 288.0, 320.0, 352.0),
	(42, 0, 7, 'm', 'D_I', '', 356.0, 395.0, 435.0),
	(42, 8, 9, 'm', 'D_I', '', 369.0, 410.0, 451.0),
	(42, 10, 11, 'm', 'D_I', '', 383.0, 425.0, 468.0),
	(42, 12, 13, 'm', 'D_I', '', 396.0, 440.0, 484.0),
	(42, 14, 15, 'm', 'D_I', '', 410.0, 455.0, 501.0),
	(42, 16, 17, 'm', 'D_I', '', 423.0, 470.0, 517.0),
	(42, 18, 19, 'm', 'D_I', '', 513.0, 570.0, 627.0),
	(42, 20, 24, 'm', 'D_I', '', 513.0, 570.0, 627.0),
	(42, 25, 29, 'm', 'D_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'D_I', '', 500.0, 555.0, 611.0),
	(42, 35, 39, 'm', 'D_I', '', 500.0, 555.0, 611.0),
	(42, 40, 44, 'm', 'D_I', '', 486.0, 540.0, 594.0),
	(42, 45, 49, 'm', 'D_I', '', 473.0, 525.0, 578.0),
	(42, 50, 54, 'm', 'D_I', '', 459.0, 510.0, 561.0),
	(42, 55, 59, 'm', 'D_I', '', 446.0, 495.0, 545.0),
	(42, 60, 64, 'm', 'D_I', '', 432.0, 480.0, 528.0),
	(42, 65, 69, 'm', 'D_I', '', 419.0, 465.0, 512.0),
	(42, 70, 74, 'm', 'D_I', '', 405.0, 450.0, 495.0),
	(42, 75, 79, 'm', 'D_I', '', 392.0, 435.0, 479.0),
	(42, 80, 84, 'm', 'D_I', '', 378.0, 420.0, 462.0),
	(42, 85, 89, 'm', 'D_I', '', 365.0, 405.0, 446.0),
	(42, 90, 200, 'm', 'D_I', '', 351.0, 390.0, 429.0),
	(53, 0, 7, 'w', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'D_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'D_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'D_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'D_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'D_I', '', 10.0, 12.0, 17.0),
	(57, 8, 9, 'w', 'D_I', '', 14.0, 17.0, 22.0),
	(57, 10, 11, 'w', 'D_I', '', 22.0, 24.0, 29.0),
	(57, 0, 7, 'm', 'D_I', '', 12.0, 14.0, 19.0),
	(57, 8, 9, 'm', 'D_I', '', 17.0, 22.0, 26.0),
	(57, 10, 11, 'm', 'D_I', '', 26.0, 31.0, 36.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'D_II', '', 6.800000000000001, 6.0, 5.1),
	(1, 8, 9, 'w', 'D_II', '', 6.7, 5.800000000000001, 5.0),
	(1, 10, 11, 'w', 'D_II', '', 6.4, 5.6000000000000005, 4.800000000000001),
	(1, 12, 13, 'w', 'D_II', '', 6.2, 5.3, 4.5),
	(1, 14, 15, 'w', 'D_II', '', 6.0, 5.2, 4.3),
	(1, 16, 17, 'w', 'D_II', '', 5.800000000000001, 4.9, 4.1),
	(1, 0, 7, 'm', 'D_II', '', 6.800000000000001, 6.0, 5.1),
	(1, 8, 9, 'm', 'D_II', '', 6.5, 5.6000000000000005, 4.7),
	(1, 10, 11, 'm', 'D_II', '', 6.1, 5.2, 4.3),
	(1, 12, 13, 'm', 'D_II', '', 5.7, 4.800000000000001, 3.9000000000000004),
	(1, 14, 15, 'm', 'D_II', '', 5.2, 4.4, 3.5999999999999996),
	(1, 16, 17, 'm', 'D_II', '', 4.9, 4.1, 3.3000000000000003),
	(4, 8, 9, 'w', 'D_II', '5 km', 32.400000000000006, 28.8, 25.200000000000003),
	(4, 10, 11, 'w', 'D_II', '10 km', 60.6, 51.6, 42.6),
	(4, 12, 13, 'w', 'D_II', '10 km', 54.0, 47.400000000000006, 40.199999999999996),
	(4, 14, 15, 'w', 'D_II', '10 km', 45.6, 39.0, 34.199999999999996),
	(4, 16, 17, 'w', 'D_II', '10 km', 39.0, 34.199999999999996, 30.0),
	(4, 18, 19, 'w', 'D_II', '20 km', 69.0, 62.400000000000006, 55.8),
	(4, 20, 24, 'w', 'D_II', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 25, 29, 'w', 'D_II', '20 km', 67.2, 60.6, 54.0),
	(4, 30, 34, 'w', 'D_II', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 35, 39, 'w', 'D_II', '20 km', 72.0, 63.6, 56.400000000000006),
	(4, 40, 44, 'w', 'D_II', '20 km', 76.80000000000001, 66.6, 59.400000000000006),
	(4, 45, 49, 'w', 'D_II', '20 km', 80.39999999999999, 70.2, 61.8),
	(4, 50, 54, 'w', 'D_II', '20 km', 82.80000000000001, 73.2, 64.2),
	(4, 55, 59, 'w', 'D_II', '20 km', 85.80000000000001, 75.6, 66.6),
	(4, 60, 64, 'w', 'D_II', '20 km', 88.80000000000001, 78.0, 68.39999999999999),
	(4, 65, 69, 'w', 'D_II', '20 km', 90.6, 79.80000000000001, 70.2),
	(4, 70, 74, 'w', 'D_II', '20 km', 93.6, 82.2, 72.6),
	(4, 75, 79, 'w', 'D_II', '20 km', 97.80000000000001, 84.6, 75.6),
	(4, 80, 84, 'w', 'D_II', '20 km', 101.39999999999999, 90.0, 78.6),
	(4, 85, 89, 'w', 'D_II', '20 km', 107.39999999999999, 96.0, 82.80000000000001),
	(4, 90, 200, 'w', 'D_II', '20 km', 111.6, 99.6, 87.0),
	(4, 8, 9, 'm', 'D_II', '5 km', 31.8, 28.200000000000003, 24.599999999999998),
	(4, 10, 11, 'm', 'D_II', '10 km', 58.199999999999996, 49.199999999999996, 40.199999999999996),
	(4, 12, 13, 'm', 'D_II', '10 km', 51.6, 44.400000000000006, 37.8),
	(4, 14, 15, 'm', 'D_II', '10 km', 38.400000000000006, 33.6, 28.8),
	(4, 16, 17, 'm', 'D_II', '10 km', 32.400000000000006, 28.200000000000003, 24.599999999999998),
	(4, 18, 19, 'm', 'D_II', '20 km', 56.400000000000006, 51.0, 46.199999999999996),
	(4, 20, 24, 'm', 'D_II', '20 km', 55.8, 50.400000000000006, 45.0),
	(4, 25, 29, 'm', 'D_II', '20 km', 60.0, 53.400000000000006, 46.8),
	(4, 30, 34, 'm', 'D_II', '20 km', 64.2, 56.400000000000006, 48.6),
	(4, 35, 39, 'm', 'D_II', '20 km', 69.6, 60.0, 49.8),
	(4, 40, 44, 'm', 'D_II', '20 km', 75.6, 62.400000000000006, 52.199999999999996),
	(4, 45, 49, 'm', 'D_II', '20 km', 79.2, 66.0, 54.0),
	(4, 50, 54, 'm', 'D_II', '20 km', 82.2, 68.39999999999999, 55.8),
	(4, 55, 59, 'm', 'D_II', '20 km', 84.6, 70.2, 57.0),
	(4, 60, 64, 'm', 'D_II', '20 km', 85.80000000000001, 72.0, 57.6),
	(4, 65, 69, 'm', 'D_II', '20 km', 87.0, 72.6, 58.199999999999996),
	(4, 70, 74, 'm', 'D_II', '20 km', 88.2, 73.80000000000001, 59.400000000000006),
	(4, 75, 79, 'm', 'D_II', '20 km', 89.39999999999999, 75.6, 61.8),
	(4, 80, 84, 'm', 'D_II', '20 km', 91.2, 77.39999999999999, 63.6),
	(4, 85, 89, 'm', 'D_II', '20 km', 93.0, 79.80000000000001, 66.6),
	(4, 90, 200, 'm', 'D_II', '20 km', 94.80000000000001, 81.6, 69.6),
	(5, 18, 19, 'w', 'D_II', '', 25.0, 22.599999999999998, 20.200000000000003),
	(5, 20, 24, 'w', 'D_II', '', 24.4, 22.0, 19.599999999999998),
	(5, 25, 29, 'w', 'D_II', '', 24.8, 22.4, 20.0),
	(5, 30, 34, 'w', 'D_II', '', 25.8, 23.4, 21.0),
	(5, 35, 39, 'w', 'D_II', '', 26.4, 24.0, 21.599999999999998),
	(5, 40, 44, 'w', 'D_II', '', 27.4, 24.8, 22.200000000000003),
	(5, 45, 49, 'w', 'D_II', '', 28.599999999999998, 25.8, 22.599999999999998),
	(5, 50, 54, 'w', 'D_II', '', 29.8, 26.599999999999998, 23.0),
	(5, 55, 59, 'w', 'D_II', '', 31.0, 27.4, 23.8),
	(5, 60, 64, 'w', 'D_II', '', 31.8, 28.200000000000003, 24.599999999999998),
	(5, 65, 69, 'w', 'D_II', '', 32.6, 29.0, 25.4),
	(5, 70, 74, 'w', 'D_II', '', 33.199999999999996, 29.599999999999998, 26.0),
	(5, 75, 79, 'w', 'D_II', '', 34.199999999999996, 30.599999999999998, 27.0),
	(5, 80, 84, 'w', 'D_II', '', 35.6, 32.0, 28.4),
	(5, 85, 89, 'w', 'D_II', '', 37.199999999999996, 33.6, 30.0),
	(5, 90, 200, 'w', 'D_II', '', 39.0, 35.400000000000006, 31.8),
	(5, 18, 19, 'm', 'D_II', '', 21.4, 19.0, 16.599999999999998),
	(5, 20, 24, 'm', 'D_II', '', 20.8, 18.4, 16.0),
	(5, 25, 29, 'm', 'D_II', '', 21.200000000000003, 18.8, 16.4),
	(5, 30, 34, 'm', 'D_II', '', 22.200000000000003, 19.8, 17.4),
	(5, 35, 39, 'm', 'D_II', '', 23.8, 20.8, 18.0),
	(5, 40, 44, 'm', 'D_II', '', 25.200000000000003, 22.200000000000003, 19.0),
	(5, 45, 49, 'm', 'D_II', '', 26.599999999999998, 23.4, 19.8),
	(5, 50, 54, 'm', 'D_II', '', 28.0, 24.4, 20.8),
	(5, 55, 59, 'm', 'D_II', '', 28.599999999999998, 25.0, 21.4),
	(5, 60, 64, 'm', 'D_II', '', 29.4, 25.8, 22.200000000000003),
	(5, 65, 69, 'm', 'D_II', '', 30.0, 26.4, 22.8),
	(5, 70, 74, 'm', 'D_II', '', 30.4, 26.8, 23.200000000000003),
	(5, 75, 79, 'm', 'D_II', '', 31.200000000000003, 27.599999999999998, 24.0),
	(5, 80, 84, 'm', 'D_II', '', 31.8, 28.200000000000003, 24.599999999999998),
	(5, 85, 89, 'm', 'D_II', '', 33.0, 29.4, 25.8),
	(5, 90, 200, 'm', 'D_II', '', 35.8, 32.199999999999996, 28.599999999999998),
	(6, 18, 19, 'w', 'D_II', '', 101.6, 94.39999999999999, 87.2),
	(6, 20, 24, 'w', 'D_II', '', 100.2, 92.2, 85.80000000000001),
	(6, 25, 29, 'w', 'D_II', '', 100.2, 92.2, 85.2),
	(6, 30, 34, 'w', 'D_II', '', 101.0, 93.6, 85.6),
	(6, 35, 39, 'w', 'D_II', '', 105.2, 95.39999999999999, 85.80000000000001),
	(6, 40, 44, 'w', 'D_II', '', 109.6, 97.6, 86.0),
	(6, 45, 49, 'w', 'D_II', '', 114.39999999999999, 99.80000000000001, 87.39999999999999),
	(6, 50, 54, 'w', 'D_II', '', 117.2, 102.6, 88.80000000000001),
	(6, 55, 59, 'w', 'D_II', '', 120.2, 105.80000000000001, 91.39999999999999),
	(6, 60, 64, 'w', 'D_II', '', 123.39999999999999, 109.0, 94.6),
	(6, 65, 69, 'w', 'D_II', '', 126.80000000000001, 112.39999999999999, 98.0),
	(6, 70, 74, 'w', 'D_II', '', 131.4, 117.0, 102.6),
	(6, 75, 79, 'w', 'D_II', '', 138.4, 124.0, 109.6),
	(6, 80, 84, 'w', 'D_II', '', 146.79999999999998, 132.4, 118.0),
	(6, 85, 89, 'w', 'D_II', '', 155.0, 140.60000000000002, 126.2),
	(6, 90, 200, 'w', 'D_II', '', 163.79999999999998, 149.4, 135.0),
	(6, 18, 19, 'm', 'D_II', '', 76.0, 68.80000000000001, 61.6),
	(6, 20, 24, 'm', 'D_II', '', 75.0, 67.80000000000001, 60.0),
	(6, 25, 29, 'm', 'D_II', '', 79.2, 71.2, 62.400000000000006),
	(6, 30, 34, 'm', 'D_II', '', 83.6, 73.39999999999999, 65.80000000000001),
	(6, 35, 39, 'm', 'D_II', '', 89.0, 78.6, 68.2),
	(6, 40, 44, 'm', 'D_II', '', 94.6, 83.39999999999999, 72.2),
	(6, 45, 49, 'm', 'D_II', '', 100.39999999999999, 87.80000000000001, 76.2),
	(6, 50, 54, 'm', 'D_II', '', 106.0, 92.0, 78.6),
	(6, 55, 59, 'm', 'D_II', '', 109.80000000000001, 95.6, 81.2),
	(6, 60, 64, 'm', 'D_II', '', 113.6, 99.2, 84.80000000000001),
	(6, 65, 69, 'm', 'D_II', '', 117.6, 103.2, 88.80000000000001),
	(6, 70, 74, 'm', 'D_II', '', 122.6, 108.2, 93.80000000000001),
	(6, 75, 79, 'm', 'D_II', '', 128.79999999999998, 114.39999999999999, 100.0),
	(6, 80, 84, 'm', 'D_II', '', 135.79999999999998, 121.39999999999999, 107.0),
	(6, 85, 89, 'm', 'D_II', '', 144.20000000000002, 129.79999999999998, 115.39999999999999),
	(6, 90, 200, 'm', 'D_II', '', 153.20000000000002, 138.79999999999998, 124.39999999999999),
	(7, 0, 7, 'w', 'D_II', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'D_II', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'D_II', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'D_II', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'D_II', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'D_II', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'D_II', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'D_II', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'D_II', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'D_II', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'D_II', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'D_II', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'D_II', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'D_II', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'D_II', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'D_II', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'D_II', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'D_II', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'D_II', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'D_II', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'D_II', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'D_II', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'D_II', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'D_II', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'D_II', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'D_II', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'D_II', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'D_II', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'D_II', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'D_II', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'D_II', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'D_II', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'D_II', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'D_II', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'D_II', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'D_II', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'D_II', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'D_II', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'D_II', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'D_II', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'D_II', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'D_II', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'D_II', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'D_II', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'D_II', '7,5 km', 76.44999999999999, 72.6, 68.2),
	(8, 20, 24, 'w', 'D_II', '7,5 km', 73.15, 69.30000000000001, 65.44999999999999),
	(8, 25, 29, 'w', 'D_II', '7,5 km', 73.7, 69.85000000000001, 66.0),
	(8, 30, 34, 'w', 'D_II', '7,5 km', 74.25000000000001, 70.39999999999999, 66.44999999999999),
	(8, 35, 39, 'w', 'D_II', '7,5 km', 77.0, 71.5, 66.83333333333333),
	(8, 40, 44, 'w', 'D_II', '7,5 km', 80.30000000000001, 73.7, 67.10000000000001),
	(8, 45, 49, 'w', 'D_II', '7,5 km', 83.05, 75.9, 68.2),
	(8, 50, 54, 'w', 'D_II', '7,5 km', 85.80000000000001, 78.10000000000001, 70.39999999999999),
	(8, 55, 59, 'w', 'D_II', '7,5 km', 88.0, 80.30000000000001, 72.6),
	(8, 60, 64, 'w', 'D_II', '7,5 km', 90.75, 81.94999999999999, 74.25000000000001),
	(8, 65, 69, 'w', 'D_II', '7,5 km', 92.66666666666667, 84.15, 77.0),
	(8, 70, 74, 'w', 'D_II', '7,5 km', 97.08333333333333, 86.9, 79.2),
	(8, 75, 79, 'w', 'D_II', '7,5 km', 101.75, 89.65, 81.94999999999999),
	(8, 80, 84, 'w', 'D_II', '7,5 km', 108.35, 93.78333333333333, 85.25000000000001),
	(8, 85, 89, 'w', 'D_II', '7,5 km', 114.39999999999999, 99.36666666666666, 90.2),
	(8, 90, 200, 'w', 'D_II', '7,5 km', 121.36666666666666, 105.6, 95.7),
	(8, 18, 19, 'm', 'D_II', '7,5 km', 64.35, 59.95, 55.55),
	(8, 20, 24, 'm', 'D_II', '7,5 km', 62.7, 58.3, 53.9),
	(8, 25, 29, 'm', 'D_II', '7,5 km', 64.35, 59.95, 55.55),
	(8, 30, 34, 'm', 'D_II', '7,5 km', 68.75, 62.7, 56.1),
	(8, 35, 39, 'm', 'D_II', '7,5 km', 71.5, 64.35, 58.849999999999994),
	(8, 40, 44, 'm', 'D_II', '7,5 km', 72.6, 66.55, 59.400000000000006),
	(8, 45, 49, 'm', 'D_II', '7,5 km', 75.35, 68.75, 60.49999999999999),
	(8, 50, 54, 'm', 'D_II', '7,5 km', 78.10000000000001, 70.39999999999999, 63.25),
	(8, 55, 59, 'm', 'D_II', '7,5 km', 80.30000000000001, 71.5, 64.9),
	(8, 60, 64, 'm', 'D_II', '7,5 km', 83.33333333333334, 74.25000000000001, 66.55),
	(8, 65, 69, 'm', 'D_II', '7,5 km', 85.98333333333333, 76.44999999999999, 68.2),
	(8, 70, 74, 'm', 'D_II', '7,5 km', 89.65, 79.2, 71.5),
	(8, 75, 79, 'm', 'D_II', '7,5 km', 94.78333333333333, 83.33333333333334, 79.2),
	(8, 80, 84, 'm', 'D_II', '7,5 km', 100.65, 87.73333333333333, 79.2),
	(8, 85, 89, 'm', 'D_II', '7,5 km', 105.6, 92.66666666666667, 83.05),
	(8, 90, 200, 'm', 'D_II', '7,5 km', 113.03333333333333, 98.26666666666667, 88.0),
	(10, 0, 7, 'w', 'D_II', '', 4.2, 6.3, 8.4),
	(10, 8, 9, 'w', 'D_II', '', 6.3, 8.4, 10.5),
	(10, 10, 11, 'w', 'D_II', '', 7.7, 10.5, 12.6),
	(10, 0, 7, 'm', 'D_II', '', 8.4, 10.5, 11.9),
	(10, 8, 9, 'm', 'D_II', '', 11.9, 14.0, 16.1),
	(10, 10, 11, 'm', 'D_II', '', 14.7, 17.5, 19.6),
	(11, 12, 13, 'w', 'D_II', '', 10.5, 12.6, 15.4),
	(11, 14, 15, 'w', 'D_II', '', 14.0, 16.8, 18.9),
	(11, 16, 17, 'w', 'D_II', '', 16.8, 18.9, 21.7),
	(11, 18, 19, 'w', 'D_II', '', 21.8, 23.9, 26.7),
	(11, 20, 24, 'w', 'D_II', '', 21.8, 23.9, 26.7),
	(11, 25, 29, 'w', 'D_II', '', 21.8, 23.9, 26.7),
	(11, 30, 34, 'w', 'D_II', '', 20.3, 22.4, 25.2),
	(11, 35, 39, 'w', 'D_II', '', 18.8, 20.9, 23.7),
	(11, 40, 44, 'w', 'D_II', '', 17.3, 19.4, 22.2),
	(11, 45, 49, 'w', 'D_II', '', 15.8, 17.9, 20.7),
	(11, 50, 54, 'w', 'D_II', '', 14.8, 16.9, 19.7),
	(11, 55, 59, 'w', 'D_II', '', 13.8, 15.9, 18.7),
	(11, 60, 64, 'w', 'D_II', '', 12.8, 14.9, 17.7),
	(11, 65, 69, 'w', 'D_II', '', 11.8, 13.9, 16.7),
	(11, 70, 74, 'w', 'D_II', '', 10.8, 12.9, 15.7),
	(11, 75, 79, 'w', 'D_II', '', 9.8, 11.9, 14.2),
	(11, 80, 84, 'w', 'D_II', '', 8.8, 10.9, 13.2),
	(11, 85, 89, 'w', 'D_II', '', 5.8, 7.9, 10.9),
	(11, 90, 200, 'w', 'D_II', '', 5.8, 7.9, 10.9),
	(11, 12, 13, 'm', 'D_II', '', 18.2, 21.0, 23.1),
	(11, 14, 15, 'm', 'D_II', '', 21.0, 23.8, 25.9),
	(11, 16, 17, 'm', 'D_II', '', 23.8, 26.6, 29.4),
	(11, 18, 19, 'm', 'D_II', '', 28.8, 31.6, 34.4),
	(11, 20, 24, 'm', 'D_II', '', 27.3, 30.1, 32.9),
	(11, 25, 29, 'm', 'D_II', '', 25.8, 28.6, 31.4),
	(11, 30, 34, 'm', 'D_II', '', 24.3, 27.1, 29.9),
	(11, 35, 39, 'm', 'D_II', '', 22.8, 25.6, 28.4),
	(11, 40, 44, 'm', 'D_II', '', 21.3, 24.1, 26.9),
	(11, 45, 49, 'm', 'D_II', '', 19.8, 22.6, 25.4),
	(11, 50, 54, 'm', 'D_II', '', 18.8, 21.6, 24.4),
	(11, 55, 59, 'm', 'D_II', '', 17.8, 20.6, 23.4),
	(11, 60, 64, 'm', 'D_II', '', 16.8, 19.6, 22.4),
	(11, 65, 69, 'm', 'D_II', '', 15.8, 18.6, 21.4),
	(11, 70, 74, 'm', 'D_II', '', 14.8, 17.6, 20.4),
	(11, 75, 79, 'm', 'D_II', '', 13.8, 16.6, 18.9),
	(11, 80, 84, 'm', 'D_II', '', 12.8, 15.6, 17.9),
	(11, 85, 89, 'm', 'D_II', '', 8.2, 10.6, 14.1),
	(11, 90, 200, 'm', 'D_II', '', 8.2, 10.6, 14.1),
	(13, 12, 13, 'w', 'D_II', '2 kg', 3.8, 4.2, 4.6),
	(13, 14, 15, 'w', 'D_II', '3 kg', 4.4, 4.8, 5.2),
	(13, 16, 17, 'w', 'D_II', '3 kg', 4.6, 5.0, 5.4),
	(13, 18, 19, 'w', 'D_II', '4 kg', 5.85, 6.3, 6.75),
	(13, 20, 24, 'w', 'D_II', '4 kg', 5.85, 6.3, 6.75),
	(13, 25, 29, 'w', 'D_II', '4 kg', 5.85, 6.3, 6.75),
	(13, 30, 34, 'w', 'D_II', '4 kg', 5.63, 6.08, 6.53),
	(13, 35, 39, 'w', 'D_II', '4 kg', 5.4, 5.85, 6.3),
	(13, 40, 44, 'w', 'D_II', '4 kg', 4.95, 5.4, 5.85),
	(13, 45, 49, 'w', 'D_II', '4 kg', 4.73, 5.18, 5.63),
	(13, 50, 54, 'w', 'D_II', '3 kg', 4.73, 5.4, 6.3),
	(13, 55, 59, 'w', 'D_II', '3 kg', 4.5, 5.18, 5.85),
	(13, 60, 64, 'w', 'D_II', '3 kg', 4.28, 4.95, 5.63),
	(13, 65, 69, 'w', 'D_II', '3 kg', 4.05, 4.73, 5.63),
	(13, 70, 74, 'w', 'D_II', '3 kg', 3.83, 4.5, 5.4),
	(13, 75, 79, 'w', 'D_II', '2 kg', 3.83, 4.73, 5.63),
	(13, 80, 84, 'w', 'D_II', '2 kg', 3.6, 4.5, 5.18),
	(13, 85, 89, 'w', 'D_II', '2 kg', 3.38, 4.05, 4.95),
	(13, 90, 200, 'w', 'D_II', '2 kg', 2.93, 3.83, 4.5),
	(13, 12, 13, 'm', 'D_II', '3 kg', 5.0, 5.4, 5.8),
	(13, 14, 15, 'm', 'D_II', '4 kg', 5.6, 6.0, 6.4),
	(13, 16, 17, 'm', 'D_II', '5 kg', 6.0, 6.4, 6.8),
	(13, 18, 19, 'm', 'D_II', '6 kg', 6.98, 7.43, 7.88),
	(13, 20, 24, 'm', 'D_II', '6 kg', 6.98, 7.65, 8.1),
	(13, 25, 29, 'm', 'D_II', '6 kg', 6.75, 7.43, 7.88),
	(13, 30, 34, 'm', 'D_II', '6 kg', 6.3, 6.98, 7.43),
	(13, 35, 39, 'm', 'D_II', '6 kg', 6.08, 6.53, 7.2),
	(13, 40, 44, 'm', 'D_II', '6 kg', 5.63, 6.3, 6.98),
	(13, 45, 49, 'm', 'D_II', '6 kg', 5.4, 6.08, 6.75),
	(13, 50, 54, 'm', 'D_II', '5 kg', 5.63, 6.3, 7.2),
	(13, 55, 59, 'm', 'D_II', '5 kg', 5.4, 6.08, 6.75),
	(13, 60, 64, 'm', 'D_II', '4 kg', 5.4, 6.3, 7.2),
	(13, 65, 69, 'm', 'D_II', '4 kg', 5.18, 6.08, 6.75),
	(13, 70, 74, 'm', 'D_II', '4 kg', 5.4, 6.08, 6.98),
	(13, 75, 79, 'm', 'D_II', '3 kg', 5.18, 5.85, 6.75),
	(13, 80, 84, 'm', 'D_II', '3 kg', 4.95, 5.63, 6.53),
	(13, 85, 89, 'm', 'D_II', '3 kg', 4.5, 5.4, 6.08),
	(13, 90, 200, 'm', 'D_II', '3 kg', 4.05, 4.73, 5.63),
	(15, 0, 7, 'w', 'D_II', '', 0.84, 1.0, 1.12),
	(15, 8, 9, 'w', 'D_II', '', 0.92, 1.04, 1.2),
	(15, 10, 11, 'w', 'D_II', '', 1.04, 1.16, 1.32),
	(15, 12, 13, 'w', 'D_II', '', 1.12, 1.28, 1.44),
	(15, 14, 15, 'w', 'D_II', '', 1.24, 1.36, 1.52),
	(15, 16, 17, 'w', 'D_II', '', 1.32, 1.44, 1.6),
	(15, 18, 19, 'w', 'D_II', '', 1.32, 1.48, 1.64),
	(15, 20, 24, 'w', 'D_II', '', 1.28, 1.44, 1.6),
	(15, 25, 29, 'w', 'D_II', '', 1.2, 1.36, 1.56),
	(15, 30, 34, 'w', 'D_II', '', 1.08, 1.28, 1.48),
	(15, 35, 39, 'w', 'D_II', '', 1.0, 1.2, 1.44),
	(15, 40, 44, 'w', 'D_II', '', 0.92, 1.12, 1.32),
	(15, 45, 49, 'w', 'D_II', '', 0.88, 1.08, 1.28),
	(15, 50, 54, 'w', 'D_II', '', 0.8, 1.04, 1.24),
	(15, 55, 59, 'w', 'D_II', '', 0.76, 0.96, 1.16),
	(15, 60, 64, 'w', 'D_II', '', 0.76, 0.96, 1.16),
	(15, 65, 69, 'w', 'D_II', '', 0.72, 0.92, 1.12),
	(15, 70, 74, 'w', 'D_II', '', 0.72, 0.92, 1.08),
	(15, 75, 79, 'w', 'D_II', '', 0.72, 0.92, 1.08),
	(15, 80, 84, 'w', 'D_II', '', 0.72, 0.88, 1.04),
	(15, 85, 89, 'w', 'D_II', '', 0.68, 0.84, 1.0),
	(15, 90, 200, 'w', 'D_II', '', 0.64, 0.8, 0.96),
	(15, 0, 7, 'm', 'D_II', '', 0.92, 1.08, 1.2),
	(15, 8, 9, 'm', 'D_II', '', 1.04, 1.2, 1.32),
	(15, 10, 11, 'm', 'D_II', '', 1.2, 1.36, 1.48),
	(15, 12, 13, 'm', 'D_II', '', 1.36, 1.52, 1.64),
	(15, 14, 15, 'm', 'D_II', '', 1.52, 1.64, 1.8),
	(15, 16, 17, 'm', 'D_II', '', 1.64, 1.76, 1.92),
	(15, 18, 19, 'm', 'D_II', '', 1.68, 1.84, 2.0),
	(15, 20, 24, 'm', 'D_II', '', 1.68, 1.84, 2.0),
	(15, 25, 29, 'm', 'D_II', '', 1.64, 1.8, 1.96),
	(15, 30, 34, 'm', 'D_II', '', 1.48, 1.68, 1.88),
	(15, 35, 39, 'm', 'D_II', '', 1.32, 1.56, 1.8),
	(15, 40, 44, 'm', 'D_II', '', 1.24, 1.48, 1.72),
	(15, 45, 49, 'm', 'D_II', '', 1.16, 1.4, 1.64),
	(15, 50, 54, 'm', 'D_II', '', 1.12, 1.36, 1.6),
	(15, 55, 59, 'm', 'D_II', '', 1.08, 1.32, 1.56),
	(15, 60, 64, 'm', 'D_II', '', 1.04, 1.28, 1.52),
	(15, 65, 69, 'm', 'D_II', '', 1.04, 1.28, 1.52),
	(15, 70, 74, 'm', 'D_II', '', 1.0, 1.24, 1.48),
	(15, 75, 79, 'm', 'D_II', '', 0.96, 1.2, 1.44),
	(15, 80, 84, 'm', 'D_II', '', 0.92, 1.16, 1.4),
	(15, 85, 89, 'm', 'D_II', '', 0.8, 1.04, 1.28),
	(15, 90, 200, 'm', 'D_II', '', 0.72, 0.96, 1.2),
	(17, 0, 7, 'w', 'D_II', '30 m', 9.6, 8.5, 7.6),
	(17, 8, 9, 'w', 'D_II', '30 m', 8.9, 7.9, 6.8),
	(17, 10, 11, 'w', 'D_II', '50 m', 13.2, 12.1, 10.9),
	(17, 12, 13, 'w', 'D_II', '50 m', 12.7, 11.5, 10.2),
	(17, 14, 15, 'w', 'D_II', '100 m', 22.3, 20.4, 18.6),
	(17, 16, 17, 'w', 'D_II', '100 m', 21.1, 19.6, 18.0),
	(17, 18, 19, 'w', 'D_II', '100 m', 21.8, 19.8, 18.4),
	(17, 20, 24, 'w', 'D_II', '100 m', 22.2, 20.2, 18.7),
	(17, 25, 29, 'w', 'D_II', '100 m', 22.7, 20.6, 19.2),
	(17, 30, 34, 'w', 'D_II', '100 m', 23.5, 21.4, 19.7),
	(17, 35, 39, 'w', 'D_II', '100 m', 24.5, 22.3, 20.4),
	(17, 40, 44, 'w', 'D_II', '50 m', 13.2, 11.9, 10.6),
	(17, 45, 49, 'w', 'D_II', '50 m', 13.8, 12.4, 10.9),
	(17, 50, 54, 'w', 'D_II', '50 m', 14.3, 12.8, 11.4),
	(17, 55, 59, 'w', 'D_II', '50 m', 14.9, 13.4, 11.9),
	(17, 60, 64, 'w', 'D_II', '50 m', 15.1, 13.7, 12.2),
	(17, 65, 69, 'w', 'D_II', '50 m', 15.4, 13.9, 12.5),
	(17, 70, 74, 'w', 'D_II', '50 m', 15.6, 14.2, 12.7),
	(17, 75, 79, 'w', 'D_II', '50 m', 16.2, 14.8, 13.3),
	(17, 80, 84, 'w', 'D_II', '50 m', 17.2, 15.7, 14.4),
	(17, 85, 89, 'w', 'D_II', '50 m', 18.6, 17.2, 15.8),
	(17, 90, 200, 'w', 'D_II', '50 m', 20.5, 19.1, 17.8),
	(17, 0, 7, 'm', 'D_II', '30 m', 9.2, 8.2, 7.2),
	(17, 8, 9, 'm', 'D_II', '30 m', 8.6, 7.7, 6.8),
	(17, 10, 11, 'm', 'D_II', '50 m', 12.4, 11.2, 10.1),
	(17, 12, 13, 'm', 'D_II', '50 m', 11.6, 10.7, 9.7),
	(17, 14, 15, 'm', 'D_II', '100 m', 20.4, 18.5, 16.9),
	(17, 16, 17, 'm', 'D_II', '100 m', 19.6, 17.8, 16.2),
	(17, 18, 19, 'm', 'D_II', '100 m', 19.2, 17.5, 15.8),
	(17, 20, 24, 'm', 'D_II', '100 m', 19.0, 17.3, 15.6),
	(17, 25, 29, 'm', 'D_II', '100 m', 19.6, 17.8, 16.0),
	(17, 30, 34, 'm', 'D_II', '100 m', 20.2, 18.1, 16.3),
	(17, 35, 39, 'm', 'D_II', '100 m', 21.1, 19.1, 17.0),
	(17, 40, 44, 'm', 'D_II', '50 m', 11.5, 10.4, 9.2),
	(17, 45, 49, 'm', 'D_II', '50 m', 12.0, 10.7, 9.5),
	(17, 50, 54, 'm', 'D_II', '50 m', 12.4, 10.9, 9.8),
	(17, 55, 59, 'm', 'D_II', '50 m', 12.6, 11.3, 10.2),
	(17, 60, 64, 'm', 'D_II', '50 m', 13.0, 11.6, 10.6),
	(17, 65, 69, 'm', 'D_II', '50 m', 13.4, 12.2, 10.9),
	(17, 70, 74, 'm', 'D_II', '50 m', 14.0, 12.8, 11.5),
	(17, 75, 79, 'm', 'D_II', '50 m', 14.6, 13.4, 12.1),
	(17, 80, 84, 'm', 'D_II', '50 m', 15.6, 14.4, 13.1),
	(17, 85, 89, 'm', 'D_II', '50 m', 16.9, 15.7, 14.4),
	(17, 90, 200, 'm', 'D_II', '50 m', 18.6, 17.4, 16.1),
	(18, 0, 7, 'w', 'D_II', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'D_II', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'D_II', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'D_II', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'D_II', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'D_II', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'D_II', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'D_II', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'D_II', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'D_II', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'D_II', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'D_II', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'D_II', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'D_II', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'D_II', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'D_II', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'D_II', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'D_II', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'D_II', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'D_II', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'D_II', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'D_II', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'D_II', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'D_II', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'D_II', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'D_II', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'D_II', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'D_II', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'D_II', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'D_II', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'D_II', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'D_II', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'D_II', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'D_II', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'D_II', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'D_II', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'D_II', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'D_II', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'D_II', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'D_II', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'D_II', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'D_II', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'D_II', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'D_II', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'D_II', '', 49.2, 43.2, 37.2),
	(19, 10, 11, 'w', 'D_II', '', 44.4, 38.4, 32.4),
	(19, 12, 13, 'w', 'D_II', '', 37.2, 32.4, 28.2),
	(19, 14, 15, 'w', 'D_II', '', 32.4, 29.4, 25.8),
	(19, 16, 17, 'w', 'D_II', '', 30.0, 27.0, 24.0),
	(19, 18, 19, 'w', 'D_II', '', 28.8, 26.4, 23.4),
	(19, 20, 24, 'w', 'D_II', '', 29.4, 26.4, 23.4),
	(19, 25, 29, 'w', 'D_II', '', 30.0, 27.0, 24.0),
	(19, 30, 34, 'w', 'D_II', '', 31.2, 28.2, 25.8),
	(19, 35, 39, 'w', 'D_II', '', 33.0, 29.4, 26.4),
	(19, 40, 44, 'w', 'D_II', '', 34.8, 30.6, 27.0),
	(19, 45, 49, 'w', 'D_II', '', 36.6, 32.4, 27.6),
	(19, 50, 54, 'w', 'D_II', '', 38.4, 33.6, 28.2),
	(19, 55, 59, 'w', 'D_II', '', 40.2, 34.8, 28.8),
	(19, 60, 64, 'w', 'D_II', '', 42.0, 36.0, 30.0),
	(19, 65, 69, 'w', 'D_II', '', 43.2, 37.2, 30.6),
	(19, 70, 74, 'w', 'D_II', '', 45.6, 38.4, 31.8),
	(19, 75, 79, 'w', 'D_II', '', 46.8, 39.6, 33.0),
	(19, 80, 84, 'w', 'D_II', '', 48.6, 41.4, 34.2),
	(19, 85, 89, 'w', 'D_II', '', 50.4, 43.2, 36.0),
	(19, 90, 200, 'w', 'D_II', '', 53.4, 45.6, 37.8),
	(19, 8, 9, 'm', 'D_II', '', 45.6, 39.6, 33.6),
	(19, 10, 11, 'm', 'D_II', '', 42.0, 36.6, 31.2),
	(19, 12, 13, 'm', 'D_II', '', 35.4, 31.2, 27.0),
	(19, 14, 15, 'm', 'D_II', '', 28.8, 25.8, 22.8),
	(19, 16, 17, 'm', 'D_II', '', 26.4, 23.4, 20.4),
	(19, 18, 19, 'm', 'D_II', '', 24.6, 21.6, 18.6),
	(19, 20, 24, 'm', 'D_II', '', 24.0, 21.0, 18.0),
	(19, 25, 29, 'm', 'D_II', '', 25.2, 21.6, 18.0),
	(19, 30, 34, 'm', 'D_II', '', 27.0, 22.2, 18.0),
	(19, 35, 39, 'm', 'D_II', '', 28.8, 24.0, 18.6),
	(19, 40, 44, 'm', 'D_II', '', 31.8, 25.8, 19.8),
	(19, 45, 49, 'm', 'D_II', '', 34.2, 27.6, 20.4),
	(19, 50, 54, 'm', 'D_II', '', 36.0, 28.8, 21.6),
	(19, 55, 59, 'm', 'D_II', '', 38.4, 30.0, 22.2),
	(19, 60, 64, 'm', 'D_II', '', 40.2, 31.2, 22.8),
	(19, 65, 69, 'm', 'D_II', '', 42.0, 32.4, 23.4),
	(19, 70, 74, 'm', 'D_II', '', 43.2, 34.2, 24.0),
	(19, 75, 79, 'm', 'D_II', '', 45.0, 35.4, 25.8),
	(19, 80, 84, 'm', 'D_II', '', 46.8, 37.8, 27.6),
	(19, 85, 89, 'm', 'D_II', '', 49.2, 39.6, 29.4),
	(19, 90, 200, 'm', 'D_II', '', 52.2, 42.6, 32.4),
	(21, 10, 11, 'w', 'D_II', '', 0.64, 0.72, 0.8),
	(21, 12, 13, 'w', 'D_II', '', 0.72, 0.8, 0.88),
	(21, 14, 15, 'w', 'D_II', '', 0.76, 0.84, 0.92),
	(21, 16, 17, 'w', 'D_II', '', 0.84, 0.92, 1.0),
	(21, 18, 19, 'w', 'D_II', '', 0.88, 0.96, 1.04),
	(21, 20, 24, 'w', 'D_II', '', 0.88, 0.96, 1.04),
	(21, 25, 29, 'w', 'D_II', '', 0.84, 0.92, 1.0),
	(21, 30, 34, 'w', 'D_II', '', 0.8, 0.88, 0.96),
	(21, 35, 39, 'w', 'D_II', '', 0.76, 0.84, 0.92),
	(21, 40, 44, 'w', 'D_II', '', 0.72, 0.8, 0.88),
	(21, 45, 49, 'w', 'D_II', '', 0.72, 0.8, 0.88),
	(21, 50, 54, 'w', 'D_II', '', 0.68, 0.76, 0.84),
	(21, 55, 59, 'w', 'D_II', '', 0.64, 0.72, 0.8),
	(21, 60, 64, 'w', 'D_II', '', 0.6, 0.68, 0.76),
	(21, 65, 69, 'w', 'D_II', '', 0.6, 0.68, 0.76),
	(21, 70, 74, 'w', 'D_II', '', 0.56, 0.64, 0.72),
	(21, 75, 79, 'w', 'D_II', '', 0.52, 0.6, 0.68),
	(21, 80, 84, 'w', 'D_II', '', 0.52, 0.6, 0.68),
	(21, 85, 89, 'w', 'D_II', '', 0.48, 0.56, 0.64),
	(21, 90, 200, 'w', 'D_II', '', 0.44, 0.48, 0.52),
	(21, 10, 11, 'm', 'D_II', '', 0.68, 0.76, 0.84),
	(21, 12, 13, 'm', 'D_II', '', 0.76, 0.84, 0.92),
	(21, 14, 15, 'm', 'D_II', '', 0.88, 0.96, 1.04),
	(21, 16, 17, 'm', 'D_II', '', 0.96, 1.04, 1.12),
	(21, 18, 19, 'm', 'D_II', '', 1.04, 1.12, 1.2),
	(21, 20, 24, 'm', 'D_II', '', 1.08, 1.16, 1.24),
	(21, 25, 29, 'm', 'D_II', '', 1.04, 1.12, 1.2),
	(21, 30, 34, 'm', 'D_II', '', 1.04, 1.12, 1.2),
	(21, 35, 39, 'm', 'D_II', '', 1.0, 1.08, 1.16),
	(21, 40, 44, 'm', 'D_II', '', 0.96, 1.04, 1.12),
	(21, 45, 49, 'm', 'D_II', '', 0.92, 1.0, 1.08),
	(21, 50, 54, 'm', 'D_II', '', 0.84, 0.92, 1.0),
	(21, 55, 59, 'm', 'D_II', '', 0.8, 0.88, 0.96),
	(21, 60, 64, 'm', 'D_II', '', 0.76, 0.84, 0.92),
	(21, 65, 69, 'm', 'D_II', '', 0.68, 0.8, 0.88),
	(21, 70, 74, 'm', 'D_II', '', 0.64, 0.76, 0.84),
	(21, 75, 79, 'm', 'D_II', '', 0.6, 0.72, 0.8),
	(21, 80, 84, 'm', 'D_II', '', 0.6, 0.68, 0.76),
	(21, 85, 89, 'm', 'D_II', '', 0.56, 0.64, 0.72),
	(21, 90, 200, 'm', 'D_II', '', 0.52, 0.6, 0.68),
	(23, 0, 7, 'w', 'D_II', '', 1.44, 1.68, 1.92),
	(23, 8, 9, 'w', 'D_II', '', 1.64, 1.88, 2.12),
	(23, 10, 11, 'w', 'D_II', '', 1.84, 2.08, 2.32),
	(23, 12, 13, 'w', 'D_II', '', 2.24, 2.48, 2.72),
	(23, 14, 15, 'w', 'D_II', '', 2.56, 2.8, 3.04),
	(23, 16, 17, 'w', 'D_II', '', 2.72, 2.96, 3.2),
	(23, 18, 19, 'w', 'D_II', '', 2.72, 2.96, 3.2),
	(23, 20, 24, 'w', 'D_II', '', 2.72, 2.96, 3.2),
	(23, 25, 29, 'w', 'D_II', '', 2.64, 2.88, 3.12),
	(23, 30, 34, 'w', 'D_II', '', 2.56, 2.8, 3.04),
	(23, 35, 39, 'w', 'D_II', '', 2.48, 2.72, 2.96),
	(23, 40, 44, 'w', 'D_II', '', 2.4, 2.64, 2.88),
	(23, 45, 49, 'w', 'D_II', '', 2.24, 2.56, 2.8),
	(23, 50, 54, 'w', 'D_II', '', 2.08, 2.4, 2.72),
	(23, 55, 59, 'w', 'D_II', '', 2.0, 2.32, 2.64),
	(23, 60, 64, 'w', 'D_II', '', 1.92, 2.24, 2.56),
	(23, 65, 69, 'w', 'D_II', '', 1.84, 2.16, 2.48),
	(23, 70, 74, 'w', 'D_II', '', 1.68, 2.0, 2.32),
	(23, 75, 79, 'w', 'D_II', '', 1.44, 1.76, 2.08),
	(23, 80, 84, 'w', 'D_II', '', 1.28, 1.6, 1.92),
	(23, 85, 89, 'w', 'D_II', '', 1.04, 1.36, 1.68),
	(23, 90, 200, 'w', 'D_II', '', 0.88, 1.2, 1.52),
	(23, 0, 7, 'm', 'D_II', '', 1.68, 1.92, 2.16),
	(23, 8, 9, 'm', 'D_II', '', 1.88, 2.12, 2.36),
	(23, 10, 11, 'm', 'D_II', '', 2.08, 2.32, 2.56),
	(23, 12, 13, 'm', 'D_II', '', 2.56, 2.8, 3.04),
	(23, 14, 15, 'm', 'D_II', '', 3.04, 3.28, 3.52),
	(23, 16, 17, 'm', 'D_II', '', 3.44, 3.68, 3.92),
	(23, 18, 19, 'm', 'D_II', '', 3.6, 3.84, 4.08),
	(23, 20, 24, 'm', 'D_II', '', 3.52, 3.76, 4.0),
	(23, 25, 29, 'm', 'D_II', '', 3.44, 3.68, 3.92),
	(23, 30, 34, 'm', 'D_II', '', 3.36, 3.6, 3.84),
	(23, 35, 39, 'm', 'D_II', '', 3.28, 3.52, 3.76),
	(23, 40, 44, 'm', 'D_II', '', 3.12, 3.44, 3.68),
	(23, 45, 49, 'm', 'D_II', '', 2.96, 3.28, 3.6),
	(23, 50, 54, 'm', 'D_II', '', 2.88, 3.2, 3.52),
	(23, 55, 59, 'm', 'D_II', '', 2.72, 3.04, 3.36),
	(23, 60, 64, 'm', 'D_II', '', 2.56, 2.88, 3.2),
	(23, 65, 69, 'm', 'D_II', '', 2.32, 2.64, 2.96),
	(23, 70, 74, 'm', 'D_II', '', 2.16, 2.48, 2.8),
	(23, 75, 79, 'm', 'D_II', '', 1.92, 2.32, 2.64),
	(23, 80, 84, 'm', 'D_II', '', 1.68, 2.08, 2.48),
	(23, 85, 89, 'm', 'D_II', '', 1.52, 1.92, 2.32),
	(23, 90, 200, 'm', 'D_II', '', 1.28, 1.68, 2.08),
	(25, 12, 13, 'w', 'D_II', '', 11.9, 13.65, 15.4),
	(25, 14, 15, 'w', 'D_II', '', 13.65, 15.75, 17.85),
	(25, 16, 17, 'w', 'D_II', '', 15.4, 17.5, 19.6),
	(25, 18, 19, 'w', 'D_II', '', 16.45, 18.55, 20.3),
	(25, 20, 24, 'w', 'D_II', '', 16.8, 18.9, 20.65),
	(25, 25, 29, 'w', 'D_II', '', 16.8, 18.9, 20.65),
	(25, 30, 34, 'w', 'D_II', '', 15.4, 17.5, 19.25),
	(25, 35, 39, 'w', 'D_II', '', 14.7, 16.8, 18.55),
	(25, 40, 44, 'w', 'D_II', '', 13.65, 15.75, 17.5),
	(25, 45, 49, 'w', 'D_II', '', 12.95, 15.05, 16.8),
	(25, 50, 54, 'w', 'D_II', '', 11.55, 14.0, 16.1),
	(25, 55, 59, 'w', 'D_II', '', 10.85, 13.3, 15.4),
	(25, 60, 64, 'w', 'D_II', '', 10.15, 12.6, 14.7),
	(25, 65, 69, 'w', 'D_II', '', 9.45, 11.9, 14.0),
	(25, 70, 74, 'w', 'D_II', '', 9.1, 11.55, 13.65),
	(25, 75, 79, 'w', 'D_II', '', 8.4, 10.85, 12.95),
	(25, 80, 84, 'w', 'D_II', '', 7.7, 10.15, 12.25),
	(25, 85, 89, 'w', 'D_II', '', 6.65, 9.1, 11.2),
	(25, 90, 200, 'w', 'D_II', '', 5.25, 7.7, 9.8),
	(25, 12, 13, 'm', 'D_II', '', 13.65, 16.8, 19.25),
	(25, 14, 15, 'm', 'D_II', '', 16.45, 19.6, 22.4),
	(25, 16, 17, 'm', 'D_II', '', 19.25, 22.4, 25.55),
	(25, 18, 19, 'm', 'D_II', '', 22.05, 25.2, 28.35),
	(25, 20, 24, 'm', 'D_II', '', 23.1, 26.6, 29.4),
	(25, 25, 29, 'm', 'D_II', '', 22.75, 26.25, 29.05),
	(25, 30, 34, 'm', 'D_II', '', 21.0, 24.5, 28.0),
	(25, 35, 39, 'm', 'D_II', '', 19.95, 23.45, 26.95),
	(25, 40, 44, 'm', 'D_II', '', 19.6, 23.1, 26.6),
	(25, 45, 49, 'm', 'D_II', '', 18.9, 22.4, 26.25),
	(25, 50, 54, 'm', 'D_II', '', 17.85, 21.7, 25.55),
	(25, 55, 59, 'm', 'D_II', '', 16.45, 20.3, 24.5),
	(25, 60, 64, 'm', 'D_II', '', 15.75, 19.6, 23.8),
	(25, 65, 69, 'm', 'D_II', '', 14.0, 17.85, 21.35),
	(25, 70, 74, 'm', 'D_II', '', 12.95, 16.8, 20.3),
	(25, 75, 79, 'm', 'D_II', '', 11.2, 14.7, 18.2),
	(25, 80, 84, 'm', 'D_II', '', 9.8, 13.3, 16.8),
	(25, 85, 89, 'm', 'D_II', '', 8.4, 11.55, 14.7),
	(25, 90, 200, 'm', 'D_II', '', 7.35, 10.5, 13.65),
	(33, 0, 7, 'w', 'D_II', '', 6.4, 9.6, 13.6),
	(33, 8, 9, 'w', 'D_II', '', 8.0, 12.0, 16.0),
	(33, 10, 11, 'w', 'D_II', '', 12.0, 16.0, 24.0),
	(33, 12, 13, 'w', 'D_II', '', 16.0, 24.0, 32.0),
	(33, 14, 15, 'w', 'D_II', '', 24.0, 32.0, 40.0),
	(33, 16, 17, 'w', 'D_II', '', 36.0, 48.0, 60.0),
	(33, 0, 7, 'm', 'D_II', '', 8.0, 12.0, 16.0),
	(33, 8, 9, 'm', 'D_II', '', 9.6, 13.6, 18.4),
	(33, 10, 11, 'm', 'D_II', '', 13.6, 20.0, 28.0),
	(33, 12, 13, 'm', 'D_II', '', 20.0, 28.0, 36.0),
	(33, 14, 15, 'm', 'D_II', '', 28.0, 36.0, 48.0),
	(33, 16, 17, 'm', 'D_II', '', 44.0, 56.0, 72.0),
	(39, 0, 7, 'w', 'D_II', '', 182.0, 203.0, 223.0),
	(39, 8, 9, 'w', 'D_II', '', 194.0, 215.0, 237.0),
	(39, 10, 11, 'w', 'D_II', '', 205.0, 228.0, 250.0),
	(39, 12, 13, 'w', 'D_II', '', 216.0, 240.0, 264.0),
	(39, 14, 15, 'w', 'D_II', '', 227.0, 253.0, 278.0),
	(39, 16, 17, 'w', 'D_II', '', 239.0, 265.0, 292.0),
	(39, 18, 19, 'w', 'D_II', '', 329.0, 365.0, 402.0),
	(39, 20, 24, 'w', 'D_II', '', 329.0, 365.0, 402.0),
	(39, 25, 29, 'w', 'D_II', '', 329.0, 365.0, 402.0),
	(39, 30, 34, 'w', 'D_II', '', 317.0, 353.0, 388.0),
	(39, 35, 39, 'w', 'D_II', '', 317.0, 353.0, 388.0),
	(39, 40, 44, 'w', 'D_II', '', 306.0, 340.0, 374.0),
	(39, 45, 49, 'w', 'D_II', '', 295.0, 328.0, 360.0),
	(39, 50, 54, 'w', 'D_II', '', 284.0, 315.0, 347.0),
	(39, 55, 59, 'w', 'D_II', '', 272.0, 303.0, 333.0),
	(39, 60, 64, 'w', 'D_II', '', 261.0, 290.0, 319.0),
	(39, 65, 69, 'w', 'D_II', '', 250.0, 278.0, 305.0),
	(39, 70, 74, 'w', 'D_II', '', 239.0, 265.0, 292.0),
	(39, 75, 79, 'w', 'D_II', '', 227.0, 253.0, 278.0),
	(39, 80, 84, 'w', 'D_II', '', 216.0, 240.0, 264.0),
	(39, 85, 89, 'w', 'D_II', '', 205.0, 228.0, 250.0),
	(39, 90, 200, 'w', 'D_II', '', 194.0, 215.0, 237.0),
	(39, 0, 7, 'm', 'D_II', '', 241.0, 268.0, 294.0),
	(39, 8, 9, 'm', 'D_II', '', 252.0, 280.0, 308.0),
	(39, 10, 11, 'm', 'D_II', '', 263.0, 293.0, 322.0),
	(39, 12, 13, 'm', 'D_II', '', 275.0, 305.0, 336.0),
	(39, 14, 15, 'm', 'D_II', '', 286.0, 318.0, 349.0),
	(39, 16, 17, 'm', 'D_II', '', 297.0, 330.0, 363.0),
	(39, 18, 19, 'm', 'D_II', '', 387.0, 430.0, 473.0),
	(39, 20, 24, 'm', 'D_II', '', 387.0, 430.0, 473.0),
	(39, 25, 29, 'm', 'D_II', '', 387.0, 430.0, 473.0),
	(39, 30, 34, 'm', 'D_II', '', 376.0, 418.0, 459.0),
	(39, 35, 39, 'm', 'D_II', '', 376.0, 418.0, 459.0),
	(39, 40, 44, 'm', 'D_II', '', 365.0, 405.0, 446.0),
	(39, 45, 49, 'm', 'D_II', '', 353.0, 393.0, 432.0),
	(39, 50, 54, 'm', 'D_II', '', 342.0, 380.0, 418.0),
	(39, 55, 59, 'm', 'D_II', '', 331.0, 368.0, 404.0),
	(39, 60, 64, 'm', 'D_II', '', 320.0, 355.0, 391.0),
	(39, 65, 69, 'm', 'D_II', '', 308.0, 343.0, 377.0),
	(39, 70, 74, 'm', 'D_II', '', 297.0, 330.0, 363.0),
	(39, 75, 79, 'm', 'D_II', '', 286.0, 318.0, 349.0),
	(39, 80, 84, 'm', 'D_II', '', 275.0, 305.0, 336.0),
	(39, 85, 89, 'm', 'D_II', '', 263.0, 293.0, 322.0),
	(39, 90, 200, 'm', 'D_II', '', 252.0, 280.0, 308.0),
	(40, 0, 7, 'w', 'D_II', '', 342.0, 380.0, 418.0),
	(40, 8, 9, 'w', 'D_II', '', 356.0, 395.0, 435.0),
	(40, 10, 11, 'w', 'D_II', '', 369.0, 410.0, 451.0),
	(40, 12, 13, 'w', 'D_II', '', 383.0, 425.0, 468.0),
	(40, 14, 15, 'w', 'D_II', '', 396.0, 440.0, 484.0),
	(40, 16, 17, 'w', 'D_II', '', 410.0, 455.0, 501.0),
	(40, 18, 19, 'w', 'D_II', '', 500.0, 555.0, 611.0),
	(40, 20, 24, 'w', 'D_II', '', 500.0, 555.0, 611.0),
	(40, 25, 29, 'w', 'D_II', '', 500.0, 555.0, 611.0),
	(40, 30, 34, 'w', 'D_II', '', 486.0, 540.0, 594.0),
	(40, 35, 39, 'w', 'D_II', '', 486.0, 540.0, 594.0),
	(40, 40, 44, 'w', 'D_II', '', 473.0, 525.0, 578.0),
	(40, 45, 49, 'w', 'D_II', '', 459.0, 510.0, 561.0),
	(40, 50, 54, 'w', 'D_II', '', 446.0, 495.0, 545.0),
	(40, 55, 59, 'w', 'D_II', '', 432.0, 480.0, 528.0),
	(40, 60, 64, 'w', 'D_II', '', 419.0, 465.0, 512.0),
	(40, 65, 69, 'w', 'D_II', '', 405.0, 450.0, 495.0),
	(40, 70, 74, 'w', 'D_II', '', 392.0, 435.0, 479.0),
	(40, 75, 79, 'w', 'D_II', '', 378.0, 420.0, 462.0),
	(40, 80, 84, 'w', 'D_II', '', 365.0, 405.0, 446.0),
	(40, 85, 89, 'w', 'D_II', '', 351.0, 390.0, 429.0),
	(40, 90, 200, 'w', 'D_II', '', 338.0, 375.0, 413.0),
	(40, 0, 7, 'm', 'D_II', '', 410.0, 455.0, 501.0),
	(40, 8, 9, 'm', 'D_II', '', 423.0, 470.0, 517.0),
	(40, 10, 11, 'm', 'D_II', '', 437.0, 485.0, 534.0),
	(40, 12, 13, 'm', 'D_II', '', 450.0, 500.0, 550.0),
	(40, 14, 15, 'm', 'D_II', '', 464.0, 515.0, 567.0),
	(40, 16, 17, 'm', 'D_II', '', 477.0, 530.0, 583.0),
	(40, 18, 19, 'm', 'D_II', '', 567.0, 630.0, 693.0),
	(40, 20, 24, 'm', 'D_II', '', 567.0, 630.0, 693.0),
	(40, 25, 29, 'm', 'D_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'D_II', '', 554.0, 615.0, 677.0),
	(40, 35, 39, 'm', 'D_II', '', 554.0, 615.0, 677.0),
	(40, 40, 44, 'm', 'D_II', '', 540.0, 600.0, 660.0),
	(40, 45, 49, 'm', 'D_II', '', 527.0, 585.0, 644.0),
	(40, 50, 54, 'm', 'D_II', '', 513.0, 570.0, 627.0),
	(40, 55, 59, 'm', 'D_II', '', 500.0, 555.0, 611.0),
	(40, 60, 64, 'm', 'D_II', '', 486.0, 540.0, 594.0),
	(40, 65, 69, 'm', 'D_II', '', 473.0, 525.0, 578.0),
	(40, 70, 74, 'm', 'D_II', '', 459.0, 510.0, 561.0),
	(40, 75, 79, 'm', 'D_II', '', 446.0, 495.0, 545.0),
	(40, 80, 84, 'm', 'D_II', '', 432.0, 480.0, 528.0),
	(40, 85, 89, 'm', 'D_II', '', 419.0, 465.0, 512.0),
	(40, 90, 200, 'm', 'D_II', '', 405.0, 450.0, 495.0),
	(41, 0, 7, 'w', 'D_II', '', 275.0, 305.0, 336.0),
	(41, 8, 9, 'w', 'D_II', '', 288.0, 320.0, 352.0),
	(41, 10, 11, 'w', 'D_II', '', 302.0, 335.0, 369.0),
	(41, 12, 13, 'w', 'D_II', '', 315.0, 350.0, 385.0),
	(41, 14, 15, 'w', 'D_II', '', 329.0, 365.0, 402.0),
	(41, 16, 17, 'w', 'D_II', '', 342.0, 380.0, 418.0),
	(41, 18, 19, 'w', 'D_II', '', 432.0, 480.0, 528.0),
	(41, 20, 24, 'w', 'D_II', '', 432.0, 480.0, 528.0),
	(41, 25, 29, 'w', 'D_II', '', 432.0, 480.0, 528.0),
	(41, 30, 34, 'w', 'D_II', '', 419.0, 465.0, 512.0),
	(41, 35, 39, 'w', 'D_II', '', 419.0, 465.0, 512.0),
	(41, 40, 44, 'w', 'D_II', '', 405.0, 450.0, 495.0),
	(41, 45, 49, 'w', 'D_II', '', 392.0, 435.0, 479.0),
	(41, 50, 54, 'w', 'D_II', '', 378.0, 420.0, 462.0),
	(41, 55, 59, 'w', 'D_II', '', 365.0, 405.0, 446.0),
	(41, 60, 64, 'w', 'D_II', '', 351.0, 390.0, 429.0),
	(41, 65, 69, 'w', 'D_II', '', 338.0, 375.0, 413.0),
	(41, 70, 74, 'w', 'D_II', '', 324.0, 360.0, 396.0),
	(41, 75, 79, 'w', 'D_II', '', 311.0, 345.0, 380.0),
	(41, 80, 84, 'w', 'D_II', '', 297.0, 330.0, 363.0),
	(41, 85, 89, 'w', 'D_II', '', 284.0, 315.0, 347.0),
	(41, 90, 200, 'w', 'D_II', '', 270.0, 300.0, 330.0),
	(41, 0, 7, 'm', 'D_II', '', 338.0, 375.0, 413.0),
	(41, 8, 9, 'm', 'D_II', '', 351.0, 390.0, 429.0),
	(41, 10, 11, 'm', 'D_II', '', 365.0, 405.0, 446.0),
	(41, 12, 13, 'm', 'D_II', '', 378.0, 420.0, 462.0),
	(41, 14, 15, 'm', 'D_II', '', 392.0, 435.0, 479.0),
	(41, 16, 17, 'm', 'D_II', '', 405.0, 450.0, 495.0),
	(41, 18, 19, 'm', 'D_II', '', 495.0, 550.0, 605.0),
	(41, 20, 24, 'm', 'D_II', '', 495.0, 550.0, 605.0),
	(41, 25, 29, 'm', 'D_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'D_II', '', 482.0, 535.0, 589.0),
	(41, 35, 39, 'm', 'D_II', '', 482.0, 535.0, 589.0),
	(41, 40, 44, 'm', 'D_II', '', 468.0, 520.0, 572.0),
	(41, 45, 49, 'm', 'D_II', '', 455.0, 505.0, 556.0),
	(41, 50, 54, 'm', 'D_II', '', 441.0, 490.0, 539.0),
	(41, 55, 59, 'm', 'D_II', '', 428.0, 475.0, 523.0),
	(41, 60, 64, 'm', 'D_II', '', 414.0, 460.0, 506.0),
	(41, 65, 69, 'm', 'D_II', '', 401.0, 445.0, 490.0),
	(41, 70, 74, 'm', 'D_II', '', 387.0, 430.0, 473.0),
	(41, 75, 79, 'm', 'D_II', '', 374.0, 415.0, 457.0),
	(41, 80, 84, 'm', 'D_II', '', 360.0, 400.0, 440.0),
	(41, 85, 89, 'm', 'D_II', '', 347.0, 385.0, 424.0),
	(41, 90, 200, 'm', 'D_II', '', 333.0, 370.0, 407.0),
	(42, 0, 7, 'w', 'D_II', '', 279.0, 310.0, 341.0),
	(42, 8, 9, 'w', 'D_II', '', 293.0, 325.0, 358.0),
	(42, 10, 11, 'w', 'D_II', '', 306.0, 340.0, 374.0),
	(42, 12, 13, 'w', 'D_II', '', 320.0, 355.0, 391.0),
	(42, 14, 15, 'w', 'D_II', '', 333.0, 370.0, 407.0),
	(42, 16, 17, 'w', 'D_II', '', 347.0, 385.0, 424.0),
	(42, 18, 19, 'w', 'D_II', '', 437.0, 485.0, 534.0),
	(42, 20, 24, 'w', 'D_II', '', 437.0, 485.0, 534.0),
	(42, 25, 29, 'w', 'D_II', '', 437.0, 485.0, 534.0),
	(42, 30, 34, 'w', 'D_II', '', 423.0, 470.0, 517.0),
	(42, 35, 39, 'w', 'D_II', '', 423.0, 470.0, 517.0),
	(42, 40, 44, 'w', 'D_II', '', 410.0, 455.0, 501.0),
	(42, 45, 49, 'w', 'D_II', '', 396.0, 440.0, 484.0),
	(42, 50, 54, 'w', 'D_II', '', 383.0, 425.0, 468.0),
	(42, 55, 59, 'w', 'D_II', '', 369.0, 410.0, 451.0),
	(42, 60, 64, 'w', 'D_II', '', 356.0, 395.0, 435.0),
	(42, 65, 69, 'w', 'D_II', '', 342.0, 380.0, 418.0),
	(42, 70, 74, 'w', 'D_II', '', 329.0, 365.0, 402.0),
	(42, 75, 79, 'w', 'D_II', '', 315.0, 350.0, 385.0),
	(42, 80, 84, 'w', 'D_II', '', 302.0, 335.0, 369.0),
	(42, 85, 89, 'w', 'D_II', '', 288.0, 320.0, 352.0),
	(42, 90, 200, 'w', 'D_II', '', 275.0, 305.0, 336.0),
	(42, 0, 7, 'm', 'D_II', '', 342.0, 380.0, 418.0),
	(42, 8, 9, 'm', 'D_II', '', 356.0, 395.0, 435.0),
	(42, 10, 11, 'm', 'D_II', '', 369.0, 410.0, 451.0),
	(42, 12, 13, 'm', 'D_II', '', 383.0, 425.0, 468.0),
	(42, 14, 15, 'm', 'D_II', '', 396.0, 440.0, 484.0),
	(42, 16, 17, 'm', 'D_II', '', 410.0, 455.0, 501.0),
	(42, 18, 19, 'm', 'D_II', '', 500.0, 555.0, 611.0),
	(42, 20, 24, 'm', 'D_II', '', 500.0, 555.0, 611.0),
	(42, 25, 29, 'm', 'D_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'D_II', '', 486.0, 540.0, 594.0),
	(42, 35, 39, 'm', 'D_II', '', 486.0, 540.0, 594.0),
	(42, 40, 44, 'm', 'D_II', '', 473.0, 525.0, 578.0),
	(42, 45, 49, 'm', 'D_II', '', 459.0, 510.0, 561.0),
	(42, 50, 54, 'm', 'D_II', '', 446.0, 495.0, 545.0),
	(42, 55, 59, 'm', 'D_II', '', 432.0, 480.0, 528.0),
	(42, 60, 64, 'm', 'D_II', '', 419.0, 465.0, 512.0),
	(42, 65, 69, 'm', 'D_II', '', 405.0, 450.0, 495.0),
	(42, 70, 74, 'm', 'D_II', '', 392.0, 435.0, 479.0),
	(42, 75, 79, 'm', 'D_II', '', 378.0, 420.0, 462.0),
	(42, 80, 84, 'm', 'D_II', '', 365.0, 405.0, 446.0),
	(42, 85, 89, 'm', 'D_II', '', 351.0, 390.0, 429.0),
	(42, 90, 200, 'm', 'D_II', '', 338.0, 375.0, 413.0),
	(53, 0, 7, 'w', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'D_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'D_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'D_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'D_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'D_II', '', 8.0, 11.0, 15.0),
	(57, 8, 9, 'w', 'D_II', '', 13.0, 15.0, 19.0),
	(57, 10, 11, 'w', 'D_II', '', 19.0, 21.0, 25.0),
	(57, 0, 7, 'm', 'D_II', '', 11.0, 13.0, 17.0),
	(57, 8, 9, 'm', 'D_II', '', 15.0, 19.0, 23.0),
	(57, 10, 11, 'm', 'D_II', '', 23.0, 27.0, 32.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'E_I', '', 6.800000000000001, 6.0, 5.1),
	(1, 8, 9, 'w', 'E_I', '', 6.7, 5.800000000000001, 5.0),
	(1, 10, 11, 'w', 'E_I', '', 6.4, 5.6000000000000005, 4.800000000000001),
	(1, 12, 13, 'w', 'E_I', '', 6.2, 5.3, 4.5),
	(1, 14, 15, 'w', 'E_I', '', 6.0, 5.2, 4.3),
	(1, 16, 17, 'w', 'E_I', '', 5.800000000000001, 4.9, 4.1),
	(1, 0, 7, 'm', 'E_I', '', 6.800000000000001, 6.0, 5.1),
	(1, 8, 9, 'm', 'E_I', '', 6.5, 5.6000000000000005, 4.7),
	(1, 10, 11, 'm', 'E_I', '', 6.1, 5.2, 4.3),
	(1, 12, 13, 'm', 'E_I', '', 5.7, 4.800000000000001, 3.9000000000000004),
	(1, 14, 15, 'm', 'E_I', '', 5.2, 4.4, 3.5999999999999996),
	(1, 16, 17, 'm', 'E_I', '', 4.9, 4.1, 3.3000000000000003),
	(4, 8, 9, 'w', 'E_I', '5 km', 32.400000000000006, 28.8, 25.200000000000003),
	(4, 10, 11, 'w', 'E_I', '10 km', 60.6, 51.6, 42.6),
	(4, 12, 13, 'w', 'E_I', '10 km', 54.0, 47.400000000000006, 40.199999999999996),
	(4, 14, 15, 'w', 'E_I', '10 km', 45.6, 39.0, 34.199999999999996),
	(4, 16, 17, 'w', 'E_I', '10 km', 39.0, 34.199999999999996, 30.0),
	(4, 18, 19, 'w', 'E_I', '20 km', 69.0, 62.400000000000006, 55.8),
	(4, 20, 24, 'w', 'E_I', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 25, 29, 'w', 'E_I', '20 km', 67.2, 60.6, 54.0),
	(4, 30, 34, 'w', 'E_I', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 35, 39, 'w', 'E_I', '20 km', 72.0, 63.6, 56.400000000000006),
	(4, 40, 44, 'w', 'E_I', '20 km', 76.80000000000001, 66.6, 59.400000000000006),
	(4, 45, 49, 'w', 'E_I', '20 km', 80.39999999999999, 70.2, 61.8),
	(4, 50, 54, 'w', 'E_I', '20 km', 82.80000000000001, 73.2, 64.2),
	(4, 55, 59, 'w', 'E_I', '20 km', 85.80000000000001, 75.6, 66.6),
	(4, 60, 64, 'w', 'E_I', '20 km', 88.80000000000001, 78.0, 68.39999999999999),
	(4, 65, 69, 'w', 'E_I', '20 km', 90.6, 79.80000000000001, 70.2),
	(4, 70, 74, 'w', 'E_I', '20 km', 93.6, 82.2, 72.6),
	(4, 75, 79, 'w', 'E_I', '20 km', 97.80000000000001, 84.6, 75.6),
	(4, 80, 84, 'w', 'E_I', '20 km', 101.39999999999999, 90.0, 78.6),
	(4, 85, 89, 'w', 'E_I', '20 km', 107.39999999999999, 96.0, 82.80000000000001),
	(4, 90, 200, 'w', 'E_I', '20 km', 111.6, 99.6, 87.0),
	(4, 8, 9, 'm', 'E_I', '5 km', 31.8, 28.200000000000003, 24.599999999999998),
	(4, 10, 11, 'm', 'E_I', '10 km', 58.199999999999996, 49.199999999999996, 40.199999999999996),
	(4, 12, 13, 'm', 'E_I', '10 km', 51.6, 44.400000000000006, 37.8),
	(4, 14, 15, 'm', 'E_I', '10 km', 38.400000000000006, 33.6, 28.8),
	(4, 16, 17, 'm', 'E_I', '10 km', 32.400000000000006, 28.200000000000003, 24.599999999999998),
	(4, 18, 19, 'm', 'E_I', '20 km', 56.400000000000006, 51.0, 46.199999999999996),
	(4, 20, 24, 'm', 'E_I', '20 km', 55.8, 50.400000000000006, 45.0),
	(4, 25, 29, 'm', 'E_I', '20 km', 60.0, 53.400000000000006, 46.8),
	(4, 30, 34, 'm', 'E_I', '20 km', 64.2, 56.400000000000006, 48.6),
	(4, 35, 39, 'm', 'E_I', '20 km', 69.6, 60.0, 49.8),
	(4, 40, 44, 'm', 'E_I', '20 km', 75.6, 62.400000000000006, 52.199999999999996),
	(4, 45, 49, 'm', 'E_I', '20 km', 79.2, 66.0, 54.0),
	(4, 50, 54, 'm', 'E_I', '20 km', 82.2, 68.39999999999999, 55.8),
	(4, 55, 59, 'm', 'E_I', '20 km', 84.6, 70.2, 57.0),
	(4, 60, 64, 'm', 'E_I', '20 km', 85.80000000000001, 72.0, 57.6),
	(4, 65, 69, 'm', 'E_I', '20 km', 87.0, 72.6, 58.199999999999996),
	(4, 70, 74, 'm', 'E_I', '20 km', 88.2, 73.80000000000001, 59.400000000000006),
	(4, 75, 79, 'm', 'E_I', '20 km', 89.39999999999999, 75.6, 61.8),
	(4, 80, 84, 'm', 'E_I', '20 km', 91.2, 77.39999999999999, 63.6),
	(4, 85, 89, 'm', 'E_I', '20 km', 93.0, 79.80000000000001, 66.6),
	(4, 90, 200, 'm', 'E_I', '20 km', 94.80000000000001, 81.6, 69.6),
	(5, 18, 19, 'w', 'E_I', '', 25.0, 22.599999999999998, 20.200000000000003),
	(5, 20, 24, 'w', 'E_I', '', 24.4, 22.0, 19.599999999999998),
	(5, 25, 29, 'w', 'E_I', '', 24.8, 22.4, 20.0),
	(5, 30, 34, 'w', 'E_I', '', 25.8, 23.4, 21.0),
	(5, 35, 39, 'w', 'E_I', '', 26.4, 24.0, 21.599999999999998),
	(5, 40, 44, 'w', 'E_I', '', 27.4, 24.8, 22.200000000000003),
	(5, 45, 49, 'w', 'E_I', '', 28.599999999999998, 25.8, 22.599999999999998),
	(5, 50, 54, 'w', 'E_I', '', 29.8, 26.599999999999998, 23.0),
	(5, 55, 59, 'w', 'E_I', '', 31.0, 27.4, 23.8),
	(5, 60, 64, 'w', 'E_I', '', 31.8, 28.200000000000003, 24.599999999999998),
	(5, 65, 69, 'w', 'E_I', '', 32.6, 29.0, 25.4),
	(5, 70, 74, 'w', 'E_I', '', 33.199999999999996, 29.599999999999998, 26.0),
	(5, 75, 79, 'w', 'E_I', '', 34.199999999999996, 30.599999999999998, 27.0),
	(5, 80, 84, 'w', 'E_I', '', 35.6, 32.0, 28.4),
	(5, 85, 89, 'w', 'E_I', '', 37.199999999999996, 33.6, 30.0),
	(5, 90, 200, 'w', 'E_I', '', 39.0, 35.400000000000006, 31.8),
	(5, 18, 19, 'm', 'E_I', '', 21.4, 19.0, 16.599999999999998),
	(5, 20, 24, 'm', 'E_I', '', 20.8, 18.4, 16.0),
	(5, 25, 29, 'm', 'E_I', '', 21.200000000000003, 18.8, 16.4),
	(5, 30, 34, 'm', 'E_I', '', 22.200000000000003, 19.8, 17.4),
	(5, 35, 39, 'm', 'E_I', '', 23.8, 20.8, 18.0),
	(5, 40, 44, 'm', 'E_I', '', 25.200000000000003, 22.200000000000003, 19.0),
	(5, 45, 49, 'm', 'E_I', '', 26.599999999999998, 23.4, 19.8),
	(5, 50, 54, 'm', 'E_I', '', 28.0, 24.4, 20.8),
	(5, 55, 59, 'm', 'E_I', '', 28.599999999999998, 25.0, 21.4),
	(5, 60, 64, 'm', 'E_I', '', 29.4, 25.8, 22.200000000000003),
	(5, 65, 69, 'm', 'E_I', '', 30.0, 26.4, 22.8),
	(5, 70, 74, 'm', 'E_I', '', 30.4, 26.8, 23.200000000000003),
	(5, 75, 79, 'm', 'E_I', '', 31.200000000000003, 27.599999999999998, 24.0),
	(5, 80, 84, 'm', 'E_I', '', 31.8, 28.200000000000003, 24.599999999999998),
	(5, 85, 89, 'm', 'E_I', '', 33.0, 29.4, 25.8),
	(5, 90, 200, 'm', 'E_I', '', 35.8, 32.199999999999996, 28.599999999999998),
	(6, 18, 19, 'w', 'E_I', '', 101.6, 94.39999999999999, 87.2),
	(6, 20, 24, 'w', 'E_I', '', 100.2, 92.2, 85.80000000000001),
	(6, 25, 29, 'w', 'E_I', '', 100.2, 92.2, 85.2),
	(6, 30, 34, 'w', 'E_I', '', 101.0, 93.6, 85.6),
	(6, 35, 39, 'w', 'E_I', '', 105.2, 95.39999999999999, 85.80000000000001),
	(6, 40, 44, 'w', 'E_I', '', 109.6, 97.6, 86.0),
	(6, 45, 49, 'w', 'E_I', '', 114.39999999999999, 99.80000000000001, 87.39999999999999),
	(6, 50, 54, 'w', 'E_I', '', 117.2, 102.6, 88.80000000000001),
	(6, 55, 59, 'w', 'E_I', '', 120.2, 105.80000000000001, 91.39999999999999),
	(6, 60, 64, 'w', 'E_I', '', 123.39999999999999, 109.0, 94.6),
	(6, 65, 69, 'w', 'E_I', '', 126.80000000000001, 112.39999999999999, 98.0),
	(6, 70, 74, 'w', 'E_I', '', 131.4, 117.0, 102.6),
	(6, 75, 79, 'w', 'E_I', '', 138.4, 124.0, 109.6),
	(6, 80, 84, 'w', 'E_I', '', 146.79999999999998, 132.4, 118.0),
	(6, 85, 89, 'w', 'E_I', '', 155.0, 140.60000000000002, 126.2),
	(6, 90, 200, 'w', 'E_I', '', 163.79999999999998, 149.4, 135.0),
	(6, 18, 19, 'm', 'E_I', '', 76.0, 68.80000000000001, 61.6),
	(6, 20, 24, 'm', 'E_I', '', 75.0, 67.80000000000001, 60.0),
	(6, 25, 29, 'm', 'E_I', '', 79.2, 71.2, 62.400000000000006),
	(6, 30, 34, 'm', 'E_I', '', 83.6, 73.39999999999999, 65.80000000000001),
	(6, 35, 39, 'm', 'E_I', '', 89.0, 78.6, 68.2),
	(6, 40, 44, 'm', 'E_I', '', 94.6, 83.39999999999999, 72.2),
	(6, 45, 49, 'm', 'E_I', '', 100.39999999999999, 87.80000000000001, 76.2),
	(6, 50, 54, 'm', 'E_I', '', 106.0, 92.0, 78.6),
	(6, 55, 59, 'm', 'E_I', '', 109.80000000000001, 95.6, 81.2),
	(6, 60, 64, 'm', 'E_I', '', 113.6, 99.2, 84.80000000000001),
	(6, 65, 69, 'm', 'E_I', '', 117.6, 103.2, 88.80000000000001),
	(6, 70, 74, 'm', 'E_I', '', 122.6, 108.2, 93.80000000000001),
	(6, 75, 79, 'm', 'E_I', '', 128.79999999999998, 114.39999999999999, 100.0),
	(6, 80, 84, 'm', 'E_I', '', 135.79999999999998, 121.39999999999999, 107.0),
	(6, 85, 89, 'm', 'E_I', '', 144.20000000000002, 129.79999999999998, 115.39999999999999),
	(6, 90, 200, 'm', 'E_I', '', 153.20000000000002, 138.79999999999998, 124.39999999999999),
	(7, 0, 7, 'w', 'E_I', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'E_I', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'E_I', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'E_I', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'E_I', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'E_I', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'E_I', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'E_I', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'E_I', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'E_I', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'E_I', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'E_I', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'E_I', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'E_I', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'E_I', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'E_I', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'E_I', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'E_I', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'E_I', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'E_I', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'E_I', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'E_I', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'E_I', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'E_I', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'E_I', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'E_I', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'E_I', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'E_I', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'E_I', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'E_I', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'E_I', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'E_I', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'E_I', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'E_I', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'E_I', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'E_I', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'E_I', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'E_I', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'E_I', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'E_I', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'E_I', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'E_I', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'E_I', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'E_I', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'E_I', '7,5 km', 76.44999999999999, 72.6, 68.2),
	(8, 20, 24, 'w', 'E_I', '7,5 km', 73.15, 69.30000000000001, 65.44999999999999),
	(8, 25, 29, 'w', 'E_I', '7,5 km', 73.7, 69.85000000000001, 66.0),
	(8, 30, 34, 'w', 'E_I', '7,5 km', 74.25000000000001, 70.39999999999999, 66.44999999999999),
	(8, 35, 39, 'w', 'E_I', '7,5 km', 77.0, 71.5, 66.83333333333333),
	(8, 40, 44, 'w', 'E_I', '7,5 km', 80.30000000000001, 73.7, 67.10000000000001),
	(8, 45, 49, 'w', 'E_I', '7,5 km', 83.05, 75.9, 68.2),
	(8, 50, 54, 'w', 'E_I', '7,5 km', 85.80000000000001, 78.10000000000001, 70.39999999999999),
	(8, 55, 59, 'w', 'E_I', '7,5 km', 88.0, 80.30000000000001, 72.6),
	(8, 60, 64, 'w', 'E_I', '7,5 km', 90.75, 81.94999999999999, 74.25000000000001),
	(8, 65, 69, 'w', 'E_I', '7,5 km', 92.66666666666667, 84.15, 77.0),
	(8, 70, 74, 'w', 'E_I', '7,5 km', 97.08333333333333, 86.9, 79.2),
	(8, 75, 79, 'w', 'E_I', '7,5 km', 101.75, 89.65, 81.94999999999999),
	(8, 80, 84, 'w', 'E_I', '7,5 km', 108.35, 93.78333333333333, 85.25000000000001),
	(8, 85, 89, 'w', 'E_I', '7,5 km', 114.39999999999999, 99.36666666666666, 90.2),
	(8, 90, 200, 'w', 'E_I', '7,5 km', 121.36666666666666, 105.6, 95.7),
	(8, 18, 19, 'm', 'E_I', '7,5 km', 64.35, 59.95, 55.55),
	(8, 20, 24, 'm', 'E_I', '7,5 km', 62.7, 58.3, 53.9),
	(8, 25, 29, 'm', 'E_I', '7,5 km', 64.35, 59.95, 55.55),
	(8, 30, 34, 'm', 'E_I', '7,5 km', 68.75, 62.7, 56.1),
	(8, 35, 39, 'm', 'E_I', '7,5 km', 71.5, 64.35, 58.849999999999994),
	(8, 40, 44, 'm', 'E_I', '7,5 km', 72.6, 66.55, 59.400000000000006),
	(8, 45, 49, 'm', 'E_I', '7,5 km', 75.35, 68.75, 60.49999999999999),
	(8, 50, 54, 'm', 'E_I', '7,5 km', 78.10000000000001, 70.39999999999999, 63.25),
	(8, 55, 59, 'm', 'E_I', '7,5 km', 80.30000000000001, 71.5, 64.9),
	(8, 60, 64, 'm', 'E_I', '7,5 km', 83.33333333333334, 74.25000000000001, 66.55),
	(8, 65, 69, 'm', 'E_I', '7,5 km', 85.98333333333333, 76.44999999999999, 68.2),
	(8, 70, 74, 'm', 'E_I', '7,5 km', 89.65, 79.2, 71.5),
	(8, 75, 79, 'm', 'E_I', '7,5 km', 94.78333333333333, 83.33333333333334, 79.2),
	(8, 80, 84, 'm', 'E_I', '7,5 km', 100.65, 87.73333333333333, 79.2),
	(8, 85, 89, 'm', 'E_I', '7,5 km', 105.6, 92.66666666666667, 83.05),
	(8, 90, 200, 'm', 'E_I', '7,5 km', 113.03333333333333, 98.26666666666667, 88.0),
	(15, 0, 7, 'w', 'E_I', '', 0.84, 1.0, 1.12),
	(15, 8, 9, 'w', 'E_I', '', 0.92, 1.04, 1.2),
	(15, 10, 11, 'w', 'E_I', '', 1.04, 1.16, 1.32),
	(15, 12, 13, 'w', 'E_I', '', 1.12, 1.28, 1.44),
	(15, 14, 15, 'w', 'E_I', '', 1.24, 1.36, 1.52),
	(15, 16, 17, 'w', 'E_I', '', 1.32, 1.44, 1.6),
	(15, 18, 19, 'w', 'E_I', '', 1.32, 1.48, 1.64),
	(15, 20, 24, 'w', 'E_I', '', 1.28, 1.44, 1.6),
	(15, 25, 29, 'w', 'E_I', '', 1.2, 1.36, 1.56),
	(15, 30, 34, 'w', 'E_I', '', 1.08, 1.28, 1.48),
	(15, 35, 39, 'w', 'E_I', '', 1.0, 1.2, 1.44),
	(15, 40, 44, 'w', 'E_I', '', 0.92, 1.12, 1.32),
	(15, 45, 49, 'w', 'E_I', '', 0.88, 1.08, 1.28),
	(15, 50, 54, 'w', 'E_I', '', 0.8, 1.04, 1.24),
	(15, 55, 59, 'w', 'E_I', '', 0.76, 0.96, 1.16),
	(15, 60, 64, 'w', 'E_I', '', 0.76, 0.96, 1.16),
	(15, 65, 69, 'w', 'E_I', '', 0.72, 0.92, 1.12),
	(15, 70, 74, 'w', 'E_I', '', 0.72, 0.92, 1.08),
	(15, 75, 79, 'w', 'E_I', '', 0.72, 0.92, 1.08),
	(15, 80, 84, 'w', 'E_I', '', 0.72, 0.88, 1.04),
	(15, 85, 89, 'w', 'E_I', '', 0.68, 0.84, 1.0),
	(15, 90, 200, 'w', 'E_I', '', 0.64, 0.8, 0.96),
	(15, 0, 7, 'm', 'E_I', '', 0.92, 1.08, 1.2),
	(15, 8, 9, 'm', 'E_I', '', 1.04, 1.2, 1.32),
	(15, 10, 11, 'm', 'E_I', '', 1.2, 1.36, 1.48),
	(15, 12, 13, 'm', 'E_I', '', 1.36, 1.52, 1.64),
	(15, 14, 15, 'm', 'E_I', '', 1.52, 1.64, 1.8),
	(15, 16, 17, 'm', 'E_I', '', 1.64, 1.76, 1.92),
	(15, 18, 19, 'm', 'E_I', '', 1.68, 1.84, 2.0),
	(15, 20, 24, 'm', 'E_I', '', 1.68, 1.84, 2.0),
	(15, 25, 29, 'm', 'E_I', '', 1.64, 1.8, 1.96),
	(15, 30, 34, 'm', 'E_I', '', 1.48, 1.68, 1.88),
	(15, 35, 39, 'm', 'E_I', '', 1.32, 1.56, 1.8),
	(15, 40, 44, 'm', 'E_I', '', 1.24, 1.48, 1.72),
	(15, 45, 49, 'm', 'E_I', '', 1.16, 1.4, 1.64),
	(15, 50, 54, 'm', 'E_I', '', 1.12, 1.36, 1.6),
	(15, 55, 59, 'm', 'E_I', '', 1.08, 1.32, 1.56),
	(15, 60, 64, 'm', 'E_I', '', 1.04, 1.28, 1.52),
	(15, 65, 69, 'm', 'E_I', '', 1.04, 1.28, 1.52),
	(15, 70, 74, 'm', 'E_I', '', 1.0, 1.24, 1.48),
	(15, 75, 79, 'm', 'E_I', '', 0.96, 1.2, 1.44),
	(15, 80, 84, 'm', 'E_I', '', 0.92, 1.16, 1.4),
	(15, 85, 89, 'm', 'E_I', '', 0.8, 1.04, 1.28),
	(15, 90, 200, 'm', 'E_I', '', 0.72, 0.96, 1.2),
	(17, 0, 7, 'w', 'E_I', '30 m', 9.6, 8.5, 7.6),
	(17, 8, 9, 'w', 'E_I', '30 m', 8.9, 7.9, 6.8),
	(17, 10, 11, 'w', 'E_I', '50 m', 13.2, 12.1, 10.9),
	(17, 12, 13, 'w', 'E_I', '50 m', 12.7, 11.5, 10.2),
	(17, 14, 15, 'w', 'E_I', '100 m', 22.3, 20.4, 18.6),
	(17, 16, 17, 'w', 'E_I', '100 m', 21.1, 19.6, 18.0),
	(17, 18, 19, 'w', 'E_I', '100 m', 21.8, 19.8, 18.4),
	(17, 20, 24, 'w', 'E_I', '100 m', 22.2, 20.2, 18.7),
	(17, 25, 29, 'w', 'E_I', '100 m', 22.7, 20.6, 19.2),
	(17, 30, 34, 'w', 'E_I', '100 m', 23.5, 21.4, 19.7),
	(17, 35, 39, 'w', 'E_I', '100 m', 24.5, 22.3, 20.4),
	(17, 40, 44, 'w', 'E_I', '50 m', 13.2, 11.9, 10.6),
	(17, 45, 49, 'w', 'E_I', '50 m', 13.8, 12.4, 10.9),
	(17, 50, 54, 'w', 'E_I', '50 m', 14.3, 12.8, 11.4),
	(17, 55, 59, 'w', 'E_I', '50 m', 14.9, 13.4, 11.9),
	(17, 60, 64, 'w', 'E_I', '50 m', 15.1, 13.7, 12.2),
	(17, 65, 69, 'w', 'E_I', '50 m', 15.4, 13.9, 12.5),
	(17, 70, 74, 'w', 'E_I', '50 m', 15.6, 14.2, 12.7),
	(17, 75, 79, 'w', 'E_I', '50 m', 16.2, 14.8, 13.3),
	(17, 80, 84, 'w', 'E_I', '50 m', 17.2, 15.7, 14.4),
	(17, 85, 89, 'w', 'E_I', '50 m', 18.6, 17.2, 15.8),
	(17, 90, 200, 'w', 'E_I', '50 m', 20.5, 19.1, 17.8),
	(17, 0, 7, 'm', 'E_I', '30 m', 9.2, 8.2, 7.2),
	(17, 8, 9, 'm', 'E_I', '30 m', 8.6, 7.7, 6.8),
	(17, 10, 11, 'm', 'E_I', '50 m', 12.4, 11.2, 10.1),
	(17, 12, 13, 'm', 'E_I', '50 m', 11.6, 10.7, 9.7),
	(17, 14, 15, 'm', 'E_I', '100 m', 20.4, 18.5, 16.9),
	(17, 16, 17, 'm', 'E_I', '100 m', 19.6, 17.8, 16.2),
	(17, 18, 19, 'm', 'E_I', '100 m', 19.2, 17.5, 15.8),
	(17, 20, 24, 'm', 'E_I', '100 m', 19.0, 17.3, 15.6),
	(17, 25, 29, 'm', 'E_I', '100 m', 19.6, 17.8, 16.0),
	(17, 30, 34, 'm', 'E_I', '100 m', 20.2, 18.1, 16.3),
	(17, 35, 39, 'm', 'E_I', '100 m', 21.1, 19.1, 17.0),
	(17, 40, 44, 'm', 'E_I', '50 m', 11.5, 10.4, 9.2),
	(17, 45, 49, 'm', 'E_I', '50 m', 12.0, 10.7, 9.5),
	(17, 50, 54, 'm', 'E_I', '50 m', 12.4, 10.9, 9.8),
	(17, 55, 59, 'm', 'E_I', '50 m', 12.6, 11.3, 10.2),
	(17, 60, 64, 'm', 'E_I', '50 m', 13.0, 11.6, 10.6),
	(17, 65, 69, 'm', 'E_I', '50 m', 13.4, 12.2, 10.9),
	(17, 70, 74, 'm', 'E_I', '50 m', 14.0, 12.8, 11.5),
	(17, 75, 79, 'm', 'E_I', '50 m', 14.6, 13.4, 12.1),
	(17, 80, 84, 'm', 'E_I', '50 m', 15.6, 14.4, 13.1),
	(17, 85, 89, 'm', 'E_I', '50 m', 16.9, 15.7, 14.4),
	(17, 90, 200, 'm', 'E_I', '50 m', 18.6, 17.4, 16.1),
	(18, 0, 7, 'w', 'E_I', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'E_I', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'E_I', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'E_I', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'E_I', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'E_I', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'E_I', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'E_I', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'E_I', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'E_I', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'E_I', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'E_I', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'E_I', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'E_I', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'E_I', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'E_I', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'E_I', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'E_I', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'E_I', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'E_I', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'E_I', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'E_I', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'E_I', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'E_I', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'E_I', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'E_I', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'E_I', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'E_I', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'E_I', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'E_I', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'E_I', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'E_I', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'E_I', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'E_I', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'E_I', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'E_I', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'E_I', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'E_I', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'E_I', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'E_I', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'E_I', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'E_I', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'E_I', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'E_I', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'E_I', '', 49.2, 43.2, 37.2),
	(19, 10, 11, 'w', 'E_I', '', 44.4, 38.4, 32.4),
	(19, 12, 13, 'w', 'E_I', '', 37.2, 32.4, 28.2),
	(19, 14, 15, 'w', 'E_I', '', 32.4, 29.4, 25.8),
	(19, 16, 17, 'w', 'E_I', '', 30.0, 27.0, 24.0),
	(19, 18, 19, 'w', 'E_I', '', 28.8, 26.4, 23.4),
	(19, 20, 24, 'w', 'E_I', '', 29.4, 26.4, 23.4),
	(19, 25, 29, 'w', 'E_I', '', 30.0, 27.0, 24.0),
	(19, 30, 34, 'w', 'E_I', '', 31.2, 28.2, 25.8),
	(19, 35, 39, 'w', 'E_I', '', 33.0, 29.4, 26.4),
	(19, 40, 44, 'w', 'E_I', '', 34.8, 30.6, 27.0),
	(19, 45, 49, 'w', 'E_I', '', 36.6, 32.4, 27.6),
	(19, 50, 54, 'w', 'E_I', '', 38.4, 33.6, 28.2),
	(19, 55, 59, 'w', 'E_I', '', 40.2, 34.8, 28.8),
	(19, 60, 64, 'w', 'E_I', '', 42.0, 36.0, 30.0),
	(19, 65, 69, 'w', 'E_I', '', 43.2, 37.2, 30.6),
	(19, 70, 74, 'w', 'E_I', '', 45.6, 38.4, 31.8),
	(19, 75, 79, 'w', 'E_I', '', 46.8, 39.6, 33.0),
	(19, 80, 84, 'w', 'E_I', '', 48.6, 41.4, 34.2),
	(19, 85, 89, 'w', 'E_I', '', 50.4, 43.2, 36.0),
	(19, 90, 200, 'w', 'E_I', '', 53.4, 45.6, 37.8),
	(19, 8, 9, 'm', 'E_I', '', 45.6, 39.6, 33.6),
	(19, 10, 11, 'm', 'E_I', '', 42.0, 36.6, 31.2),
	(19, 12, 13, 'm', 'E_I', '', 35.4, 31.2, 27.0),
	(19, 14, 15, 'm', 'E_I', '', 28.8, 25.8, 22.8),
	(19, 16, 17, 'm', 'E_I', '', 26.4, 23.4, 20.4),
	(19, 18, 19, 'm', 'E_I', '', 24.6, 21.6, 18.6),
	(19, 20, 24, 'm', 'E_I', '', 24.0, 21.0, 18.0),
	(19, 25, 29, 'm', 'E_I', '', 25.2, 21.6, 18.0),
	(19, 30, 34, 'm', 'E_I', '', 27.0, 22.2, 18.0),
	(19, 35, 39, 'm', 'E_I', '', 28.8, 24.0, 18.6),
	(19, 40, 44, 'm', 'E_I', '', 31.8, 25.8, 19.8),
	(19, 45, 49, 'm', 'E_I', '', 34.2, 27.6, 20.4),
	(19, 50, 54, 'm', 'E_I', '', 36.0, 28.8, 21.6),
	(19, 55, 59, 'm', 'E_I', '', 38.4, 30.0, 22.2),
	(19, 60, 64, 'm', 'E_I', '', 40.2, 31.2, 22.8),
	(19, 65, 69, 'm', 'E_I', '', 42.0, 32.4, 23.4),
	(19, 70, 74, 'm', 'E_I', '', 43.2, 34.2, 24.0),
	(19, 75, 79, 'm', 'E_I', '', 45.0, 35.4, 25.8),
	(19, 80, 84, 'm', 'E_I', '', 46.8, 37.8, 27.6),
	(19, 85, 89, 'm', 'E_I', '', 49.2, 39.6, 29.4),
	(19, 90, 200, 'm', 'E_I', '', 52.2, 42.6, 32.4),
	(21, 10, 11, 'w', 'E_I', '', 0.64, 0.72, 0.8),
	(21, 12, 13, 'w', 'E_I', '', 0.72, 0.8, 0.88),
	(21, 14, 15, 'w', 'E_I', '', 0.76, 0.84, 0.92),
	(21, 16, 17, 'w', 'E_I', '', 0.84, 0.92, 1.0),
	(21, 18, 19, 'w', 'E_I', '', 0.88, 0.96, 1.04),
	(21, 20, 24, 'w', 'E_I', '', 0.88, 0.96, 1.04),
	(21, 25, 29, 'w', 'E_I', '', 0.84, 0.92, 1.0),
	(21, 30, 34, 'w', 'E_I', '', 0.8, 0.88, 0.96),
	(21, 35, 39, 'w', 'E_I', '', 0.76, 0.84, 0.92),
	(21, 40, 44, 'w', 'E_I', '', 0.72, 0.8, 0.88),
	(21, 45, 49, 'w', 'E_I', '', 0.72, 0.8, 0.88),
	(21, 50, 54, 'w', 'E_I', '', 0.68, 0.76, 0.84),
	(21, 55, 59, 'w', 'E_I', '', 0.64, 0.72, 0.8),
	(21, 60, 64, 'w', 'E_I', '', 0.6, 0.68, 0.76),
	(21, 65, 69, 'w', 'E_I', '', 0.6, 0.68, 0.76),
	(21, 70, 74, 'w', 'E_I', '', 0.56, 0.64, 0.72),
	(21, 75, 79, 'w', 'E_I', '', 0.52, 0.6, 0.68),
	(21, 80, 84, 'w', 'E_I', '', 0.52, 0.6, 0.68),
	(21, 85, 89, 'w', 'E_I', '', 0.48, 0.56, 0.64),
	(21, 90, 200, 'w', 'E_I', '', 0.44, 0.48, 0.52),
	(21, 10, 11, 'm', 'E_I', '', 0.68, 0.76, 0.84),
	(21, 12, 13, 'm', 'E_I', '', 0.76, 0.84, 0.92),
	(21, 14, 15, 'm', 'E_I', '', 0.88, 0.96, 1.04),
	(21, 16, 17, 'm', 'E_I', '', 0.96, 1.04, 1.12),
	(21, 18, 19, 'm', 'E_I', '', 1.04, 1.12, 1.2),
	(21, 20, 24, 'm', 'E_I', '', 1.08, 1.16, 1.24),
	(21, 25, 29, 'm', 'E_I', '', 1.04, 1.12, 1.2),
	(21, 30, 34, 'm', 'E_I', '', 1.04, 1.12, 1.2),
	(21, 35, 39, 'm', 'E_I', '', 1.0, 1.08, 1.16),
	(21, 40, 44, 'm', 'E_I', '', 0.96, 1.04, 1.12),
	(21, 45, 49, 'm', 'E_I', '', 0.92, 1.0, 1.08),
	(21, 50, 54, 'm', 'E_I', '', 0.84, 0.92, 1.0),
	(21, 55, 59, 'm', 'E_I', '', 0.8, 0.88, 0.96),
	(21, 60, 64, 'm', 'E_I', '', 0.76, 0.84, 0.92),
	(21, 65, 69, 'm', 'E_I', '', 0.68, 0.8, 0.88),
	(21, 70, 74, 'm', 'E_I', '', 0.64, 0.76, 0.84),
	(21, 75, 79, 'm', 'E_I', '', 0.6, 0.72, 0.8),
	(21, 80, 84, 'm', 'E_I', '', 0.6, 0.68, 0.76),
	(21, 85, 89, 'm', 'E_I', '', 0.56, 0.64, 0.72),
	(21, 90, 200, 'm', 'E_I', '', 0.52, 0.6, 0.68),
	(23, 0, 7, 'w', 'E_I', '', 1.44, 1.68, 1.92),
	(23, 8, 9, 'w', 'E_I', '', 1.64, 1.88, 2.12),
	(23, 10, 11, 'w', 'E_I', '', 1.84, 2.08, 2.32),
	(23, 12, 13, 'w', 'E_I', '', 2.24, 2.48, 2.72),
	(23, 14, 15, 'w', 'E_I', '', 2.56, 2.8, 3.04),
	(23, 16, 17, 'w', 'E_I', '', 2.72, 2.96, 3.2),
	(23, 18, 19, 'w', 'E_I', '', 2.72, 2.96, 3.2),
	(23, 20, 24, 'w', 'E_I', '', 2.72, 2.96, 3.2),
	(23, 25, 29, 'w', 'E_I', '', 2.64, 2.88, 3.12),
	(23, 30, 34, 'w', 'E_I', '', 2.56, 2.8, 3.04),
	(23, 35, 39, 'w', 'E_I', '', 2.48, 2.72, 2.96),
	(23, 40, 44, 'w', 'E_I', '', 2.4, 2.64, 2.88),
	(23, 45, 49, 'w', 'E_I', '', 2.24, 2.56, 2.8),
	(23, 50, 54, 'w', 'E_I', '', 2.08, 2.4, 2.72),
	(23, 55, 59, 'w', 'E_I', '', 2.0, 2.32, 2.64),
	(23, 60, 64, 'w', 'E_I', '', 1.92, 2.24, 2.56),
	(23, 65, 69, 'w', 'E_I', '', 1.84, 2.16, 2.48),
	(23, 70, 74, 'w', 'E_I', '', 1.68, 2.0, 2.32),
	(23, 75, 79, 'w', 'E_I', '', 1.44, 1.76, 2.08),
	(23, 80, 84, 'w', 'E_I', '', 1.28, 1.6, 1.92),
	(23, 85, 89, 'w', 'E_I', '', 1.04, 1.36, 1.68),
	(23, 90, 200, 'w', 'E_I', '', 0.88, 1.2, 1.52),
	(23, 0, 7, 'm', 'E_I', '', 1.68, 1.92, 2.16),
	(23, 8, 9, 'm', 'E_I', '', 1.88, 2.12, 2.36),
	(23, 10, 11, 'm', 'E_I', '', 2.08, 2.32, 2.56),
	(23, 12, 13, 'm', 'E_I', '', 2.56, 2.8, 3.04),
	(23, 14, 15, 'm', 'E_I', '', 3.04, 3.28, 3.52),
	(23, 16, 17, 'm', 'E_I', '', 3.44, 3.68, 3.92),
	(23, 18, 19, 'm', 'E_I', '', 3.6, 3.84, 4.08),
	(23, 20, 24, 'm', 'E_I', '', 3.52, 3.76, 4.0),
	(23, 25, 29, 'm', 'E_I', '', 3.44, 3.68, 3.92),
	(23, 30, 34, 'm', 'E_I', '', 3.36, 3.6, 3.84),
	(23, 35, 39, 'm', 'E_I', '', 3.28, 3.52, 3.76),
	(23, 40, 44, 'm', 'E_I', '', 3.12, 3.44, 3.68),
	(23, 45, 49, 'm', 'E_I', '', 2.96, 3.28, 3.6),
	(23, 50, 54, 'm', 'E_I', '', 2.88, 3.2, 3.52),
	(23, 55, 59, 'm', 'E_I', '', 2.72, 3.04, 3.36),
	(23, 60, 64, 'm', 'E_I', '', 2.56, 2.88, 3.2),
	(23, 65, 69, 'm', 'E_I', '', 2.32, 2.64, 2.96),
	(23, 70, 74, 'm', 'E_I', '', 2.16, 2.48, 2.8),
	(23, 75, 79, 'm', 'E_I', '', 1.92, 2.32, 2.64),
	(23, 80, 84, 'm', 'E_I', '', 1.68, 2.08, 2.48),
	(23, 85, 89, 'm', 'E_I', '', 1.52, 1.92, 2.32),
	(23, 90, 200, 'm', 'E_I', '', 1.28, 1.68, 2.08),
	(33, 0, 7, 'w', 'E_I', '', 6.4, 9.6, 13.6),
	(33, 8, 9, 'w', 'E_I', '', 8.0, 12.0, 16.0),
	(33, 10, 11, 'w', 'E_I', '', 12.0, 16.0, 24.0),
	(33, 12, 13, 'w', 'E_I', '', 16.0, 24.0, 32.0),
	(33, 14, 15, 'w', 'E_I', '', 24.0, 32.0, 40.0),
	(33, 16, 17, 'w', 'E_I', '', 36.0, 48.0, 60.0),
	(33, 0, 7, 'm', 'E_I', '', 8.0, 12.0, 16.0),
	(33, 8, 9, 'm', 'E_I', '', 9.6, 13.6, 18.4),
	(33, 10, 11, 'm', 'E_I', '', 13.6, 20.0, 28.0),
	(33, 12, 13, 'm', 'E_I', '', 20.0, 28.0, 36.0),
	(33, 14, 15, 'm', 'E_I', '', 28.0, 36.0, 48.0),
	(33, 16, 17, 'm', 'E_I', '', 44.0, 56.0, 72.0),
	(39, 0, 7, 'w', 'E_I', '', 128.0, 143.0, 157.0),
	(39, 8, 9, 'w', 'E_I', '', 140.0, 155.0, 171.0),
	(39, 10, 11, 'w', 'E_I', '', 151.0, 168.0, 184.0),
	(39, 12, 13, 'w', 'E_I', '', 162.0, 180.0, 198.0),
	(39, 14, 15, 'w', 'E_I', '', 173.0, 193.0, 212.0),
	(39, 16, 17, 'w', 'E_I', '', 185.0, 205.0, 226.0),
	(39, 18, 19, 'w', 'E_I', '', 275.0, 305.0, 336.0),
	(39, 20, 24, 'w', 'E_I', '', 275.0, 305.0, 336.0),
	(39, 25, 29, 'w', 'E_I', '', 275.0, 305.0, 336.0),
	(39, 30, 34, 'w', 'E_I', '', 263.0, 293.0, 322.0),
	(39, 35, 39, 'w', 'E_I', '', 263.0, 293.0, 322.0),
	(39, 40, 44, 'w', 'E_I', '', 252.0, 280.0, 308.0),
	(39, 45, 49, 'w', 'E_I', '', 241.0, 268.0, 294.0),
	(39, 50, 54, 'w', 'E_I', '', 230.0, 255.0, 281.0),
	(39, 55, 59, 'w', 'E_I', '', 218.0, 243.0, 267.0),
	(39, 60, 64, 'w', 'E_I', '', 207.0, 230.0, 253.0),
	(39, 65, 69, 'w', 'E_I', '', 196.0, 218.0, 239.0),
	(39, 70, 74, 'w', 'E_I', '', 185.0, 205.0, 226.0),
	(39, 75, 79, 'w', 'E_I', '', 173.0, 193.0, 212.0),
	(39, 80, 84, 'w', 'E_I', '', 162.0, 180.0, 198.0),
	(39, 85, 89, 'w', 'E_I', '', 151.0, 168.0, 184.0),
	(39, 90, 200, 'w', 'E_I', '', 140.0, 155.0, 171.0),
	(39, 0, 7, 'm', 'E_I', '', 187.0, 208.0, 228.0),
	(39, 8, 9, 'm', 'E_I', '', 198.0, 220.0, 242.0),
	(39, 10, 11, 'm', 'E_I', '', 209.0, 233.0, 256.0),
	(39, 12, 13, 'm', 'E_I', '', 221.0, 245.0, 270.0),
	(39, 14, 15, 'm', 'E_I', '', 232.0, 258.0, 283.0),
	(39, 16, 17, 'm', 'E_I', '', 243.0, 270.0, 297.0),
	(39, 18, 19, 'm', 'E_I', '', 333.0, 370.0, 407.0),
	(39, 20, 24, 'm', 'E_I', '', 333.0, 370.0, 407.0),
	(39, 25, 29, 'm', 'E_I', '', 333.0, 370.0, 407.0),
	(39, 30, 34, 'm', 'E_I', '', 322.0, 358.0, 393.0),
	(39, 35, 39, 'm', 'E_I', '', 322.0, 358.0, 393.0),
	(39, 40, 44, 'm', 'E_I', '', 311.0, 345.0, 380.0),
	(39, 45, 49, 'm', 'E_I', '', 299.0, 333.0, 366.0),
	(39, 50, 54, 'm', 'E_I', '', 288.0, 320.0, 352.0),
	(39, 55, 59, 'm', 'E_I', '', 277.0, 308.0, 338.0),
	(39, 60, 64, 'm', 'E_I', '', 266.0, 295.0, 325.0),
	(39, 65, 69, 'm', 'E_I', '', 254.0, 283.0, 311.0),
	(39, 70, 74, 'm', 'E_I', '', 243.0, 270.0, 297.0),
	(39, 75, 79, 'm', 'E_I', '', 232.0, 258.0, 283.0),
	(39, 80, 84, 'm', 'E_I', '', 221.0, 245.0, 270.0),
	(39, 85, 89, 'm', 'E_I', '', 209.0, 233.0, 256.0),
	(39, 90, 200, 'm', 'E_I', '', 198.0, 220.0, 242.0),
	(40, 0, 7, 'w', 'E_I', '', 288.0, 320.0, 352.0),
	(40, 8, 9, 'w', 'E_I', '', 302.0, 335.0, 369.0),
	(40, 10, 11, 'w', 'E_I', '', 315.0, 350.0, 385.0),
	(40, 12, 13, 'w', 'E_I', '', 329.0, 365.0, 402.0),
	(40, 14, 15, 'w', 'E_I', '', 342.0, 380.0, 418.0),
	(40, 16, 17, 'w', 'E_I', '', 356.0, 395.0, 435.0),
	(40, 18, 19, 'w', 'E_I', '', 446.0, 495.0, 545.0),
	(40, 20, 24, 'w', 'E_I', '', 446.0, 495.0, 545.0),
	(40, 25, 29, 'w', 'E_I', '', 446.0, 495.0, 545.0),
	(40, 30, 34, 'w', 'E_I', '', 432.0, 480.0, 528.0),
	(40, 35, 39, 'w', 'E_I', '', 432.0, 480.0, 528.0),
	(40, 40, 44, 'w', 'E_I', '', 419.0, 465.0, 512.0),
	(40, 45, 49, 'w', 'E_I', '', 405.0, 450.0, 495.0),
	(40, 50, 54, 'w', 'E_I', '', 392.0, 435.0, 479.0),
	(40, 55, 59, 'w', 'E_I', '', 378.0, 420.0, 462.0),
	(40, 60, 64, 'w', 'E_I', '', 365.0, 405.0, 446.0),
	(40, 65, 69, 'w', 'E_I', '', 351.0, 390.0, 429.0),
	(40, 70, 74, 'w', 'E_I', '', 338.0, 375.0, 413.0),
	(40, 75, 79, 'w', 'E_I', '', 324.0, 360.0, 396.0),
	(40, 80, 84, 'w', 'E_I', '', 311.0, 345.0, 380.0),
	(40, 85, 89, 'w', 'E_I', '', 297.0, 330.0, 363.0),
	(40, 90, 200, 'w', 'E_I', '', 284.0, 315.0, 347.0),
	(40, 0, 7, 'm', 'E_I', '', 356.0, 395.0, 435.0),
	(40, 8, 9, 'm', 'E_I', '', 369.0, 410.0, 451.0),
	(40, 10, 11, 'm', 'E_I', '', 383.0, 425.0, 468.0),
	(40, 12, 13, 'm', 'E_I', '', 396.0, 440.0, 484.0),
	(40, 14, 15, 'm', 'E_I', '', 410.0, 455.0, 501.0),
	(40, 16, 17, 'm', 'E_I', '', 423.0, 470.0, 517.0),
	(40, 18, 19, 'm', 'E_I', '', 513.0, 570.0, 627.0),
	(40, 20, 24, 'm', 'E_I', '', 513.0, 570.0, 627.0),
	(40, 25, 29, 'm', 'E_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'E_I', '', 500.0, 555.0, 611.0),
	(40, 35, 39, 'm', 'E_I', '', 500.0, 555.0, 611.0),
	(40, 40, 44, 'm', 'E_I', '', 486.0, 540.0, 594.0),
	(40, 45, 49, 'm', 'E_I', '', 473.0, 525.0, 578.0),
	(40, 50, 54, 'm', 'E_I', '', 459.0, 510.0, 561.0),
	(40, 55, 59, 'm', 'E_I', '', 446.0, 495.0, 545.0),
	(40, 60, 64, 'm', 'E_I', '', 432.0, 480.0, 528.0),
	(40, 65, 69, 'm', 'E_I', '', 419.0, 465.0, 512.0),
	(40, 70, 74, 'm', 'E_I', '', 405.0, 450.0, 495.0),
	(40, 75, 79, 'm', 'E_I', '', 392.0, 435.0, 479.0),
	(40, 80, 84, 'm', 'E_I', '', 378.0, 420.0, 462.0),
	(40, 85, 89, 'm', 'E_I', '', 365.0, 405.0, 446.0),
	(40, 90, 200, 'm', 'E_I', '', 351.0, 390.0, 429.0),
	(41, 0, 7, 'w', 'E_I', '', 221.0, 245.0, 270.0),
	(41, 8, 9, 'w', 'E_I', '', 234.0, 260.0, 286.0),
	(41, 10, 11, 'w', 'E_I', '', 248.0, 275.0, 303.0),
	(41, 12, 13, 'w', 'E_I', '', 261.0, 290.0, 319.0),
	(41, 14, 15, 'w', 'E_I', '', 275.0, 305.0, 336.0),
	(41, 16, 17, 'w', 'E_I', '', 288.0, 320.0, 352.0),
	(41, 18, 19, 'w', 'E_I', '', 378.0, 420.0, 462.0),
	(41, 20, 24, 'w', 'E_I', '', 378.0, 420.0, 462.0),
	(41, 25, 29, 'w', 'E_I', '', 378.0, 420.0, 462.0),
	(41, 30, 34, 'w', 'E_I', '', 365.0, 405.0, 446.0),
	(41, 35, 39, 'w', 'E_I', '', 365.0, 405.0, 446.0),
	(41, 40, 44, 'w', 'E_I', '', 351.0, 390.0, 429.0),
	(41, 45, 49, 'w', 'E_I', '', 338.0, 375.0, 413.0),
	(41, 50, 54, 'w', 'E_I', '', 324.0, 360.0, 396.0),
	(41, 55, 59, 'w', 'E_I', '', 311.0, 345.0, 380.0),
	(41, 60, 64, 'w', 'E_I', '', 297.0, 330.0, 363.0),
	(41, 65, 69, 'w', 'E_I', '', 284.0, 315.0, 347.0),
	(41, 70, 74, 'w', 'E_I', '', 270.0, 300.0, 330.0),
	(41, 75, 79, 'w', 'E_I', '', 257.0, 285.0, 314.0),
	(41, 80, 84, 'w', 'E_I', '', 243.0, 270.0, 297.0),
	(41, 85, 89, 'w', 'E_I', '', 230.0, 255.0, 281.0),
	(41, 90, 200, 'w', 'E_I', '', 216.0, 240.0, 264.0),
	(41, 0, 7, 'm', 'E_I', '', 284.0, 315.0, 347.0),
	(41, 8, 9, 'm', 'E_I', '', 297.0, 330.0, 363.0),
	(41, 10, 11, 'm', 'E_I', '', 311.0, 345.0, 380.0),
	(41, 12, 13, 'm', 'E_I', '', 324.0, 360.0, 396.0),
	(41, 14, 15, 'm', 'E_I', '', 338.0, 375.0, 413.0),
	(41, 16, 17, 'm', 'E_I', '', 351.0, 390.0, 429.0),
	(41, 18, 19, 'm', 'E_I', '', 441.0, 490.0, 539.0),
	(41, 20, 24, 'm', 'E_I', '', 441.0, 490.0, 539.0),
	(41, 25, 29, 'm', 'E_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'E_I', '', 428.0, 475.0, 523.0),
	(41, 35, 39, 'm', 'E_I', '', 428.0, 475.0, 523.0),
	(41, 40, 44, 'm', 'E_I', '', 414.0, 460.0, 506.0),
	(41, 45, 49, 'm', 'E_I', '', 401.0, 445.0, 490.0),
	(41, 50, 54, 'm', 'E_I', '', 387.0, 430.0, 473.0),
	(41, 55, 59, 'm', 'E_I', '', 374.0, 415.0, 457.0),
	(41, 60, 64, 'm', 'E_I', '', 360.0, 400.0, 440.0),
	(41, 65, 69, 'm', 'E_I', '', 347.0, 385.0, 424.0),
	(41, 70, 74, 'm', 'E_I', '', 333.0, 370.0, 407.0),
	(41, 75, 79, 'm', 'E_I', '', 320.0, 355.0, 391.0),
	(41, 80, 84, 'm', 'E_I', '', 306.0, 340.0, 374.0),
	(41, 85, 89, 'm', 'E_I', '', 293.0, 325.0, 358.0),
	(41, 90, 200, 'm', 'E_I', '', 279.0, 310.0, 341.0),
	(42, 0, 7, 'w', 'E_I', '', 225.0, 250.0, 275.0),
	(42, 8, 9, 'w', 'E_I', '', 239.0, 265.0, 292.0),
	(42, 10, 11, 'w', 'E_I', '', 252.0, 280.0, 308.0),
	(42, 12, 13, 'w', 'E_I', '', 266.0, 295.0, 325.0),
	(42, 14, 15, 'w', 'E_I', '', 279.0, 310.0, 341.0),
	(42, 16, 17, 'w', 'E_I', '', 293.0, 325.0, 358.0),
	(42, 18, 19, 'w', 'E_I', '', 383.0, 425.0, 468.0),
	(42, 20, 24, 'w', 'E_I', '', 383.0, 425.0, 468.0),
	(42, 25, 29, 'w', 'E_I', '', 383.0, 425.0, 468.0),
	(42, 30, 34, 'w', 'E_I', '', 369.0, 410.0, 451.0),
	(42, 35, 39, 'w', 'E_I', '', 369.0, 410.0, 451.0),
	(42, 40, 44, 'w', 'E_I', '', 356.0, 395.0, 435.0),
	(42, 45, 49, 'w', 'E_I', '', 342.0, 380.0, 418.0),
	(42, 50, 54, 'w', 'E_I', '', 329.0, 365.0, 402.0),
	(42, 55, 59, 'w', 'E_I', '', 315.0, 350.0, 385.0),
	(42, 60, 64, 'w', 'E_I', '', 302.0, 335.0, 369.0),
	(42, 65, 69, 'w', 'E_I', '', 288.0, 320.0, 352.0),
	(42, 70, 74, 'w', 'E_I', '', 275.0, 305.0, 336.0),
	(42, 75, 79, 'w', 'E_I', '', 261.0, 290.0, 319.0),
	(42, 80, 84, 'w', 'E_I', '', 248.0, 275.0, 303.0),
	(42, 85, 89, 'w', 'E_I', '', 234.0, 260.0, 286.0),
	(42, 90, 200, 'w', 'E_I', '', 221.0, 245.0, 270.0),
	(42, 0, 7, 'm', 'E_I', '', 288.0, 320.0, 352.0),
	(42, 8, 9, 'm', 'E_I', '', 302.0, 335.0, 369.0),
	(42, 10, 11, 'm', 'E_I', '', 315.0, 350.0, 385.0),
	(42, 12, 13, 'm', 'E_I', '', 329.0, 365.0, 402.0),
	(42, 14, 15, 'm', 'E_I', '', 342.0, 380.0, 418.0),
	(42, 16, 17, 'm', 'E_I', '', 356.0, 395.0, 435.0),
	(42, 18, 19, 'm', 'E_I', '', 446.0, 495.0, 545.0),
	(42, 20, 24, 'm', 'E_I', '', 446.0, 495.0, 545.0),
	(42, 25, 29, 'm', 'E_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'E_I', '', 432.0, 480.0, 528.0),
	(42, 35, 39, 'm', 'E_I', '', 432.0, 480.0, 528.0),
	(42, 40, 44, 'm', 'E_I', '', 419.0, 465.0, 512.0),
	(42, 45, 49, 'm', 'E_I', '', 405.0, 450.0, 495.0),
	(42, 50, 54, 'm', 'E_I', '', 392.0, 435.0, 479.0),
	(42, 55, 59, 'm', 'E_I', '', 378.0, 420.0, 462.0),
	(42, 60, 64, 'm', 'E_I', '', 365.0, 405.0, 446.0),
	(42, 65, 69, 'm', 'E_I', '', 351.0, 390.0, 429.0),
	(42, 70, 74, 'm', 'E_I', '', 338.0, 375.0, 413.0),
	(42, 75, 79, 'm', 'E_I', '', 324.0, 360.0, 396.0),
	(42, 80, 84, 'm', 'E_I', '', 311.0, 345.0, 380.0),
	(42, 85, 89, 'm', 'E_I', '', 297.0, 330.0, 363.0),
	(42, 90, 200, 'm', 'E_I', '', 284.0, 315.0, 347.0),
	(45, 0, 7, 'w', 'E_I', '', 12.0, 15.0, 18.0),
	(45, 8, 9, 'w', 'E_I', '', 13.5, 16.5, 19.5),
	(45, 10, 11, 'w', 'E_I', '', 15.0, 18.0, 21.0),
	(45, 12, 13, 'w', 'E_I', '', 16.5, 19.5, 22.5),
	(45, 14, 15, 'w', 'E_I', '', 18.0, 21.0, 24.0),
	(45, 16, 17, 'w', 'E_I', '', 19.5, 22.5, 25.5),
	(45, 18, 19, 'w', 'E_I', '', 21.0, 24.0, 27.0),
	(45, 20, 24, 'w', 'E_I', '', 20.0, 23.0, 26.0),
	(45, 25, 29, 'w', 'E_I', '', 19.0, 22.0, 25.0),
	(45, 30, 34, 'w', 'E_I', '', 18.0, 21.0, 24.0),
	(45, 35, 39, 'w', 'E_I', '', 17.0, 20.0, 23.0),
	(45, 40, 44, 'w', 'E_I', '', 16.0, 19.0, 22.0),
	(45, 45, 49, 'w', 'E_I', '', 15.0, 18.0, 21.0),
	(45, 50, 54, 'w', 'E_I', '', 14.0, 17.0, 20.0),
	(45, 55, 59, 'w', 'E_I', '', 13.0, 16.0, 19.0),
	(45, 60, 64, 'w', 'E_I', '', 12.0, 15.0, 18.0),
	(45, 65, 69, 'w', 'E_I', '', 11.0, 14.0, 17.0),
	(45, 70, 74, 'w', 'E_I', '', 10.0, 13.0, 16.0),
	(45, 75, 79, 'w', 'E_I', '', 9.0, 12.0, 15.0),
	(45, 80, 84, 'w', 'E_I', '', 8.0, 11.0, 14.0),
	(45, 85, 89, 'w', 'E_I', '', 7.0, 10.0, 13.0),
	(45, 90, 200, 'w', 'E_I', '', 6.0, 9.0, 12.0),
	(45, 0, 7, 'm', 'E_I', '', 16.5, 19.5, 22.5),
	(45, 8, 9, 'm', 'E_I', '', 18.0, 21.0, 24.0),
	(45, 10, 11, 'm', 'E_I', '', 19.5, 22.5, 25.5),
	(45, 12, 13, 'm', 'E_I', '', 21.0, 24.0, 27.0),
	(45, 14, 15, 'm', 'E_I', '', 22.5, 25.5, 28.5),
	(45, 16, 17, 'm', 'E_I', '', 24.0, 27.0, 30.0),
	(45, 18, 19, 'm', 'E_I', '', 25.5, 28.5, 31.5),
	(45, 20, 24, 'm', 'E_I', '', 24.5, 27.5, 30.5),
	(45, 25, 29, 'm', 'E_I', '', 23.5, 26.5, 29.5),
	(45, 30, 34, 'm', 'E_I', '', 22.5, 25.5, 28.5),
	(45, 35, 39, 'm', 'E_I', '', 21.5, 24.5, 27.5),
	(45, 40, 44, 'm', 'E_I', '', 20.5, 23.5, 26.5),
	(45, 45, 49, 'm', 'E_I', '', 19.5, 22.5, 25.5),
	(45, 50, 54, 'm', 'E_I', '', 18.5, 21.5, 24.5),
	(45, 55, 59, 'm', 'E_I', '', 17.5, 20.5, 23.5),
	(45, 60, 64, 'm', 'E_I', '', 16.5, 19.5, 22.5),
	(45, 65, 69, 'm', 'E_I', '', 15.5, 18.5, 21.5),
	(45, 70, 74, 'm', 'E_I', '', 14.5, 17.5, 20.5),
	(45, 75, 79, 'm', 'E_I', '', 13.5, 16.5, 19.5),
	(45, 80, 84, 'm', 'E_I', '', 12.5, 15.5, 18.5),
	(45, 85, 89, 'm', 'E_I', '', 11.5, 14.5, 17.5),
	(45, 90, 200, 'm', 'E_I', '', 10.5, 13.5, 16.5),
	(54, 0, 7, 'w', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 8, 9, 'w', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 10, 11, 'w', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 12, 13, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 14, 15, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 16, 17, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 18, 19, 'w', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 20, 24, 'w', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 25, 29, 'w', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 30, 34, 'w', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 35, 39, 'w', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 40, 44, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 45, 49, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 50, 54, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 55, 59, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 60, 64, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 65, 69, 'w', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 70, 74, 'w', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 75, 79, 'w', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 80, 84, 'w', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 85, 89, 'w', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 90, 200, 'w', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 0, 7, 'm', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 8, 9, 'm', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 10, 11, 'm', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 12, 13, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 14, 15, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 16, 17, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 18, 19, 'm', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 20, 24, 'm', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 25, 29, 'm', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 30, 34, 'm', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 35, 39, 'm', 'E_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 40, 44, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 45, 49, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 50, 54, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 55, 59, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 60, 64, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 65, 69, 'm', 'E_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 70, 74, 'm', 'E_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 75, 79, 'm', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 80, 84, 'm', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 85, 89, 'm', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 90, 200, 'm', 'E_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'E_II', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'w', 'E_II', '', 7.250000000000001, 6.283333333333333, 5.416666666666667),
	(1, 10, 11, 'w', 'E_II', '', 6.933333333333333, 6.066666666666666, 5.2),
	(1, 12, 13, 'w', 'E_II', '', 6.716666666666666, 5.75, 4.883333333333334),
	(1, 14, 15, 'w', 'E_II', '', 6.5, 5.633333333333333, 4.666666666666667),
	(1, 16, 17, 'w', 'E_II', '', 6.283333333333333, 5.3, 4.449999999999999),
	(1, 0, 7, 'm', 'E_II', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'm', 'E_II', '', 7.033333333333332, 6.066666666666666, 5.1),
	(1, 10, 11, 'm', 'E_II', '', 6.6000000000000005, 5.633333333333333, 4.666666666666667),
	(1, 12, 13, 'm', 'E_II', '', 6.166666666666666, 5.2, 4.2333333333333325),
	(1, 14, 15, 'm', 'E_II', '', 5.633333333333333, 4.766666666666667, 3.9000000000000004),
	(1, 16, 17, 'm', 'E_II', '', 5.3, 4.449999999999999, 3.5833333333333335),
	(4, 8, 9, 'w', 'E_II', '5 km', 35.1, 31.200000000000003, 27.3),
	(4, 10, 11, 'w', 'E_II', '10 km', 65.65, 55.9, 46.150000000000006),
	(4, 12, 13, 'w', 'E_II', '10 km', 58.49999999999999, 51.35, 43.55),
	(4, 14, 15, 'w', 'E_II', '10 km', 49.400000000000006, 42.25, 37.050000000000004),
	(4, 16, 17, 'w', 'E_II', '10 km', 42.25, 37.050000000000004, 32.49999999999999),
	(4, 18, 19, 'w', 'E_II', '20 km', 74.75, 67.6, 60.45),
	(4, 20, 24, 'w', 'E_II', '20 km', 74.10000000000001, 66.94999999999999, 59.150000000000006),
	(4, 25, 29, 'w', 'E_II', '20 km', 72.80000000000001, 65.65, 58.49999999999999),
	(4, 30, 34, 'w', 'E_II', '20 km', 74.10000000000001, 66.94999999999999, 59.150000000000006),
	(4, 35, 39, 'w', 'E_II', '20 km', 78.0, 68.9, 61.1),
	(4, 40, 44, 'w', 'E_II', '20 km', 83.2, 72.15, 64.35),
	(4, 45, 49, 'w', 'E_II', '20 km', 87.10000000000001, 76.05, 66.94999999999999),
	(4, 50, 54, 'w', 'E_II', '20 km', 89.7, 79.30000000000001, 69.55),
	(4, 55, 59, 'w', 'E_II', '20 km', 92.94999999999999, 81.9, 72.15),
	(4, 60, 64, 'w', 'E_II', '20 km', 96.2, 84.5, 74.10000000000001),
	(4, 65, 69, 'w', 'E_II', '20 km', 98.15, 86.44999999999999, 76.05),
	(4, 70, 74, 'w', 'E_II', '20 km', 101.39999999999999, 89.05, 78.65),
	(4, 75, 79, 'w', 'E_II', '20 km', 105.94999999999999, 91.65, 81.9),
	(4, 80, 84, 'w', 'E_II', '20 km', 109.85000000000001, 97.5, 85.15),
	(4, 85, 89, 'w', 'E_II', '20 km', 116.35, 104.0, 89.7),
	(4, 90, 200, 'w', 'E_II', '20 km', 120.9, 107.9, 94.25000000000001),
	(4, 8, 9, 'm', 'E_II', '5 km', 34.45, 30.549999999999997, 26.650000000000002),
	(4, 10, 11, 'm', 'E_II', '10 km', 63.050000000000004, 53.3, 43.55),
	(4, 12, 13, 'm', 'E_II', '10 km', 55.9, 48.1, 40.95),
	(4, 14, 15, 'm', 'E_II', '10 km', 41.6, 36.400000000000006, 31.200000000000003),
	(4, 16, 17, 'm', 'E_II', '10 km', 35.1, 30.549999999999997, 26.650000000000002),
	(4, 18, 19, 'm', 'E_II', '20 km', 61.1, 55.25, 50.050000000000004),
	(4, 20, 24, 'm', 'E_II', '20 km', 60.45, 54.6, 48.75000000000001),
	(4, 25, 29, 'm', 'E_II', '20 km', 65.0, 57.849999999999994, 50.7),
	(4, 30, 34, 'm', 'E_II', '20 km', 69.55, 61.1, 52.65),
	(4, 35, 39, 'm', 'E_II', '20 km', 75.39999999999999, 65.0, 53.95),
	(4, 40, 44, 'm', 'E_II', '20 km', 81.9, 67.6, 56.55),
	(4, 45, 49, 'm', 'E_II', '20 km', 85.80000000000001, 71.5, 58.49999999999999),
	(4, 50, 54, 'm', 'E_II', '20 km', 89.05, 74.10000000000001, 60.45),
	(4, 55, 59, 'm', 'E_II', '20 km', 91.65, 76.05, 61.75000000000001),
	(4, 60, 64, 'm', 'E_II', '20 km', 92.94999999999999, 78.0, 62.400000000000006),
	(4, 65, 69, 'm', 'E_II', '20 km', 94.25000000000001, 78.65, 63.050000000000004),
	(4, 70, 74, 'm', 'E_II', '20 km', 95.55, 79.94999999999999, 64.35),
	(4, 75, 79, 'm', 'E_II', '20 km', 96.85000000000001, 81.9, 66.94999999999999),
	(4, 80, 84, 'm', 'E_II', '20 km', 98.80000000000001, 83.85000000000001, 68.9),
	(4, 85, 89, 'm', 'E_II', '20 km', 100.75, 86.44999999999999, 72.15),
	(4, 90, 200, 'm', 'E_II', '20 km', 102.7, 88.39999999999999, 75.39999999999999),
	(5, 18, 19, 'w', 'E_II', '', 27.083333333333336, 24.48333333333333, 21.883333333333336),
	(5, 20, 24, 'w', 'E_II', '', 26.433333333333337, 23.833333333333332, 21.233333333333334),
	(5, 25, 29, 'w', 'E_II', '', 26.866666666666667, 24.266666666666666, 21.666666666666664),
	(5, 30, 34, 'w', 'E_II', '', 27.95, 25.35, 22.75),
	(5, 35, 39, 'w', 'E_II', '', 28.599999999999998, 26.0, 23.4),
	(5, 40, 44, 'w', 'E_II', '', 29.683333333333334, 26.866666666666667, 24.05),
	(5, 45, 49, 'w', 'E_II', '', 30.983333333333334, 27.95, 24.48333333333333),
	(5, 50, 54, 'w', 'E_II', '', 32.28333333333334, 28.816666666666663, 24.916666666666668),
	(5, 55, 59, 'w', 'E_II', '', 33.583333333333336, 29.683333333333334, 25.78333333333333),
	(5, 60, 64, 'w', 'E_II', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 65, 69, 'w', 'E_II', '', 35.31666666666666, 31.416666666666668, 27.516666666666666),
	(5, 70, 74, 'w', 'E_II', '', 35.96666666666666, 32.06666666666666, 28.166666666666668),
	(5, 75, 79, 'w', 'E_II', '', 37.050000000000004, 33.150000000000006, 29.249999999999996),
	(5, 80, 84, 'w', 'E_II', '', 38.56666666666667, 34.666666666666664, 30.76666666666667),
	(5, 85, 89, 'w', 'E_II', '', 40.3, 36.400000000000006, 32.49999999999999),
	(5, 90, 200, 'w', 'E_II', '', 42.25, 38.35, 34.45),
	(5, 18, 19, 'm', 'E_II', '', 23.183333333333334, 20.583333333333336, 17.983333333333334),
	(5, 20, 24, 'm', 'E_II', '', 22.533333333333335, 19.93333333333333, 17.333333333333332),
	(5, 25, 29, 'm', 'E_II', '', 22.966666666666665, 20.366666666666664, 17.76666666666667),
	(5, 30, 34, 'm', 'E_II', '', 24.05, 21.45, 18.85),
	(5, 35, 39, 'm', 'E_II', '', 25.78333333333333, 22.533333333333335, 19.5),
	(5, 40, 44, 'm', 'E_II', '', 27.3, 24.05, 20.583333333333336),
	(5, 45, 49, 'm', 'E_II', '', 28.816666666666663, 25.35, 21.45),
	(5, 50, 54, 'm', 'E_II', '', 30.333333333333332, 26.433333333333337, 22.533333333333335),
	(5, 55, 59, 'm', 'E_II', '', 30.983333333333334, 27.083333333333336, 23.183333333333334),
	(5, 60, 64, 'm', 'E_II', '', 31.85, 27.95, 24.05),
	(5, 65, 69, 'm', 'E_II', '', 32.49999999999999, 28.599999999999998, 24.700000000000003),
	(5, 70, 74, 'm', 'E_II', '', 32.93333333333334, 29.03333333333333, 25.13333333333333),
	(5, 75, 79, 'm', 'E_II', '', 33.8, 29.9, 26.0),
	(5, 80, 84, 'm', 'E_II', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 85, 89, 'm', 'E_II', '', 35.75000000000001, 31.85, 27.95),
	(5, 90, 200, 'm', 'E_II', '', 38.78333333333333, 34.88333333333333, 30.983333333333334),
	(6, 18, 19, 'w', 'E_II', '', 110.06666666666668, 102.26666666666667, 94.46666666666667),
	(6, 20, 24, 'w', 'E_II', '', 108.55, 99.88333333333334, 92.94999999999999),
	(6, 25, 29, 'w', 'E_II', '', 108.55, 99.88333333333334, 92.30000000000001),
	(6, 30, 34, 'w', 'E_II', '', 109.41666666666667, 101.39999999999999, 92.73333333333333),
	(6, 35, 39, 'w', 'E_II', '', 113.96666666666667, 103.35, 92.94999999999999),
	(6, 40, 44, 'w', 'E_II', '', 118.73333333333333, 105.73333333333333, 93.16666666666666),
	(6, 45, 49, 'w', 'E_II', '', 123.93333333333334, 108.11666666666666, 94.68333333333332),
	(6, 50, 54, 'w', 'E_II', '', 126.96666666666667, 111.15, 96.2),
	(6, 55, 59, 'w', 'E_II', '', 130.21666666666667, 114.61666666666667, 99.01666666666668),
	(6, 60, 64, 'w', 'E_II', '', 133.68333333333334, 118.08333333333333, 102.48333333333335),
	(6, 65, 69, 'w', 'E_II', '', 137.36666666666667, 121.76666666666665, 106.16666666666666),
	(6, 70, 74, 'w', 'E_II', '', 142.35000000000002, 126.75, 111.15),
	(6, 75, 79, 'w', 'E_II', '', 149.93333333333334, 134.33333333333331, 118.73333333333333),
	(6, 80, 84, 'w', 'E_II', '', 159.03333333333336, 143.4333333333333, 127.83333333333333),
	(6, 85, 89, 'w', 'E_II', '', 167.91666666666669, 152.31666666666666, 136.71666666666667),
	(6, 90, 200, 'w', 'E_II', '', 177.45000000000002, 161.85, 146.25),
	(6, 18, 19, 'm', 'E_II', '', 82.33333333333334, 74.53333333333332, 66.73333333333333),
	(6, 20, 24, 'm', 'E_II', '', 81.25000000000001, 73.44999999999999, 65.0),
	(6, 25, 29, 'm', 'E_II', '', 85.80000000000001, 77.13333333333333, 67.6),
	(6, 30, 34, 'm', 'E_II', '', 90.56666666666668, 79.51666666666667, 71.28333333333333),
	(6, 35, 39, 'm', 'E_II', '', 96.41666666666667, 85.15, 73.88333333333334),
	(6, 40, 44, 'm', 'E_II', '', 102.48333333333335, 90.35, 78.21666666666665),
	(6, 45, 49, 'm', 'E_II', '', 108.76666666666665, 95.11666666666666, 82.55),
	(6, 50, 54, 'm', 'E_II', '', 114.83333333333333, 99.66666666666667, 85.15),
	(6, 55, 59, 'm', 'E_II', '', 118.94999999999999, 103.56666666666668, 87.96666666666667),
	(6, 60, 64, 'm', 'E_II', '', 123.06666666666668, 107.46666666666667, 91.86666666666666),
	(6, 65, 69, 'm', 'E_II', '', 127.39999999999999, 111.80000000000001, 96.2),
	(6, 70, 74, 'm', 'E_II', '', 132.8166666666667, 117.21666666666665, 101.61666666666667),
	(6, 75, 79, 'm', 'E_II', '', 139.53333333333333, 123.93333333333334, 108.33333333333334),
	(6, 80, 84, 'm', 'E_II', '', 147.11666666666665, 131.51666666666668, 115.91666666666666),
	(6, 85, 89, 'm', 'E_II', '', 156.21666666666667, 140.61666666666667, 125.01666666666668),
	(6, 90, 200, 'm', 'E_II', '', 165.9666666666667, 150.36666666666667, 134.76666666666668),
	(7, 0, 7, 'w', 'E_II', '200 m', 11.7, 9.966666666666667, 8.233333333333334),
	(7, 8, 9, 'w', 'E_II', '200 m', 10.4, 9.100000000000001, 7.7),
	(7, 10, 11, 'w', 'E_II', '200 m', 9.533333333333333, 8.333333333333332, 7.1499999999999995),
	(7, 12, 13, 'w', 'E_II', '400 m', 19.283333333333335, 16.8, 14.299999999999999),
	(7, 14, 15, 'w', 'E_II', '400 m', 17.01666666666667, 15.166666666666666, 13.0),
	(7, 16, 17, 'w', 'E_II', '400 m', 15.383333333333335, 13.65, 11.8),
	(7, 18, 19, 'w', 'E_II', '800 m', 31.200000000000003, 27.516666666666666, 23.93333333333333),
	(7, 20, 24, 'w', 'E_II', '800 m', 30.650000000000002, 27.083333333333336, 23.4),
	(7, 25, 29, 'w', 'E_II', '800 m', 33.150000000000006, 27.416666666666668, 24.266666666666666),
	(7, 30, 34, 'w', 'E_II', '800 m', 37.483333333333334, 30.76666666666667, 25.35),
	(7, 35, 39, 'w', 'E_II', '800 m', 41.6, 33.26666666666666, 26.433333333333337),
	(7, 40, 44, 'w', 'E_II', '800 m', 44.199999999999996, 35.96666666666666, 27.733333333333334),
	(7, 45, 49, 'w', 'E_II', '800 m', 45.93333333333334, 37.7, 27.95),
	(7, 50, 54, 'w', 'E_II', '400 m', 23.4, 19.5, 14.950000000000001),
	(7, 55, 59, 'w', 'E_II', '400 m', 24.15, 19.93333333333333, 15.483333333333333),
	(7, 60, 64, 'w', 'E_II', '400 m', 24.700000000000003, 20.266666666666666, 15.816666666666666),
	(7, 65, 69, 'w', 'E_II', '400 m', 25.249999999999996, 20.48333333333333, 15.933333333333334),
	(7, 70, 74, 'w', 'E_II', '400 m', 25.78333333333333, 20.9, 16.46666666666667),
	(7, 75, 79, 'w', 'E_II', '200 m', 13.316666666666666, 10.833333333333334, 8.45),
	(7, 80, 84, 'w', 'E_II', '200 m', 13.55, 11.049999999999999, 8.783333333333335),
	(7, 85, 89, 'w', 'E_II', '200 m', 13.766666666666667, 11.366666666666667, 9.216666666666669),
	(7, 90, 200, 'w', 'E_II', '200 m', 13.983333333333333, 11.583333333333332, 9.533333333333333),
	(7, 0, 7, 'm', 'E_II', '200 m', 11.7, 9.533333333333333, 8.016666666666666),
	(7, 8, 9, 'm', 'E_II', '200 m', 10.4, 8.783333333333335, 7.366666666666666),
	(7, 10, 11, 'm', 'E_II', '200 m', 9.100000000000001, 8.233333333333334, 6.716666666666666),
	(7, 12, 13, 'm', 'E_II', '400 m', 17.549999999999997, 14.950000000000001, 12.683333333333334),
	(7, 14, 15, 'm', 'E_II', '400 m', 15.6, 13.316666666666666, 11.483333333333333),
	(7, 16, 17, 'm', 'E_II', '400 m', 14.299999999999999, 12.566666666666666, 10.833333333333334),
	(7, 18, 19, 'm', 'E_II', '800 m', 29.366666666666664, 25.78333333333333, 22.099999999999998),
	(7, 20, 24, 'm', 'E_II', '800 m', 28.816666666666663, 25.35, 21.35),
	(7, 25, 29, 'm', 'E_II', '800 m', 30.116666666666667, 26.0, 22.099999999999998),
	(7, 30, 34, 'm', 'E_II', '800 m', 33.483333333333334, 27.95, 23.4),
	(7, 35, 39, 'm', 'E_II', '800 m', 37.483333333333334, 31.200000000000003, 25.03333333333333),
	(7, 40, 44, 'm', 'E_II', '800 m', 42.13333333333333, 34.35, 26.549999999999997),
	(7, 45, 49, 'm', 'E_II', '800 m', 44.849999999999994, 36.18333333333333, 26.866666666666667),
	(7, 50, 54, 'm', 'E_II', '400 m', 22.650000000000002, 18.633333333333333, 13.983333333333333),
	(7, 55, 59, 'm', 'E_II', '400 m', 23.183333333333334, 18.966666666666665, 14.733333333333333),
	(7, 60, 64, 'm', 'E_II', '400 m', 23.616666666666667, 19.183333333333334, 14.833333333333334),
	(7, 65, 69, 'm', 'E_II', '400 m', 23.93333333333333, 19.616666666666667, 14.950000000000001),
	(7, 70, 74, 'm', 'E_II', '400 m', 23.93333333333333, 19.816666666666663, 15.049999999999999),
	(7, 75, 79, 'm', 'E_II', '200 m', 12.25, 9.966666666666667, 7.916666666666666),
	(7, 80, 84, 'm', 'E_II', '200 m', 12.350000000000001, 10.183333333333332, 8.016666666666666),
	(7, 85, 89, 'm', 'E_II', '200 m', 12.350000000000001, 10.4, 8.333333333333332),
	(7, 90, 200, 'm', 'E_II', '200 m', 12.683333333333334, 10.616666666666665, 8.783333333333335),
	(8, 18, 19, 'w', 'E_II', '7,5 km', 79.91666666666666, 75.9, 71.30000000000001),
	(8, 20, 24, 'w', 'E_II', '7,5 km', 76.46666666666667, 72.44999999999999, 68.43333333333334),
	(8, 25, 29, 'w', 'E_II', '7,5 km', 77.05, 73.01666666666668, 69.0),
	(8, 30, 34, 'w', 'E_II', '7,5 km', 77.61666666666667, 73.6, 69.48333333333335),
	(8, 35, 39, 'w', 'E_II', '7,5 km', 80.5, 74.75, 69.86666666666666),
	(8, 40, 44, 'w', 'E_II', '7,5 km', 83.94999999999999, 77.05, 70.15),
	(8, 45, 49, 'w', 'E_II', '7,5 km', 86.81666666666666, 79.35, 71.30000000000001),
	(8, 50, 54, 'w', 'E_II', '7,5 km', 89.7, 81.65, 73.6),
	(8, 55, 59, 'w', 'E_II', '7,5 km', 92.0, 83.94999999999999, 75.9),
	(8, 60, 64, 'w', 'E_II', '7,5 km', 94.86666666666666, 85.68333333333332, 77.61666666666667),
	(8, 65, 69, 'w', 'E_II', '7,5 km', 96.88333333333334, 87.98333333333333, 80.5),
	(8, 70, 74, 'w', 'E_II', '7,5 km', 101.48333333333335, 90.85000000000001, 82.80000000000001),
	(8, 75, 79, 'w', 'E_II', '7,5 km', 106.38333333333334, 93.73333333333333, 85.68333333333332),
	(8, 80, 84, 'w', 'E_II', '7,5 km', 113.26666666666667, 98.03333333333333, 89.13333333333333),
	(8, 85, 89, 'w', 'E_II', '7,5 km', 119.6, 103.88333333333334, 94.30000000000001),
	(8, 90, 200, 'w', 'E_II', '7,5 km', 126.88333333333334, 110.39999999999999, 100.05),
	(8, 18, 19, 'm', 'E_II', '7,5 km', 67.26666666666667, 62.666666666666664, 58.08333333333333),
	(8, 20, 24, 'm', 'E_II', '7,5 km', 65.55, 60.95, 56.35),
	(8, 25, 29, 'm', 'E_II', '7,5 km', 67.26666666666667, 62.666666666666664, 58.08333333333333),
	(8, 30, 34, 'm', 'E_II', '7,5 km', 71.88333333333334, 65.55, 58.65),
	(8, 35, 39, 'm', 'E_II', '7,5 km', 74.75, 67.26666666666667, 61.51666666666667),
	(8, 40, 44, 'm', 'E_II', '7,5 km', 75.9, 69.56666666666668, 62.1),
	(8, 45, 49, 'm', 'E_II', '7,5 km', 78.78333333333333, 71.88333333333334, 63.25),
	(8, 50, 54, 'm', 'E_II', '7,5 km', 81.65, 73.6, 66.13333333333333),
	(8, 55, 59, 'm', 'E_II', '7,5 km', 83.94999999999999, 74.75, 67.85000000000001),
	(8, 60, 64, 'm', 'E_II', '7,5 km', 87.11666666666666, 77.61666666666667, 69.56666666666668),
	(8, 65, 69, 'm', 'E_II', '7,5 km', 89.9, 79.91666666666666, 71.30000000000001),
	(8, 70, 74, 'm', 'E_II', '7,5 km', 93.73333333333333, 82.80000000000001, 74.75),
	(8, 75, 79, 'm', 'E_II', '7,5 km', 99.08333333333333, 87.11666666666666, 82.80000000000001),
	(8, 80, 84, 'm', 'E_II', '7,5 km', 105.21666666666665, 91.71666666666668, 82.80000000000001),
	(8, 85, 89, 'm', 'E_II', '7,5 km', 110.39999999999999, 96.88333333333334, 86.81666666666666),
	(8, 90, 200, 'm', 'E_II', '7,5 km', 118.16666666666666, 102.73333333333333, 92.0),
	(15, 0, 7, 'w', 'E_II', '', 0.74, 0.88, 0.98),
	(15, 8, 9, 'w', 'E_II', '', 0.81, 0.91, 1.05),
	(15, 10, 11, 'w', 'E_II', '', 0.91, 1.02, 1.16),
	(15, 12, 13, 'w', 'E_II', '', 0.98, 1.12, 1.26),
	(15, 14, 15, 'w', 'E_II', '', 1.09, 1.19, 1.33),
	(15, 16, 17, 'w', 'E_II', '', 1.16, 1.26, 1.4),
	(15, 18, 19, 'w', 'E_II', '', 1.16, 1.3, 1.44),
	(15, 20, 24, 'w', 'E_II', '', 1.12, 1.26, 1.4),
	(15, 25, 29, 'w', 'E_II', '', 1.05, 1.19, 1.37),
	(15, 30, 34, 'w', 'E_II', '', 0.95, 1.12, 1.3),
	(15, 35, 39, 'w', 'E_II', '', 0.88, 1.05, 1.26),
	(15, 40, 44, 'w', 'E_II', '', 0.81, 0.98, 1.16),
	(15, 45, 49, 'w', 'E_II', '', 0.77, 0.95, 1.12),
	(15, 50, 54, 'w', 'E_II', '', 0.7, 0.91, 1.09),
	(15, 55, 59, 'w', 'E_II', '', 0.67, 0.84, 1.02),
	(15, 60, 64, 'w', 'E_II', '', 0.67, 0.84, 1.02),
	(15, 65, 69, 'w', 'E_II', '', 0.63, 0.81, 0.98),
	(15, 70, 74, 'w', 'E_II', '', 0.63, 0.81, 0.95),
	(15, 75, 79, 'w', 'E_II', '', 0.63, 0.81, 0.95),
	(15, 80, 84, 'w', 'E_II', '', 0.63, 0.77, 0.91),
	(15, 85, 89, 'w', 'E_II', '', 0.6, 0.74, 0.88),
	(15, 90, 200, 'w', 'E_II', '', 0.56, 0.7, 0.84),
	(15, 0, 7, 'm', 'E_II', '', 0.81, 0.95, 1.05),
	(15, 8, 9, 'm', 'E_II', '', 0.91, 1.05, 1.16),
	(15, 10, 11, 'm', 'E_II', '', 1.05, 1.19, 1.3),
	(15, 12, 13, 'm', 'E_II', '', 1.19, 1.33, 1.44),
	(15, 14, 15, 'm', 'E_II', '', 1.33, 1.44, 1.58),
	(15, 16, 17, 'm', 'E_II', '', 1.44, 1.54, 1.68),
	(15, 18, 19, 'm', 'E_II', '', 1.47, 1.61, 1.75),
	(15, 20, 24, 'm', 'E_II', '', 1.47, 1.61, 1.75),
	(15, 25, 29, 'm', 'E_II', '', 1.44, 1.58, 1.72),
	(15, 30, 34, 'm', 'E_II', '', 1.3, 1.47, 1.65),
	(15, 35, 39, 'm', 'E_II', '', 1.16, 1.37, 1.58),
	(15, 40, 44, 'm', 'E_II', '', 1.09, 1.3, 1.51),
	(15, 45, 49, 'm', 'E_II', '', 1.02, 1.23, 1.44),
	(15, 50, 54, 'm', 'E_II', '', 0.98, 1.19, 1.4),
	(15, 55, 59, 'm', 'E_II', '', 0.95, 1.16, 1.37),
	(15, 60, 64, 'm', 'E_II', '', 0.91, 1.12, 1.33),
	(15, 65, 69, 'm', 'E_II', '', 0.91, 1.12, 1.33),
	(15, 70, 74, 'm', 'E_II', '', 0.88, 1.09, 1.3),
	(15, 75, 79, 'm', 'E_II', '', 0.84, 1.05, 1.26),
	(15, 80, 84, 'm', 'E_II', '', 0.81, 1.02, 1.23),
	(15, 85, 89, 'm', 'E_II', '', 0.7, 0.91, 1.12),
	(15, 90, 200, 'm', 'E_II', '', 0.63, 0.84, 1.05),
	(17, 0, 7, 'w', 'E_II', '30 m', 10.4, 9.2, 8.2),
	(17, 8, 9, 'w', 'E_II', '30 m', 9.6, 8.6, 7.4),
	(17, 10, 11, 'w', 'E_II', '50 m', 14.3, 13.1, 11.8),
	(17, 12, 13, 'w', 'E_II', '50 m', 13.8, 12.5, 11.1),
	(17, 14, 15, 'w', 'E_II', '100 m', 24.2, 22.1, 20.2),
	(17, 16, 17, 'w', 'E_II', '100 m', 22.9, 21.2, 19.5),
	(17, 18, 19, 'w', 'E_II', '100 m', 23.7, 21.5, 19.9),
	(17, 20, 24, 'w', 'E_II', '100 m', 24.1, 21.8, 20.3),
	(17, 25, 29, 'w', 'E_II', '100 m', 24.6, 22.4, 20.8),
	(17, 30, 34, 'w', 'E_II', '100 m', 25.5, 23.1, 21.3),
	(17, 35, 39, 'w', 'E_II', '100 m', 26.5, 24.2, 22.1),
	(17, 40, 44, 'w', 'E_II', '50 m', 14.3, 12.9, 11.4),
	(17, 45, 49, 'w', 'E_II', '50 m', 15.0, 13.4, 11.8),
	(17, 50, 54, 'w', 'E_II', '50 m', 15.5, 13.9, 12.4),
	(17, 55, 59, 'w', 'E_II', '50 m', 16.1, 14.6, 12.9),
	(17, 60, 64, 'w', 'E_II', '50 m', 16.4, 14.8, 13.3),
	(17, 65, 69, 'w', 'E_II', '50 m', 16.6, 15.1, 13.5),
	(17, 70, 74, 'w', 'E_II', '50 m', 16.9, 15.3, 13.8),
	(17, 75, 79, 'w', 'E_II', '50 m', 17.6, 16.0, 14.4),
	(17, 80, 84, 'w', 'E_II', '50 m', 18.6, 17.0, 15.6),
	(17, 85, 89, 'w', 'E_II', '50 m', 20.2, 18.6, 17.2),
	(17, 90, 200, 'w', 'E_II', '50 m', 22.2, 20.7, 19.2),
	(17, 0, 7, 'm', 'E_II', '30 m', 10.0, 8.8, 7.8),
	(17, 8, 9, 'm', 'E_II', '30 m', 9.4, 8.3, 7.4),
	(17, 10, 11, 'm', 'E_II', '50 m', 13.4, 12.1, 10.9),
	(17, 12, 13, 'm', 'E_II', '50 m', 12.6, 11.6, 10.5),
	(17, 14, 15, 'm', 'E_II', '100 m', 22.1, 20.0, 18.3),
	(17, 16, 17, 'm', 'E_II', '100 m', 21.2, 19.2, 17.6),
	(17, 18, 19, 'm', 'E_II', '100 m', 20.8, 19.0, 17.2),
	(17, 20, 24, 'm', 'E_II', '100 m', 20.5, 18.7, 16.9),
	(17, 25, 29, 'm', 'E_II', '100 m', 21.2, 19.2, 17.3),
	(17, 30, 34, 'm', 'E_II', '100 m', 21.8, 19.6, 17.7),
	(17, 35, 39, 'm', 'E_II', '100 m', 22.9, 20.7, 18.5),
	(17, 40, 44, 'm', 'E_II', '50 m', 12.5, 11.3, 10.0),
	(17, 45, 49, 'm', 'E_II', '50 m', 13.0, 11.6, 10.3),
	(17, 50, 54, 'm', 'E_II', '50 m', 13.4, 11.8, 10.7),
	(17, 55, 59, 'm', 'E_II', '50 m', 13.7, 12.2, 11.1),
	(17, 60, 64, 'm', 'E_II', '50 m', 14.0, 12.6, 11.4),
	(17, 65, 69, 'm', 'E_II', '50 m', 14.6, 13.3, 11.8),
	(17, 70, 74, 'm', 'E_II', '50 m', 15.2, 13.9, 12.5),
	(17, 75, 79, 'm', 'E_II', '50 m', 15.9, 14.6, 13.1),
	(17, 80, 84, 'm', 'E_II', '50 m', 16.9, 15.6, 14.2),
	(17, 85, 89, 'm', 'E_II', '50 m', 18.3, 17.0, 15.6),
	(17, 90, 200, 'm', 'E_II', '50 m', 20.2, 18.9, 17.4),
	(18, 0, 7, 'w', 'E_II', '', 60.5, 50.1, 39.7),
	(18, 8, 9, 'w', 'E_II', '', 54.6, 44.2, 36.4),
	(18, 10, 11, 'w', 'E_II', '', 50.7, 41.0, 33.2),
	(18, 12, 13, 'w', 'E_II', '', 45.5, 37.7, 30.6),
	(18, 14, 15, 'w', 'E_II', '', 42.9, 35.8, 28.0),
	(18, 16, 17, 'w', 'E_II', '', 39.7, 33.2, 26.0),
	(18, 18, 19, 'w', 'E_II', '', 38.4, 31.2, 24.1),
	(18, 20, 24, 'w', 'E_II', '', 37.7, 31.2, 24.1),
	(18, 25, 29, 'w', 'E_II', '', 39.0, 32.5, 25.4),
	(18, 30, 34, 'w', 'E_II', '', 42.3, 34.5, 27.3),
	(18, 35, 39, 'w', 'E_II', '', 46.8, 37.7, 28.6),
	(18, 40, 44, 'w', 'E_II', '', 52.0, 41.0, 30.6),
	(18, 45, 49, 'w', 'E_II', '', 57.2, 45.5, 32.5),
	(18, 50, 54, 'w', 'E_II', '', 62.4, 50.7, 36.4),
	(18, 55, 59, 'w', 'E_II', '', 67.0, 55.3, 39.7),
	(18, 60, 64, 'w', 'E_II', '', 70.9, 57.9, 42.3),
	(18, 65, 69, 'w', 'E_II', '', 73.5, 60.5, 44.9),
	(18, 70, 74, 'w', 'E_II', '', 76.7, 62.4, 46.8),
	(18, 75, 79, 'w', 'E_II', '', 79.3, 65.0, 49.4),
	(18, 80, 84, 'w', 'E_II', '', 82.6, 67.6, 52.0),
	(18, 85, 89, 'w', 'E_II', '', 85.2, 69.6, 54.0),
	(18, 90, 200, 'w', 'E_II', '', 86.5, 70.9, 55.3),
	(18, 0, 7, 'm', 'E_II', '', 59.8, 49.4, 39.0),
	(18, 8, 9, 'm', 'E_II', '', 53.3, 42.9, 33.8),
	(18, 10, 11, 'm', 'E_II', '', 46.8, 37.7, 29.3),
	(18, 12, 13, 'm', 'E_II', '', 42.9, 35.1, 27.3),
	(18, 14, 15, 'm', 'E_II', '', 40.3, 33.2, 26.0),
	(18, 16, 17, 'm', 'E_II', '', 38.4, 31.9, 24.7),
	(18, 18, 19, 'm', 'E_II', '', 36.4, 29.9, 22.8),
	(18, 20, 24, 'm', 'E_II', '', 35.1, 28.6, 20.2),
	(18, 25, 29, 'm', 'E_II', '', 37.7, 29.9, 21.5),
	(18, 30, 34, 'm', 'E_II', '', 41.0, 31.2, 22.1),
	(18, 35, 39, 'm', 'E_II', '', 45.5, 34.5, 24.1),
	(18, 40, 44, 'm', 'E_II', '', 50.1, 38.4, 24.7),
	(18, 45, 49, 'm', 'E_II', '', 54.6, 42.3, 26.7),
	(18, 50, 54, 'm', 'E_II', '', 58.5, 45.5, 29.9),
	(18, 55, 59, 'm', 'E_II', '', 63.7, 48.1, 32.5),
	(18, 60, 64, 'm', 'E_II', '', 66.3, 50.7, 35.1),
	(18, 65, 69, 'm', 'E_II', '', 68.3, 52.7, 37.1),
	(18, 70, 74, 'm', 'E_II', '', 71.5, 55.9, 40.3),
	(18, 75, 79, 'm', 'E_II', '', 74.8, 59.2, 43.6),
	(18, 80, 84, 'm', 'E_II', '', 76.7, 62.4, 46.8),
	(18, 85, 89, 'm', 'E_II', '', 77.4, 63.7, 49.4),
	(18, 90, 200, 'm', 'E_II', '', 78.0, 65.0, 52.0),
	(19, 8, 9, 'w', 'E_II', '', 53.3, 46.8, 40.3),
	(19, 10, 11, 'w', 'E_II', '', 48.1, 41.6, 35.1),
	(19, 12, 13, 'w', 'E_II', '', 40.3, 35.1, 30.6),
	(19, 14, 15, 'w', 'E_II', '', 35.1, 31.9, 28.0),
	(19, 16, 17, 'w', 'E_II', '', 32.5, 29.3, 26.0),
	(19, 18, 19, 'w', 'E_II', '', 31.2, 28.6, 25.4),
	(19, 20, 24, 'w', 'E_II', '', 31.9, 28.6, 25.4),
	(19, 25, 29, 'w', 'E_II', '', 32.5, 29.3, 26.0),
	(19, 30, 34, 'w', 'E_II', '', 33.8, 30.6, 28.0),
	(19, 35, 39, 'w', 'E_II', '', 35.8, 31.9, 28.6),
	(19, 40, 44, 'w', 'E_II', '', 37.7, 33.2, 29.3),
	(19, 45, 49, 'w', 'E_II', '', 39.7, 35.1, 29.9),
	(19, 50, 54, 'w', 'E_II', '', 41.6, 36.4, 30.6),
	(19, 55, 59, 'w', 'E_II', '', 43.6, 37.7, 31.2),
	(19, 60, 64, 'w', 'E_II', '', 45.5, 39.0, 32.5),
	(19, 65, 69, 'w', 'E_II', '', 46.8, 40.3, 33.2),
	(19, 70, 74, 'w', 'E_II', '', 49.4, 41.6, 34.5),
	(19, 75, 79, 'w', 'E_II', '', 50.7, 42.9, 35.8),
	(19, 80, 84, 'w', 'E_II', '', 52.7, 44.9, 37.1),
	(19, 85, 89, 'w', 'E_II', '', 54.6, 46.8, 39.0),
	(19, 90, 200, 'w', 'E_II', '', 57.9, 49.4, 41.0),
	(19, 8, 9, 'm', 'E_II', '', 49.4, 42.9, 36.4),
	(19, 10, 11, 'm', 'E_II', '', 45.5, 39.7, 33.8),
	(19, 12, 13, 'm', 'E_II', '', 38.4, 33.8, 29.3),
	(19, 14, 15, 'm', 'E_II', '', 31.2, 28.0, 24.7),
	(19, 16, 17, 'm', 'E_II', '', 28.6, 25.4, 22.1),
	(19, 18, 19, 'm', 'E_II', '', 26.7, 23.4, 20.2),
	(19, 20, 24, 'm', 'E_II', '', 26.0, 22.8, 19.5),
	(19, 25, 29, 'm', 'E_II', '', 27.3, 23.4, 19.5),
	(19, 30, 34, 'm', 'E_II', '', 29.3, 24.1, 19.5),
	(19, 35, 39, 'm', 'E_II', '', 31.2, 26.0, 20.2),
	(19, 40, 44, 'm', 'E_II', '', 34.5, 28.0, 21.5),
	(19, 45, 49, 'm', 'E_II', '', 37.1, 29.9, 22.1),
	(19, 50, 54, 'm', 'E_II', '', 39.0, 31.2, 23.4),
	(19, 55, 59, 'm', 'E_II', '', 41.6, 32.5, 24.1),
	(19, 60, 64, 'm', 'E_II', '', 43.6, 33.8, 24.7),
	(19, 65, 69, 'm', 'E_II', '', 45.5, 35.1, 25.4),
	(19, 70, 74, 'm', 'E_II', '', 46.8, 37.1, 26.0),
	(19, 75, 79, 'm', 'E_II', '', 48.8, 38.4, 28.0),
	(19, 80, 84, 'm', 'E_II', '', 50.7, 41.0, 29.9),
	(19, 85, 89, 'm', 'E_II', '', 53.3, 42.9, 31.9),
	(19, 90, 200, 'm', 'E_II', '', 56.6, 46.2, 35.1),
	(21, 10, 11, 'w', 'E_II', '', 0.56, 0.63, 0.7),
	(21, 12, 13, 'w', 'E_II', '', 0.63, 0.7, 0.77),
	(21, 14, 15, 'w', 'E_II', '', 0.67, 0.74, 0.81),
	(21, 16, 17, 'w', 'E_II', '', 0.74, 0.81, 0.88),
	(21, 18, 19, 'w', 'E_II', '', 0.77, 0.84, 0.91),
	(21, 20, 24, 'w', 'E_II', '', 0.77, 0.84, 0.91),
	(21, 25, 29, 'w', 'E_II', '', 0.74, 0.81, 0.88),
	(21, 30, 34, 'w', 'E_II', '', 0.7, 0.77, 0.84),
	(21, 35, 39, 'w', 'E_II', '', 0.67, 0.74, 0.81),
	(21, 40, 44, 'w', 'E_II', '', 0.63, 0.7, 0.77),
	(21, 45, 49, 'w', 'E_II', '', 0.63, 0.7, 0.77),
	(21, 50, 54, 'w', 'E_II', '', 0.6, 0.67, 0.74),
	(21, 55, 59, 'w', 'E_II', '', 0.56, 0.63, 0.7),
	(21, 60, 64, 'w', 'E_II', '', 0.53, 0.6, 0.67),
	(21, 65, 69, 'w', 'E_II', '', 0.53, 0.6, 0.67),
	(21, 70, 74, 'w', 'E_II', '', 0.49, 0.56, 0.63),
	(21, 75, 79, 'w', 'E_II', '', 0.46, 0.53, 0.6),
	(21, 80, 84, 'w', 'E_II', '', 0.46, 0.53, 0.6),
	(21, 85, 89, 'w', 'E_II', '', 0.42, 0.49, 0.56),
	(21, 90, 200, 'w', 'E_II', '', 0.39, 0.42, 0.46),
	(21, 10, 11, 'm', 'E_II', '', 0.6, 0.67, 0.74),
	(21, 12, 13, 'm', 'E_II', '', 0.67, 0.74, 0.81),
	(21, 14, 15, 'm', 'E_II', '', 0.77, 0.84, 0.91),
	(21, 16, 17, 'm', 'E_II', '', 0.84, 0.91, 0.98),
	(21, 18, 19, 'm', 'E_II', '', 0.91, 0.98, 1.05),
	(21, 20, 24, 'm', 'E_II', '', 0.95, 1.02, 1.09),
	(21, 25, 29, 'm', 'E_II', '', 0.91, 0.98, 1.05),
	(21, 30, 34, 'm', 'E_II', '', 0.91, 0.98, 1.05),
	(21, 35, 39, 'm', 'E_II', '', 0.88, 0.95, 1.02),
	(21, 40, 44, 'm', 'E_II', '', 0.84, 0.91, 0.98),
	(21, 45, 49, 'm', 'E_II', '', 0.81, 0.88, 0.95),
	(21, 50, 54, 'm', 'E_II', '', 0.74, 0.81, 0.88),
	(21, 55, 59, 'm', 'E_II', '', 0.7, 0.77, 0.84),
	(21, 60, 64, 'm', 'E_II', '', 0.67, 0.74, 0.81),
	(21, 65, 69, 'm', 'E_II', '', 0.6, 0.7, 0.77),
	(21, 70, 74, 'm', 'E_II', '', 0.56, 0.67, 0.74),
	(21, 75, 79, 'm', 'E_II', '', 0.53, 0.63, 0.7),
	(21, 80, 84, 'm', 'E_II', '', 0.53, 0.6, 0.67),
	(21, 85, 89, 'm', 'E_II', '', 0.49, 0.56, 0.63),
	(21, 90, 200, 'm', 'E_II', '', 0.46, 0.53, 0.6),
	(23, 0, 7, 'w', 'E_II', '', 1.21, 1.42, 1.63),
	(23, 8, 9, 'w', 'E_II', '', 1.41, 1.62, 1.83),
	(23, 10, 11, 'w', 'E_II', '', 1.61, 1.82, 2.03),
	(23, 12, 13, 'w', 'E_II', '', 1.96, 2.17, 2.38),
	(23, 14, 15, 'w', 'E_II', '', 2.24, 2.45, 2.66),
	(23, 16, 17, 'w', 'E_II', '', 2.38, 2.59, 2.8),
	(23, 18, 19, 'w', 'E_II', '', 2.38, 2.59, 2.8),
	(23, 20, 24, 'w', 'E_II', '', 2.38, 2.59, 2.8),
	(23, 25, 29, 'w', 'E_II', '', 2.31, 2.52, 2.73),
	(23, 30, 34, 'w', 'E_II', '', 2.24, 2.45, 2.66),
	(23, 35, 39, 'w', 'E_II', '', 2.17, 2.38, 2.59),
	(23, 40, 44, 'w', 'E_II', '', 2.1, 2.31, 2.52),
	(23, 45, 49, 'w', 'E_II', '', 1.96, 2.24, 2.45),
	(23, 50, 54, 'w', 'E_II', '', 1.82, 2.1, 2.38),
	(23, 55, 59, 'w', 'E_II', '', 1.75, 2.03, 2.31),
	(23, 60, 64, 'w', 'E_II', '', 1.68, 1.96, 2.24),
	(23, 65, 69, 'w', 'E_II', '', 1.61, 1.89, 2.17),
	(23, 70, 74, 'w', 'E_II', '', 1.47, 1.75, 2.03),
	(23, 75, 79, 'w', 'E_II', '', 1.26, 1.54, 1.82),
	(23, 80, 84, 'w', 'E_II', '', 1.12, 1.4, 1.68),
	(23, 85, 89, 'w', 'E_II', '', 0.91, 1.19, 1.47),
	(23, 90, 200, 'w', 'E_II', '', 0.77, 1.05, 1.33),
	(23, 0, 7, 'm', 'E_II', '', 1.42, 1.63, 1.84),
	(23, 8, 9, 'm', 'E_II', '', 1.62, 1.83, 2.04),
	(23, 10, 11, 'm', 'E_II', '', 1.82, 2.03, 2.24),
	(23, 12, 13, 'm', 'E_II', '', 2.24, 2.45, 2.66),
	(23, 14, 15, 'm', 'E_II', '', 2.66, 2.87, 3.08),
	(23, 16, 17, 'm', 'E_II', '', 3.01, 3.22, 3.43),
	(23, 18, 19, 'm', 'E_II', '', 3.15, 3.36, 3.57),
	(23, 20, 24, 'm', 'E_II', '', 3.08, 3.29, 3.5),
	(23, 25, 29, 'm', 'E_II', '', 3.01, 3.22, 3.43),
	(23, 30, 34, 'm', 'E_II', '', 2.94, 3.15, 3.36),
	(23, 35, 39, 'm', 'E_II', '', 2.87, 3.08, 3.29),
	(23, 40, 44, 'm', 'E_II', '', 2.73, 3.01, 3.22),
	(23, 45, 49, 'm', 'E_II', '', 2.59, 2.87, 3.15),
	(23, 50, 54, 'm', 'E_II', '', 2.52, 2.8, 3.08),
	(23, 55, 59, 'm', 'E_II', '', 2.38, 2.66, 2.94),
	(23, 60, 64, 'm', 'E_II', '', 2.24, 2.52, 2.8),
	(23, 65, 69, 'm', 'E_II', '', 2.03, 2.31, 2.59),
	(23, 70, 74, 'm', 'E_II', '', 1.89, 2.17, 2.45),
	(23, 75, 79, 'm', 'E_II', '', 1.68, 2.03, 2.31),
	(23, 80, 84, 'm', 'E_II', '', 1.47, 1.82, 2.17),
	(23, 85, 89, 'm', 'E_II', '', 1.33, 1.68, 2.03),
	(23, 90, 200, 'm', 'E_II', '', 1.12, 1.47, 1.82),
	(33, 0, 7, 'w', 'E_II', '', 5.6000000000000005, 8.4, 11.899999999999999),
	(33, 8, 9, 'w', 'E_II', '', 7.0, 10.500000000000002, 14.0),
	(33, 10, 11, 'w', 'E_II', '', 10.500000000000002, 14.0, 21.0),
	(33, 12, 13, 'w', 'E_II', '', 14.0, 21.0, 28.0),
	(33, 14, 15, 'w', 'E_II', '', 21.0, 28.0, 35.0),
	(33, 16, 17, 'w', 'E_II', '', 31.5, 42.0, 52.49999999999999),
	(33, 0, 7, 'm', 'E_II', '', 7.0, 10.500000000000002, 14.0),
	(33, 8, 9, 'm', 'E_II', '', 8.4, 11.899999999999999, 16.099999999999998),
	(33, 10, 11, 'm', 'E_II', '', 11.899999999999999, 17.5, 24.5),
	(33, 12, 13, 'm', 'E_II', '', 17.5, 24.5, 31.5),
	(33, 14, 15, 'm', 'E_II', '', 24.5, 31.5, 42.0),
	(33, 16, 17, 'm', 'E_II', '', 38.49999999999999, 49.0, 63.0),
	(39, 0, 7, 'w', 'E_II', '', 74.0, 83.0, 91.0),
	(39, 8, 9, 'w', 'E_II', '', 86.0, 95.0, 105.0),
	(39, 10, 11, 'w', 'E_II', '', 97.0, 108.0, 118.0),
	(39, 12, 13, 'w', 'E_II', '', 108.0, 120.0, 132.0),
	(39, 14, 15, 'w', 'E_II', '', 119.0, 133.0, 146.0),
	(39, 16, 17, 'w', 'E_II', '', 131.0, 145.0, 160.0),
	(39, 18, 19, 'w', 'E_II', '', 221.0, 245.0, 270.0),
	(39, 20, 24, 'w', 'E_II', '', 221.0, 245.0, 270.0),
	(39, 25, 29, 'w', 'E_II', '', 221.0, 245.0, 270.0),
	(39, 30, 34, 'w', 'E_II', '', 209.0, 233.0, 256.0),
	(39, 35, 39, 'w', 'E_II', '', 209.0, 233.0, 256.0),
	(39, 40, 44, 'w', 'E_II', '', 198.0, 220.0, 242.0),
	(39, 45, 49, 'w', 'E_II', '', 187.0, 208.0, 228.0),
	(39, 50, 54, 'w', 'E_II', '', 176.0, 195.0, 215.0),
	(39, 55, 59, 'w', 'E_II', '', 164.0, 183.0, 201.0),
	(39, 60, 64, 'w', 'E_II', '', 153.0, 170.0, 187.0),
	(39, 65, 69, 'w', 'E_II', '', 142.0, 158.0, 173.0),
	(39, 70, 74, 'w', 'E_II', '', 131.0, 145.0, 160.0),
	(39, 75, 79, 'w', 'E_II', '', 119.0, 133.0, 146.0),
	(39, 80, 84, 'w', 'E_II', '', 108.0, 120.0, 132.0),
	(39, 85, 89, 'w', 'E_II', '', 97.0, 108.0, 118.0),
	(39, 90, 200, 'w', 'E_II', '', 86.0, 95.0, 105.0),
	(39, 0, 7, 'm', 'E_II', '', 133.0, 148.0, 162.0),
	(39, 8, 9, 'm', 'E_II', '', 144.0, 160.0, 176.0),
	(39, 10, 11, 'm', 'E_II', '', 155.0, 173.0, 190.0),
	(39, 12, 13, 'm', 'E_II', '', 167.0, 185.0, 204.0),
	(39, 14, 15, 'm', 'E_II', '', 178.0, 198.0, 217.0),
	(39, 16, 17, 'm', 'E_II', '', 189.0, 210.0, 231.0),
	(39, 18, 19, 'm', 'E_II', '', 279.0, 310.0, 341.0),
	(39, 20, 24, 'm', 'E_II', '', 279.0, 310.0, 341.0),
	(39, 25, 29, 'm', 'E_II', '', 279.0, 310.0, 341.0),
	(39, 30, 34, 'm', 'E_II', '', 268.0, 298.0, 327.0),
	(39, 35, 39, 'm', 'E_II', '', 268.0, 298.0, 327.0),
	(39, 40, 44, 'm', 'E_II', '', 257.0, 285.0, 314.0),
	(39, 45, 49, 'm', 'E_II', '', 245.0, 273.0, 300.0),
	(39, 50, 54, 'm', 'E_II', '', 234.0, 260.0, 286.0),
	(39, 55, 59, 'm', 'E_II', '', 223.0, 248.0, 272.0),
	(39, 60, 64, 'm', 'E_II', '', 212.0, 235.0, 259.0),
	(39, 65, 69, 'm', 'E_II', '', 200.0, 223.0, 245.0),
	(39, 70, 74, 'm', 'E_II', '', 189.0, 210.0, 231.0),
	(39, 75, 79, 'm', 'E_II', '', 178.0, 198.0, 217.0),
	(39, 80, 84, 'm', 'E_II', '', 167.0, 185.0, 204.0),
	(39, 85, 89, 'm', 'E_II', '', 155.0, 173.0, 190.0),
	(39, 90, 200, 'm', 'E_II', '', 144.0, 160.0, 176.0),
	(40, 0, 7, 'w', 'E_II', '', 234.0, 260.0, 286.0),
	(40, 8, 9, 'w', 'E_II', '', 248.0, 275.0, 303.0),
	(40, 10, 11, 'w', 'E_II', '', 261.0, 290.0, 319.0),
	(40, 12, 13, 'w', 'E_II', '', 275.0, 305.0, 336.0),
	(40, 14, 15, 'w', 'E_II', '', 288.0, 320.0, 352.0),
	(40, 16, 17, 'w', 'E_II', '', 302.0, 335.0, 369.0),
	(40, 18, 19, 'w', 'E_II', '', 392.0, 435.0, 479.0),
	(40, 20, 24, 'w', 'E_II', '', 392.0, 435.0, 479.0),
	(40, 25, 29, 'w', 'E_II', '', 392.0, 435.0, 479.0),
	(40, 30, 34, 'w', 'E_II', '', 378.0, 420.0, 462.0),
	(40, 35, 39, 'w', 'E_II', '', 378.0, 420.0, 462.0),
	(40, 40, 44, 'w', 'E_II', '', 365.0, 405.0, 446.0),
	(40, 45, 49, 'w', 'E_II', '', 351.0, 390.0, 429.0),
	(40, 50, 54, 'w', 'E_II', '', 338.0, 375.0, 413.0),
	(40, 55, 59, 'w', 'E_II', '', 324.0, 360.0, 396.0),
	(40, 60, 64, 'w', 'E_II', '', 311.0, 345.0, 380.0),
	(40, 65, 69, 'w', 'E_II', '', 297.0, 330.0, 363.0),
	(40, 70, 74, 'w', 'E_II', '', 284.0, 315.0, 347.0),
	(40, 75, 79, 'w', 'E_II', '', 270.0, 300.0, 330.0),
	(40, 80, 84, 'w', 'E_II', '', 257.0, 285.0, 314.0),
	(40, 85, 89, 'w', 'E_II', '', 243.0, 270.0, 297.0),
	(40, 90, 200, 'w', 'E_II', '', 230.0, 255.0, 281.0),
	(40, 0, 7, 'm', 'E_II', '', 302.0, 335.0, 369.0),
	(40, 8, 9, 'm', 'E_II', '', 315.0, 350.0, 385.0),
	(40, 10, 11, 'm', 'E_II', '', 329.0, 365.0, 402.0),
	(40, 12, 13, 'm', 'E_II', '', 342.0, 380.0, 418.0),
	(40, 14, 15, 'm', 'E_II', '', 356.0, 395.0, 435.0),
	(40, 16, 17, 'm', 'E_II', '', 369.0, 410.0, 451.0),
	(40, 18, 19, 'm', 'E_II', '', 459.0, 510.0, 561.0),
	(40, 20, 24, 'm', 'E_II', '', 459.0, 510.0, 561.0),
	(40, 25, 29, 'm', 'E_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'E_II', '', 446.0, 495.0, 545.0),
	(40, 35, 39, 'm', 'E_II', '', 446.0, 495.0, 545.0),
	(40, 40, 44, 'm', 'E_II', '', 432.0, 480.0, 528.0),
	(40, 45, 49, 'm', 'E_II', '', 419.0, 465.0, 512.0),
	(40, 50, 54, 'm', 'E_II', '', 405.0, 450.0, 495.0),
	(40, 55, 59, 'm', 'E_II', '', 392.0, 435.0, 479.0),
	(40, 60, 64, 'm', 'E_II', '', 378.0, 420.0, 462.0),
	(40, 65, 69, 'm', 'E_II', '', 365.0, 405.0, 446.0),
	(40, 70, 74, 'm', 'E_II', '', 351.0, 390.0, 429.0),
	(40, 75, 79, 'm', 'E_II', '', 338.0, 375.0, 413.0),
	(40, 80, 84, 'm', 'E_II', '', 324.0, 360.0, 396.0),
	(40, 85, 89, 'm', 'E_II', '', 311.0, 345.0, 380.0),
	(40, 90, 200, 'm', 'E_II', '', 297.0, 330.0, 363.0),
	(41, 0, 7, 'w', 'E_II', '', 167.0, 185.0, 204.0),
	(41, 8, 9, 'w', 'E_II', '', 180.0, 200.0, 220.0),
	(41, 10, 11, 'w', 'E_II', '', 194.0, 215.0, 237.0),
	(41, 12, 13, 'w', 'E_II', '', 207.0, 230.0, 253.0),
	(41, 14, 15, 'w', 'E_II', '', 221.0, 245.0, 270.0),
	(41, 16, 17, 'w', 'E_II', '', 234.0, 260.0, 286.0),
	(41, 18, 19, 'w', 'E_II', '', 324.0, 360.0, 396.0),
	(41, 20, 24, 'w', 'E_II', '', 324.0, 360.0, 396.0),
	(41, 25, 29, 'w', 'E_II', '', 324.0, 360.0, 396.0),
	(41, 30, 34, 'w', 'E_II', '', 311.0, 345.0, 380.0),
	(41, 35, 39, 'w', 'E_II', '', 311.0, 345.0, 380.0),
	(41, 40, 44, 'w', 'E_II', '', 297.0, 330.0, 363.0),
	(41, 45, 49, 'w', 'E_II', '', 284.0, 315.0, 347.0),
	(41, 50, 54, 'w', 'E_II', '', 270.0, 300.0, 330.0),
	(41, 55, 59, 'w', 'E_II', '', 257.0, 285.0, 314.0),
	(41, 60, 64, 'w', 'E_II', '', 243.0, 270.0, 297.0),
	(41, 65, 69, 'w', 'E_II', '', 230.0, 255.0, 281.0),
	(41, 70, 74, 'w', 'E_II', '', 216.0, 240.0, 264.0),
	(41, 75, 79, 'w', 'E_II', '', 203.0, 225.0, 248.0),
	(41, 80, 84, 'w', 'E_II', '', 189.0, 210.0, 231.0),
	(41, 85, 89, 'w', 'E_II', '', 176.0, 195.0, 215.0),
	(41, 90, 200, 'w', 'E_II', '', 162.0, 180.0, 198.0),
	(41, 0, 7, 'm', 'E_II', '', 230.0, 255.0, 281.0),
	(41, 8, 9, 'm', 'E_II', '', 243.0, 270.0, 297.0),
	(41, 10, 11, 'm', 'E_II', '', 257.0, 285.0, 314.0),
	(41, 12, 13, 'm', 'E_II', '', 270.0, 300.0, 330.0),
	(41, 14, 15, 'm', 'E_II', '', 284.0, 315.0, 347.0),
	(41, 16, 17, 'm', 'E_II', '', 297.0, 330.0, 363.0),
	(41, 18, 19, 'm', 'E_II', '', 387.0, 430.0, 473.0),
	(41, 20, 24, 'm', 'E_II', '', 387.0, 430.0, 473.0),
	(41, 25, 29, 'm', 'E_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'E_II', '', 374.0, 415.0, 457.0),
	(41, 35, 39, 'm', 'E_II', '', 374.0, 415.0, 457.0),
	(41, 40, 44, 'm', 'E_II', '', 360.0, 400.0, 440.0),
	(41, 45, 49, 'm', 'E_II', '', 347.0, 385.0, 424.0),
	(41, 50, 54, 'm', 'E_II', '', 333.0, 370.0, 407.0),
	(41, 55, 59, 'm', 'E_II', '', 320.0, 355.0, 391.0),
	(41, 60, 64, 'm', 'E_II', '', 306.0, 340.0, 374.0),
	(41, 65, 69, 'm', 'E_II', '', 293.0, 325.0, 358.0),
	(41, 70, 74, 'm', 'E_II', '', 279.0, 310.0, 341.0),
	(41, 75, 79, 'm', 'E_II', '', 266.0, 295.0, 325.0),
	(41, 80, 84, 'm', 'E_II', '', 252.0, 280.0, 308.0),
	(41, 85, 89, 'm', 'E_II', '', 239.0, 265.0, 292.0),
	(41, 90, 200, 'm', 'E_II', '', 225.0, 250.0, 275.0),
	(42, 0, 7, 'w', 'E_II', '', 171.0, 190.0, 209.0),
	(42, 8, 9, 'w', 'E_II', '', 185.0, 205.0, 226.0),
	(42, 10, 11, 'w', 'E_II', '', 198.0, 220.0, 242.0),
	(42, 12, 13, 'w', 'E_II', '', 212.0, 235.0, 259.0),
	(42, 14, 15, 'w', 'E_II', '', 225.0, 250.0, 275.0),
	(42, 16, 17, 'w', 'E_II', '', 239.0, 265.0, 292.0),
	(42, 18, 19, 'w', 'E_II', '', 329.0, 365.0, 402.0),
	(42, 20, 24, 'w', 'E_II', '', 329.0, 365.0, 402.0),
	(42, 25, 29, 'w', 'E_II', '', 329.0, 365.0, 402.0),
	(42, 30, 34, 'w', 'E_II', '', 315.0, 350.0, 385.0),
	(42, 35, 39, 'w', 'E_II', '', 315.0, 350.0, 385.0),
	(42, 40, 44, 'w', 'E_II', '', 302.0, 335.0, 369.0),
	(42, 45, 49, 'w', 'E_II', '', 288.0, 320.0, 352.0),
	(42, 50, 54, 'w', 'E_II', '', 275.0, 305.0, 336.0),
	(42, 55, 59, 'w', 'E_II', '', 261.0, 290.0, 319.0),
	(42, 60, 64, 'w', 'E_II', '', 248.0, 275.0, 303.0),
	(42, 65, 69, 'w', 'E_II', '', 234.0, 260.0, 286.0),
	(42, 70, 74, 'w', 'E_II', '', 221.0, 245.0, 270.0),
	(42, 75, 79, 'w', 'E_II', '', 207.0, 230.0, 253.0),
	(42, 80, 84, 'w', 'E_II', '', 194.0, 215.0, 237.0),
	(42, 85, 89, 'w', 'E_II', '', 180.0, 200.0, 220.0),
	(42, 90, 200, 'w', 'E_II', '', 167.0, 185.0, 204.0),
	(42, 0, 7, 'm', 'E_II', '', 234.0, 260.0, 286.0),
	(42, 8, 9, 'm', 'E_II', '', 248.0, 275.0, 303.0),
	(42, 10, 11, 'm', 'E_II', '', 261.0, 290.0, 319.0),
	(42, 12, 13, 'm', 'E_II', '', 275.0, 305.0, 336.0),
	(42, 14, 15, 'm', 'E_II', '', 288.0, 320.0, 352.0),
	(42, 16, 17, 'm', 'E_II', '', 302.0, 335.0, 369.0),
	(42, 18, 19, 'm', 'E_II', '', 392.0, 435.0, 479.0),
	(42, 20, 24, 'm', 'E_II', '', 392.0, 435.0, 479.0),
	(42, 25, 29, 'm', 'E_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'E_II', '', 378.0, 420.0, 462.0),
	(42, 35, 39, 'm', 'E_II', '', 378.0, 420.0, 462.0),
	(42, 40, 44, 'm', 'E_II', '', 365.0, 405.0, 446.0),
	(42, 45, 49, 'm', 'E_II', '', 351.0, 390.0, 429.0),
	(42, 50, 54, 'm', 'E_II', '', 338.0, 375.0, 413.0),
	(42, 55, 59, 'm', 'E_II', '', 324.0, 360.0, 396.0),
	(42, 60, 64, 'm', 'E_II', '', 311.0, 345.0, 380.0),
	(42, 65, 69, 'm', 'E_II', '', 297.0, 330.0, 363.0),
	(42, 70, 74, 'm', 'E_II', '', 284.0, 315.0, 347.0),
	(42, 75, 79, 'm', 'E_II', '', 270.0, 300.0, 330.0),
	(42, 80, 84, 'm', 'E_II', '', 257.0, 285.0, 314.0),
	(42, 85, 89, 'm', 'E_II', '', 243.0, 270.0, 297.0),
	(42, 90, 200, 'm', 'E_II', '', 230.0, 255.0, 281.0),
	(45, 0, 7, 'w', 'E_II', '', 10.5, 13.5, 16.5),
	(45, 8, 9, 'w', 'E_II', '', 12.0, 15.0, 18.0),
	(45, 10, 11, 'w', 'E_II', '', 13.5, 16.5, 19.5),
	(45, 12, 13, 'w', 'E_II', '', 15.0, 18.0, 21.0),
	(45, 14, 15, 'w', 'E_II', '', 16.5, 19.5, 22.5),
	(45, 16, 17, 'w', 'E_II', '', 18.0, 21.0, 24.0),
	(45, 18, 19, 'w', 'E_II', '', 19.5, 22.5, 25.5),
	(45, 20, 24, 'w', 'E_II', '', 18.5, 21.5, 24.5),
	(45, 25, 29, 'w', 'E_II', '', 17.5, 20.5, 23.5),
	(45, 30, 34, 'w', 'E_II', '', 16.5, 19.5, 22.5),
	(45, 35, 39, 'w', 'E_II', '', 15.5, 18.5, 21.5),
	(45, 40, 44, 'w', 'E_II', '', 14.5, 17.5, 20.5),
	(45, 45, 49, 'w', 'E_II', '', 13.5, 16.5, 19.5),
	(45, 50, 54, 'w', 'E_II', '', 12.5, 15.5, 18.5),
	(45, 55, 59, 'w', 'E_II', '', 11.5, 14.5, 17.5),
	(45, 60, 64, 'w', 'E_II', '', 10.5, 13.5, 16.5),
	(45, 65, 69, 'w', 'E_II', '', 9.5, 12.5, 15.5),
	(45, 70, 74, 'w', 'E_II', '', 8.5, 11.5, 14.5),
	(45, 75, 79, 'w', 'E_II', '', 7.5, 10.5, 13.5),
	(45, 80, 84, 'w', 'E_II', '', 6.5, 9.5, 12.5),
	(45, 85, 89, 'w', 'E_II', '', 5.5, 8.5, 11.5),
	(45, 90, 200, 'w', 'E_II', '', 4.5, 7.5, 10.5),
	(45, 0, 7, 'm', 'E_II', '', 15.0, 18.0, 21.0),
	(45, 8, 9, 'm', 'E_II', '', 16.5, 19.5, 22.5),
	(45, 10, 11, 'm', 'E_II', '', 18.0, 21.0, 24.0),
	(45, 12, 13, 'm', 'E_II', '', 19.5, 22.5, 25.5),
	(45, 14, 15, 'm', 'E_II', '', 21.0, 24.0, 27.0),
	(45, 16, 17, 'm', 'E_II', '', 22.5, 25.5, 28.5),
	(45, 18, 19, 'm', 'E_II', '', 24.0, 27.0, 30.0),
	(45, 20, 24, 'm', 'E_II', '', 23.0, 26.0, 29.0),
	(45, 25, 29, 'm', 'E_II', '', 22.0, 25.0, 28.0),
	(45, 30, 34, 'm', 'E_II', '', 21.0, 24.0, 27.0),
	(45, 35, 39, 'm', 'E_II', '', 20.0, 23.0, 26.0),
	(45, 40, 44, 'm', 'E_II', '', 19.0, 22.0, 25.0),
	(45, 45, 49, 'm', 'E_II', '', 18.0, 21.0, 24.0),
	(45, 50, 54, 'm', 'E_II', '', 17.0, 20.0, 23.0),
	(45, 55, 59, 'm', 'E_II', '', 16.0, 19.0, 22.0),
	(45, 60, 64, 'm', 'E_II', '', 15.0, 18.0, 21.0),
	(45, 65, 69, 'm', 'E_II', '', 14.0, 17.0, 20.0),
	(45, 70, 74, 'm', 'E_II', '', 13.0, 16.0, 19.0),
	(45, 75, 79, 'm', 'E_II', '', 12.0, 15.0, 18.0),
	(45, 80, 84, 'm', 'E_II', '', 11.0, 14.0, 17.0),
	(45, 85, 89, 'm', 'E_II', '', 10.0, 13.0, 16.0),
	(45, 90, 200, 'm', 'E_II', '', 9.0, 12.0, 15.0),
	(54, 0, 7, 'w', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 8, 9, 'w', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 10, 11, 'w', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 12, 13, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 14, 15, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 16, 17, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 18, 19, 'w', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 20, 24, 'w', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 25, 29, 'w', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 30, 34, 'w', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 35, 39, 'w', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 40, 44, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 45, 49, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 50, 54, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 55, 59, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 60, 64, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 65, 69, 'w', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 70, 74, 'w', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 75, 79, 'w', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 80, 84, 'w', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 85, 89, 'w', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 90, 200, 'w', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 0, 7, 'm', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 8, 9, 'm', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 10, 11, 'm', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 12, 13, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 14, 15, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 16, 17, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 18, 19, 'm', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 20, 24, 'm', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 25, 29, 'm', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 30, 34, 'm', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 35, 39, 'm', 'E_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 40, 44, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 45, 49, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 50, 54, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 55, 59, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 60, 64, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 65, 69, 'm', 'E_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 70, 74, 'm', 'E_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(54, 75, 79, 'm', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 80, 84, 'm', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 85, 89, 'm', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(54, 90, 200, 'm', 'E_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'F_I', '', 6.2333333333333325, 5.5, 4.683333333333334),
	(1, 8, 9, 'w', 'F_I', '', 6.133333333333334, 5.316666666666667, 4.583333333333333),
	(1, 10, 11, 'w', 'F_I', '', 5.866666666666666, 5.133333333333334, 4.4),
	(1, 12, 13, 'w', 'F_I', '', 5.683333333333334, 4.866666666666666, 4.133333333333334),
	(1, 14, 15, 'w', 'F_I', '', 5.5, 4.766666666666667, 3.9499999999999997),
	(1, 16, 17, 'w', 'F_I', '', 5.316666666666667, 4.5, 3.7666666666666666),
	(1, 0, 7, 'm', 'F_I', '', 6.2333333333333325, 5.5, 4.683333333333334),
	(1, 8, 9, 'm', 'F_I', '', 5.966666666666667, 5.133333333333334, 4.316666666666667),
	(1, 10, 11, 'm', 'F_I', '', 5.583333333333333, 4.766666666666667, 3.9499999999999997),
	(1, 12, 13, 'm', 'F_I', '', 5.2333333333333325, 4.4, 3.5833333333333335),
	(1, 14, 15, 'm', 'F_I', '', 4.766666666666667, 4.033333333333332, 3.3000000000000003),
	(1, 16, 17, 'm', 'F_I', '', 4.5, 3.7666666666666666, 3.033333333333333),
	(4, 8, 9, 'w', 'F_I', '5 km Tandem', 29.700000000000003, 26.4, 23.099999999999998),
	(4, 10, 11, 'w', 'F_I', '10 km Tandem', 55.55, 47.3, 39.050000000000004),
	(4, 12, 13, 'w', 'F_I', '10 km Tandem', 49.49999999999999, 43.45, 36.849999999999994),
	(4, 14, 15, 'w', 'F_I', '10 km Tandem', 41.8, 35.75000000000001, 31.35),
	(4, 16, 17, 'w', 'F_I', '10 km Tandem', 35.75000000000001, 31.35, 27.5),
	(4, 18, 19, 'w', 'F_I', '20 km Tandem', 63.25, 57.199999999999996, 51.150000000000006),
	(4, 20, 24, 'w', 'F_I', '20 km Tandem', 62.7, 56.65, 50.050000000000004),
	(4, 25, 29, 'w', 'F_I', '20 km Tandem', 61.6, 55.55, 49.49999999999999),
	(4, 30, 34, 'w', 'F_I', '20 km Tandem', 62.7, 56.65, 50.050000000000004),
	(4, 35, 39, 'w', 'F_I', '20 km Tandem', 66.0, 58.3, 51.7),
	(4, 40, 44, 'w', 'F_I', '20 km Tandem', 70.39999999999999, 61.050000000000004, 54.45),
	(4, 45, 49, 'w', 'F_I', '20 km Tandem', 73.7, 64.35, 56.65),
	(4, 50, 54, 'w', 'F_I', '20 km Tandem', 75.9, 67.10000000000001, 58.849999999999994),
	(4, 55, 59, 'w', 'F_I', '20 km Tandem', 78.65, 69.30000000000001, 61.050000000000004),
	(4, 60, 64, 'w', 'F_I', '20 km Tandem', 81.39999999999999, 71.5, 62.7),
	(4, 65, 69, 'w', 'F_I', '20 km Tandem', 83.05, 73.15, 64.35),
	(4, 70, 74, 'w', 'F_I', '20 km Tandem', 85.80000000000001, 75.35, 66.55),
	(4, 75, 79, 'w', 'F_I', '20 km Tandem', 89.65, 77.55, 69.30000000000001),
	(4, 80, 84, 'w', 'F_I', '20 km Tandem', 92.94999999999999, 82.5, 72.05),
	(4, 85, 89, 'w', 'F_I', '20 km Tandem', 98.44999999999999, 88.0, 75.9),
	(4, 90, 200, 'w', 'F_I', '20 km Tandem', 102.30000000000001, 91.30000000000001, 79.75),
	(4, 8, 9, 'm', 'F_I', '5 km Tandem', 29.15, 25.85, 22.549999999999997),
	(4, 10, 11, 'm', 'F_I', '10 km Tandem', 53.35, 45.1, 36.849999999999994),
	(4, 12, 13, 'm', 'F_I', '10 km Tandem', 47.3, 40.7, 34.65),
	(4, 14, 15, 'm', 'F_I', '10 km Tandem', 35.199999999999996, 30.8, 26.4),
	(4, 16, 17, 'm', 'F_I', '10 km Tandem', 29.700000000000003, 25.85, 22.549999999999997),
	(4, 18, 19, 'm', 'F_I', '20 km Tandem', 51.7, 46.75000000000001, 42.35),
	(4, 20, 24, 'm', 'F_I', '20 km Tandem', 51.150000000000006, 46.199999999999996, 41.25),
	(4, 25, 29, 'm', 'F_I', '20 km Tandem', 55.0, 48.95, 42.9),
	(4, 30, 34, 'm', 'F_I', '20 km Tandem', 58.849999999999994, 51.7, 44.55),
	(4, 35, 39, 'm', 'F_I', '20 km Tandem', 63.8, 55.0, 45.65),
	(4, 40, 44, 'm', 'F_I', '20 km Tandem', 69.30000000000001, 57.199999999999996, 47.849999999999994),
	(4, 45, 49, 'm', 'F_I', '20 km Tandem', 72.6, 60.49999999999999, 49.49999999999999),
	(4, 50, 54, 'm', 'F_I', '20 km Tandem', 75.35, 62.7, 51.150000000000006),
	(4, 55, 59, 'm', 'F_I', '20 km Tandem', 77.55, 64.35, 52.25),
	(4, 60, 64, 'm', 'F_I', '20 km Tandem', 78.65, 66.0, 52.8),
	(4, 65, 69, 'm', 'F_I', '20 km Tandem', 79.75, 66.55, 53.35),
	(4, 70, 74, 'm', 'F_I', '20 km Tandem', 80.85000000000001, 67.65, 54.45),
	(4, 75, 79, 'm', 'F_I', '20 km Tandem', 81.94999999999999, 69.30000000000001, 56.65),
	(4, 80, 84, 'm', 'F_I', '20 km Tandem', 83.6, 70.94999999999999, 58.3),
	(4, 85, 89, 'm', 'F_I', '20 km Tandem', 85.25000000000001, 73.15, 61.050000000000004),
	(4, 90, 200, 'm', 'F_I', '20 km Tandem', 86.9, 74.80000000000001, 63.8),
	(5, 18, 19, 'w', 'F_I', '', 22.916666666666668, 20.716666666666665, 18.516666666666666),
	(5, 20, 24, 'w', 'F_I', '', 22.366666666666664, 20.166666666666668, 17.966666666666665),
	(5, 25, 29, 'w', 'F_I', '', 22.733333333333334, 20.533333333333335, 18.333333333333332),
	(5, 30, 34, 'w', 'F_I', '', 23.650000000000002, 21.45, 19.249999999999996),
	(5, 35, 39, 'w', 'F_I', '', 24.200000000000003, 22.0, 19.8),
	(5, 40, 44, 'w', 'F_I', '', 25.116666666666667, 22.733333333333334, 20.35),
	(5, 45, 49, 'w', 'F_I', '', 26.216666666666665, 23.650000000000002, 20.716666666666665),
	(5, 50, 54, 'w', 'F_I', '', 27.31666666666667, 24.383333333333333, 21.083333333333336),
	(5, 55, 59, 'w', 'F_I', '', 28.416666666666668, 25.116666666666667, 21.816666666666663),
	(5, 60, 64, 'w', 'F_I', '', 29.15, 25.85, 22.549999999999997),
	(5, 65, 69, 'w', 'F_I', '', 29.883333333333336, 26.583333333333336, 23.283333333333335),
	(5, 70, 74, 'w', 'F_I', '', 30.433333333333337, 27.13333333333333, 23.833333333333332),
	(5, 75, 79, 'w', 'F_I', '', 31.35, 28.05, 24.75),
	(5, 80, 84, 'w', 'F_I', '', 32.63333333333334, 29.333333333333332, 26.03333333333333),
	(5, 85, 89, 'w', 'F_I', '', 34.1, 30.8, 27.5),
	(5, 90, 200, 'w', 'F_I', '', 35.75000000000001, 32.45, 29.15),
	(5, 18, 19, 'm', 'F_I', '', 19.616666666666667, 17.416666666666668, 15.216666666666669),
	(5, 20, 24, 'm', 'F_I', '', 19.066666666666666, 16.866666666666667, 14.666666666666668),
	(5, 25, 29, 'm', 'F_I', '', 19.433333333333337, 17.233333333333334, 15.033333333333333),
	(5, 30, 34, 'm', 'F_I', '', 20.35, 18.15, 15.950000000000001),
	(5, 35, 39, 'm', 'F_I', '', 21.816666666666663, 19.066666666666666, 16.5),
	(5, 40, 44, 'm', 'F_I', '', 23.099999999999998, 20.35, 17.416666666666668),
	(5, 45, 49, 'm', 'F_I', '', 24.383333333333333, 21.45, 18.15),
	(5, 50, 54, 'm', 'F_I', '', 25.666666666666664, 22.366666666666664, 19.066666666666666),
	(5, 55, 59, 'm', 'F_I', '', 26.216666666666665, 22.916666666666668, 19.616666666666667),
	(5, 60, 64, 'm', 'F_I', '', 26.95, 23.650000000000002, 20.35),
	(5, 65, 69, 'm', 'F_I', '', 27.5, 24.200000000000003, 20.9),
	(5, 70, 74, 'm', 'F_I', '', 27.866666666666667, 24.566666666666666, 21.266666666666666),
	(5, 75, 79, 'm', 'F_I', '', 28.599999999999998, 25.3, 22.0),
	(5, 80, 84, 'm', 'F_I', '', 29.15, 25.85, 22.549999999999997),
	(5, 85, 89, 'm', 'F_I', '', 30.249999999999996, 26.95, 23.650000000000002),
	(5, 90, 200, 'm', 'F_I', '', 32.81666666666667, 29.516666666666666, 26.216666666666665),
	(6, 18, 19, 'w', 'F_I', '', 93.13333333333333, 86.53333333333332, 79.93333333333334),
	(6, 20, 24, 'w', 'F_I', '', 91.85000000000001, 84.51666666666667, 78.65),
	(6, 25, 29, 'w', 'F_I', '', 91.85000000000001, 84.51666666666667, 78.10000000000001),
	(6, 30, 34, 'w', 'F_I', '', 92.58333333333333, 85.80000000000001, 78.46666666666667),
	(6, 35, 39, 'w', 'F_I', '', 96.43333333333334, 87.44999999999999, 78.65),
	(6, 40, 44, 'w', 'F_I', '', 100.46666666666667, 89.46666666666667, 78.83333333333333),
	(6, 45, 49, 'w', 'F_I', '', 104.86666666666666, 91.48333333333335, 80.11666666666666),
	(6, 50, 54, 'w', 'F_I', '', 107.43333333333334, 94.05, 81.39999999999999),
	(6, 55, 59, 'w', 'F_I', '', 110.18333333333334, 96.98333333333333, 83.78333333333333),
	(6, 60, 64, 'w', 'F_I', '', 113.11666666666666, 99.91666666666666, 86.71666666666668),
	(6, 65, 69, 'w', 'F_I', '', 116.23333333333333, 103.03333333333333, 89.83333333333333),
	(6, 70, 74, 'w', 'F_I', '', 120.44999999999999, 107.25000000000001, 94.05),
	(6, 75, 79, 'w', 'F_I', '', 126.86666666666666, 113.66666666666667, 100.46666666666667),
	(6, 80, 84, 'w', 'F_I', '', 134.56666666666666, 121.36666666666666, 108.16666666666666),
	(6, 85, 89, 'w', 'F_I', '', 142.08333333333334, 128.88333333333333, 115.68333333333332),
	(6, 90, 200, 'w', 'F_I', '', 150.15, 136.95, 123.75),
	(6, 18, 19, 'm', 'F_I', '', 69.66666666666667, 63.06666666666666, 56.46666666666667),
	(6, 20, 24, 'm', 'F_I', '', 68.75, 62.150000000000006, 55.0),
	(6, 25, 29, 'm', 'F_I', '', 72.6, 65.26666666666667, 57.199999999999996),
	(6, 30, 34, 'm', 'F_I', '', 76.63333333333333, 67.28333333333333, 60.31666666666666),
	(6, 35, 39, 'm', 'F_I', '', 81.58333333333333, 72.05, 62.51666666666667),
	(6, 40, 44, 'm', 'F_I', '', 86.71666666666668, 76.44999999999999, 66.18333333333334),
	(6, 45, 49, 'm', 'F_I', '', 92.03333333333333, 80.48333333333335, 69.85000000000001),
	(6, 50, 54, 'm', 'F_I', '', 97.16666666666666, 84.33333333333334, 72.05),
	(6, 55, 59, 'm', 'F_I', '', 100.65, 87.63333333333333, 74.43333333333334),
	(6, 60, 64, 'm', 'F_I', '', 104.13333333333333, 90.93333333333334, 77.73333333333333),
	(6, 65, 69, 'm', 'F_I', '', 107.80000000000001, 94.6, 81.39999999999999),
	(6, 70, 74, 'm', 'F_I', '', 112.38333333333334, 99.18333333333334, 85.98333333333333),
	(6, 75, 79, 'm', 'F_I', '', 118.06666666666668, 104.86666666666666, 91.66666666666667),
	(6, 80, 84, 'm', 'F_I', '', 124.48333333333335, 111.28333333333333, 98.08333333333333),
	(6, 85, 89, 'm', 'F_I', '', 132.18333333333337, 118.98333333333333, 105.78333333333333),
	(6, 90, 200, 'm', 'F_I', '', 140.4333333333333, 127.23333333333333, 114.03333333333333),
	(7, 0, 7, 'w', 'F_I', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'F_I', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'F_I', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'F_I', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'F_I', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'F_I', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'F_I', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'F_I', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'F_I', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'F_I', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'F_I', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'F_I', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'F_I', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'F_I', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'F_I', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'F_I', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'F_I', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'F_I', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'F_I', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'F_I', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'F_I', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'F_I', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'F_I', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'F_I', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'F_I', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'F_I', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'F_I', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'F_I', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'F_I', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'F_I', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'F_I', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'F_I', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'F_I', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'F_I', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'F_I', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'F_I', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'F_I', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'F_I', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'F_I', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'F_I', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'F_I', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'F_I', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'F_I', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'F_I', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'F_I', '7,5 km', 72.98333333333333, 69.30000000000001, 65.10000000000001),
	(8, 20, 24, 'w', 'F_I', '7,5 km', 69.83333333333333, 66.15, 62.483333333333334),
	(8, 25, 29, 'w', 'F_I', '7,5 km', 70.35, 66.68333333333332, 63.0),
	(8, 30, 34, 'w', 'F_I', '7,5 km', 70.88333333333334, 67.2, 63.43333333333333),
	(8, 35, 39, 'w', 'F_I', '7,5 km', 73.5, 68.25000000000001, 63.78333333333333),
	(8, 40, 44, 'w', 'F_I', '7,5 km', 76.65, 70.35, 64.05),
	(8, 45, 49, 'w', 'F_I', '7,5 km', 79.28333333333333, 72.44999999999999, 65.10000000000001),
	(8, 50, 54, 'w', 'F_I', '7,5 km', 81.9, 74.55, 67.2),
	(8, 55, 59, 'w', 'F_I', '7,5 km', 84.0, 76.65, 69.30000000000001),
	(8, 60, 64, 'w', 'F_I', '7,5 km', 86.63333333333333, 78.23333333333333, 70.88333333333334),
	(8, 65, 69, 'w', 'F_I', '7,5 km', 88.46666666666667, 80.33333333333334, 73.5),
	(8, 70, 74, 'w', 'F_I', '7,5 km', 92.66666666666667, 82.94999999999999, 75.6),
	(8, 75, 79, 'w', 'F_I', '7,5 km', 97.13333333333333, 85.58333333333333, 78.23333333333333),
	(8, 80, 84, 'w', 'F_I', '7,5 km', 103.41666666666667, 89.51666666666667, 81.38333333333334),
	(8, 85, 89, 'w', 'F_I', '7,5 km', 109.2, 94.85000000000001, 86.10000000000001),
	(8, 90, 200, 'w', 'F_I', '7,5 km', 115.85000000000001, 100.80000000000001, 91.35),
	(8, 18, 19, 'm', 'F_I', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 20, 24, 'm', 'F_I', '7,5 km', 59.849999999999994, 55.65, 51.45),
	(8, 25, 29, 'm', 'F_I', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 30, 34, 'm', 'F_I', '7,5 km', 65.63333333333333, 59.849999999999994, 53.55),
	(8, 35, 39, 'm', 'F_I', '7,5 km', 68.25000000000001, 61.43333333333333, 56.18333333333333),
	(8, 40, 44, 'm', 'F_I', '7,5 km', 69.30000000000001, 63.53333333333333, 56.7),
	(8, 45, 49, 'm', 'F_I', '7,5 km', 71.93333333333334, 65.63333333333333, 57.75000000000001),
	(8, 50, 54, 'm', 'F_I', '7,5 km', 74.55, 67.2, 60.383333333333326),
	(8, 55, 59, 'm', 'F_I', '7,5 km', 76.65, 68.25000000000001, 61.95),
	(8, 60, 64, 'm', 'F_I', '7,5 km', 79.53333333333332, 70.88333333333334, 63.53333333333333),
	(8, 65, 69, 'm', 'F_I', '7,5 km', 82.08333333333333, 72.98333333333333, 65.10000000000001),
	(8, 70, 74, 'm', 'F_I', '7,5 km', 85.58333333333333, 75.6, 68.25000000000001),
	(8, 75, 79, 'm', 'F_I', '7,5 km', 90.46666666666667, 79.53333333333332, 75.6),
	(8, 80, 84, 'm', 'F_I', '7,5 km', 96.06666666666668, 83.73333333333333, 75.6),
	(8, 85, 89, 'm', 'F_I', '7,5 km', 100.80000000000001, 88.46666666666667, 79.28333333333333),
	(8, 90, 200, 'm', 'F_I', '7,5 km', 107.88333333333334, 93.80000000000001, 84.0),
	(10, 0, 7, 'w', 'F_I', '', 5.4, 8.1, 10.8),
	(10, 8, 9, 'w', 'F_I', '', 8.1, 10.8, 13.5),
	(10, 10, 11, 'w', 'F_I', '', 9.9, 13.5, 16.2),
	(10, 0, 7, 'm', 'F_I', '', 10.8, 13.5, 15.3),
	(10, 8, 9, 'm', 'F_I', '', 15.3, 18.0, 20.7),
	(10, 10, 11, 'm', 'F_I', '', 18.9, 22.5, 25.2),
	(11, 12, 13, 'w', 'F_I', '', 13.5, 16.2, 19.8),
	(11, 14, 15, 'w', 'F_I', '', 18.0, 21.6, 24.3),
	(11, 16, 17, 'w', 'F_I', '', 21.6, 24.3, 27.9),
	(11, 12, 13, 'm', 'F_I', '', 23.4, 27.0, 29.7),
	(11, 14, 15, 'm', 'F_I', '', 27.0, 30.6, 33.3),
	(11, 16, 17, 'm', 'F_I', '', 30.6, 34.2, 37.8),
	(12, 0, 7, 'w', 'F_I', '1 kg', 3.75, 4.2, 4.88),
	(12, 8, 9, 'w', 'F_I', '1 kg', 4.25, 4.7, 5.38),
	(12, 10, 11, 'w', 'F_I', '1 kg', 4.75, 5.2, 5.88),
	(12, 12, 13, 'w', 'F_I', '1 kg', 5.25, 5.7, 6.38),
	(12, 14, 15, 'w', 'F_I', '1 kg', 5.75, 6.2, 6.88),
	(12, 16, 17, 'w', 'F_I', '1 kg', 6.25, 6.7, 7.38),
	(12, 18, 19, 'w', 'F_I', '2 kg', 6.75, 7.2, 7.88),
	(12, 20, 24, 'w', 'F_I', '2 kg', 6.75, 7.2, 7.88),
	(12, 25, 29, 'w', 'F_I', '2 kg', 6.3, 6.98, 7.65),
	(12, 30, 34, 'w', 'F_I', '2 kg', 5.85, 6.75, 7.65),
	(12, 35, 39, 'w', 'F_I', '2 kg', 5.4, 6.53, 7.43),
	(12, 40, 44, 'w', 'F_I', '2 kg', 4.73, 6.08, 7.43),
	(12, 45, 49, 'w', 'F_I', '2 kg', 4.28, 5.85, 7.2),
	(12, 50, 54, 'w', 'F_I', '2 kg', 3.83, 5.4, 6.98),
	(12, 55, 59, 'w', 'F_I', '2 kg', 3.6, 5.18, 6.75),
	(12, 60, 64, 'w', 'F_I', '2 kg', 3.38, 4.95, 6.53),
	(12, 65, 69, 'w', 'F_I', '2 kg', 3.15, 4.73, 6.3),
	(12, 70, 74, 'w', 'F_I', '2 kg', 2.93, 4.5, 6.08),
	(12, 75, 79, 'w', 'F_I', '2 kg', 2.93, 4.28, 5.85),
	(12, 80, 84, 'w', 'F_I', '2 kg', 2.7, 4.28, 5.63),
	(12, 85, 89, 'w', 'F_I', '2 kg', 2.7, 4.05, 5.4),
	(12, 90, 200, 'w', 'F_I', '2 kg', 2.48, 3.83, 4.95),
	(12, 0, 7, 'm', 'F_I', '1 kg', 6.23, 6.9, 7.58),
	(12, 8, 9, 'm', 'F_I', '1 kg', 6.73, 7.4, 8.08),
	(12, 10, 11, 'm', 'F_I', '1 kg', 7.23, 7.9, 8.58),
	(12, 12, 13, 'm', 'F_I', '1 kg', 7.73, 8.4, 9.08),
	(12, 14, 15, 'm', 'F_I', '1 kg', 8.23, 8.9, 9.58),
	(12, 16, 17, 'm', 'F_I', '1 kg', 8.73, 9.4, 10.08),
	(12, 18, 19, 'm', 'F_I', '2 kg', 9.23, 9.9, 10.58),
	(12, 20, 24, 'm', 'F_I', '2 kg', 9.23, 10.13, 10.8),
	(12, 25, 29, 'm', 'F_I', '2 kg', 8.78, 9.68, 10.58),
	(12, 30, 34, 'm', 'F_I', '2 kg', 8.1, 9.23, 10.35),
	(12, 35, 39, 'm', 'F_I', '2 kg', 7.43, 8.78, 10.13),
	(12, 40, 44, 'm', 'F_I', '2 kg', 6.98, 8.33, 9.68),
	(12, 45, 49, 'm', 'F_I', '2 kg', 6.3, 7.88, 9.45),
	(12, 50, 54, 'm', 'F_I', '2 kg', 5.85, 7.65, 9.23),
	(12, 55, 59, 'm', 'F_I', '2 kg', 5.4, 7.43, 9.0),
	(12, 60, 64, 'm', 'F_I', '2 kg', 5.18, 6.98, 8.78),
	(12, 65, 69, 'm', 'F_I', '2 kg', 4.73, 6.53, 8.33),
	(12, 70, 74, 'm', 'F_I', '2 kg', 4.5, 6.3, 8.1),
	(12, 75, 79, 'm', 'F_I', '2 kg', 4.05, 5.85, 7.65),
	(12, 80, 84, 'm', 'F_I', '2 kg', 3.83, 5.63, 7.43),
	(12, 85, 89, 'm', 'F_I', '2 kg', 3.6, 5.4, 7.2),
	(12, 90, 200, 'm', 'F_I', '2 kg', 3.15, 4.95, 6.75),
	(13, 12, 13, 'w', 'F_I', '2 kg', 4.04, 4.46, 4.89),
	(13, 14, 15, 'w', 'F_I', '3 kg', 4.68, 5.1, 5.53),
	(13, 16, 17, 'w', 'F_I', '3 kg', 4.89, 5.31, 5.74),
	(13, 18, 19, 'w', 'F_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 20, 24, 'w', 'F_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 25, 29, 'w', 'F_I', '4 kg', 6.18, 6.65, 7.13),
	(13, 30, 34, 'w', 'F_I', '4 kg', 5.94, 6.41, 6.89),
	(13, 35, 39, 'w', 'F_I', '4 kg', 5.7, 6.18, 6.65),
	(13, 40, 44, 'w', 'F_I', '4 kg', 5.23, 5.7, 6.18),
	(13, 45, 49, 'w', 'F_I', '4 kg', 4.99, 5.46, 5.94),
	(13, 50, 54, 'w', 'F_I', '3 kg', 4.99, 5.7, 6.65),
	(13, 55, 59, 'w', 'F_I', '3 kg', 4.75, 5.46, 6.18),
	(13, 60, 64, 'w', 'F_I', '3 kg', 4.51, 5.23, 5.94),
	(13, 65, 69, 'w', 'F_I', '3 kg', 4.28, 4.99, 5.94),
	(13, 70, 74, 'w', 'F_I', '3 kg', 4.04, 4.75, 5.7),
	(13, 75, 79, 'w', 'F_I', '2 kg', 4.04, 4.99, 5.94),
	(13, 80, 84, 'w', 'F_I', '2 kg', 3.8, 4.75, 5.46),
	(13, 85, 89, 'w', 'F_I', '2 kg', 3.56, 4.28, 5.23),
	(13, 90, 200, 'w', 'F_I', '2 kg', 3.09, 4.04, 4.75),
	(13, 12, 13, 'm', 'F_I', '3 kg', 5.31, 5.74, 6.16),
	(13, 14, 15, 'm', 'F_I', '4 kg', 5.95, 6.38, 6.8),
	(13, 16, 17, 'm', 'F_I', '5 kg', 6.38, 6.8, 7.23),
	(13, 18, 19, 'm', 'F_I', '6 kg', 7.36, 7.84, 8.31),
	(13, 20, 24, 'm', 'F_I', '7,26 kg', 7.36, 8.08, 8.55),
	(13, 25, 29, 'm', 'F_I', '7,26 kg', 7.13, 7.84, 8.31),
	(13, 30, 34, 'm', 'F_I', '7,26 kg', 6.65, 7.36, 7.84),
	(13, 35, 39, 'm', 'F_I', '7,26 kg', 6.41, 6.89, 7.6),
	(13, 40, 44, 'm', 'F_I', '7,26 kg', 5.94, 6.65, 7.36),
	(13, 45, 49, 'm', 'F_I', '7,26 kg', 5.7, 6.41, 7.13),
	(13, 50, 54, 'm', 'F_I', '6 kg', 5.94, 6.65, 7.6),
	(13, 55, 59, 'm', 'F_I', '6 kg', 5.7, 6.41, 7.13),
	(13, 60, 64, 'm', 'F_I', '5 kg', 5.7, 6.65, 7.6),
	(13, 65, 69, 'm', 'F_I', '5 kg', 5.46, 6.41, 7.13),
	(13, 70, 74, 'm', 'F_I', '4 kg', 5.7, 6.41, 7.36),
	(13, 75, 79, 'm', 'F_I', '4 kg', 5.46, 6.18, 7.13),
	(13, 80, 84, 'm', 'F_I', '3 kg', 5.23, 5.94, 6.89),
	(13, 85, 89, 'm', 'F_I', '3 kg', 4.75, 5.7, 6.41),
	(13, 90, 200, 'm', 'F_I', '3 kg', 4.28, 4.99, 5.94),
	(15, 0, 7, 'w', 'F_I', '', 0.95, 1.13, 1.26),
	(15, 8, 9, 'w', 'F_I', '', 1.04, 1.17, 1.35),
	(15, 10, 11, 'w', 'F_I', '', 1.17, 1.31, 1.49),
	(15, 12, 13, 'w', 'F_I', '', 1.26, 1.44, 1.62),
	(15, 14, 15, 'w', 'F_I', '', 1.4, 1.53, 1.71),
	(15, 16, 17, 'w', 'F_I', '', 1.49, 1.62, 1.8),
	(15, 18, 19, 'w', 'F_I', '', 1.49, 1.67, 1.85),
	(15, 20, 24, 'w', 'F_I', '', 1.44, 1.62, 1.8),
	(15, 25, 29, 'w', 'F_I', '', 1.35, 1.53, 1.76),
	(15, 30, 34, 'w', 'F_I', '', 1.22, 1.44, 1.67),
	(15, 35, 39, 'w', 'F_I', '', 1.13, 1.35, 1.62),
	(15, 40, 44, 'w', 'F_I', '', 1.04, 1.26, 1.49),
	(15, 45, 49, 'w', 'F_I', '', 0.99, 1.22, 1.44),
	(15, 50, 54, 'w', 'F_I', '', 0.9, 1.17, 1.4),
	(15, 55, 59, 'w', 'F_I', '', 0.86, 1.08, 1.31),
	(15, 60, 64, 'w', 'F_I', '', 0.86, 1.08, 1.31),
	(15, 65, 69, 'w', 'F_I', '', 0.81, 1.04, 1.26),
	(15, 70, 74, 'w', 'F_I', '', 0.81, 1.04, 1.22),
	(15, 75, 79, 'w', 'F_I', '', 0.81, 1.04, 1.22),
	(15, 80, 84, 'w', 'F_I', '', 0.81, 0.99, 1.17),
	(15, 85, 89, 'w', 'F_I', '', 0.77, 0.95, 1.13),
	(15, 90, 200, 'w', 'F_I', '', 0.72, 0.9, 1.08),
	(15, 0, 7, 'm', 'F_I', '', 1.04, 1.22, 1.35),
	(15, 8, 9, 'm', 'F_I', '', 1.17, 1.35, 1.49),
	(15, 10, 11, 'm', 'F_I', '', 1.35, 1.53, 1.67),
	(15, 12, 13, 'm', 'F_I', '', 1.53, 1.71, 1.85),
	(15, 14, 15, 'm', 'F_I', '', 1.71, 1.85, 2.03),
	(15, 16, 17, 'm', 'F_I', '', 1.85, 1.98, 2.16),
	(15, 18, 19, 'm', 'F_I', '', 1.89, 2.07, 2.25),
	(15, 20, 24, 'm', 'F_I', '', 1.89, 2.07, 2.25),
	(15, 25, 29, 'm', 'F_I', '', 1.85, 2.03, 2.21),
	(15, 30, 34, 'm', 'F_I', '', 1.67, 1.89, 2.12),
	(15, 35, 39, 'm', 'F_I', '', 1.49, 1.76, 2.03),
	(15, 40, 44, 'm', 'F_I', '', 1.4, 1.67, 1.94),
	(15, 45, 49, 'm', 'F_I', '', 1.31, 1.58, 1.85),
	(15, 50, 54, 'm', 'F_I', '', 1.26, 1.53, 1.8),
	(15, 55, 59, 'm', 'F_I', '', 1.22, 1.49, 1.76),
	(15, 60, 64, 'm', 'F_I', '', 1.17, 1.44, 1.71),
	(15, 65, 69, 'm', 'F_I', '', 1.17, 1.44, 1.71),
	(15, 70, 74, 'm', 'F_I', '', 1.13, 1.4, 1.67),
	(15, 75, 79, 'm', 'F_I', '', 1.08, 1.35, 1.62),
	(15, 80, 84, 'm', 'F_I', '', 1.04, 1.31, 1.58),
	(15, 85, 89, 'm', 'F_I', '', 0.9, 1.17, 1.44),
	(15, 90, 200, 'm', 'F_I', '', 0.81, 1.08, 1.35),
	(17, 0, 7, 'w', 'F_I', '30 m', 8.8, 7.8, 6.9),
	(17, 8, 9, 'w', 'F_I', '30 m', 8.1, 7.3, 6.3),
	(17, 10, 11, 'w', 'F_I', '50 m', 12.1, 11.1, 10.0),
	(17, 12, 13, 'w', 'F_I', '50 m', 11.7, 10.6, 9.4),
	(17, 14, 15, 'w', 'F_I', '100 m', 20.5, 18.7, 17.1),
	(17, 16, 17, 'w', 'F_I', '100 m', 19.4, 17.9, 16.5),
	(17, 18, 19, 'w', 'F_I', '100 m', 20.0, 18.2, 16.8),
	(17, 20, 24, 'w', 'F_I', '100 m', 20.4, 18.5, 17.2),
	(17, 25, 29, 'w', 'F_I', '100 m', 20.8, 18.9, 17.6),
	(17, 30, 34, 'w', 'F_I', '100 m', 21.6, 19.6, 18.0),
	(17, 35, 39, 'w', 'F_I', '100 m', 22.4, 20.5, 18.7),
	(17, 40, 44, 'w', 'F_I', '50 m', 12.1, 10.9, 9.7),
	(17, 45, 49, 'w', 'F_I', '50 m', 12.7, 11.3, 10.0),
	(17, 50, 54, 'w', 'F_I', '50 m', 13.1, 11.8, 10.5),
	(17, 55, 59, 'w', 'F_I', '50 m', 13.6, 12.3, 10.9),
	(17, 60, 64, 'w', 'F_I', '50 m', 13.9, 12.5, 11.2),
	(17, 65, 69, 'w', 'F_I', '50 m', 14.1, 12.8, 11.4),
	(17, 70, 74, 'w', 'F_I', '50 m', 14.3, 13.0, 11.7),
	(17, 75, 79, 'w', 'F_I', '50 m', 14.9, 13.5, 12.2),
	(17, 80, 84, 'w', 'F_I', '50 m', 15.7, 14.4, 13.2),
	(17, 85, 89, 'w', 'F_I', '50 m', 17.1, 15.7, 14.5),
	(17, 90, 200, 'w', 'F_I', '50 m', 18.8, 17.5, 16.3),
	(17, 0, 7, 'm', 'F_I', '30 m', 8.5, 7.5, 6.6),
	(17, 8, 9, 'm', 'F_I', '30 m', 7.9, 7.0, 6.3),
	(17, 10, 11, 'm', 'F_I', '50 m', 11.3, 10.2, 9.2),
	(17, 12, 13, 'm', 'F_I', '50 m', 10.7, 9.8, 8.9),
	(17, 14, 15, 'm', 'F_I', '100 m', 18.7, 16.9, 15.5),
	(17, 16, 17, 'm', 'F_I', '100 m', 17.9, 16.3, 14.9),
	(17, 18, 19, 'm', 'F_I', '100 m', 17.6, 16.1, 14.5),
	(17, 20, 24, 'm', 'F_I', '100 m', 17.4, 15.8, 14.3),
	(17, 25, 29, 'm', 'F_I', '100 m', 17.9, 16.3, 14.6),
	(17, 30, 34, 'm', 'F_I', '100 m', 18.5, 16.6, 15.0),
	(17, 35, 39, 'm', 'F_I', '100 m', 19.4, 17.5, 15.6),
	(17, 40, 44, 'm', 'F_I', '50 m', 10.6, 9.6, 8.5),
	(17, 45, 49, 'm', 'F_I', '50 m', 11.0, 9.8, 8.7),
	(17, 50, 54, 'm', 'F_I', '50 m', 11.3, 10.0, 9.0),
	(17, 55, 59, 'm', 'F_I', '50 m', 11.6, 10.3, 9.4),
	(17, 60, 64, 'm', 'F_I', '50 m', 11.9, 10.7, 9.7),
	(17, 65, 69, 'm', 'F_I', '50 m', 12.3, 11.2, 10.0),
	(17, 70, 74, 'm', 'F_I', '50 m', 12.9, 11.8, 10.6),
	(17, 75, 79, 'm', 'F_I', '50 m', 13.4, 12.3, 11.1),
	(17, 80, 84, 'm', 'F_I', '50 m', 14.3, 13.2, 12.0),
	(17, 85, 89, 'm', 'F_I', '50 m', 15.5, 14.4, 13.2),
	(17, 90, 200, 'm', 'F_I', '50 m', 17.1, 16.0, 14.7),
	(18, 0, 7, 'w', 'F_I', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'F_I', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'F_I', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'F_I', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'F_I', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'F_I', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'F_I', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'F_I', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'F_I', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'F_I', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'F_I', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'F_I', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'F_I', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'F_I', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'F_I', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'F_I', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'F_I', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'F_I', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'F_I', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'F_I', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'F_I', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'F_I', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'F_I', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'F_I', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'F_I', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'F_I', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'F_I', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'F_I', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'F_I', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'F_I', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'F_I', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'F_I', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'F_I', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'F_I', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'F_I', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'F_I', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'F_I', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'F_I', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'F_I', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'F_I', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'F_I', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'F_I', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'F_I', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'F_I', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'F_I', 'Tandem', 45.1, 39.6, 34.1),
	(19, 10, 11, 'w', 'F_I', 'Tandem', 40.7, 35.2, 29.7),
	(19, 12, 13, 'w', 'F_I', 'Tandem', 34.1, 29.7, 25.9),
	(19, 14, 15, 'w', 'F_I', 'Tandem', 29.7, 27.0, 23.7),
	(19, 16, 17, 'w', 'F_I', 'Tandem', 27.5, 24.8, 22.0),
	(19, 18, 19, 'w', 'F_I', 'Tandem', 26.4, 24.2, 21.5),
	(19, 20, 24, 'w', 'F_I', 'Tandem', 27.0, 24.2, 21.5),
	(19, 25, 29, 'w', 'F_I', 'Tandem', 27.5, 24.8, 22.0),
	(19, 30, 34, 'w', 'F_I', 'Tandem', 28.6, 25.9, 23.7),
	(19, 35, 39, 'w', 'F_I', 'Tandem', 30.3, 27.0, 24.2),
	(19, 40, 44, 'w', 'F_I', 'Tandem', 31.9, 28.1, 24.8),
	(19, 45, 49, 'w', 'F_I', 'Tandem', 33.6, 29.7, 25.3),
	(19, 50, 54, 'w', 'F_I', 'Tandem', 35.2, 30.8, 25.9),
	(19, 55, 59, 'w', 'F_I', 'Tandem', 36.9, 31.9, 26.4),
	(19, 60, 64, 'w', 'F_I', 'Tandem', 38.5, 33.0, 27.5),
	(19, 65, 69, 'w', 'F_I', 'Tandem', 39.6, 34.1, 28.1),
	(19, 70, 74, 'w', 'F_I', 'Tandem', 41.8, 35.2, 29.2),
	(19, 75, 79, 'w', 'F_I', 'Tandem', 42.9, 36.3, 30.3),
	(19, 80, 84, 'w', 'F_I', 'Tandem', 44.6, 38.0, 31.4),
	(19, 85, 89, 'w', 'F_I', 'Tandem', 46.2, 39.6, 33.0),
	(19, 90, 200, 'w', 'F_I', 'Tandem', 49.0, 41.8, 34.7),
	(19, 8, 9, 'm', 'F_I', 'Tandem', 41.8, 36.3, 30.8),
	(19, 10, 11, 'm', 'F_I', 'Tandem', 38.5, 33.6, 28.6),
	(19, 12, 13, 'm', 'F_I', 'Tandem', 32.5, 28.6, 24.8),
	(19, 14, 15, 'm', 'F_I', 'Tandem', 26.4, 23.7, 20.9),
	(19, 16, 17, 'm', 'F_I', 'Tandem', 24.2, 21.5, 18.7),
	(19, 18, 19, 'm', 'F_I', 'Tandem', 22.6, 19.8, 17.1),
	(19, 20, 24, 'm', 'F_I', 'Tandem', 22.0, 19.3, 16.5),
	(19, 25, 29, 'm', 'F_I', 'Tandem', 23.1, 19.8, 16.5),
	(19, 30, 34, 'm', 'F_I', 'Tandem', 24.8, 20.4, 16.5),
	(19, 35, 39, 'm', 'F_I', 'Tandem', 26.4, 22.0, 17.1),
	(19, 40, 44, 'm', 'F_I', 'Tandem', 29.2, 23.7, 18.2),
	(19, 45, 49, 'm', 'F_I', 'Tandem', 31.4, 25.3, 18.7),
	(19, 50, 54, 'm', 'F_I', 'Tandem', 33.0, 26.4, 19.8),
	(19, 55, 59, 'm', 'F_I', 'Tandem', 35.2, 27.5, 20.4),
	(19, 60, 64, 'm', 'F_I', 'Tandem', 36.9, 28.6, 20.9),
	(19, 65, 69, 'm', 'F_I', 'Tandem', 38.5, 29.7, 21.5),
	(19, 70, 74, 'm', 'F_I', 'Tandem', 39.6, 31.4, 22.0),
	(19, 75, 79, 'm', 'F_I', 'Tandem', 41.3, 32.5, 23.7),
	(19, 80, 84, 'm', 'F_I', 'Tandem', 42.9, 34.7, 25.3),
	(19, 85, 89, 'm', 'F_I', 'Tandem', 45.1, 36.3, 27.0),
	(19, 90, 200, 'm', 'F_I', 'Tandem', 47.9, 39.1, 29.7),
	(21, 10, 11, 'w', 'F_I', 'aus dem Stand', 0.64, 0.72, 0.8),
	(21, 12, 13, 'w', 'F_I', 'aus dem Stand', 0.72, 0.8, 0.88),
	(21, 14, 15, 'w', 'F_I', 'aus dem Stand', 0.76, 0.84, 0.92),
	(21, 16, 17, 'w', 'F_I', 'aus dem Stand', 0.84, 0.92, 1.0),
	(21, 18, 19, 'w', 'F_I', 'aus dem Stand', 0.88, 0.96, 1.04),
	(21, 20, 24, 'w', 'F_I', 'aus dem Stand', 0.88, 0.96, 1.04),
	(21, 25, 29, 'w', 'F_I', 'aus dem Stand', 0.84, 0.92, 1.0),
	(21, 30, 34, 'w', 'F_I', 'aus dem Stand', 0.8, 0.88, 0.96),
	(21, 35, 39, 'w', 'F_I', 'aus dem Stand', 0.76, 0.84, 0.92),
	(21, 40, 44, 'w', 'F_I', 'aus dem Stand', 0.72, 0.8, 0.88),
	(21, 45, 49, 'w', 'F_I', 'aus dem Stand', 0.72, 0.8, 0.88),
	(21, 50, 54, 'w', 'F_I', 'aus dem Stand', 0.68, 0.76, 0.84),
	(21, 55, 59, 'w', 'F_I', 'aus dem Stand', 0.64, 0.72, 0.8),
	(21, 60, 64, 'w', 'F_I', 'aus dem Stand', 0.6, 0.68, 0.76),
	(21, 65, 69, 'w', 'F_I', 'aus dem Stand', 0.6, 0.68, 0.76),
	(21, 70, 74, 'w', 'F_I', 'aus dem Stand', 0.56, 0.64, 0.72),
	(21, 75, 79, 'w', 'F_I', 'aus dem Stand', 0.52, 0.6, 0.68),
	(21, 80, 84, 'w', 'F_I', 'aus dem Stand', 0.52, 0.6, 0.68),
	(21, 85, 89, 'w', 'F_I', 'aus dem Stand', 0.48, 0.56, 0.64),
	(21, 90, 200, 'w', 'F_I', 'aus dem Stand', 0.44, 0.48, 0.52),
	(21, 10, 11, 'm', 'F_I', 'aus dem Stand', 0.68, 0.76, 0.84),
	(21, 12, 13, 'm', 'F_I', 'aus dem Stand', 0.76, 0.84, 0.92),
	(21, 14, 15, 'm', 'F_I', 'aus dem Stand', 0.88, 0.96, 1.04),
	(21, 16, 17, 'm', 'F_I', 'aus dem Stand', 0.96, 1.04, 1.12),
	(21, 18, 19, 'm', 'F_I', 'aus dem Stand', 1.04, 1.12, 1.2),
	(21, 20, 24, 'm', 'F_I', 'aus dem Stand', 1.08, 1.16, 1.24),
	(21, 25, 29, 'm', 'F_I', 'aus dem Stand', 1.04, 1.12, 1.2),
	(21, 30, 34, 'm', 'F_I', 'aus dem Stand', 1.04, 1.12, 1.2),
	(21, 35, 39, 'm', 'F_I', 'aus dem Stand', 1.0, 1.08, 1.16),
	(21, 40, 44, 'm', 'F_I', 'aus dem Stand', 0.96, 1.04, 1.12),
	(21, 45, 49, 'm', 'F_I', 'aus dem Stand', 0.92, 1.0, 1.08),
	(21, 50, 54, 'm', 'F_I', 'aus dem Stand', 0.84, 0.92, 1.0),
	(21, 55, 59, 'm', 'F_I', 'aus dem Stand', 0.8, 0.88, 0.96),
	(21, 60, 64, 'm', 'F_I', 'aus dem Stand', 0.76, 0.84, 0.92),
	(21, 65, 69, 'm', 'F_I', 'aus dem Stand', 0.68, 0.8, 0.88),
	(21, 70, 74, 'm', 'F_I', 'aus dem Stand', 0.64, 0.76, 0.84),
	(21, 75, 79, 'm', 'F_I', 'aus dem Stand', 0.6, 0.72, 0.8),
	(21, 80, 84, 'm', 'F_I', 'aus dem Stand', 0.6, 0.68, 0.76),
	(21, 85, 89, 'm', 'F_I', 'aus dem Stand', 0.56, 0.64, 0.72),
	(21, 90, 200, 'm', 'F_I', 'aus dem Stand', 0.52, 0.6, 0.68),
	(23, 0, 7, 'w', 'F_I', 'aus der Absprungfläche', 1.44, 1.68, 1.92),
	(23, 8, 9, 'w', 'F_I', 'aus der Absprungfläche', 1.64, 1.88, 2.12),
	(23, 10, 11, 'w', 'F_I', 'aus der Absprungfläche', 1.84, 2.08, 2.32),
	(23, 12, 13, 'w', 'F_I', 'aus der Absprungfläche', 2.24, 2.48, 2.72),
	(23, 14, 15, 'w', 'F_I', 'aus der Absprungfläche', 2.56, 2.8, 3.04),
	(23, 16, 17, 'w', 'F_I', 'aus der Absprungfläche', 2.72, 2.96, 3.2),
	(23, 18, 19, 'w', 'F_I', 'aus der Absprungfläche', 2.72, 2.96, 3.2),
	(23, 20, 24, 'w', 'F_I', 'aus der Absprungfläche', 2.72, 2.96, 3.2),
	(23, 25, 29, 'w', 'F_I', 'aus der Absprungfläche', 2.64, 2.88, 3.12),
	(23, 30, 34, 'w', 'F_I', 'aus der Absprungfläche', 2.56, 2.8, 3.04),
	(23, 35, 39, 'w', 'F_I', 'aus der Absprungfläche', 2.48, 2.72, 2.96),
	(23, 40, 44, 'w', 'F_I', 'aus der Absprungfläche', 2.4, 2.64, 2.88),
	(23, 45, 49, 'w', 'F_I', 'aus der Absprungfläche', 2.24, 2.56, 2.8),
	(23, 50, 54, 'w', 'F_I', 'aus der Absprungfläche', 2.08, 2.4, 2.72),
	(23, 55, 59, 'w', 'F_I', 'aus der Absprungfläche', 2.0, 2.32, 2.64),
	(23, 60, 64, 'w', 'F_I', 'aus der Absprungfläche', 1.92, 2.24, 2.56),
	(23, 65, 69, 'w', 'F_I', 'aus der Absprungfläche', 1.84, 2.16, 2.48),
	(23, 70, 74, 'w', 'F_I', 'aus der Absprungfläche', 1.68, 2.0, 2.32),
	(23, 75, 79, 'w', 'F_I', 'aus der Absprungfläche', 1.44, 1.76, 2.08),
	(23, 80, 84, 'w', 'F_I', 'aus der Absprungfläche', 1.28, 1.6, 1.92),
	(23, 85, 89, 'w', 'F_I', 'aus der Absprungfläche', 1.04, 1.36, 1.68),
	(23, 90, 200, 'w', 'F_I', 'aus der Absprungfläche', 0.88, 1.2, 1.52),
	(23, 0, 7, 'm', 'F_I', 'aus der Absprungfläche', 1.68, 1.92, 2.16),
	(23, 8, 9, 'm', 'F_I', 'aus der Absprungfläche', 1.88, 2.12, 2.36),
	(23, 10, 11, 'm', 'F_I', 'aus der Absprungfläche', 2.08, 2.32, 2.56),
	(23, 12, 13, 'm', 'F_I', 'aus der Absprungfläche', 2.56, 2.8, 3.04),
	(23, 14, 15, 'm', 'F_I', 'aus der Absprungfläche', 3.04, 3.28, 3.52),
	(23, 16, 17, 'm', 'F_I', 'aus der Absprungfläche', 3.44, 3.68, 3.92),
	(23, 18, 19, 'm', 'F_I', 'aus der Absprungfläche', 3.6, 3.84, 4.08),
	(23, 20, 24, 'm', 'F_I', 'aus der Absprungfläche', 3.52, 3.76, 4.0),
	(23, 25, 29, 'm', 'F_I', 'aus der Absprungfläche', 3.44, 3.68, 3.92),
	(23, 30, 34, 'm', 'F_I', 'aus der Absprungfläche', 3.36, 3.6, 3.84),
	(23, 35, 39, 'm', 'F_I', 'aus der Absprungfläche', 3.28, 3.52, 3.76),
	(23, 40, 44, 'm', 'F_I', 'aus der Absprungfläche', 3.12, 3.44, 3.68),
	(23, 45, 49, 'm', 'F_I', 'aus der Absprungfläche', 2.96, 3.28, 3.6),
	(23, 50, 54, 'm', 'F_I', 'aus der Absprungfläche', 2.88, 3.2, 3.52),
	(23, 55, 59, 'm', 'F_I', 'aus der Absprungfläche', 2.72, 3.04, 3.36),
	(23, 60, 64, 'm', 'F_I', 'aus der Absprungfläche', 2.56, 2.88, 3.2),
	(23, 65, 69, 'm', 'F_I', 'aus der Absprungfläche', 2.32, 2.64, 2.96),
	(23, 70, 74, 'm', 'F_I', 'aus der Absprungfläche', 2.16, 2.48, 2.8),
	(23, 75, 79, 'm', 'F_I', 'aus der Absprungfläche', 1.92, 2.32, 2.64),
	(23, 80, 84, 'm', 'F_I', 'aus der Absprungfläche', 1.68, 2.08, 2.48),
	(23, 85, 89, 'm', 'F_I', 'aus der Absprungfläche', 1.52, 1.92, 2.32),
	(23, 90, 200, 'm', 'F_I', 'aus der Absprungfläche', 1.28, 1.68, 2.08),
	(25, 12, 13, 'w', 'F_I', '', 15.3, 17.55, 19.8),
	(25, 14, 15, 'w', 'F_I', '', 17.55, 20.25, 22.95),
	(25, 16, 17, 'w', 'F_I', '', 19.8, 22.5, 25.2),
	(25, 18, 19, 'w', 'F_I', '', 21.15, 23.85, 26.1),
	(25, 20, 24, 'w', 'F_I', '', 21.6, 24.3, 26.55),
	(25, 25, 29, 'w', 'F_I', '', 21.6, 24.3, 26.55),
	(25, 30, 34, 'w', 'F_I', '', 19.8, 22.5, 24.75),
	(25, 35, 39, 'w', 'F_I', '', 18.9, 21.6, 23.85),
	(25, 40, 44, 'w', 'F_I', '', 17.55, 20.25, 22.5),
	(25, 45, 49, 'w', 'F_I', '', 16.65, 19.35, 21.6),
	(25, 50, 54, 'w', 'F_I', '', 14.85, 18.0, 20.7),
	(25, 55, 59, 'w', 'F_I', '', 13.95, 17.1, 19.8),
	(25, 60, 64, 'w', 'F_I', '', 13.05, 16.2, 18.9),
	(25, 65, 69, 'w', 'F_I', '', 12.15, 15.3, 18.0),
	(25, 70, 74, 'w', 'F_I', '', 11.7, 14.85, 17.55),
	(25, 75, 79, 'w', 'F_I', '', 10.8, 13.95, 16.65),
	(25, 80, 84, 'w', 'F_I', '', 9.9, 13.05, 15.75),
	(25, 85, 89, 'w', 'F_I', '', 8.55, 11.7, 14.4),
	(25, 90, 200, 'w', 'F_I', '', 6.75, 9.9, 12.6),
	(25, 12, 13, 'm', 'F_I', '', 17.55, 21.6, 24.75),
	(25, 14, 15, 'm', 'F_I', '', 21.15, 25.2, 28.8),
	(25, 16, 17, 'm', 'F_I', '', 24.75, 28.8, 32.85),
	(25, 18, 19, 'm', 'F_I', '', 28.35, 32.4, 36.45),
	(25, 20, 24, 'm', 'F_I', '', 29.7, 34.2, 37.8),
	(25, 25, 29, 'm', 'F_I', '', 29.25, 33.75, 37.35),
	(25, 30, 34, 'm', 'F_I', '', 27.0, 31.5, 36.0),
	(25, 35, 39, 'm', 'F_I', '', 25.65, 30.15, 34.65),
	(25, 40, 44, 'm', 'F_I', '', 25.2, 29.7, 34.2),
	(25, 45, 49, 'm', 'F_I', '', 24.3, 28.8, 33.75),
	(25, 50, 54, 'm', 'F_I', '', 22.95, 27.9, 32.85),
	(25, 55, 59, 'm', 'F_I', '', 21.15, 26.1, 31.5),
	(25, 60, 64, 'm', 'F_I', '', 20.25, 25.2, 30.6),
	(25, 65, 69, 'm', 'F_I', '', 18.0, 22.95, 27.45),
	(25, 70, 74, 'm', 'F_I', '', 16.65, 21.6, 26.1),
	(25, 75, 79, 'm', 'F_I', '', 14.4, 18.9, 23.4),
	(25, 80, 84, 'm', 'F_I', '', 12.6, 17.1, 21.6),
	(25, 85, 89, 'm', 'F_I', '', 10.8, 14.85, 18.9),
	(25, 90, 200, 'm', 'F_I', '', 9.45, 13.5, 17.55),
	(33, 0, 7, 'w', 'F_I', '', 7.2, 10.8, 15.299999999999999),
	(33, 8, 9, 'w', 'F_I', '', 9.0, 13.500000000000002, 18.0),
	(33, 10, 11, 'w', 'F_I', '', 13.500000000000002, 18.0, 27.0),
	(33, 12, 13, 'w', 'F_I', '', 18.0, 27.0, 36.0),
	(33, 14, 15, 'w', 'F_I', '', 27.0, 36.0, 45.0),
	(33, 16, 17, 'w', 'F_I', '', 40.49999999999999, 54.0, 67.5),
	(33, 0, 7, 'm', 'F_I', '', 9.0, 13.500000000000002, 18.0),
	(33, 8, 9, 'm', 'F_I', '', 10.8, 15.299999999999999, 20.700000000000003),
	(33, 10, 11, 'm', 'F_I', '', 15.299999999999999, 22.5, 31.5),
	(33, 12, 13, 'm', 'F_I', '', 22.5, 31.5, 40.49999999999999),
	(33, 14, 15, 'm', 'F_I', '', 31.5, 40.49999999999999, 54.0),
	(33, 16, 17, 'm', 'F_I', '', 49.49999999999999, 63.0, 81.0),
	(39, 0, 7, 'w', 'F_I', '', 191.0, 213.0, 234.0),
	(39, 8, 9, 'w', 'F_I', '', 203.0, 225.0, 248.0),
	(39, 10, 11, 'w', 'F_I', '', 214.0, 238.0, 261.0),
	(39, 12, 13, 'w', 'F_I', '', 225.0, 250.0, 275.0),
	(39, 14, 15, 'w', 'F_I', '', 236.0, 263.0, 289.0),
	(39, 16, 17, 'w', 'F_I', '', 248.0, 275.0, 303.0),
	(39, 18, 19, 'w', 'F_I', '', 338.0, 375.0, 413.0),
	(39, 20, 24, 'w', 'F_I', '', 338.0, 375.0, 413.0),
	(39, 25, 29, 'w', 'F_I', '', 338.0, 375.0, 413.0),
	(39, 30, 34, 'w', 'F_I', '', 326.0, 363.0, 399.0),
	(39, 35, 39, 'w', 'F_I', '', 326.0, 363.0, 399.0),
	(39, 40, 44, 'w', 'F_I', '', 315.0, 350.0, 385.0),
	(39, 45, 49, 'w', 'F_I', '', 304.0, 338.0, 371.0),
	(39, 50, 54, 'w', 'F_I', '', 293.0, 325.0, 358.0),
	(39, 55, 59, 'w', 'F_I', '', 281.0, 313.0, 344.0),
	(39, 60, 64, 'w', 'F_I', '', 270.0, 300.0, 330.0),
	(39, 65, 69, 'w', 'F_I', '', 259.0, 288.0, 316.0),
	(39, 70, 74, 'w', 'F_I', '', 248.0, 275.0, 303.0),
	(39, 75, 79, 'w', 'F_I', '', 236.0, 263.0, 289.0),
	(39, 80, 84, 'w', 'F_I', '', 225.0, 250.0, 275.0),
	(39, 85, 89, 'w', 'F_I', '', 214.0, 238.0, 261.0),
	(39, 90, 200, 'w', 'F_I', '', 203.0, 225.0, 248.0),
	(39, 0, 7, 'm', 'F_I', '', 250.0, 278.0, 305.0),
	(39, 8, 9, 'm', 'F_I', '', 261.0, 290.0, 319.0),
	(39, 10, 11, 'm', 'F_I', '', 272.0, 303.0, 333.0),
	(39, 12, 13, 'm', 'F_I', '', 284.0, 315.0, 347.0),
	(39, 14, 15, 'm', 'F_I', '', 295.0, 328.0, 360.0),
	(39, 16, 17, 'm', 'F_I', '', 306.0, 340.0, 374.0),
	(39, 18, 19, 'm', 'F_I', '', 396.0, 440.0, 484.0),
	(39, 20, 24, 'm', 'F_I', '', 396.0, 440.0, 484.0),
	(39, 25, 29, 'm', 'F_I', '', 396.0, 440.0, 484.0),
	(39, 30, 34, 'm', 'F_I', '', 385.0, 428.0, 470.0),
	(39, 35, 39, 'm', 'F_I', '', 385.0, 428.0, 470.0),
	(39, 40, 44, 'm', 'F_I', '', 374.0, 415.0, 457.0),
	(39, 45, 49, 'm', 'F_I', '', 362.0, 403.0, 443.0),
	(39, 50, 54, 'm', 'F_I', '', 351.0, 390.0, 429.0),
	(39, 55, 59, 'm', 'F_I', '', 340.0, 378.0, 415.0),
	(39, 60, 64, 'm', 'F_I', '', 329.0, 365.0, 402.0),
	(39, 65, 69, 'm', 'F_I', '', 317.0, 353.0, 388.0),
	(39, 70, 74, 'm', 'F_I', '', 306.0, 340.0, 374.0),
	(39, 75, 79, 'm', 'F_I', '', 295.0, 328.0, 360.0),
	(39, 80, 84, 'm', 'F_I', '', 284.0, 315.0, 347.0),
	(39, 85, 89, 'm', 'F_I', '', 272.0, 303.0, 333.0),
	(39, 90, 200, 'm', 'F_I', '', 261.0, 290.0, 319.0),
	(40, 0, 7, 'w', 'F_I', '', 315.0, 350.0, 385.0),
	(40, 8, 9, 'w', 'F_I', '', 329.0, 365.0, 402.0),
	(40, 10, 11, 'w', 'F_I', '', 342.0, 380.0, 418.0),
	(40, 12, 13, 'w', 'F_I', '', 356.0, 395.0, 435.0),
	(40, 14, 15, 'w', 'F_I', '', 369.0, 410.0, 451.0),
	(40, 16, 17, 'w', 'F_I', '', 383.0, 425.0, 468.0),
	(40, 18, 19, 'w', 'F_I', '', 473.0, 525.0, 578.0),
	(40, 20, 24, 'w', 'F_I', '', 473.0, 525.0, 578.0),
	(40, 25, 29, 'w', 'F_I', '', 473.0, 525.0, 578.0),
	(40, 30, 34, 'w', 'F_I', '', 459.0, 510.0, 561.0),
	(40, 35, 39, 'w', 'F_I', '', 459.0, 510.0, 561.0),
	(40, 40, 44, 'w', 'F_I', '', 446.0, 495.0, 545.0),
	(40, 45, 49, 'w', 'F_I', '', 432.0, 480.0, 528.0),
	(40, 50, 54, 'w', 'F_I', '', 419.0, 465.0, 512.0),
	(40, 55, 59, 'w', 'F_I', '', 405.0, 450.0, 495.0),
	(40, 60, 64, 'w', 'F_I', '', 392.0, 435.0, 479.0),
	(40, 65, 69, 'w', 'F_I', '', 378.0, 420.0, 462.0),
	(40, 70, 74, 'w', 'F_I', '', 365.0, 405.0, 446.0),
	(40, 75, 79, 'w', 'F_I', '', 351.0, 390.0, 429.0),
	(40, 80, 84, 'w', 'F_I', '', 338.0, 375.0, 413.0),
	(40, 85, 89, 'w', 'F_I', '', 324.0, 360.0, 396.0),
	(40, 90, 200, 'w', 'F_I', '', 311.0, 345.0, 380.0),
	(40, 0, 7, 'm', 'F_I', '', 383.0, 425.0, 468.0),
	(40, 8, 9, 'm', 'F_I', '', 396.0, 440.0, 484.0),
	(40, 10, 11, 'm', 'F_I', '', 410.0, 455.0, 501.0),
	(40, 12, 13, 'm', 'F_I', '', 423.0, 470.0, 517.0),
	(40, 14, 15, 'm', 'F_I', '', 437.0, 485.0, 534.0),
	(40, 16, 17, 'm', 'F_I', '', 450.0, 500.0, 550.0),
	(40, 18, 19, 'm', 'F_I', '', 540.0, 600.0, 660.0),
	(40, 20, 24, 'm', 'F_I', '', 540.0, 600.0, 660.0),
	(40, 25, 29, 'm', 'F_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'F_I', '', 527.0, 585.0, 644.0),
	(40, 35, 39, 'm', 'F_I', '', 527.0, 585.0, 644.0),
	(40, 40, 44, 'm', 'F_I', '', 513.0, 570.0, 627.0),
	(40, 45, 49, 'm', 'F_I', '', 500.0, 555.0, 611.0),
	(40, 50, 54, 'm', 'F_I', '', 486.0, 540.0, 594.0),
	(40, 55, 59, 'm', 'F_I', '', 473.0, 525.0, 578.0),
	(40, 60, 64, 'm', 'F_I', '', 459.0, 510.0, 561.0),
	(40, 65, 69, 'm', 'F_I', '', 446.0, 495.0, 545.0),
	(40, 70, 74, 'm', 'F_I', '', 432.0, 480.0, 528.0),
	(40, 75, 79, 'm', 'F_I', '', 419.0, 465.0, 512.0),
	(40, 80, 84, 'm', 'F_I', '', 405.0, 450.0, 495.0),
	(40, 85, 89, 'm', 'F_I', '', 392.0, 435.0, 479.0),
	(40, 90, 200, 'm', 'F_I', '', 378.0, 420.0, 462.0),
	(41, 0, 7, 'w', 'F_I', '', 261.0, 290.0, 319.0),
	(41, 8, 9, 'w', 'F_I', '', 275.0, 305.0, 336.0),
	(41, 10, 11, 'w', 'F_I', '', 288.0, 320.0, 352.0),
	(41, 12, 13, 'w', 'F_I', '', 302.0, 335.0, 369.0),
	(41, 14, 15, 'w', 'F_I', '', 315.0, 350.0, 385.0),
	(41, 16, 17, 'w', 'F_I', '', 329.0, 365.0, 402.0),
	(41, 18, 19, 'w', 'F_I', '', 419.0, 465.0, 512.0),
	(41, 20, 24, 'w', 'F_I', '', 419.0, 465.0, 512.0),
	(41, 25, 29, 'w', 'F_I', '', 419.0, 465.0, 512.0),
	(41, 30, 34, 'w', 'F_I', '', 405.0, 450.0, 495.0),
	(41, 35, 39, 'w', 'F_I', '', 405.0, 450.0, 495.0),
	(41, 40, 44, 'w', 'F_I', '', 392.0, 435.0, 479.0),
	(41, 45, 49, 'w', 'F_I', '', 378.0, 420.0, 462.0),
	(41, 50, 54, 'w', 'F_I', '', 365.0, 405.0, 446.0),
	(41, 55, 59, 'w', 'F_I', '', 351.0, 390.0, 429.0),
	(41, 60, 64, 'w', 'F_I', '', 338.0, 375.0, 413.0),
	(41, 65, 69, 'w', 'F_I', '', 324.0, 360.0, 396.0),
	(41, 70, 74, 'w', 'F_I', '', 311.0, 345.0, 380.0),
	(41, 75, 79, 'w', 'F_I', '', 297.0, 330.0, 363.0),
	(41, 80, 84, 'w', 'F_I', '', 284.0, 315.0, 347.0),
	(41, 85, 89, 'w', 'F_I', '', 270.0, 300.0, 330.0),
	(41, 90, 200, 'w', 'F_I', '', 257.0, 285.0, 314.0),
	(41, 0, 7, 'm', 'F_I', '', 324.0, 360.0, 396.0),
	(41, 8, 9, 'm', 'F_I', '', 338.0, 375.0, 413.0),
	(41, 10, 11, 'm', 'F_I', '', 351.0, 390.0, 429.0),
	(41, 12, 13, 'm', 'F_I', '', 365.0, 405.0, 446.0),
	(41, 14, 15, 'm', 'F_I', '', 378.0, 420.0, 462.0),
	(41, 16, 17, 'm', 'F_I', '', 392.0, 435.0, 479.0),
	(41, 18, 19, 'm', 'F_I', '', 482.0, 535.0, 589.0),
	(41, 20, 24, 'm', 'F_I', '', 482.0, 535.0, 589.0),
	(41, 25, 29, 'm', 'F_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'F_I', '', 468.0, 520.0, 572.0),
	(41, 35, 39, 'm', 'F_I', '', 468.0, 520.0, 572.0),
	(41, 40, 44, 'm', 'F_I', '', 455.0, 505.0, 556.0),
	(41, 45, 49, 'm', 'F_I', '', 441.0, 490.0, 539.0),
	(41, 50, 54, 'm', 'F_I', '', 428.0, 475.0, 523.0),
	(41, 55, 59, 'm', 'F_I', '', 414.0, 460.0, 506.0),
	(41, 60, 64, 'm', 'F_I', '', 401.0, 445.0, 490.0),
	(41, 65, 69, 'm', 'F_I', '', 387.0, 430.0, 473.0),
	(41, 70, 74, 'm', 'F_I', '', 374.0, 415.0, 457.0),
	(41, 75, 79, 'm', 'F_I', '', 360.0, 400.0, 440.0),
	(41, 80, 84, 'm', 'F_I', '', 347.0, 385.0, 424.0),
	(41, 85, 89, 'm', 'F_I', '', 333.0, 370.0, 407.0),
	(41, 90, 200, 'm', 'F_I', '', 320.0, 355.0, 391.0),
	(42, 0, 7, 'w', 'F_I', '', 266.0, 295.0, 325.0),
	(42, 8, 9, 'w', 'F_I', '', 279.0, 310.0, 341.0),
	(42, 10, 11, 'w', 'F_I', '', 293.0, 325.0, 358.0),
	(42, 12, 13, 'w', 'F_I', '', 306.0, 340.0, 374.0),
	(42, 14, 15, 'w', 'F_I', '', 320.0, 355.0, 391.0),
	(42, 16, 17, 'w', 'F_I', '', 333.0, 370.0, 407.0),
	(42, 18, 19, 'w', 'F_I', '', 423.0, 470.0, 517.0),
	(42, 20, 24, 'w', 'F_I', '', 423.0, 470.0, 517.0),
	(42, 25, 29, 'w', 'F_I', '', 423.0, 470.0, 517.0),
	(42, 30, 34, 'w', 'F_I', '', 410.0, 455.0, 501.0),
	(42, 35, 39, 'w', 'F_I', '', 410.0, 455.0, 501.0),
	(42, 40, 44, 'w', 'F_I', '', 396.0, 440.0, 484.0),
	(42, 45, 49, 'w', 'F_I', '', 383.0, 425.0, 468.0),
	(42, 50, 54, 'w', 'F_I', '', 369.0, 410.0, 451.0),
	(42, 55, 59, 'w', 'F_I', '', 356.0, 395.0, 435.0),
	(42, 60, 64, 'w', 'F_I', '', 342.0, 380.0, 418.0),
	(42, 65, 69, 'w', 'F_I', '', 329.0, 365.0, 402.0),
	(42, 70, 74, 'w', 'F_I', '', 315.0, 350.0, 385.0),
	(42, 75, 79, 'w', 'F_I', '', 302.0, 335.0, 369.0),
	(42, 80, 84, 'w', 'F_I', '', 288.0, 320.0, 352.0),
	(42, 85, 89, 'w', 'F_I', '', 275.0, 305.0, 336.0),
	(42, 90, 200, 'w', 'F_I', '', 261.0, 290.0, 319.0),
	(42, 0, 7, 'm', 'F_I', '', 329.0, 365.0, 402.0),
	(42, 8, 9, 'm', 'F_I', '', 342.0, 380.0, 418.0),
	(42, 10, 11, 'm', 'F_I', '', 356.0, 395.0, 435.0),
	(42, 12, 13, 'm', 'F_I', '', 369.0, 410.0, 451.0),
	(42, 14, 15, 'm', 'F_I', '', 383.0, 425.0, 468.0),
	(42, 16, 17, 'm', 'F_I', '', 396.0, 440.0, 484.0),
	(42, 18, 19, 'm', 'F_I', '', 486.0, 540.0, 594.0),
	(42, 20, 24, 'm', 'F_I', '', 486.0, 540.0, 594.0),
	(42, 25, 29, 'm', 'F_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'F_I', '', 473.0, 525.0, 578.0),
	(42, 35, 39, 'm', 'F_I', '', 473.0, 525.0, 578.0),
	(42, 40, 44, 'm', 'F_I', '', 459.0, 510.0, 561.0),
	(42, 45, 49, 'm', 'F_I', '', 446.0, 495.0, 545.0),
	(42, 50, 54, 'm', 'F_I', '', 432.0, 480.0, 528.0),
	(42, 55, 59, 'm', 'F_I', '', 419.0, 465.0, 512.0),
	(42, 60, 64, 'm', 'F_I', '', 405.0, 450.0, 495.0),
	(42, 65, 69, 'm', 'F_I', '', 392.0, 435.0, 479.0),
	(42, 70, 74, 'm', 'F_I', '', 378.0, 420.0, 462.0),
	(42, 75, 79, 'm', 'F_I', '', 365.0, 405.0, 446.0),
	(42, 80, 84, 'm', 'F_I', '', 351.0, 390.0, 429.0),
	(42, 85, 89, 'm', 'F_I', '', 338.0, 375.0, 413.0),
	(42, 90, 200, 'm', 'F_I', '', 324.0, 360.0, 396.0),
	(44, 12, 13, 'w', 'F_I', '', 6.86, 7.59, 8.31),
	(44, 14, 15, 'w', 'F_I', '', 7.95, 8.67, 9.39),
	(44, 16, 17, 'w', 'F_I', '', 8.31, 9.03, 9.75),
	(44, 18, 19, 'w', 'F_I', '', 10.5, 11.31, 12.11),
	(44, 20, 24, 'w', 'F_I', '', 10.5, 11.31, 12.11),
	(44, 25, 29, 'w', 'F_I', '', 10.5, 11.31, 12.11),
	(44, 30, 34, 'w', 'F_I', '', 10.09, 10.9, 11.71),
	(44, 35, 39, 'w', 'F_I', '', 9.69, 10.5, 11.31),
	(44, 40, 44, 'w', 'F_I', '', 8.88, 9.69, 10.5),
	(44, 45, 49, 'w', 'F_I', '', 8.48, 9.29, 10.09),
	(44, 50, 54, 'w', 'F_I', '', 8.48, 9.69, 11.31),
	(44, 55, 59, 'w', 'F_I', '', 8.08, 9.29, 10.5),
	(44, 60, 64, 'w', 'F_I', '', 7.67, 8.88, 10.09),
	(44, 65, 69, 'w', 'F_I', '', 7.27, 8.48, 10.09),
	(44, 70, 74, 'w', 'F_I', '', 6.86, 8.08, 9.69),
	(44, 75, 79, 'w', 'F_I', '', 6.86, 8.48, 10.09),
	(44, 80, 84, 'w', 'F_I', '', 6.46, 8.08, 9.29),
	(44, 85, 89, 'w', 'F_I', '', 6.06, 7.27, 8.88),
	(44, 90, 200, 'w', 'F_I', '', 5.25, 6.86, 8.08),
	(44, 12, 13, 'm', 'F_I', '', 9.03, 9.75, 10.48),
	(44, 14, 15, 'm', 'F_I', '', 10.12, 10.84, 11.56),
	(44, 16, 17, 'm', 'F_I', '', 10.84, 11.56, 12.28),
	(44, 18, 19, 'm', 'F_I', '', 12.52, 13.32, 14.13),
	(44, 20, 24, 'm', 'F_I', '', 12.52, 13.73, 14.54),
	(44, 25, 29, 'm', 'F_I', '', 12.11, 13.32, 14.13),
	(44, 30, 34, 'm', 'F_I', '', 11.31, 12.52, 13.32),
	(44, 35, 39, 'm', 'F_I', '', 10.9, 11.71, 12.92),
	(44, 40, 44, 'm', 'F_I', '', 10.09, 11.31, 12.52),
	(44, 45, 49, 'm', 'F_I', '', 9.69, 10.9, 12.11),
	(44, 50, 54, 'm', 'F_I', '', 10.09, 11.31, 12.92),
	(44, 55, 59, 'm', 'F_I', '', 9.69, 10.9, 12.11),
	(44, 60, 64, 'm', 'F_I', '', 9.69, 11.31, 12.92),
	(44, 65, 69, 'm', 'F_I', '', 9.29, 10.9, 12.11),
	(44, 70, 74, 'm', 'F_I', '', 9.69, 10.9, 12.52),
	(44, 75, 79, 'm', 'F_I', '', 9.29, 10.5, 12.11),
	(44, 80, 84, 'm', 'F_I', '', 8.88, 10.09, 11.71),
	(44, 85, 89, 'm', 'F_I', '', 8.08, 9.69, 10.9),
	(44, 90, 200, 'm', 'F_I', '', 7.27, 8.48, 10.09),
	(53, 0, 7, 'w', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'F_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'F_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'F_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'F_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'F_I', '', 11.0, 14.0, 19.0),
	(57, 8, 9, 'w', 'F_I', '', 16.0, 19.0, 24.0),
	(57, 10, 11, 'w', 'F_I', '', 24.0, 27.0, 32.0),
	(57, 0, 7, 'm', 'F_I', '', 14.0, 16.0, 22.0),
	(57, 8, 9, 'm', 'F_I', '', 19.0, 24.0, 30.0),
	(57, 10, 11, 'm', 'F_I', '', 30.0, 35.0, 41.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'F_II', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'w', 'F_II', '', 7.250000000000001, 6.283333333333333, 5.416666666666667),
	(1, 10, 11, 'w', 'F_II', '', 6.933333333333333, 6.066666666666666, 5.2),
	(1, 12, 13, 'w', 'F_II', '', 6.716666666666666, 5.75, 4.883333333333334),
	(1, 14, 15, 'w', 'F_II', '', 6.5, 5.633333333333333, 4.666666666666667),
	(1, 16, 17, 'w', 'F_II', '', 6.283333333333333, 5.3, 4.449999999999999),
	(1, 0, 7, 'm', 'F_II', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'm', 'F_II', '', 7.033333333333332, 6.066666666666666, 5.1),
	(1, 10, 11, 'm', 'F_II', '', 6.6000000000000005, 5.633333333333333, 4.666666666666667),
	(1, 12, 13, 'm', 'F_II', '', 6.166666666666666, 5.2, 4.2333333333333325),
	(1, 14, 15, 'm', 'F_II', '', 5.633333333333333, 4.766666666666667, 3.9000000000000004),
	(1, 16, 17, 'm', 'F_II', '', 5.3, 4.449999999999999, 3.5833333333333335),
	(4, 8, 9, 'w', 'F_II', '5 km Tandem', 29.700000000000003, 26.4, 23.099999999999998),
	(4, 10, 11, 'w', 'F_II', '10 km Tandem', 55.55, 47.3, 39.050000000000004),
	(4, 12, 13, 'w', 'F_II', '10 km Tandem', 49.49999999999999, 43.45, 36.849999999999994),
	(4, 14, 15, 'w', 'F_II', '10 km Tandem', 41.8, 35.75000000000001, 31.35),
	(4, 16, 17, 'w', 'F_II', '10 km Tandem', 35.75000000000001, 31.35, 27.5),
	(4, 18, 19, 'w', 'F_II', '20 km Tandem', 63.25, 57.199999999999996, 51.150000000000006),
	(4, 20, 24, 'w', 'F_II', '20 km Tandem', 62.7, 56.65, 50.050000000000004),
	(4, 25, 29, 'w', 'F_II', '20 km Tandem', 61.6, 55.55, 49.49999999999999),
	(4, 30, 34, 'w', 'F_II', '20 km Tandem', 62.7, 56.65, 50.050000000000004),
	(4, 35, 39, 'w', 'F_II', '20 km Tandem', 66.0, 58.3, 51.7),
	(4, 40, 44, 'w', 'F_II', '20 km Tandem', 70.39999999999999, 61.050000000000004, 54.45),
	(4, 45, 49, 'w', 'F_II', '20 km Tandem', 73.7, 64.35, 56.65),
	(4, 50, 54, 'w', 'F_II', '20 km Tandem', 75.9, 67.10000000000001, 58.849999999999994),
	(4, 55, 59, 'w', 'F_II', '20 km Tandem', 78.65, 69.30000000000001, 61.050000000000004),
	(4, 60, 64, 'w', 'F_II', '20 km Tandem', 81.39999999999999, 71.5, 62.7),
	(4, 65, 69, 'w', 'F_II', '20 km Tandem', 83.05, 73.15, 64.35),
	(4, 70, 74, 'w', 'F_II', '20 km Tandem', 85.80000000000001, 75.35, 66.55),
	(4, 75, 79, 'w', 'F_II', '20 km Tandem', 89.65, 77.55, 69.30000000000001),
	(4, 80, 84, 'w', 'F_II', '20 km Tandem', 92.94999999999999, 82.5, 72.05),
	(4, 85, 89, 'w', 'F_II', '20 km Tandem', 98.44999999999999, 88.0, 75.9),
	(4, 90, 200, 'w', 'F_II', '20 km Tandem', 102.30000000000001, 91.30000000000001, 79.75),
	(4, 8, 9, 'm', 'F_II', '5 km Tandem', 29.15, 25.85, 22.549999999999997),
	(4, 10, 11, 'm', 'F_II', '10 km Tandem', 53.35, 45.1, 36.849999999999994),
	(4, 12, 13, 'm', 'F_II', '10 km Tandem', 47.3, 40.7, 34.65),
	(4, 14, 15, 'm', 'F_II', '10 km Tandem', 35.199999999999996, 30.8, 26.4),
	(4, 16, 17, 'm', 'F_II', '10 km Tandem', 29.700000000000003, 25.85, 22.549999999999997),
	(4, 18, 19, 'm', 'F_II', '20 km Tandem', 51.7, 46.75000000000001, 42.35),
	(4, 20, 24, 'm', 'F_II', '20 km Tandem', 51.150000000000006, 46.199999999999996, 41.25),
	(4, 25, 29, 'm', 'F_II', '20 km Tandem', 55.0, 48.95, 42.9),
	(4, 30, 34, 'm', 'F_II', '20 km Tandem', 58.849999999999994, 51.7, 44.55),
	(4, 35, 39, 'm', 'F_II', '20 km Tandem', 63.8, 55.0, 45.65),
	(4, 40, 44, 'm', 'F_II', '20 km Tandem', 69.30000000000001, 57.199999999999996, 47.849999999999994),
	(4, 45, 49, 'm', 'F_II', '20 km Tandem', 72.6, 60.49999999999999, 49.49999999999999),
	(4, 50, 54, 'm', 'F_II', '20 km Tandem', 75.35, 62.7, 51.150000000000006),
	(4, 55, 59, 'm', 'F_II', '20 km Tandem', 77.55, 64.35, 52.25),
	(4, 60, 64, 'm', 'F_II', '20 km Tandem', 78.65, 66.0, 52.8),
	(4, 65, 69, 'm', 'F_II', '20 km Tandem', 79.75, 66.55, 53.35),
	(4, 70, 74, 'm', 'F_II', '20 km Tandem', 80.85000000000001, 67.65, 54.45),
	(4, 75, 79, 'm', 'F_II', '20 km Tandem', 81.94999999999999, 69.30000000000001, 56.65),
	(4, 80, 84, 'm', 'F_II', '20 km Tandem', 83.6, 70.94999999999999, 58.3),
	(4, 85, 89, 'm', 'F_II', '20 km Tandem', 85.25000000000001, 73.15, 61.050000000000004),
	(4, 90, 200, 'm', 'F_II', '20 km Tandem', 86.9, 74.80000000000001, 63.8),
	(5, 18, 19, 'w', 'F_II', '', 27.083333333333336, 24.48333333333333, 21.883333333333336),
	(5, 20, 24, 'w', 'F_II', '', 26.433333333333337, 23.833333333333332, 21.233333333333334),
	(5, 25, 29, 'w', 'F_II', '', 26.866666666666667, 24.266666666666666, 21.666666666666664),
	(5, 30, 34, 'w', 'F_II', '', 27.95, 25.35, 22.75),
	(5, 35, 39, 'w', 'F_II', '', 28.599999999999998, 26.0, 23.4),
	(5, 40, 44, 'w', 'F_II', '', 29.683333333333334, 26.866666666666667, 24.05),
	(5, 45, 49, 'w', 'F_II', '', 30.983333333333334, 27.95, 24.48333333333333),
	(5, 50, 54, 'w', 'F_II', '', 32.28333333333334, 28.816666666666663, 24.916666666666668),
	(5, 55, 59, 'w', 'F_II', '', 33.583333333333336, 29.683333333333334, 25.78333333333333),
	(5, 60, 64, 'w', 'F_II', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 65, 69, 'w', 'F_II', '', 35.31666666666666, 31.416666666666668, 27.516666666666666),
	(5, 70, 74, 'w', 'F_II', '', 35.96666666666666, 32.06666666666666, 28.166666666666668),
	(5, 75, 79, 'w', 'F_II', '', 37.050000000000004, 33.150000000000006, 29.249999999999996),
	(5, 80, 84, 'w', 'F_II', '', 38.56666666666667, 34.666666666666664, 30.76666666666667),
	(5, 85, 89, 'w', 'F_II', '', 40.3, 36.400000000000006, 32.49999999999999),
	(5, 90, 200, 'w', 'F_II', '', 42.25, 38.35, 34.45),
	(5, 18, 19, 'm', 'F_II', '', 23.183333333333334, 20.583333333333336, 17.983333333333334),
	(5, 20, 24, 'm', 'F_II', '', 22.533333333333335, 19.93333333333333, 17.333333333333332),
	(5, 25, 29, 'm', 'F_II', '', 22.966666666666665, 20.366666666666664, 17.76666666666667),
	(5, 30, 34, 'm', 'F_II', '', 24.05, 21.45, 18.85),
	(5, 35, 39, 'm', 'F_II', '', 25.78333333333333, 22.533333333333335, 19.5),
	(5, 40, 44, 'm', 'F_II', '', 27.3, 24.05, 20.583333333333336),
	(5, 45, 49, 'm', 'F_II', '', 28.816666666666663, 25.35, 21.45),
	(5, 50, 54, 'm', 'F_II', '', 30.333333333333332, 26.433333333333337, 22.533333333333335),
	(5, 55, 59, 'm', 'F_II', '', 30.983333333333334, 27.083333333333336, 23.183333333333334),
	(5, 60, 64, 'm', 'F_II', '', 31.85, 27.95, 24.05),
	(5, 65, 69, 'm', 'F_II', '', 32.49999999999999, 28.599999999999998, 24.700000000000003),
	(5, 70, 74, 'm', 'F_II', '', 32.93333333333334, 29.03333333333333, 25.13333333333333),
	(5, 75, 79, 'm', 'F_II', '', 33.8, 29.9, 26.0),
	(5, 80, 84, 'm', 'F_II', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 85, 89, 'm', 'F_II', '', 35.75000000000001, 31.85, 27.95),
	(5, 90, 200, 'm', 'F_II', '', 38.78333333333333, 34.88333333333333, 30.983333333333334),
	(6, 18, 19, 'w', 'F_II', '', 110.06666666666668, 102.26666666666667, 94.46666666666667),
	(6, 20, 24, 'w', 'F_II', '', 108.55, 99.88333333333334, 92.94999999999999),
	(6, 25, 29, 'w', 'F_II', '', 108.55, 99.88333333333334, 92.30000000000001),
	(6, 30, 34, 'w', 'F_II', '', 109.41666666666667, 101.39999999999999, 92.73333333333333),
	(6, 35, 39, 'w', 'F_II', '', 113.96666666666667, 103.35, 92.94999999999999),
	(6, 40, 44, 'w', 'F_II', '', 118.73333333333333, 105.73333333333333, 93.16666666666666),
	(6, 45, 49, 'w', 'F_II', '', 123.93333333333334, 108.11666666666666, 94.68333333333332),
	(6, 50, 54, 'w', 'F_II', '', 126.96666666666667, 111.15, 96.2),
	(6, 55, 59, 'w', 'F_II', '', 130.21666666666667, 114.61666666666667, 99.01666666666668),
	(6, 60, 64, 'w', 'F_II', '', 133.68333333333334, 118.08333333333333, 102.48333333333335),
	(6, 65, 69, 'w', 'F_II', '', 137.36666666666667, 121.76666666666665, 106.16666666666666),
	(6, 70, 74, 'w', 'F_II', '', 142.35000000000002, 126.75, 111.15),
	(6, 75, 79, 'w', 'F_II', '', 149.93333333333334, 134.33333333333331, 118.73333333333333),
	(6, 80, 84, 'w', 'F_II', '', 159.03333333333336, 143.4333333333333, 127.83333333333333),
	(6, 85, 89, 'w', 'F_II', '', 167.91666666666669, 152.31666666666666, 136.71666666666667),
	(6, 90, 200, 'w', 'F_II', '', 177.45000000000002, 161.85, 146.25),
	(6, 18, 19, 'm', 'F_II', '', 82.33333333333334, 74.53333333333332, 66.73333333333333),
	(6, 20, 24, 'm', 'F_II', '', 81.25000000000001, 73.44999999999999, 65.0),
	(6, 25, 29, 'm', 'F_II', '', 85.80000000000001, 77.13333333333333, 67.6),
	(6, 30, 34, 'm', 'F_II', '', 90.56666666666668, 79.51666666666667, 71.28333333333333),
	(6, 35, 39, 'm', 'F_II', '', 96.41666666666667, 85.15, 73.88333333333334),
	(6, 40, 44, 'm', 'F_II', '', 102.48333333333335, 90.35, 78.21666666666665),
	(6, 45, 49, 'm', 'F_II', '', 108.76666666666665, 95.11666666666666, 82.55),
	(6, 50, 54, 'm', 'F_II', '', 114.83333333333333, 99.66666666666667, 85.15),
	(6, 55, 59, 'm', 'F_II', '', 118.94999999999999, 103.56666666666668, 87.96666666666667),
	(6, 60, 64, 'm', 'F_II', '', 123.06666666666668, 107.46666666666667, 91.86666666666666),
	(6, 65, 69, 'm', 'F_II', '', 127.39999999999999, 111.80000000000001, 96.2),
	(6, 70, 74, 'm', 'F_II', '', 132.8166666666667, 117.21666666666665, 101.61666666666667),
	(6, 75, 79, 'm', 'F_II', '', 139.53333333333333, 123.93333333333334, 108.33333333333334),
	(6, 80, 84, 'm', 'F_II', '', 147.11666666666665, 131.51666666666668, 115.91666666666666),
	(6, 85, 89, 'm', 'F_II', '', 156.21666666666667, 140.61666666666667, 125.01666666666668),
	(6, 90, 200, 'm', 'F_II', '', 165.9666666666667, 150.36666666666667, 134.76666666666668),
	(7, 0, 7, 'w', 'F_II', '200 m', 11.7, 9.966666666666667, 8.233333333333334),
	(7, 8, 9, 'w', 'F_II', '200 m', 10.4, 9.100000000000001, 7.7),
	(7, 10, 11, 'w', 'F_II', '200 m', 9.533333333333333, 8.333333333333332, 7.1499999999999995),
	(7, 12, 13, 'w', 'F_II', '400 m', 19.283333333333335, 16.8, 14.299999999999999),
	(7, 14, 15, 'w', 'F_II', '400 m', 17.01666666666667, 15.166666666666666, 13.0),
	(7, 16, 17, 'w', 'F_II', '400 m', 15.383333333333335, 13.65, 11.8),
	(7, 18, 19, 'w', 'F_II', '800 m', 31.200000000000003, 27.516666666666666, 23.93333333333333),
	(7, 20, 24, 'w', 'F_II', '800 m', 30.650000000000002, 27.083333333333336, 23.4),
	(7, 25, 29, 'w', 'F_II', '800 m', 33.150000000000006, 27.416666666666668, 24.266666666666666),
	(7, 30, 34, 'w', 'F_II', '800 m', 37.483333333333334, 30.76666666666667, 25.35),
	(7, 35, 39, 'w', 'F_II', '800 m', 41.6, 33.26666666666666, 26.433333333333337),
	(7, 40, 44, 'w', 'F_II', '800 m', 44.199999999999996, 35.96666666666666, 27.733333333333334),
	(7, 45, 49, 'w', 'F_II', '800 m', 45.93333333333334, 37.7, 27.95),
	(7, 50, 54, 'w', 'F_II', '400 m', 23.4, 19.5, 14.950000000000001),
	(7, 55, 59, 'w', 'F_II', '400 m', 24.15, 19.93333333333333, 15.483333333333333),
	(7, 60, 64, 'w', 'F_II', '400 m', 24.700000000000003, 20.266666666666666, 15.816666666666666),
	(7, 65, 69, 'w', 'F_II', '400 m', 25.249999999999996, 20.48333333333333, 15.933333333333334),
	(7, 70, 74, 'w', 'F_II', '400 m', 25.78333333333333, 20.9, 16.46666666666667),
	(7, 75, 79, 'w', 'F_II', '200 m', 13.316666666666666, 10.833333333333334, 8.45),
	(7, 80, 84, 'w', 'F_II', '200 m', 13.55, 11.049999999999999, 8.783333333333335),
	(7, 85, 89, 'w', 'F_II', '200 m', 13.766666666666667, 11.366666666666667, 9.216666666666669),
	(7, 90, 200, 'w', 'F_II', '200 m', 13.983333333333333, 11.583333333333332, 9.533333333333333),
	(7, 0, 7, 'm', 'F_II', '200 m', 11.7, 9.533333333333333, 8.016666666666666),
	(7, 8, 9, 'm', 'F_II', '200 m', 10.4, 8.783333333333335, 7.366666666666666),
	(7, 10, 11, 'm', 'F_II', '200 m', 9.100000000000001, 8.233333333333334, 6.716666666666666),
	(7, 12, 13, 'm', 'F_II', '400 m', 17.549999999999997, 14.950000000000001, 12.683333333333334),
	(7, 14, 15, 'm', 'F_II', '400 m', 15.6, 13.316666666666666, 11.483333333333333),
	(7, 16, 17, 'm', 'F_II', '400 m', 14.299999999999999, 12.566666666666666, 10.833333333333334),
	(7, 18, 19, 'm', 'F_II', '800 m', 29.366666666666664, 25.78333333333333, 22.099999999999998),
	(7, 20, 24, 'm', 'F_II', '800 m', 28.816666666666663, 25.35, 21.35),
	(7, 25, 29, 'm', 'F_II', '800 m', 30.116666666666667, 26.0, 22.099999999999998),
	(7, 30, 34, 'm', 'F_II', '800 m', 33.483333333333334, 27.95, 23.4),
	(7, 35, 39, 'm', 'F_II', '800 m', 37.483333333333334, 31.200000000000003, 25.03333333333333),
	(7, 40, 44, 'm', 'F_II', '800 m', 42.13333333333333, 34.35, 26.549999999999997),
	(7, 45, 49, 'm', 'F_II', '800 m', 44.849999999999994, 36.18333333333333, 26.866666666666667),
	(7, 50, 54, 'm', 'F_II', '400 m', 22.650000000000002, 18.633333333333333, 13.983333333333333),
	(7, 55, 59, 'm', 'F_II', '400 m', 23.183333333333334, 18.966666666666665, 14.733333333333333),
	(7, 60, 64, 'm', 'F_II', '400 m', 23.616666666666667, 19.183333333333334, 14.833333333333334),
	(7, 65, 69, 'm', 'F_II', '400 m', 23.93333333333333, 19.616666666666667, 14.950000000000001),
	(7, 70, 74, 'm', 'F_II', '400 m', 23.93333333333333, 19.816666666666663, 15.049999999999999),
	(7, 75, 79, 'm', 'F_II', '200 m', 12.25, 9.966666666666667, 7.916666666666666),
	(7, 80, 84, 'm', 'F_II', '200 m', 12.350000000000001, 10.183333333333332, 8.016666666666666),
	(7, 85, 89, 'm', 'F_II', '200 m', 12.350000000000001, 10.4, 8.333333333333332),
	(7, 90, 200, 'm', 'F_II', '200 m', 12.683333333333334, 10.616666666666665, 8.783333333333335),
	(8, 18, 19, 'w', 'F_II', '7,5 km', 72.98333333333333, 69.30000000000001, 65.10000000000001),
	(8, 20, 24, 'w', 'F_II', '7,5 km', 69.83333333333333, 66.15, 62.483333333333334),
	(8, 25, 29, 'w', 'F_II', '7,5 km', 70.35, 66.68333333333332, 63.0),
	(8, 30, 34, 'w', 'F_II', '7,5 km', 70.88333333333334, 67.2, 63.43333333333333),
	(8, 35, 39, 'w', 'F_II', '7,5 km', 73.5, 68.25000000000001, 63.78333333333333),
	(8, 40, 44, 'w', 'F_II', '7,5 km', 76.65, 70.35, 64.05),
	(8, 45, 49, 'w', 'F_II', '7,5 km', 79.28333333333333, 72.44999999999999, 65.10000000000001),
	(8, 50, 54, 'w', 'F_II', '7,5 km', 81.9, 74.55, 67.2),
	(8, 55, 59, 'w', 'F_II', '7,5 km', 84.0, 76.65, 69.30000000000001),
	(8, 60, 64, 'w', 'F_II', '7,5 km', 86.63333333333333, 78.23333333333333, 70.88333333333334),
	(8, 65, 69, 'w', 'F_II', '7,5 km', 88.46666666666667, 80.33333333333334, 73.5),
	(8, 70, 74, 'w', 'F_II', '7,5 km', 92.66666666666667, 82.94999999999999, 75.6),
	(8, 75, 79, 'w', 'F_II', '7,5 km', 97.13333333333333, 85.58333333333333, 78.23333333333333),
	(8, 80, 84, 'w', 'F_II', '7,5 km', 103.41666666666667, 89.51666666666667, 81.38333333333334),
	(8, 85, 89, 'w', 'F_II', '7,5 km', 109.2, 94.85000000000001, 86.10000000000001),
	(8, 90, 200, 'w', 'F_II', '7,5 km', 115.85000000000001, 100.80000000000001, 91.35),
	(8, 18, 19, 'm', 'F_II', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 20, 24, 'm', 'F_II', '7,5 km', 59.849999999999994, 55.65, 51.45),
	(8, 25, 29, 'm', 'F_II', '7,5 km', 61.43333333333333, 57.233333333333334, 53.03333333333334),
	(8, 30, 34, 'm', 'F_II', '7,5 km', 65.63333333333333, 59.849999999999994, 53.55),
	(8, 35, 39, 'm', 'F_II', '7,5 km', 68.25000000000001, 61.43333333333333, 56.18333333333333),
	(8, 40, 44, 'm', 'F_II', '7,5 km', 69.30000000000001, 63.53333333333333, 56.7),
	(8, 45, 49, 'm', 'F_II', '7,5 km', 71.93333333333334, 65.63333333333333, 57.75000000000001),
	(8, 50, 54, 'm', 'F_II', '7,5 km', 74.55, 67.2, 60.383333333333326),
	(8, 55, 59, 'm', 'F_II', '7,5 km', 76.65, 68.25000000000001, 61.95),
	(8, 60, 64, 'm', 'F_II', '7,5 km', 79.53333333333332, 70.88333333333334, 63.53333333333333),
	(8, 65, 69, 'm', 'F_II', '7,5 km', 82.08333333333333, 72.98333333333333, 65.10000000000001),
	(8, 70, 74, 'm', 'F_II', '7,5 km', 85.58333333333333, 75.6, 68.25000000000001),
	(8, 75, 79, 'm', 'F_II', '7,5 km', 90.46666666666667, 79.53333333333332, 75.6),
	(8, 80, 84, 'm', 'F_II', '7,5 km', 96.06666666666668, 83.73333333333333, 75.6),
	(8, 85, 89, 'm', 'F_II', '7,5 km', 100.80000000000001, 88.46666666666667, 79.28333333333333),
	(8, 90, 200, 'm', 'F_II', '7,5 km', 107.88333333333334, 93.80000000000001, 84.0),
	(10, 0, 7, 'w', 'F_II', '', 4.8, 7.2, 9.6),
	(10, 8, 9, 'w', 'F_II', '', 7.2, 9.6, 12.0),
	(10, 10, 11, 'w', 'F_II', '', 8.8, 12.0, 14.4),
	(10, 0, 7, 'm', 'F_II', '', 9.6, 12.0, 13.6),
	(10, 8, 9, 'm', 'F_II', '', 13.6, 16.0, 18.4),
	(10, 10, 11, 'm', 'F_II', '', 16.8, 20.0, 22.4),
	(11, 12, 13, 'w', 'F_II', '', 12.0, 14.4, 17.6),
	(11, 14, 15, 'w', 'F_II', '', 16.0, 19.2, 21.6),
	(11, 16, 17, 'w', 'F_II', '', 19.2, 21.6, 24.8),
	(11, 12, 13, 'm', 'F_II', '', 20.8, 24.0, 26.4),
	(11, 14, 15, 'm', 'F_II', '', 24.0, 27.2, 29.6),
	(11, 16, 17, 'm', 'F_II', '', 27.2, 30.4, 33.6),
	(12, 0, 7, 'w', 'F_II', '1 kg', 3.75, 4.2, 4.88),
	(12, 8, 9, 'w', 'F_II', '1 kg', 4.25, 4.7, 5.38),
	(12, 10, 11, 'w', 'F_II', '1 kg', 4.75, 5.2, 5.88),
	(12, 12, 13, 'w', 'F_II', '1 kg', 5.25, 5.7, 6.38),
	(12, 14, 15, 'w', 'F_II', '1 kg', 5.75, 6.2, 6.88),
	(12, 16, 17, 'w', 'F_II', '1 kg', 6.25, 6.7, 7.38),
	(12, 18, 19, 'w', 'F_II', '2 kg', 6.75, 7.2, 7.88),
	(12, 20, 24, 'w', 'F_II', '2 kg', 6.75, 7.2, 7.88),
	(12, 25, 29, 'w', 'F_II', '2 kg', 6.3, 6.98, 7.65),
	(12, 30, 34, 'w', 'F_II', '2 kg', 5.85, 6.75, 7.65),
	(12, 35, 39, 'w', 'F_II', '2 kg', 5.4, 6.53, 7.43),
	(12, 40, 44, 'w', 'F_II', '2 kg', 4.73, 6.08, 7.43),
	(12, 45, 49, 'w', 'F_II', '2 kg', 4.28, 5.85, 7.2),
	(12, 50, 54, 'w', 'F_II', '2 kg', 3.83, 5.4, 6.98),
	(12, 55, 59, 'w', 'F_II', '2 kg', 3.6, 5.18, 6.75),
	(12, 60, 64, 'w', 'F_II', '2 kg', 3.38, 4.95, 6.53),
	(12, 65, 69, 'w', 'F_II', '2 kg', 3.15, 4.73, 6.3),
	(12, 70, 74, 'w', 'F_II', '2 kg', 2.93, 4.5, 6.08),
	(12, 75, 79, 'w', 'F_II', '2 kg', 2.93, 4.28, 5.85),
	(12, 80, 84, 'w', 'F_II', '2 kg', 2.7, 4.28, 5.63),
	(12, 85, 89, 'w', 'F_II', '2 kg', 2.7, 4.05, 5.4),
	(12, 90, 200, 'w', 'F_II', '2 kg', 2.48, 3.83, 4.95),
	(12, 0, 7, 'm', 'F_II', '1 kg', 6.23, 6.9, 7.58),
	(12, 8, 9, 'm', 'F_II', '1 kg', 6.73, 7.4, 8.08),
	(12, 10, 11, 'm', 'F_II', '1 kg', 7.23, 7.9, 8.58),
	(12, 12, 13, 'm', 'F_II', '1 kg', 7.73, 8.4, 9.08),
	(12, 14, 15, 'm', 'F_II', '1 kg', 8.23, 8.9, 9.58),
	(12, 16, 17, 'm', 'F_II', '1 kg', 8.73, 9.4, 10.08),
	(12, 18, 19, 'm', 'F_II', '2 kg', 9.23, 9.9, 10.58),
	(12, 20, 24, 'm', 'F_II', '2 kg', 9.23, 10.13, 10.8),
	(12, 25, 29, 'm', 'F_II', '2 kg', 8.78, 9.68, 10.58),
	(12, 30, 34, 'm', 'F_II', '2 kg', 8.1, 9.23, 10.35),
	(12, 35, 39, 'm', 'F_II', '2 kg', 7.43, 8.78, 10.13),
	(12, 40, 44, 'm', 'F_II', '2 kg', 6.98, 8.33, 9.68),
	(12, 45, 49, 'm', 'F_II', '2 kg', 6.3, 7.88, 9.45),
	(12, 50, 54, 'm', 'F_II', '2 kg', 5.85, 7.65, 9.23),
	(12, 55, 59, 'm', 'F_II', '2 kg', 5.4, 7.43, 9.0),
	(12, 60, 64, 'm', 'F_II', '2 kg', 5.18, 6.98, 8.78),
	(12, 65, 69, 'm', 'F_II', '2 kg', 4.73, 6.53, 8.33),
	(12, 70, 74, 'm', 'F_II', '2 kg', 4.5, 6.3, 8.1),
	(12, 75, 79, 'm', 'F_II', '2 kg', 4.05, 5.85, 7.65),
	(12, 80, 84, 'm', 'F_II', '2 kg', 3.83, 5.63, 7.43),
	(12, 85, 89, 'm', 'F_II', '2 kg', 3.6, 5.4, 7.2),
	(12, 90, 200, 'm', 'F_II', '2 kg', 3.15, 4.95, 6.75),
	(13, 12, 13, 'w', 'F_II', '2 kg', 4.04, 4.46, 4.89),
	(13, 14, 15, 'w', 'F_II', '3 kg', 4.68, 5.1, 5.53),
	(13, 16, 17, 'w', 'F_II', '3 kg', 4.89, 5.31, 5.74),
	(13, 18, 19, 'w', 'F_II', '4 kg', 6.18, 6.65, 7.13),
	(13, 20, 24, 'w', 'F_II', '4 kg', 6.18, 6.65, 7.13),
	(13, 25, 29, 'w', 'F_II', '4 kg', 6.18, 6.65, 7.13),
	(13, 30, 34, 'w', 'F_II', '4 kg', 5.94, 6.41, 6.89),
	(13, 35, 39, 'w', 'F_II', '4 kg', 5.7, 6.18, 6.65),
	(13, 40, 44, 'w', 'F_II', '4 kg', 5.23, 5.7, 6.18),
	(13, 45, 49, 'w', 'F_II', '4 kg', 4.99, 5.46, 5.94),
	(13, 50, 54, 'w', 'F_II', '3 kg', 4.99, 5.7, 6.65),
	(13, 55, 59, 'w', 'F_II', '3 kg', 4.75, 5.46, 6.18),
	(13, 60, 64, 'w', 'F_II', '3 kg', 4.51, 5.23, 5.94),
	(13, 65, 69, 'w', 'F_II', '3 kg', 4.28, 4.99, 5.94),
	(13, 70, 74, 'w', 'F_II', '3 kg', 4.04, 4.75, 5.7),
	(13, 75, 79, 'w', 'F_II', '2 kg', 4.04, 4.99, 5.94),
	(13, 80, 84, 'w', 'F_II', '2 kg', 3.8, 4.75, 5.46),
	(13, 85, 89, 'w', 'F_II', '2 kg', 3.56, 4.28, 5.23),
	(13, 90, 200, 'w', 'F_II', '2 kg', 3.09, 4.04, 4.75),
	(13, 12, 13, 'm', 'F_II', '3 kg', 5.31, 5.74, 6.16),
	(13, 14, 15, 'm', 'F_II', '4 kg', 5.95, 6.38, 6.8),
	(13, 16, 17, 'm', 'F_II', '5 kg', 6.38, 6.8, 7.23),
	(13, 18, 19, 'm', 'F_II', '6 kg', 7.36, 7.84, 8.31),
	(13, 20, 24, 'm', 'F_II', '7,26 kg', 7.36, 8.08, 8.55),
	(13, 25, 29, 'm', 'F_II', '7,26 kg', 7.13, 7.84, 8.31),
	(13, 30, 34, 'm', 'F_II', '7,26 kg', 6.65, 7.36, 7.84),
	(13, 35, 39, 'm', 'F_II', '7,26 kg', 6.41, 6.89, 7.6),
	(13, 40, 44, 'm', 'F_II', '7,26 kg', 5.94, 6.65, 7.36),
	(13, 45, 49, 'm', 'F_II', '7,26 kg', 5.7, 6.41, 7.13),
	(13, 50, 54, 'm', 'F_II', '6 kg', 5.94, 6.65, 7.6),
	(13, 55, 59, 'm', 'F_II', '6 kg', 5.7, 6.41, 7.13),
	(13, 60, 64, 'm', 'F_II', '5 kg', 5.7, 6.65, 7.6),
	(13, 65, 69, 'm', 'F_II', '5 kg', 5.46, 6.41, 7.13),
	(13, 70, 74, 'm', 'F_II', '4 kg', 5.7, 6.41, 7.36),
	(13, 75, 79, 'm', 'F_II', '4 kg', 5.46, 6.18, 7.13),
	(13, 80, 84, 'm', 'F_II', '3 kg', 5.23, 5.94, 6.89),
	(13, 85, 89, 'm', 'F_II', '3 kg', 4.75, 5.7, 6.41),
	(13, 90, 200, 'm', 'F_II', '3 kg', 4.28, 4.99, 5.94),
	(15, 0, 7, 'w', 'F_II', '', 0.84, 1.0, 1.12),
	(15, 8, 9, 'w', 'F_II', '', 0.92, 1.04, 1.2),
	(15, 10, 11, 'w', 'F_II', '', 1.04, 1.16, 1.32),
	(15, 12, 13, 'w', 'F_II', '', 1.12, 1.28, 1.44),
	(15, 14, 15, 'w', 'F_II', '', 1.24, 1.36, 1.52),
	(15, 16, 17, 'w', 'F_II', '', 1.32, 1.44, 1.6),
	(15, 18, 19, 'w', 'F_II', '', 1.32, 1.48, 1.64),
	(15, 20, 24, 'w', 'F_II', '', 1.28, 1.44, 1.6),
	(15, 25, 29, 'w', 'F_II', '', 1.2, 1.36, 1.56),
	(15, 30, 34, 'w', 'F_II', '', 1.08, 1.28, 1.48),
	(15, 35, 39, 'w', 'F_II', '', 1.0, 1.2, 1.44),
	(15, 40, 44, 'w', 'F_II', '', 0.92, 1.12, 1.32),
	(15, 45, 49, 'w', 'F_II', '', 0.88, 1.08, 1.28),
	(15, 50, 54, 'w', 'F_II', '', 0.8, 1.04, 1.24),
	(15, 55, 59, 'w', 'F_II', '', 0.76, 0.96, 1.16),
	(15, 60, 64, 'w', 'F_II', '', 0.76, 0.96, 1.16),
	(15, 65, 69, 'w', 'F_II', '', 0.72, 0.92, 1.12),
	(15, 70, 74, 'w', 'F_II', '', 0.72, 0.92, 1.08),
	(15, 75, 79, 'w', 'F_II', '', 0.72, 0.92, 1.08),
	(15, 80, 84, 'w', 'F_II', '', 0.72, 0.88, 1.04),
	(15, 85, 89, 'w', 'F_II', '', 0.68, 0.84, 1.0),
	(15, 90, 200, 'w', 'F_II', '', 0.64, 0.8, 0.96),
	(15, 0, 7, 'm', 'F_II', '', 0.92, 1.08, 1.2),
	(15, 8, 9, 'm', 'F_II', '', 1.04, 1.2, 1.32),
	(15, 10, 11, 'm', 'F_II', '', 1.2, 1.36, 1.48),
	(15, 12, 13, 'm', 'F_II', '', 1.36, 1.52, 1.64),
	(15, 14, 15, 'm', 'F_II', '', 1.52, 1.64, 1.8),
	(15, 16, 17, 'm', 'F_II', '', 1.64, 1.76, 1.92),
	(15, 18, 19, 'm', 'F_II', '', 1.68, 1.84, 2.0),
	(15, 20, 24, 'm', 'F_II', '', 1.68, 1.84, 2.0),
	(15, 25, 29, 'm', 'F_II', '', 1.64, 1.8, 1.96),
	(15, 30, 34, 'm', 'F_II', '', 1.48, 1.68, 1.88),
	(15, 35, 39, 'm', 'F_II', '', 1.32, 1.56, 1.8),
	(15, 40, 44, 'm', 'F_II', '', 1.24, 1.48, 1.72),
	(15, 45, 49, 'm', 'F_II', '', 1.16, 1.4, 1.64),
	(15, 50, 54, 'm', 'F_II', '', 1.12, 1.36, 1.6),
	(15, 55, 59, 'm', 'F_II', '', 1.08, 1.32, 1.56),
	(15, 60, 64, 'm', 'F_II', '', 1.04, 1.28, 1.52),
	(15, 65, 69, 'm', 'F_II', '', 1.04, 1.28, 1.52),
	(15, 70, 74, 'm', 'F_II', '', 1.0, 1.24, 1.48),
	(15, 75, 79, 'm', 'F_II', '', 0.96, 1.2, 1.44),
	(15, 80, 84, 'm', 'F_II', '', 0.92, 1.16, 1.4),
	(15, 85, 89, 'm', 'F_II', '', 0.8, 1.04, 1.28),
	(15, 90, 200, 'm', 'F_II', '', 0.72, 0.96, 1.2),
	(17, 0, 7, 'w', 'F_II', '30 m', 10.4, 9.2, 8.2),
	(17, 8, 9, 'w', 'F_II', '30 m', 9.6, 8.6, 7.4),
	(17, 10, 11, 'w', 'F_II', '50 m', 14.3, 13.1, 11.8),
	(17, 12, 13, 'w', 'F_II', '50 m', 13.8, 12.5, 11.1),
	(17, 14, 15, 'w', 'F_II', '100 m', 24.2, 22.1, 20.2),
	(17, 16, 17, 'w', 'F_II', '100 m', 22.9, 21.2, 19.5),
	(17, 18, 19, 'w', 'F_II', '100 m', 23.7, 21.5, 19.9),
	(17, 20, 24, 'w', 'F_II', '100 m', 24.1, 21.8, 20.3),
	(17, 25, 29, 'w', 'F_II', '100 m', 24.6, 22.4, 20.8),
	(17, 30, 34, 'w', 'F_II', '100 m', 25.5, 23.1, 21.3),
	(17, 35, 39, 'w', 'F_II', '100 m', 26.5, 24.2, 22.1),
	(17, 40, 44, 'w', 'F_II', '50 m', 14.3, 12.9, 11.4),
	(17, 45, 49, 'w', 'F_II', '50 m', 15.0, 13.4, 11.8),
	(17, 50, 54, 'w', 'F_II', '50 m', 15.5, 13.9, 12.4),
	(17, 55, 59, 'w', 'F_II', '50 m', 16.1, 14.6, 12.9),
	(17, 60, 64, 'w', 'F_II', '50 m', 16.4, 14.8, 13.3),
	(17, 65, 69, 'w', 'F_II', '50 m', 16.6, 15.1, 13.5),
	(17, 70, 74, 'w', 'F_II', '50 m', 16.9, 15.3, 13.8),
	(17, 75, 79, 'w', 'F_II', '50 m', 17.6, 16.0, 14.4),
	(17, 80, 84, 'w', 'F_II', '50 m', 18.6, 17.0, 15.6),
	(17, 85, 89, 'w', 'F_II', '50 m', 20.2, 18.6, 17.2),
	(17, 90, 200, 'w', 'F_II', '50 m', 22.2, 20.7, 19.2),
	(17, 0, 7, 'm', 'F_II', '30 m', 10.0, 8.8, 7.8),
	(17, 8, 9, 'm', 'F_II', '30 m', 9.4, 8.3, 7.4),
	(17, 10, 11, 'm', 'F_II', '50 m', 13.4, 12.1, 10.9),
	(17, 12, 13, 'm', 'F_II', '50 m', 12.6, 11.6, 10.5),
	(17, 14, 15, 'm', 'F_II', '100 m', 22.1, 20.0, 18.3),
	(17, 16, 17, 'm', 'F_II', '100 m', 21.2, 19.2, 17.6),
	(17, 18, 19, 'm', 'F_II', '100 m', 20.8, 19.0, 17.2),
	(17, 20, 24, 'm', 'F_II', '100 m', 20.5, 18.7, 16.9),
	(17, 25, 29, 'm', 'F_II', '100 m', 21.2, 19.2, 17.3),
	(17, 30, 34, 'm', 'F_II', '100 m', 21.8, 19.6, 17.7),
	(17, 35, 39, 'm', 'F_II', '100 m', 22.9, 20.7, 18.5),
	(17, 40, 44, 'm', 'F_II', '50 m', 12.5, 11.3, 10.0),
	(17, 45, 49, 'm', 'F_II', '50 m', 13.0, 11.6, 10.3),
	(17, 50, 54, 'm', 'F_II', '50 m', 13.4, 11.8, 10.7),
	(17, 55, 59, 'm', 'F_II', '50 m', 13.7, 12.2, 11.1),
	(17, 60, 64, 'm', 'F_II', '50 m', 14.0, 12.6, 11.4),
	(17, 65, 69, 'm', 'F_II', '50 m', 14.6, 13.3, 11.8),
	(17, 70, 74, 'm', 'F_II', '50 m', 15.2, 13.9, 12.5),
	(17, 75, 79, 'm', 'F_II', '50 m', 15.9, 14.6, 13.1),
	(17, 80, 84, 'm', 'F_II', '50 m', 16.9, 15.6, 14.2),
	(17, 85, 89, 'm', 'F_II', '50 m', 18.3, 17.0, 15.6),
	(17, 90, 200, 'm', 'F_II', '50 m', 20.2, 18.9, 17.4),
	(18, 0, 7, 'w', 'F_II', '', 60.5, 50.1, 39.7),
	(18, 8, 9, 'w', 'F_II', '', 54.6, 44.2, 36.4),
	(18, 10, 11, 'w', 'F_II', '', 50.7, 41.0, 33.2),
	(18, 12, 13, 'w', 'F_II', '', 45.5, 37.7, 30.6),
	(18, 14, 15, 'w', 'F_II', '', 42.9, 35.8, 28.0),
	(18, 16, 17, 'w', 'F_II', '', 39.7, 33.2, 26.0),
	(18, 18, 19, 'w', 'F_II', '', 38.4, 31.2, 24.1),
	(18, 20, 24, 'w', 'F_II', '', 37.7, 31.2, 24.1),
	(18, 25, 29, 'w', 'F_II', '', 39.0, 32.5, 25.4),
	(18, 30, 34, 'w', 'F_II', '', 42.3, 34.5, 27.3),
	(18, 35, 39, 'w', 'F_II', '', 46.8, 37.7, 28.6),
	(18, 40, 44, 'w', 'F_II', '', 52.0, 41.0, 30.6),
	(18, 45, 49, 'w', 'F_II', '', 57.2, 45.5, 32.5),
	(18, 50, 54, 'w', 'F_II', '', 62.4, 50.7, 36.4),
	(18, 55, 59, 'w', 'F_II', '', 67.0, 55.3, 39.7),
	(18, 60, 64, 'w', 'F_II', '', 70.9, 57.9, 42.3),
	(18, 65, 69, 'w', 'F_II', '', 73.5, 60.5, 44.9),
	(18, 70, 74, 'w', 'F_II', '', 76.7, 62.4, 46.8),
	(18, 75, 79, 'w', 'F_II', '', 79.3, 65.0, 49.4),
	(18, 80, 84, 'w', 'F_II', '', 82.6, 67.6, 52.0),
	(18, 85, 89, 'w', 'F_II', '', 85.2, 69.6, 54.0),
	(18, 90, 200, 'w', 'F_II', '', 86.5, 70.9, 55.3),
	(18, 0, 7, 'm', 'F_II', '', 59.8, 49.4, 39.0),
	(18, 8, 9, 'm', 'F_II', '', 53.3, 42.9, 33.8),
	(18, 10, 11, 'm', 'F_II', '', 46.8, 37.7, 29.3),
	(18, 12, 13, 'm', 'F_II', '', 42.9, 35.1, 27.3),
	(18, 14, 15, 'm', 'F_II', '', 40.3, 33.2, 26.0),
	(18, 16, 17, 'm', 'F_II', '', 38.4, 31.9, 24.7),
	(18, 18, 19, 'm', 'F_II', '', 36.4, 29.9, 22.8),
	(18, 20, 24, 'm', 'F_II', '', 35.1, 28.6, 20.2),
	(18, 25, 29, 'm', 'F_II', '', 37.7, 29.9, 21.5),
	(18, 30, 34, 'm', 'F_II', '', 41.0, 31.2, 22.1),
	(18, 35, 39, 'm', 'F_II', '', 45.5, 34.5, 24.1),
	(18, 40, 44, 'm', 'F_II', '', 50.1, 38.4, 24.7),
	(18, 45, 49, 'm', 'F_II', '', 54.6, 42.3, 26.7),
	(18, 50, 54, 'm', 'F_II', '', 58.5, 45.5, 29.9),
	(18, 55, 59, 'm', 'F_II', '', 63.7, 48.1, 32.5),
	(18, 60, 64, 'm', 'F_II', '', 66.3, 50.7, 35.1),
	(18, 65, 69, 'm', 'F_II', '', 68.3, 52.7, 37.1),
	(18, 70, 74, 'm', 'F_II', '', 71.5, 55.9, 40.3),
	(18, 75, 79, 'm', 'F_II', '', 74.8, 59.2, 43.6),
	(18, 80, 84, 'm', 'F_II', '', 76.7, 62.4, 46.8),
	(18, 85, 89, 'm', 'F_II', '', 77.4, 63.7, 49.4),
	(18, 90, 200, 'm', 'F_II', '', 78.0, 65.0, 52.0),
	(19, 8, 9, 'w', 'F_II', 'Tandem', 45.1, 39.6, 34.1),
	(19, 10, 11, 'w', 'F_II', 'Tandem', 40.7, 35.2, 29.7),
	(19, 12, 13, 'w', 'F_II', 'Tandem', 34.1, 29.7, 25.9),
	(19, 14, 15, 'w', 'F_II', 'Tandem', 29.7, 27.0, 23.7),
	(19, 16, 17, 'w', 'F_II', 'Tandem', 27.5, 24.8, 22.0),
	(19, 18, 19, 'w', 'F_II', 'Tandem', 26.4, 24.2, 21.5),
	(19, 20, 24, 'w', 'F_II', 'Tandem', 27.0, 24.2, 21.5),
	(19, 25, 29, 'w', 'F_II', 'Tandem', 27.5, 24.8, 22.0),
	(19, 30, 34, 'w', 'F_II', 'Tandem', 28.6, 25.9, 23.7),
	(19, 35, 39, 'w', 'F_II', 'Tandem', 30.3, 27.0, 24.2),
	(19, 40, 44, 'w', 'F_II', 'Tandem', 31.9, 28.1, 24.8),
	(19, 45, 49, 'w', 'F_II', 'Tandem', 33.6, 29.7, 25.3),
	(19, 50, 54, 'w', 'F_II', 'Tandem', 35.2, 30.8, 25.9),
	(19, 55, 59, 'w', 'F_II', 'Tandem', 36.9, 31.9, 26.4),
	(19, 60, 64, 'w', 'F_II', 'Tandem', 38.5, 33.0, 27.5),
	(19, 65, 69, 'w', 'F_II', 'Tandem', 39.6, 34.1, 28.1),
	(19, 70, 74, 'w', 'F_II', 'Tandem', 41.8, 35.2, 29.2),
	(19, 75, 79, 'w', 'F_II', 'Tandem', 42.9, 36.3, 30.3),
	(19, 80, 84, 'w', 'F_II', 'Tandem', 44.6, 38.0, 31.4),
	(19, 85, 89, 'w', 'F_II', 'Tandem', 46.2, 39.6, 33.0),
	(19, 90, 200, 'w', 'F_II', 'Tandem', 49.0, 41.8, 34.7),
	(19, 8, 9, 'm', 'F_II', 'Tandem', 41.8, 36.3, 30.8),
	(19, 10, 11, 'm', 'F_II', 'Tandem', 38.5, 33.6, 28.6),
	(19, 12, 13, 'm', 'F_II', 'Tandem', 32.5, 28.6, 24.8),
	(19, 14, 15, 'm', 'F_II', 'Tandem', 26.4, 23.7, 20.9),
	(19, 16, 17, 'm', 'F_II', 'Tandem', 24.2, 21.5, 18.7),
	(19, 18, 19, 'm', 'F_II', 'Tandem', 22.6, 19.8, 17.1),
	(19, 20, 24, 'm', 'F_II', 'Tandem', 22.0, 19.3, 16.5),
	(19, 25, 29, 'm', 'F_II', 'Tandem', 23.1, 19.8, 16.5),
	(19, 30, 34, 'm', 'F_II', 'Tandem', 24.8, 20.4, 16.5),
	(19, 35, 39, 'm', 'F_II', 'Tandem', 26.4, 22.0, 17.1),
	(19, 40, 44, 'm', 'F_II', 'Tandem', 29.2, 23.7, 18.2),
	(19, 45, 49, 'm', 'F_II', 'Tandem', 31.4, 25.3, 18.7),
	(19, 50, 54, 'm', 'F_II', 'Tandem', 33.0, 26.4, 19.8),
	(19, 55, 59, 'm', 'F_II', 'Tandem', 35.2, 27.5, 20.4),
	(19, 60, 64, 'm', 'F_II', 'Tandem', 36.9, 28.6, 20.9),
	(19, 65, 69, 'm', 'F_II', 'Tandem', 38.5, 29.7, 21.5),
	(19, 70, 74, 'm', 'F_II', 'Tandem', 39.6, 31.4, 22.0),
	(19, 75, 79, 'm', 'F_II', 'Tandem', 41.3, 32.5, 23.7),
	(19, 80, 84, 'm', 'F_II', 'Tandem', 42.9, 34.7, 25.3),
	(19, 85, 89, 'm', 'F_II', 'Tandem', 45.1, 36.3, 27.0),
	(19, 90, 200, 'm', 'F_II', 'Tandem', 47.9, 39.1, 29.7),
	(21, 10, 11, 'w', 'F_II', 'aus dem Stand', 0.52, 0.59, 0.65),
	(21, 12, 13, 'w', 'F_II', 'aus dem Stand', 0.59, 0.65, 0.72),
	(21, 14, 15, 'w', 'F_II', 'aus dem Stand', 0.62, 0.68, 0.75),
	(21, 16, 17, 'w', 'F_II', 'aus dem Stand', 0.68, 0.75, 0.81),
	(21, 18, 19, 'w', 'F_II', 'aus dem Stand', 0.72, 0.78, 0.85),
	(21, 20, 24, 'w', 'F_II', 'aus dem Stand', 0.72, 0.78, 0.85),
	(21, 25, 29, 'w', 'F_II', 'aus dem Stand', 0.68, 0.75, 0.81),
	(21, 30, 34, 'w', 'F_II', 'aus dem Stand', 0.65, 0.72, 0.78),
	(21, 35, 39, 'w', 'F_II', 'aus dem Stand', 0.62, 0.68, 0.75),
	(21, 40, 44, 'w', 'F_II', 'aus dem Stand', 0.59, 0.65, 0.72),
	(21, 45, 49, 'w', 'F_II', 'aus dem Stand', 0.59, 0.65, 0.72),
	(21, 50, 54, 'w', 'F_II', 'aus dem Stand', 0.55, 0.62, 0.68),
	(21, 55, 59, 'w', 'F_II', 'aus dem Stand', 0.52, 0.59, 0.65),
	(21, 60, 64, 'w', 'F_II', 'aus dem Stand', 0.49, 0.55, 0.62),
	(21, 65, 69, 'w', 'F_II', 'aus dem Stand', 0.49, 0.55, 0.62),
	(21, 70, 74, 'w', 'F_II', 'aus dem Stand', 0.46, 0.52, 0.59),
	(21, 75, 79, 'w', 'F_II', 'aus dem Stand', 0.42, 0.49, 0.55),
	(21, 80, 84, 'w', 'F_II', 'aus dem Stand', 0.42, 0.49, 0.55),
	(21, 85, 89, 'w', 'F_II', 'aus dem Stand', 0.39, 0.46, 0.52),
	(21, 90, 200, 'w', 'F_II', 'aus dem Stand', 0.36, 0.39, 0.42),
	(21, 10, 11, 'm', 'F_II', 'aus dem Stand', 0.55, 0.62, 0.68),
	(21, 12, 13, 'm', 'F_II', 'aus dem Stand', 0.62, 0.68, 0.75),
	(21, 14, 15, 'm', 'F_II', 'aus dem Stand', 0.72, 0.78, 0.85),
	(21, 16, 17, 'm', 'F_II', 'aus dem Stand', 0.78, 0.85, 0.91),
	(21, 18, 19, 'm', 'F_II', 'aus dem Stand', 0.85, 0.91, 0.98),
	(21, 20, 24, 'm', 'F_II', 'aus dem Stand', 0.88, 0.94, 1.01),
	(21, 25, 29, 'm', 'F_II', 'aus dem Stand', 0.85, 0.91, 0.98),
	(21, 30, 34, 'm', 'F_II', 'aus dem Stand', 0.85, 0.91, 0.98),
	(21, 35, 39, 'm', 'F_II', 'aus dem Stand', 0.81, 0.88, 0.94),
	(21, 40, 44, 'm', 'F_II', 'aus dem Stand', 0.78, 0.85, 0.91),
	(21, 45, 49, 'm', 'F_II', 'aus dem Stand', 0.75, 0.81, 0.88),
	(21, 50, 54, 'm', 'F_II', 'aus dem Stand', 0.68, 0.75, 0.81),
	(21, 55, 59, 'm', 'F_II', 'aus dem Stand', 0.65, 0.72, 0.78),
	(21, 60, 64, 'm', 'F_II', 'aus dem Stand', 0.62, 0.68, 0.75),
	(21, 65, 69, 'm', 'F_II', 'aus dem Stand', 0.55, 0.65, 0.72),
	(21, 70, 74, 'm', 'F_II', 'aus dem Stand', 0.52, 0.62, 0.68),
	(21, 75, 79, 'm', 'F_II', 'aus dem Stand', 0.49, 0.59, 0.65),
	(21, 80, 84, 'm', 'F_II', 'aus dem Stand', 0.49, 0.55, 0.62),
	(21, 85, 89, 'm', 'F_II', 'aus dem Stand', 0.46, 0.52, 0.59),
	(21, 90, 200, 'm', 'F_II', 'aus dem Stand', 0.42, 0.49, 0.55),
	(23, 0, 7, 'w', 'F_II', 'aus der Absprungfläche', 1.21, 1.42, 1.63),
	(23, 8, 9, 'w', 'F_II', 'aus der Absprungfläche', 1.41, 1.62, 1.83),
	(23, 10, 11, 'w', 'F_II', 'aus der Absprungfläche', 1.61, 1.82, 2.03),
	(23, 12, 13, 'w', 'F_II', 'aus der Absprungfläche', 1.96, 2.17, 2.38),
	(23, 14, 15, 'w', 'F_II', 'aus der Absprungfläche', 2.24, 2.45, 2.66),
	(23, 16, 17, 'w', 'F_II', 'aus der Absprungfläche', 2.38, 2.59, 2.8),
	(23, 18, 19, 'w', 'F_II', 'aus der Absprungfläche', 2.38, 2.59, 2.8),
	(23, 20, 24, 'w', 'F_II', 'aus der Absprungfläche', 2.38, 2.59, 2.8),
	(23, 25, 29, 'w', 'F_II', 'aus der Absprungfläche', 2.31, 2.52, 2.73),
	(23, 30, 34, 'w', 'F_II', 'aus der Absprungfläche', 2.24, 2.45, 2.66),
	(23, 35, 39, 'w', 'F_II', 'aus der Absprungfläche', 2.17, 2.38, 2.59),
	(23, 40, 44, 'w', 'F_II', 'aus der Absprungfläche', 2.1, 2.31, 2.52),
	(23, 45, 49, 'w', 'F_II', 'aus der Absprungfläche', 1.96, 2.24, 2.45),
	(23, 50, 54, 'w', 'F_II', 'aus der Absprungfläche', 1.82, 2.1, 2.38),
	(23, 55, 59, 'w', 'F_II', 'aus der Absprungfläche', 1.75, 2.03, 2.31),
	(23, 60, 64, 'w', 'F_II', 'aus der Absprungfläche', 1.68, 1.96, 2.24),
	(23, 65, 69, 'w', 'F_II', 'aus der Absprungfläche', 1.61, 1.89, 2.17),
	(23, 70, 74, 'w', 'F_II', 'aus der Absprungfläche', 1.47, 1.75, 2.03),
	(23, 75, 79, 'w', 'F_II', 'aus der Absprungfläche', 1.26, 1.54, 1.82),
	(23, 80, 84, 'w', 'F_II', 'aus der Absprungfläche', 1.12, 1.4, 1.68),
	(23, 85, 89, 'w', 'F_II', 'aus der Absprungfläche', 0.91, 1.19, 1.47),
	(23, 90, 200, 'w', 'F_II', 'aus der Absprungfläche', 0.77, 1.05, 1.33),
	(23, 0, 7, 'm', 'F_II', 'aus der Absprungfläche', 1.42, 1.63, 1.84),
	(23, 8, 9, 'm', 'F_II', 'aus der Absprungfläche', 1.62, 1.83, 2.04),
	(23, 10, 11, 'm', 'F_II', 'aus der Absprungfläche', 1.82, 2.03, 2.24),
	(23, 12, 13, 'm', 'F_II', 'aus der Absprungfläche', 2.24, 2.45, 2.66),
	(23, 14, 15, 'm', 'F_II', 'aus der Absprungfläche', 2.66, 2.87, 3.08),
	(23, 16, 17, 'm', 'F_II', 'aus der Absprungfläche', 3.01, 3.22, 3.43),
	(23, 18, 19, 'm', 'F_II', 'aus der Absprungfläche', 3.15, 3.36, 3.57),
	(23, 20, 24, 'm', 'F_II', 'aus der Absprungfläche', 3.08, 3.29, 3.5),
	(23, 25, 29, 'm', 'F_II', 'aus der Absprungfläche', 3.01, 3.22, 3.43),
	(23, 30, 34, 'm', 'F_II', 'aus der Absprungfläche', 2.94, 3.15, 3.36),
	(23, 35, 39, 'm', 'F_II', 'aus der Absprungfläche', 2.87, 3.08, 3.29),
	(23, 40, 44, 'm', 'F_II', 'aus der Absprungfläche', 2.73, 3.01, 3.22),
	(23, 45, 49, 'm', 'F_II', 'aus der Absprungfläche', 2.59, 2.87, 3.15),
	(23, 50, 54, 'm', 'F_II', 'aus der Absprungfläche', 2.52, 2.8, 3.08),
	(23, 55, 59, 'm', 'F_II', 'aus der Absprungfläche', 2.38, 2.66, 2.94),
	(23, 60, 64, 'm', 'F_II', 'aus der Absprungfläche', 2.24, 2.52, 2.8),
	(23, 65, 69, 'm', 'F_II', 'aus der Absprungfläche', 2.03, 2.31, 2.59),
	(23, 70, 74, 'm', 'F_II', 'aus der Absprungfläche', 1.89, 2.17, 2.45),
	(23, 75, 79, 'm', 'F_II', 'aus der Absprungfläche', 1.68, 2.03, 2.31),
	(23, 80, 84, 'm', 'F_II', 'aus der Absprungfläche', 1.47, 1.82, 2.17),
	(23, 85, 89, 'm', 'F_II', 'aus der Absprungfläche', 1.33, 1.68, 2.03),
	(23, 90, 200, 'm', 'F_II', 'aus der Absprungfläche', 1.12, 1.47, 1.82),
	(33, 0, 7, 'w', 'F_II', '', 5.6000000000000005, 8.4, 11.899999999999999),
	(33, 8, 9, 'w', 'F_II', '', 7.0, 10.500000000000002, 14.0),
	(33, 10, 11, 'w', 'F_II', '', 10.500000000000002, 14.0, 21.0),
	(33, 12, 13, 'w', 'F_II', '', 14.0, 21.0, 28.0),
	(33, 14, 15, 'w', 'F_II', '', 21.0, 28.0, 35.0),
	(33, 16, 17, 'w', 'F_II', '', 31.5, 42.0, 52.49999999999999),
	(33, 0, 7, 'm', 'F_II', '', 7.0, 10.500000000000002, 14.0),
	(33, 8, 9, 'm', 'F_II', '', 8.4, 11.899999999999999, 16.099999999999998),
	(33, 10, 11, 'm', 'F_II', '', 11.899999999999999, 17.5, 24.5),
	(33, 12, 13, 'm', 'F_II', '', 17.5, 24.5, 31.5),
	(33, 14, 15, 'm', 'F_II', '', 24.5, 31.5, 42.0),
	(33, 16, 17, 'm', 'F_II', '', 38.49999999999999, 49.0, 63.0),
	(39, 0, 7, 'w', 'F_II', '', 146.0, 163.0, 179.0),
	(39, 8, 9, 'w', 'F_II', '', 158.0, 175.0, 193.0),
	(39, 10, 11, 'w', 'F_II', '', 169.0, 188.0, 206.0),
	(39, 12, 13, 'w', 'F_II', '', 180.0, 200.0, 220.0),
	(39, 14, 15, 'w', 'F_II', '', 191.0, 213.0, 234.0),
	(39, 16, 17, 'w', 'F_II', '', 203.0, 225.0, 248.0),
	(39, 18, 19, 'w', 'F_II', '', 293.0, 325.0, 358.0),
	(39, 20, 24, 'w', 'F_II', '', 293.0, 325.0, 358.0),
	(39, 25, 29, 'w', 'F_II', '', 293.0, 325.0, 358.0),
	(39, 30, 34, 'w', 'F_II', '', 281.0, 313.0, 344.0),
	(39, 35, 39, 'w', 'F_II', '', 281.0, 313.0, 344.0),
	(39, 40, 44, 'w', 'F_II', '', 270.0, 300.0, 330.0),
	(39, 45, 49, 'w', 'F_II', '', 259.0, 288.0, 316.0),
	(39, 50, 54, 'w', 'F_II', '', 248.0, 275.0, 303.0),
	(39, 55, 59, 'w', 'F_II', '', 236.0, 263.0, 289.0),
	(39, 60, 64, 'w', 'F_II', '', 225.0, 250.0, 275.0),
	(39, 65, 69, 'w', 'F_II', '', 214.0, 238.0, 261.0),
	(39, 70, 74, 'w', 'F_II', '', 203.0, 225.0, 248.0),
	(39, 75, 79, 'w', 'F_II', '', 191.0, 213.0, 234.0),
	(39, 80, 84, 'w', 'F_II', '', 180.0, 200.0, 220.0),
	(39, 85, 89, 'w', 'F_II', '', 169.0, 188.0, 206.0),
	(39, 90, 200, 'w', 'F_II', '', 158.0, 175.0, 193.0),
	(39, 0, 7, 'm', 'F_II', '', 205.0, 228.0, 250.0),
	(39, 8, 9, 'm', 'F_II', '', 216.0, 240.0, 264.0),
	(39, 10, 11, 'm', 'F_II', '', 227.0, 253.0, 278.0),
	(39, 12, 13, 'm', 'F_II', '', 239.0, 265.0, 292.0),
	(39, 14, 15, 'm', 'F_II', '', 250.0, 278.0, 305.0),
	(39, 16, 17, 'm', 'F_II', '', 261.0, 290.0, 319.0),
	(39, 18, 19, 'm', 'F_II', '', 351.0, 390.0, 429.0),
	(39, 20, 24, 'm', 'F_II', '', 351.0, 390.0, 429.0),
	(39, 25, 29, 'm', 'F_II', '', 351.0, 390.0, 429.0),
	(39, 30, 34, 'm', 'F_II', '', 340.0, 378.0, 415.0),
	(39, 35, 39, 'm', 'F_II', '', 340.0, 378.0, 415.0),
	(39, 40, 44, 'm', 'F_II', '', 329.0, 365.0, 402.0),
	(39, 45, 49, 'm', 'F_II', '', 317.0, 353.0, 388.0),
	(39, 50, 54, 'm', 'F_II', '', 306.0, 340.0, 374.0),
	(39, 55, 59, 'm', 'F_II', '', 295.0, 328.0, 360.0),
	(39, 60, 64, 'm', 'F_II', '', 284.0, 315.0, 347.0),
	(39, 65, 69, 'm', 'F_II', '', 272.0, 303.0, 333.0),
	(39, 70, 74, 'm', 'F_II', '', 261.0, 290.0, 319.0),
	(39, 75, 79, 'm', 'F_II', '', 250.0, 278.0, 305.0),
	(39, 80, 84, 'm', 'F_II', '', 239.0, 265.0, 292.0),
	(39, 85, 89, 'm', 'F_II', '', 227.0, 253.0, 278.0),
	(39, 90, 200, 'm', 'F_II', '', 216.0, 240.0, 264.0),
	(40, 0, 7, 'w', 'F_II', '', 270.0, 300.0, 330.0),
	(40, 8, 9, 'w', 'F_II', '', 284.0, 315.0, 347.0),
	(40, 10, 11, 'w', 'F_II', '', 297.0, 330.0, 363.0),
	(40, 12, 13, 'w', 'F_II', '', 311.0, 345.0, 380.0),
	(40, 14, 15, 'w', 'F_II', '', 324.0, 360.0, 396.0),
	(40, 16, 17, 'w', 'F_II', '', 338.0, 375.0, 413.0),
	(40, 18, 19, 'w', 'F_II', '', 428.0, 475.0, 523.0),
	(40, 20, 24, 'w', 'F_II', '', 428.0, 475.0, 523.0),
	(40, 25, 29, 'w', 'F_II', '', 428.0, 475.0, 523.0),
	(40, 30, 34, 'w', 'F_II', '', 414.0, 460.0, 506.0),
	(40, 35, 39, 'w', 'F_II', '', 414.0, 460.0, 506.0),
	(40, 40, 44, 'w', 'F_II', '', 401.0, 445.0, 490.0),
	(40, 45, 49, 'w', 'F_II', '', 387.0, 430.0, 473.0),
	(40, 50, 54, 'w', 'F_II', '', 374.0, 415.0, 457.0),
	(40, 55, 59, 'w', 'F_II', '', 360.0, 400.0, 440.0),
	(40, 60, 64, 'w', 'F_II', '', 347.0, 385.0, 424.0),
	(40, 65, 69, 'w', 'F_II', '', 333.0, 370.0, 407.0),
	(40, 70, 74, 'w', 'F_II', '', 320.0, 355.0, 391.0),
	(40, 75, 79, 'w', 'F_II', '', 306.0, 340.0, 374.0),
	(40, 80, 84, 'w', 'F_II', '', 293.0, 325.0, 358.0),
	(40, 85, 89, 'w', 'F_II', '', 279.0, 310.0, 341.0),
	(40, 90, 200, 'w', 'F_II', '', 266.0, 295.0, 325.0),
	(40, 0, 7, 'm', 'F_II', '', 338.0, 375.0, 413.0),
	(40, 8, 9, 'm', 'F_II', '', 351.0, 390.0, 429.0),
	(40, 10, 11, 'm', 'F_II', '', 365.0, 405.0, 446.0),
	(40, 12, 13, 'm', 'F_II', '', 378.0, 420.0, 462.0),
	(40, 14, 15, 'm', 'F_II', '', 392.0, 435.0, 479.0),
	(40, 16, 17, 'm', 'F_II', '', 405.0, 450.0, 495.0),
	(40, 18, 19, 'm', 'F_II', '', 495.0, 550.0, 605.0),
	(40, 20, 24, 'm', 'F_II', '', 495.0, 550.0, 605.0),
	(40, 25, 29, 'm', 'F_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'F_II', '', 482.0, 535.0, 589.0),
	(40, 35, 39, 'm', 'F_II', '', 482.0, 535.0, 589.0),
	(40, 40, 44, 'm', 'F_II', '', 468.0, 520.0, 572.0),
	(40, 45, 49, 'm', 'F_II', '', 455.0, 505.0, 556.0),
	(40, 50, 54, 'm', 'F_II', '', 441.0, 490.0, 539.0),
	(40, 55, 59, 'm', 'F_II', '', 428.0, 475.0, 523.0),
	(40, 60, 64, 'm', 'F_II', '', 414.0, 460.0, 506.0),
	(40, 65, 69, 'm', 'F_II', '', 401.0, 445.0, 490.0),
	(40, 70, 74, 'm', 'F_II', '', 387.0, 430.0, 473.0),
	(40, 75, 79, 'm', 'F_II', '', 374.0, 415.0, 457.0),
	(40, 80, 84, 'm', 'F_II', '', 360.0, 400.0, 440.0),
	(40, 85, 89, 'm', 'F_II', '', 347.0, 385.0, 424.0),
	(40, 90, 200, 'm', 'F_II', '', 333.0, 370.0, 407.0),
	(41, 0, 7, 'w', 'F_II', '', 216.0, 240.0, 264.0),
	(41, 8, 9, 'w', 'F_II', '', 230.0, 255.0, 281.0),
	(41, 10, 11, 'w', 'F_II', '', 243.0, 270.0, 297.0),
	(41, 12, 13, 'w', 'F_II', '', 257.0, 285.0, 314.0),
	(41, 14, 15, 'w', 'F_II', '', 270.0, 300.0, 330.0),
	(41, 16, 17, 'w', 'F_II', '', 284.0, 315.0, 347.0),
	(41, 18, 19, 'w', 'F_II', '', 374.0, 415.0, 457.0),
	(41, 20, 24, 'w', 'F_II', '', 374.0, 415.0, 457.0),
	(41, 25, 29, 'w', 'F_II', '', 374.0, 415.0, 457.0),
	(41, 30, 34, 'w', 'F_II', '', 360.0, 400.0, 440.0),
	(41, 35, 39, 'w', 'F_II', '', 360.0, 400.0, 440.0),
	(41, 40, 44, 'w', 'F_II', '', 347.0, 385.0, 424.0),
	(41, 45, 49, 'w', 'F_II', '', 333.0, 370.0, 407.0),
	(41, 50, 54, 'w', 'F_II', '', 320.0, 355.0, 391.0),
	(41, 55, 59, 'w', 'F_II', '', 306.0, 340.0, 374.0),
	(41, 60, 64, 'w', 'F_II', '', 293.0, 325.0, 358.0),
	(41, 65, 69, 'w', 'F_II', '', 279.0, 310.0, 341.0),
	(41, 70, 74, 'w', 'F_II', '', 266.0, 295.0, 325.0),
	(41, 75, 79, 'w', 'F_II', '', 252.0, 280.0, 308.0),
	(41, 80, 84, 'w', 'F_II', '', 239.0, 265.0, 292.0),
	(41, 85, 89, 'w', 'F_II', '', 225.0, 250.0, 275.0),
	(41, 90, 200, 'w', 'F_II', '', 212.0, 235.0, 259.0),
	(41, 0, 7, 'm', 'F_II', '', 279.0, 310.0, 341.0),
	(41, 8, 9, 'm', 'F_II', '', 293.0, 325.0, 358.0),
	(41, 10, 11, 'm', 'F_II', '', 306.0, 340.0, 374.0),
	(41, 12, 13, 'm', 'F_II', '', 320.0, 355.0, 391.0),
	(41, 14, 15, 'm', 'F_II', '', 333.0, 370.0, 407.0),
	(41, 16, 17, 'm', 'F_II', '', 347.0, 385.0, 424.0),
	(41, 18, 19, 'm', 'F_II', '', 437.0, 485.0, 534.0),
	(41, 20, 24, 'm', 'F_II', '', 437.0, 485.0, 534.0),
	(41, 25, 29, 'm', 'F_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'F_II', '', 423.0, 470.0, 517.0),
	(41, 35, 39, 'm', 'F_II', '', 423.0, 470.0, 517.0),
	(41, 40, 44, 'm', 'F_II', '', 410.0, 455.0, 501.0),
	(41, 45, 49, 'm', 'F_II', '', 396.0, 440.0, 484.0),
	(41, 50, 54, 'm', 'F_II', '', 383.0, 425.0, 468.0),
	(41, 55, 59, 'm', 'F_II', '', 369.0, 410.0, 451.0),
	(41, 60, 64, 'm', 'F_II', '', 356.0, 395.0, 435.0),
	(41, 65, 69, 'm', 'F_II', '', 342.0, 380.0, 418.0),
	(41, 70, 74, 'm', 'F_II', '', 329.0, 365.0, 402.0),
	(41, 75, 79, 'm', 'F_II', '', 315.0, 350.0, 385.0),
	(41, 80, 84, 'm', 'F_II', '', 302.0, 335.0, 369.0),
	(41, 85, 89, 'm', 'F_II', '', 288.0, 320.0, 352.0),
	(41, 90, 200, 'm', 'F_II', '', 275.0, 305.0, 336.0),
	(42, 0, 7, 'w', 'F_II', '', 221.0, 245.0, 270.0),
	(42, 8, 9, 'w', 'F_II', '', 234.0, 260.0, 286.0),
	(42, 10, 11, 'w', 'F_II', '', 248.0, 275.0, 303.0),
	(42, 12, 13, 'w', 'F_II', '', 261.0, 290.0, 319.0),
	(42, 14, 15, 'w', 'F_II', '', 275.0, 305.0, 336.0),
	(42, 16, 17, 'w', 'F_II', '', 288.0, 320.0, 352.0),
	(42, 18, 19, 'w', 'F_II', '', 378.0, 420.0, 462.0),
	(42, 20, 24, 'w', 'F_II', '', 378.0, 420.0, 462.0),
	(42, 25, 29, 'w', 'F_II', '', 378.0, 420.0, 462.0),
	(42, 30, 34, 'w', 'F_II', '', 365.0, 405.0, 446.0),
	(42, 35, 39, 'w', 'F_II', '', 365.0, 405.0, 446.0),
	(42, 40, 44, 'w', 'F_II', '', 351.0, 390.0, 429.0),
	(42, 45, 49, 'w', 'F_II', '', 338.0, 375.0, 413.0),
	(42, 50, 54, 'w', 'F_II', '', 324.0, 360.0, 396.0),
	(42, 55, 59, 'w', 'F_II', '', 311.0, 345.0, 380.0),
	(42, 60, 64, 'w', 'F_II', '', 297.0, 330.0, 363.0),
	(42, 65, 69, 'w', 'F_II', '', 284.0, 315.0, 347.0),
	(42, 70, 74, 'w', 'F_II', '', 270.0, 300.0, 330.0),
	(42, 75, 79, 'w', 'F_II', '', 257.0, 285.0, 314.0),
	(42, 80, 84, 'w', 'F_II', '', 243.0, 270.0, 297.0),
	(42, 85, 89, 'w', 'F_II', '', 230.0, 255.0, 281.0),
	(42, 90, 200, 'w', 'F_II', '', 216.0, 240.0, 264.0),
	(42, 0, 7, 'm', 'F_II', '', 284.0, 315.0, 347.0),
	(42, 8, 9, 'm', 'F_II', '', 297.0, 330.0, 363.0),
	(42, 10, 11, 'm', 'F_II', '', 311.0, 345.0, 380.0),
	(42, 12, 13, 'm', 'F_II', '', 324.0, 360.0, 396.0),
	(42, 14, 15, 'm', 'F_II', '', 338.0, 375.0, 413.0),
	(42, 16, 17, 'm', 'F_II', '', 351.0, 390.0, 429.0),
	(42, 18, 19, 'm', 'F_II', '', 441.0, 490.0, 539.0),
	(42, 20, 24, 'm', 'F_II', '', 441.0, 490.0, 539.0),
	(42, 25, 29, 'm', 'F_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'F_II', '', 428.0, 475.0, 523.0),
	(42, 35, 39, 'm', 'F_II', '', 428.0, 475.0, 523.0),
	(42, 40, 44, 'm', 'F_II', '', 414.0, 460.0, 506.0),
	(42, 45, 49, 'm', 'F_II', '', 401.0, 445.0, 490.0),
	(42, 50, 54, 'm', 'F_II', '', 387.0, 430.0, 473.0),
	(42, 55, 59, 'm', 'F_II', '', 374.0, 415.0, 457.0),
	(42, 60, 64, 'm', 'F_II', '', 360.0, 400.0, 440.0),
	(42, 65, 69, 'm', 'F_II', '', 347.0, 385.0, 424.0),
	(42, 70, 74, 'm', 'F_II', '', 333.0, 370.0, 407.0),
	(42, 75, 79, 'm', 'F_II', '', 320.0, 355.0, 391.0),
	(42, 80, 84, 'm', 'F_II', '', 306.0, 340.0, 374.0),
	(42, 85, 89, 'm', 'F_II', '', 293.0, 325.0, 358.0),
	(42, 90, 200, 'm', 'F_II', '', 279.0, 310.0, 341.0),
	(44, 12, 13, 'w', 'F_II', '', 6.86, 7.59, 8.31),
	(44, 14, 15, 'w', 'F_II', '', 7.95, 8.67, 9.39),
	(44, 16, 17, 'w', 'F_II', '', 8.31, 9.03, 9.75),
	(44, 18, 19, 'w', 'F_II', '', 10.5, 11.31, 12.11),
	(44, 20, 24, 'w', 'F_II', '', 10.5, 11.31, 12.11),
	(44, 25, 29, 'w', 'F_II', '', 10.5, 11.31, 12.11),
	(44, 30, 34, 'w', 'F_II', '', 10.09, 10.9, 11.71),
	(44, 35, 39, 'w', 'F_II', '', 9.69, 10.5, 11.31),
	(44, 40, 44, 'w', 'F_II', '', 8.88, 9.69, 10.5),
	(44, 45, 49, 'w', 'F_II', '', 8.48, 9.29, 10.09),
	(44, 50, 54, 'w', 'F_II', '', 8.48, 9.69, 11.31),
	(44, 55, 59, 'w', 'F_II', '', 8.08, 9.29, 10.5),
	(44, 60, 64, 'w', 'F_II', '', 7.67, 8.88, 10.09),
	(44, 65, 69, 'w', 'F_II', '', 7.27, 8.48, 10.09),
	(44, 70, 74, 'w', 'F_II', '', 6.86, 8.08, 9.69),
	(44, 75, 79, 'w', 'F_II', '', 6.86, 8.48, 10.09),
	(44, 80, 84, 'w', 'F_II', '', 6.46, 8.08, 9.29),
	(44, 85, 89, 'w', 'F_II', '', 6.06, 7.27, 8.88),
	(44, 90, 200, 'w', 'F_II', '', 5.25, 6.86, 8.08),
	(44, 12, 13, 'm', 'F_II', '', 9.03, 9.75, 10.48),
	(44, 14, 15, 'm', 'F_II', '', 10.12, 10.84, 11.56),
	(44, 16, 17, 'm', 'F_II', '', 10.84, 11.56, 12.28),
	(44, 18, 19, 'm', 'F_II', '', 12.52, 13.32, 14.13),
	(44, 20, 24, 'm', 'F_II', '', 12.52, 13.73, 14.54),
	(44, 25, 29, 'm', 'F_II', '', 12.11, 13.32, 14.13),
	(44, 30, 34, 'm', 'F_II', '', 11.31, 12.52, 13.32),
	(44, 35, 39, 'm', 'F_II', '', 10.9, 11.71, 12.92),
	(44, 40, 44, 'm', 'F_II', '', 10.09, 11.31, 12.52),
	(44, 45, 49, 'm', 'F_II', '', 9.69, 10.9, 12.11),
	(44, 50, 54, 'm', 'F_II', '', 10.09, 11.31, 12.92),
	(44, 55, 59, 'm', 'F_II', '', 9.69, 10.9, 12.11),
	(44, 60, 64, 'm', 'F_II', '', 9.69, 11.31, 12.92),
	(44, 65, 69, 'm', 'F_II', '', 9.29, 10.9, 12.11),
	(44, 70, 74, 'm', 'F_II', '', 9.69, 10.9, 12.52),
	(44, 75, 79, 'm', 'F_II', '', 9.29, 10.5, 12.11),
	(44, 80, 84, 'm', 'F_II', '', 8.88, 10.09, 11.71),
	(44, 85, 89, 'm', 'F_II', '', 8.08, 9.69, 10.9),
	(44, 90, 200, 'm', 'F_II', '', 7.27, 8.48, 10.09),
	(53, 0, 7, 'w', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'F_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'F_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'F_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'F_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'F_III', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'w', 'F_III', '', 7.250000000000001, 6.283333333333333, 5.416666666666667),
	(1, 10, 11, 'w', 'F_III', '', 6.933333333333333, 6.066666666666666, 5.2),
	(1, 12, 13, 'w', 'F_III', '', 6.716666666666666, 5.75, 4.883333333333334),
	(1, 14, 15, 'w', 'F_III', '', 6.5, 5.633333333333333, 4.666666666666667),
	(1, 16, 17, 'w', 'F_III', '', 6.283333333333333, 5.3, 4.449999999999999),
	(1, 0, 7, 'm', 'F_III', '', 7.366666666666666, 6.5, 5.533333333333334),
	(1, 8, 9, 'm', 'F_III', '', 7.033333333333332, 6.066666666666666, 5.1),
	(1, 10, 11, 'm', 'F_III', '', 6.6000000000000005, 5.633333333333333, 4.666666666666667),
	(1, 12, 13, 'm', 'F_III', '', 6.166666666666666, 5.2, 4.2333333333333325),
	(1, 14, 15, 'm', 'F_III', '', 5.633333333333333, 4.766666666666667, 3.9000000000000004),
	(1, 16, 17, 'm', 'F_III', '', 5.3, 4.449999999999999, 3.5833333333333335),
	(4, 8, 9, 'w', 'F_III', '5 km', 32.400000000000006, 28.8, 25.200000000000003),
	(4, 10, 11, 'w', 'F_III', '10 km', 60.6, 51.6, 42.6),
	(4, 12, 13, 'w', 'F_III', '10 km', 54.0, 47.400000000000006, 40.199999999999996),
	(4, 14, 15, 'w', 'F_III', '10 km', 45.6, 39.0, 34.199999999999996),
	(4, 16, 17, 'w', 'F_III', '10 km', 39.0, 34.199999999999996, 30.0),
	(4, 18, 19, 'w', 'F_III', '20 km', 69.0, 62.400000000000006, 55.8),
	(4, 20, 24, 'w', 'F_III', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 25, 29, 'w', 'F_III', '20 km', 67.2, 60.6, 54.0),
	(4, 30, 34, 'w', 'F_III', '20 km', 68.39999999999999, 61.8, 54.6),
	(4, 35, 39, 'w', 'F_III', '20 km', 72.0, 63.6, 56.400000000000006),
	(4, 40, 44, 'w', 'F_III', '20 km', 76.80000000000001, 66.6, 59.400000000000006),
	(4, 45, 49, 'w', 'F_III', '20 km', 80.39999999999999, 70.2, 61.8),
	(4, 50, 54, 'w', 'F_III', '20 km', 82.80000000000001, 73.2, 64.2),
	(4, 55, 59, 'w', 'F_III', '20 km', 85.80000000000001, 75.6, 66.6),
	(4, 60, 64, 'w', 'F_III', '20 km', 88.80000000000001, 78.0, 68.39999999999999),
	(4, 65, 69, 'w', 'F_III', '20 km', 90.6, 79.80000000000001, 70.2),
	(4, 70, 74, 'w', 'F_III', '20 km', 93.6, 82.2, 72.6),
	(4, 75, 79, 'w', 'F_III', '20 km', 97.80000000000001, 84.6, 75.6),
	(4, 80, 84, 'w', 'F_III', '20 km', 101.39999999999999, 90.0, 78.6),
	(4, 85, 89, 'w', 'F_III', '20 km', 107.39999999999999, 96.0, 82.80000000000001),
	(4, 90, 200, 'w', 'F_III', '20 km', 111.6, 99.6, 87.0),
	(4, 8, 9, 'm', 'F_III', '5 km', 31.8, 28.200000000000003, 24.599999999999998),
	(4, 10, 11, 'm', 'F_III', '10 km', 58.199999999999996, 49.199999999999996, 40.199999999999996),
	(4, 12, 13, 'm', 'F_III', '10 km', 51.6, 44.400000000000006, 37.8),
	(4, 14, 15, 'm', 'F_III', '10 km', 38.400000000000006, 33.6, 28.8),
	(4, 16, 17, 'm', 'F_III', '10 km', 32.400000000000006, 28.200000000000003, 24.599999999999998),
	(4, 18, 19, 'm', 'F_III', '20 km', 56.400000000000006, 51.0, 46.199999999999996),
	(4, 20, 24, 'm', 'F_III', '20 km', 55.8, 50.400000000000006, 45.0),
	(4, 25, 29, 'm', 'F_III', '20 km', 60.0, 53.400000000000006, 46.8),
	(4, 30, 34, 'm', 'F_III', '20 km', 64.2, 56.400000000000006, 48.6),
	(4, 35, 39, 'm', 'F_III', '20 km', 69.6, 60.0, 49.8),
	(4, 40, 44, 'm', 'F_III', '20 km', 75.6, 62.400000000000006, 52.199999999999996),
	(4, 45, 49, 'm', 'F_III', '20 km', 79.2, 66.0, 54.0),
	(4, 50, 54, 'm', 'F_III', '20 km', 82.2, 68.39999999999999, 55.8),
	(4, 55, 59, 'm', 'F_III', '20 km', 84.6, 70.2, 57.0),
	(4, 60, 64, 'm', 'F_III', '20 km', 85.80000000000001, 72.0, 57.6),
	(4, 65, 69, 'm', 'F_III', '20 km', 87.0, 72.6, 58.199999999999996),
	(4, 70, 74, 'm', 'F_III', '20 km', 88.2, 73.80000000000001, 59.400000000000006),
	(4, 75, 79, 'm', 'F_III', '20 km', 89.39999999999999, 75.6, 61.8),
	(4, 80, 84, 'm', 'F_III', '20 km', 91.2, 77.39999999999999, 63.6),
	(4, 85, 89, 'm', 'F_III', '20 km', 93.0, 79.80000000000001, 66.6),
	(4, 90, 200, 'm', 'F_III', '20 km', 94.80000000000001, 81.6, 69.6),
	(5, 18, 19, 'w', 'F_III', '', 27.083333333333336, 24.48333333333333, 21.883333333333336),
	(5, 20, 24, 'w', 'F_III', '', 26.433333333333337, 23.833333333333332, 21.233333333333334),
	(5, 25, 29, 'w', 'F_III', '', 26.866666666666667, 24.266666666666666, 21.666666666666664),
	(5, 30, 34, 'w', 'F_III', '', 27.95, 25.35, 22.75),
	(5, 35, 39, 'w', 'F_III', '', 28.599999999999998, 26.0, 23.4),
	(5, 40, 44, 'w', 'F_III', '', 29.683333333333334, 26.866666666666667, 24.05),
	(5, 45, 49, 'w', 'F_III', '', 30.983333333333334, 27.95, 24.48333333333333),
	(5, 50, 54, 'w', 'F_III', '', 32.28333333333334, 28.816666666666663, 24.916666666666668),
	(5, 55, 59, 'w', 'F_III', '', 33.583333333333336, 29.683333333333334, 25.78333333333333),
	(5, 60, 64, 'w', 'F_III', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 65, 69, 'w', 'F_III', '', 35.31666666666666, 31.416666666666668, 27.516666666666666),
	(5, 70, 74, 'w', 'F_III', '', 35.96666666666666, 32.06666666666666, 28.166666666666668),
	(5, 75, 79, 'w', 'F_III', '', 37.050000000000004, 33.150000000000006, 29.249999999999996),
	(5, 80, 84, 'w', 'F_III', '', 38.56666666666667, 34.666666666666664, 30.76666666666667),
	(5, 85, 89, 'w', 'F_III', '', 40.3, 36.400000000000006, 32.49999999999999),
	(5, 90, 200, 'w', 'F_III', '', 42.25, 38.35, 34.45),
	(5, 18, 19, 'm', 'F_III', '', 23.183333333333334, 20.583333333333336, 17.983333333333334),
	(5, 20, 24, 'm', 'F_III', '', 22.533333333333335, 19.93333333333333, 17.333333333333332),
	(5, 25, 29, 'm', 'F_III', '', 22.966666666666665, 20.366666666666664, 17.76666666666667),
	(5, 30, 34, 'm', 'F_III', '', 24.05, 21.45, 18.85),
	(5, 35, 39, 'm', 'F_III', '', 25.78333333333333, 22.533333333333335, 19.5),
	(5, 40, 44, 'm', 'F_III', '', 27.3, 24.05, 20.583333333333336),
	(5, 45, 49, 'm', 'F_III', '', 28.816666666666663, 25.35, 21.45),
	(5, 50, 54, 'm', 'F_III', '', 30.333333333333332, 26.433333333333337, 22.533333333333335),
	(5, 55, 59, 'm', 'F_III', '', 30.983333333333334, 27.083333333333336, 23.183333333333334),
	(5, 60, 64, 'm', 'F_III', '', 31.85, 27.95, 24.05),
	(5, 65, 69, 'm', 'F_III', '', 32.49999999999999, 28.599999999999998, 24.700000000000003),
	(5, 70, 74, 'm', 'F_III', '', 32.93333333333334, 29.03333333333333, 25.13333333333333),
	(5, 75, 79, 'm', 'F_III', '', 33.8, 29.9, 26.0),
	(5, 80, 84, 'm', 'F_III', '', 34.45, 30.549999999999997, 26.650000000000002),
	(5, 85, 89, 'm', 'F_III', '', 35.75000000000001, 31.85, 27.95),
	(5, 90, 200, 'm', 'F_III', '', 38.78333333333333, 34.88333333333333, 30.983333333333334),
	(6, 18, 19, 'w', 'F_III', '', 110.06666666666668, 102.26666666666667, 94.46666666666667),
	(6, 20, 24, 'w', 'F_III', '', 108.55, 99.88333333333334, 92.94999999999999),
	(6, 25, 29, 'w', 'F_III', '', 108.55, 99.88333333333334, 92.30000000000001),
	(6, 30, 34, 'w', 'F_III', '', 109.41666666666667, 101.39999999999999, 92.73333333333333),
	(6, 35, 39, 'w', 'F_III', '', 113.96666666666667, 103.35, 92.94999999999999),
	(6, 40, 44, 'w', 'F_III', '', 118.73333333333333, 105.73333333333333, 93.16666666666666),
	(6, 45, 49, 'w', 'F_III', '', 123.93333333333334, 108.11666666666666, 94.68333333333332),
	(6, 50, 54, 'w', 'F_III', '', 126.96666666666667, 111.15, 96.2),
	(6, 55, 59, 'w', 'F_III', '', 130.21666666666667, 114.61666666666667, 99.01666666666668),
	(6, 60, 64, 'w', 'F_III', '', 133.68333333333334, 118.08333333333333, 102.48333333333335),
	(6, 65, 69, 'w', 'F_III', '', 137.36666666666667, 121.76666666666665, 106.16666666666666),
	(6, 70, 74, 'w', 'F_III', '', 142.35000000000002, 126.75, 111.15),
	(6, 75, 79, 'w', 'F_III', '', 149.93333333333334, 134.33333333333331, 118.73333333333333),
	(6, 80, 84, 'w', 'F_III', '', 159.03333333333336, 143.4333333333333, 127.83333333333333),
	(6, 85, 89, 'w', 'F_III', '', 167.91666666666669, 152.31666666666666, 136.71666666666667),
	(6, 90, 200, 'w', 'F_III', '', 177.45000000000002, 161.85, 146.25),
	(6, 18, 19, 'm', 'F_III', '', 82.33333333333334, 74.53333333333332, 66.73333333333333),
	(6, 20, 24, 'm', 'F_III', '', 81.25000000000001, 73.44999999999999, 65.0),
	(6, 25, 29, 'm', 'F_III', '', 85.80000000000001, 77.13333333333333, 67.6),
	(6, 30, 34, 'm', 'F_III', '', 90.56666666666668, 79.51666666666667, 71.28333333333333),
	(6, 35, 39, 'm', 'F_III', '', 96.41666666666667, 85.15, 73.88333333333334),
	(6, 40, 44, 'm', 'F_III', '', 102.48333333333335, 90.35, 78.21666666666665),
	(6, 45, 49, 'm', 'F_III', '', 108.76666666666665, 95.11666666666666, 82.55),
	(6, 50, 54, 'm', 'F_III', '', 114.83333333333333, 99.66666666666667, 85.15),
	(6, 55, 59, 'm', 'F_III', '', 118.94999999999999, 103.56666666666668, 87.96666666666667),
	(6, 60, 64, 'm', 'F_III', '', 123.06666666666668, 107.46666666666667, 91.86666666666666),
	(6, 65, 69, 'm', 'F_III', '', 127.39999999999999, 111.80000000000001, 96.2),
	(6, 70, 74, 'm', 'F_III', '', 132.8166666666667, 117.21666666666665, 101.61666666666667),
	(6, 75, 79, 'm', 'F_III', '', 139.53333333333333, 123.93333333333334, 108.33333333333334),
	(6, 80, 84, 'm', 'F_III', '', 147.11666666666665, 131.51666666666668, 115.91666666666666),
	(6, 85, 89, 'm', 'F_III', '', 156.21666666666667, 140.61666666666667, 125.01666666666668),
	(6, 90, 200, 'm', 'F_III', '', 165.9666666666667, 150.36666666666667, 134.76666666666668),
	(7, 0, 7, 'w', 'F_III', '200 m', 10.8, 9.2, 7.6000000000000005),
	(7, 8, 9, 'w', 'F_III', '200 m', 9.6, 8.4, 7.1),
	(7, 10, 11, 'w', 'F_III', '200 m', 8.8, 7.7, 6.6000000000000005),
	(7, 12, 13, 'w', 'F_III', '400 m', 17.8, 15.500000000000002, 13.2),
	(7, 14, 15, 'w', 'F_III', '400 m', 15.7, 14.0, 12.0),
	(7, 16, 17, 'w', 'F_III', '400 m', 14.2, 12.6, 10.899999999999999),
	(7, 18, 19, 'w', 'F_III', '800 m', 28.8, 25.4, 22.099999999999998),
	(7, 20, 24, 'w', 'F_III', '800 m', 28.3, 25.0, 21.599999999999998),
	(7, 25, 29, 'w', 'F_III', '800 m', 30.599999999999998, 25.3, 22.4),
	(7, 30, 34, 'w', 'F_III', '800 m', 34.6, 28.4, 23.4),
	(7, 35, 39, 'w', 'F_III', '800 m', 38.400000000000006, 30.700000000000003, 24.4),
	(7, 40, 44, 'w', 'F_III', '800 m', 40.8, 33.199999999999996, 25.599999999999998),
	(7, 45, 49, 'w', 'F_III', '800 m', 42.400000000000006, 34.8, 25.8),
	(7, 50, 54, 'w', 'F_III', '400 m', 21.599999999999998, 18.0, 13.8),
	(7, 55, 59, 'w', 'F_III', '400 m', 22.3, 18.4, 14.299999999999999),
	(7, 60, 64, 'w', 'F_III', '400 m', 22.8, 18.700000000000003, 14.6),
	(7, 65, 69, 'w', 'F_III', '400 m', 23.3, 18.9, 14.7),
	(7, 70, 74, 'w', 'F_III', '400 m', 23.8, 19.3, 15.2),
	(7, 75, 79, 'w', 'F_III', '200 m', 12.299999999999999, 10.0, 7.800000000000001),
	(7, 80, 84, 'w', 'F_III', '200 m', 12.500000000000002, 10.2, 8.100000000000001),
	(7, 85, 89, 'w', 'F_III', '200 m', 12.7, 10.500000000000002, 8.500000000000002),
	(7, 90, 200, 'w', 'F_III', '200 m', 12.899999999999999, 10.7, 8.8),
	(7, 0, 7, 'm', 'F_III', '200 m', 10.8, 8.8, 7.4),
	(7, 8, 9, 'm', 'F_III', '200 m', 9.6, 8.100000000000001, 6.800000000000001),
	(7, 10, 11, 'm', 'F_III', '200 m', 8.4, 7.6000000000000005, 6.2),
	(7, 12, 13, 'm', 'F_III', '400 m', 16.200000000000003, 13.8, 11.7),
	(7, 14, 15, 'm', 'F_III', '400 m', 14.4, 12.299999999999999, 10.6),
	(7, 16, 17, 'm', 'F_III', '400 m', 13.2, 11.6, 10.0),
	(7, 18, 19, 'm', 'F_III', '800 m', 27.099999999999998, 23.8, 20.4),
	(7, 20, 24, 'm', 'F_III', '800 m', 26.599999999999998, 23.4, 19.700000000000003),
	(7, 25, 29, 'm', 'F_III', '800 m', 27.8, 24.0, 20.4),
	(7, 30, 34, 'm', 'F_III', '800 m', 30.9, 25.8, 21.599999999999998),
	(7, 35, 39, 'm', 'F_III', '800 m', 34.6, 28.8, 23.099999999999998),
	(7, 40, 44, 'm', 'F_III', '800 m', 38.9, 31.700000000000003, 24.5),
	(7, 45, 49, 'm', 'F_III', '800 m', 41.400000000000006, 33.400000000000006, 24.8),
	(7, 50, 54, 'm', 'F_III', '400 m', 20.9, 17.200000000000003, 12.899999999999999),
	(7, 55, 59, 'm', 'F_III', '400 m', 21.4, 17.5, 13.6),
	(7, 60, 64, 'm', 'F_III', '400 m', 21.8, 17.700000000000003, 13.7),
	(7, 65, 69, 'm', 'F_III', '400 m', 22.099999999999998, 18.099999999999998, 13.8),
	(7, 70, 74, 'm', 'F_III', '400 m', 22.099999999999998, 18.3, 13.899999999999999),
	(7, 75, 79, 'm', 'F_III', '200 m', 11.299999999999999, 9.2, 7.3),
	(7, 80, 84, 'm', 'F_III', '200 m', 11.4, 9.4, 7.4),
	(7, 85, 89, 'm', 'F_III', '200 m', 11.4, 9.6, 7.7),
	(7, 90, 200, 'm', 'F_III', '200 m', 11.7, 9.8, 8.100000000000001),
	(8, 18, 19, 'w', 'F_III', '7,5 km', 76.44999999999999, 72.6, 68.2),
	(8, 20, 24, 'w', 'F_III', '7,5 km', 73.15, 69.30000000000001, 65.44999999999999),
	(8, 25, 29, 'w', 'F_III', '7,5 km', 73.7, 69.85000000000001, 66.0),
	(8, 30, 34, 'w', 'F_III', '7,5 km', 74.25000000000001, 70.39999999999999, 66.44999999999999),
	(8, 35, 39, 'w', 'F_III', '7,5 km', 77.0, 71.5, 66.83333333333333),
	(8, 40, 44, 'w', 'F_III', '7,5 km', 80.30000000000001, 73.7, 67.10000000000001),
	(8, 45, 49, 'w', 'F_III', '7,5 km', 83.05, 75.9, 68.2),
	(8, 50, 54, 'w', 'F_III', '7,5 km', 85.80000000000001, 78.10000000000001, 70.39999999999999),
	(8, 55, 59, 'w', 'F_III', '7,5 km', 88.0, 80.30000000000001, 72.6),
	(8, 60, 64, 'w', 'F_III', '7,5 km', 90.75, 81.94999999999999, 74.25000000000001),
	(8, 65, 69, 'w', 'F_III', '7,5 km', 92.66666666666667, 84.15, 77.0),
	(8, 70, 74, 'w', 'F_III', '7,5 km', 97.08333333333333, 86.9, 79.2),
	(8, 75, 79, 'w', 'F_III', '7,5 km', 101.75, 89.65, 81.94999999999999),
	(8, 80, 84, 'w', 'F_III', '7,5 km', 108.35, 93.78333333333333, 85.25000000000001),
	(8, 85, 89, 'w', 'F_III', '7,5 km', 114.39999999999999, 99.36666666666666, 90.2),
	(8, 90, 200, 'w', 'F_III', '7,5 km', 121.36666666666666, 105.6, 95.7),
	(8, 18, 19, 'm', 'F_III', '7,5 km', 64.35, 59.95, 55.55),
	(8, 20, 24, 'm', 'F_III', '7,5 km', 62.7, 58.3, 53.9),
	(8, 25, 29, 'm', 'F_III', '7,5 km', 64.35, 59.95, 55.55),
	(8, 30, 34, 'm', 'F_III', '7,5 km', 68.75, 62.7, 56.1),
	(8, 35, 39, 'm', 'F_III', '7,5 km', 71.5, 64.35, 58.849999999999994),
	(8, 40, 44, 'm', 'F_III', '7,5 km', 72.6, 66.55, 59.400000000000006),
	(8, 45, 49, 'm', 'F_III', '7,5 km', 75.35, 68.75, 60.49999999999999),
	(8, 50, 54, 'm', 'F_III', '7,5 km', 78.10000000000001, 70.39999999999999, 63.25),
	(8, 55, 59, 'm', 'F_III', '7,5 km', 80.30000000000001, 71.5, 64.9),
	(8, 60, 64, 'm', 'F_III', '7,5 km', 83.33333333333334, 74.25000000000001, 66.55),
	(8, 65, 69, 'm', 'F_III', '7,5 km', 85.98333333333333, 76.44999999999999, 68.2),
	(8, 70, 74, 'm', 'F_III', '7,5 km', 89.65, 79.2, 71.5),
	(8, 75, 79, 'm', 'F_III', '7,5 km', 94.78333333333333, 83.33333333333334, 79.2),
	(8, 80, 84, 'm', 'F_III', '7,5 km', 100.65, 87.73333333333333, 79.2),
	(8, 85, 89, 'm', 'F_III', '7,5 km', 105.6, 92.66666666666667, 83.05),
	(8, 90, 200, 'm', 'F_III', '7,5 km', 113.03333333333333, 98.26666666666667, 88.0),
	(10, 0, 7, 'w', 'F_III', '', 5.4, 8.1, 10.8),
	(10, 8, 9, 'w', 'F_III', '', 8.1, 10.8, 13.5),
	(10, 10, 11, 'w', 'F_III', '', 9.9, 13.5, 16.2),
	(10, 0, 7, 'm', 'F_III', '', 10.8, 13.5, 15.3),
	(10, 8, 9, 'm', 'F_III', '', 15.3, 18.0, 20.7),
	(10, 10, 11, 'm', 'F_III', '', 18.9, 22.5, 25.2),
	(11, 12, 13, 'w', 'F_III', '', 13.5, 16.2, 19.8),
	(11, 14, 15, 'w', 'F_III', '', 18.0, 21.6, 24.3),
	(11, 16, 17, 'w', 'F_III', '', 21.6, 24.3, 27.9),
	(11, 12, 13, 'm', 'F_III', '', 23.4, 27.0, 29.7),
	(11, 14, 15, 'm', 'F_III', '', 27.0, 30.6, 33.3),
	(11, 16, 17, 'm', 'F_III', '', 30.6, 34.2, 37.8),
	(12, 0, 7, 'w', 'F_III', '1 kg', 3.75, 4.2, 4.88),
	(12, 8, 9, 'w', 'F_III', '1 kg', 4.25, 4.7, 5.38),
	(12, 10, 11, 'w', 'F_III', '1 kg', 4.75, 5.2, 5.88),
	(12, 12, 13, 'w', 'F_III', '1 kg', 5.25, 5.7, 6.38),
	(12, 14, 15, 'w', 'F_III', '1 kg', 5.75, 6.2, 6.88),
	(12, 16, 17, 'w', 'F_III', '1 kg', 6.25, 6.7, 7.38),
	(12, 18, 19, 'w', 'F_III', '2 kg', 6.75, 7.2, 7.88),
	(12, 20, 24, 'w', 'F_III', '2 kg', 6.75, 7.2, 7.88),
	(12, 25, 29, 'w', 'F_III', '2 kg', 6.3, 6.98, 7.65),
	(12, 30, 34, 'w', 'F_III', '2 kg', 5.85, 6.75, 7.65),
	(12, 35, 39, 'w', 'F_III', '2 kg', 5.4, 6.53, 7.43),
	(12, 40, 44, 'w', 'F_III', '2 kg', 4.73, 6.08, 7.43),
	(12, 45, 49, 'w', 'F_III', '2 kg', 4.28, 5.85, 7.2),
	(12, 50, 54, 'w', 'F_III', '2 kg', 3.83, 5.4, 6.98),
	(12, 55, 59, 'w', 'F_III', '2 kg', 3.6, 5.18, 6.75),
	(12, 60, 64, 'w', 'F_III', '2 kg', 3.38, 4.95, 6.53),
	(12, 65, 69, 'w', 'F_III', '2 kg', 3.15, 4.73, 6.3),
	(12, 70, 74, 'w', 'F_III', '2 kg', 2.93, 4.5, 6.08),
	(12, 75, 79, 'w', 'F_III', '2 kg', 2.93, 4.28, 5.85),
	(12, 80, 84, 'w', 'F_III', '2 kg', 2.7, 4.28, 5.63),
	(12, 85, 89, 'w', 'F_III', '2 kg', 2.7, 4.05, 5.4),
	(12, 90, 200, 'w', 'F_III', '2 kg', 2.48, 3.83, 4.95),
	(12, 0, 7, 'm', 'F_III', '1 kg', 6.23, 6.9, 7.58),
	(12, 8, 9, 'm', 'F_III', '1 kg', 6.73, 7.4, 8.08),
	(12, 10, 11, 'm', 'F_III', '1 kg', 7.23, 7.9, 8.58),
	(12, 12, 13, 'm', 'F_III', '1 kg', 7.73, 8.4, 9.08),
	(12, 14, 15, 'm', 'F_III', '1 kg', 8.23, 8.9, 9.58),
	(12, 16, 17, 'm', 'F_III', '1 kg', 8.73, 9.4, 10.08),
	(12, 18, 19, 'm', 'F_III', '2 kg', 9.23, 9.9, 10.58),
	(12, 20, 24, 'm', 'F_III', '2 kg', 9.23, 10.13, 10.8),
	(12, 25, 29, 'm', 'F_III', '2 kg', 8.78, 9.68, 10.58),
	(12, 30, 34, 'm', 'F_III', '2 kg', 8.1, 9.23, 10.35),
	(12, 35, 39, 'm', 'F_III', '2 kg', 7.43, 8.78, 10.13),
	(12, 40, 44, 'm', 'F_III', '2 kg', 6.98, 8.33, 9.68),
	(12, 45, 49, 'm', 'F_III', '2 kg', 6.3, 7.88, 9.45),
	(12, 50, 54, 'm', 'F_III', '2 kg', 5.85, 7.65, 9.23),
	(12, 55, 59, 'm', 'F_III', '2 kg', 5.4, 7.43, 9.0),
	(12, 60, 64, 'm', 'F_III', '2 kg', 5.18, 6.98, 8.78),
	(12, 65, 69, 'm', 'F_III', '2 kg', 4.73, 6.53, 8.33),
	(12, 70, 74, 'm', 'F_III', '2 kg', 4.5, 6.3, 8.1),
	(12, 75, 79, 'm', 'F_III', '2 kg', 4.05, 5.85, 7.65),
	(12, 80, 84, 'm', 'F_III', '2 kg', 3.83, 5.63, 7.43),
	(12, 85, 89, 'm', 'F_III', '2 kg', 3.6, 5.4, 7.2),
	(12, 90, 200, 'm', 'F_III', '2 kg', 3.15, 4.95, 6.75),
	(13, 12, 13, 'w', 'F_III', '2 kg', 4.51, 4.99, 5.46),
	(13, 14, 15, 'w', 'F_III', '3 kg', 5.23, 5.7, 6.18),
	(13, 16, 17, 'w', 'F_III', '3 kg', 5.46, 5.94, 6.41),
	(13, 18, 19, 'w', 'F_III', '4 kg', 6.18, 6.65, 7.13),
	(13, 20, 24, 'w', 'F_III', '4 kg', 6.18, 6.65, 7.13),
	(13, 25, 29, 'w', 'F_III', '4 kg', 6.18, 6.65, 7.13),
	(13, 30, 34, 'w', 'F_III', '4 kg', 5.94, 6.41, 6.89),
	(13, 35, 39, 'w', 'F_III', '4 kg', 5.7, 6.18, 6.65),
	(13, 40, 44, 'w', 'F_III', '4 kg', 5.23, 5.7, 6.18),
	(13, 45, 49, 'w', 'F_III', '4 kg', 4.99, 5.46, 5.94),
	(13, 50, 54, 'w', 'F_III', '3 kg', 4.99, 5.7, 6.65),
	(13, 55, 59, 'w', 'F_III', '3 kg', 4.75, 5.46, 6.18),
	(13, 60, 64, 'w', 'F_III', '3 kg', 4.51, 5.23, 5.94),
	(13, 65, 69, 'w', 'F_III', '3 kg', 4.28, 4.99, 5.94),
	(13, 70, 74, 'w', 'F_III', '3 kg', 4.04, 4.75, 5.7),
	(13, 75, 79, 'w', 'F_III', '2 kg', 4.04, 4.99, 5.94),
	(13, 80, 84, 'w', 'F_III', '2 kg', 3.8, 4.75, 5.46),
	(13, 85, 89, 'w', 'F_III', '2 kg', 3.56, 4.28, 5.23),
	(13, 90, 200, 'w', 'F_III', '2 kg', 3.09, 4.04, 4.75),
	(13, 12, 13, 'm', 'F_III', '3 kg', 5.94, 6.41, 6.89),
	(13, 14, 15, 'm', 'F_III', '4 kg', 6.65, 7.13, 7.6),
	(13, 16, 17, 'm', 'F_III', '5 kg', 7.13, 7.6, 8.08),
	(13, 18, 19, 'm', 'F_III', '6 kg', 7.36, 7.84, 8.31),
	(13, 20, 24, 'm', 'F_III', '7,26 kg', 7.36, 8.08, 8.55),
	(13, 25, 29, 'm', 'F_III', '7,26 kg', 7.13, 7.84, 8.31),
	(13, 30, 34, 'm', 'F_III', '7,26 kg', 6.65, 7.36, 7.84),
	(13, 35, 39, 'm', 'F_III', '7,26 kg', 6.41, 6.89, 7.6),
	(13, 40, 44, 'm', 'F_III', '7,26 kg', 5.94, 6.65, 7.36),
	(13, 45, 49, 'm', 'F_III', '7,26 kg', 5.7, 6.41, 7.13),
	(13, 50, 54, 'm', 'F_III', '6 kg', 5.94, 6.65, 7.6),
	(13, 55, 59, 'm', 'F_III', '6 kg', 5.7, 6.41, 7.13),
	(13, 60, 64, 'm', 'F_III', '5 kg', 5.7, 6.65, 7.6),
	(13, 65, 69, 'm', 'F_III', '5 kg', 5.46, 6.41, 7.13),
	(13, 70, 74, 'm', 'F_III', '4 kg', 5.7, 6.41, 7.36),
	(13, 75, 79, 'm', 'F_III', '4 kg', 5.46, 6.18, 7.13),
	(13, 80, 84, 'm', 'F_III', '3 kg', 5.23, 5.94, 6.89),
	(13, 85, 89, 'm', 'F_III', '3 kg', 4.75, 5.7, 6.41),
	(13, 90, 200, 'm', 'F_III', '3 kg', 4.28, 4.99, 5.94),
	(15, 0, 7, 'w', 'F_III', '', 0.95, 1.13, 1.26),
	(15, 8, 9, 'w', 'F_III', '', 1.04, 1.17, 1.35),
	(15, 10, 11, 'w', 'F_III', '', 1.17, 1.31, 1.49),
	(15, 12, 13, 'w', 'F_III', '', 1.26, 1.44, 1.62),
	(15, 14, 15, 'w', 'F_III', '', 1.4, 1.53, 1.71),
	(15, 16, 17, 'w', 'F_III', '', 1.49, 1.62, 1.8),
	(15, 18, 19, 'w', 'F_III', '', 1.49, 1.67, 1.85),
	(15, 20, 24, 'w', 'F_III', '', 1.44, 1.62, 1.8),
	(15, 25, 29, 'w', 'F_III', '', 1.35, 1.53, 1.76),
	(15, 30, 34, 'w', 'F_III', '', 1.22, 1.44, 1.67),
	(15, 35, 39, 'w', 'F_III', '', 1.13, 1.35, 1.62),
	(15, 40, 44, 'w', 'F_III', '', 1.04, 1.26, 1.49),
	(15, 45, 49, 'w', 'F_III', '', 0.99, 1.22, 1.44),
	(15, 50, 54, 'w', 'F_III', '', 0.9, 1.17, 1.4),
	(15, 55, 59, 'w', 'F_III', '', 0.86, 1.08, 1.31),
	(15, 60, 64, 'w', 'F_III', '', 0.86, 1.08, 1.31),
	(15, 65, 69, 'w', 'F_III', '', 0.81, 1.04, 1.26),
	(15, 70, 74, 'w', 'F_III', '', 0.81, 1.04, 1.22),
	(15, 75, 79, 'w', 'F_III', '', 0.81, 1.04, 1.22),
	(15, 80, 84, 'w', 'F_III', '', 0.81, 0.99, 1.17),
	(15, 85, 89, 'w', 'F_III', '', 0.77, 0.95, 1.13),
	(15, 90, 200, 'w', 'F_III', '', 0.72, 0.9, 1.08),
	(15, 0, 7, 'm', 'F_III', '', 1.04, 1.22, 1.35),
	(15, 8, 9, 'm', 'F_III', '', 1.17, 1.35, 1.49),
	(15, 10, 11, 'm', 'F_III', '', 1.35, 1.53, 1.67),
	(15, 12, 13, 'm', 'F_III', '', 1.53, 1.71, 1.85),
	(15, 14, 15, 'm', 'F_III', '', 1.71, 1.85, 2.03),
	(15, 16, 17, 'm', 'F_III', '', 1.85, 1.98, 2.16),
	(15, 18, 19, 'm', 'F_III', '', 1.89, 2.07, 2.25),
	(15, 20, 24, 'm', 'F_III', '', 1.89, 2.07, 2.25),
	(15, 25, 29, 'm', 'F_III', '', 1.85, 2.03, 2.21),
	(15, 30, 34, 'm', 'F_III', '', 1.67, 1.89, 2.12),
	(15, 35, 39, 'm', 'F_III', '', 1.49, 1.76, 2.03),
	(15, 40, 44, 'm', 'F_III', '', 1.4, 1.67, 1.94),
	(15, 45, 49, 'm', 'F_III', '', 1.31, 1.58, 1.85),
	(15, 50, 54, 'm', 'F_III', '', 1.26, 1.53, 1.8),
	(15, 55, 59, 'm', 'F_III', '', 1.22, 1.49, 1.76),
	(15, 60, 64, 'm', 'F_III', '', 1.17, 1.44, 1.71),
	(15, 65, 69, 'm', 'F_III', '', 1.17, 1.44, 1.71),
	(15, 70, 74, 'm', 'F_III', '', 1.13, 1.4, 1.67),
	(15, 75, 79, 'm', 'F_III', '', 1.08, 1.35, 1.62),
	(15, 80, 84, 'm', 'F_III', '', 1.04, 1.31, 1.58),
	(15, 85, 89, 'm', 'F_III', '', 0.9, 1.17, 1.44),
	(15, 90, 200, 'm', 'F_III', '', 0.81, 1.08, 1.35),
	(17, 0, 7, 'w', 'F_III', '30 m', 10.4, 9.2, 8.2),
	(17, 8, 9, 'w', 'F_III', '30 m', 9.6, 8.6, 7.4),
	(17, 10, 11, 'w', 'F_III', '50 m', 14.3, 13.1, 11.8),
	(17, 12, 13, 'w', 'F_III', '50 m', 13.8, 12.5, 11.1),
	(17, 14, 15, 'w', 'F_III', '100 m', 24.2, 22.1, 20.2),
	(17, 16, 17, 'w', 'F_III', '100 m', 22.9, 21.2, 19.5),
	(17, 18, 19, 'w', 'F_III', '100 m', 23.7, 21.5, 19.9),
	(17, 20, 24, 'w', 'F_III', '100 m', 24.1, 21.8, 20.3),
	(17, 25, 29, 'w', 'F_III', '100 m', 24.6, 22.4, 20.8),
	(17, 30, 34, 'w', 'F_III', '100 m', 25.5, 23.1, 21.3),
	(17, 35, 39, 'w', 'F_III', '100 m', 26.5, 24.2, 22.1),
	(17, 40, 44, 'w', 'F_III', '50 m', 14.3, 12.9, 11.4),
	(17, 45, 49, 'w', 'F_III', '50 m', 15.0, 13.4, 11.8),
	(17, 50, 54, 'w', 'F_III', '50 m', 15.5, 13.9, 12.4),
	(17, 55, 59, 'w', 'F_III', '50 m', 16.1, 14.6, 12.9),
	(17, 60, 64, 'w', 'F_III', '50 m', 16.4, 14.8, 13.3),
	(17, 65, 69, 'w', 'F_III', '50 m', 16.6, 15.1, 13.5),
	(17, 70, 74, 'w', 'F_III', '50 m', 16.9, 15.3, 13.8),
	(17, 75, 79, 'w', 'F_III', '50 m', 17.6, 16.0, 14.4),
	(17, 80, 84, 'w', 'F_III', '50 m', 18.6, 17.0, 15.6),
	(17, 85, 89, 'w', 'F_III', '50 m', 20.2, 18.6, 17.2),
	(17, 90, 200, 'w', 'F_III', '50 m', 22.2, 20.7, 19.2),
	(17, 0, 7, 'm', 'F_III', '30 m', 10.0, 8.8, 7.8),
	(17, 8, 9, 'm', 'F_III', '30 m', 9.4, 8.3, 7.4),
	(17, 10, 11, 'm', 'F_III', '50 m', 13.4, 12.1, 10.9),
	(17, 12, 13, 'm', 'F_III', '50 m', 12.6, 11.6, 10.5),
	(17, 14, 15, 'm', 'F_III', '100 m', 22.1, 20.0, 18.3),
	(17, 16, 17, 'm', 'F_III', '100 m', 21.2, 19.2, 17.6),
	(17, 18, 19, 'm', 'F_III', '100 m', 20.8, 19.0, 17.2),
	(17, 20, 24, 'm', 'F_III', '100 m', 20.5, 18.7, 16.9),
	(17, 25, 29, 'm', 'F_III', '100 m', 21.2, 19.2, 17.3),
	(17, 30, 34, 'm', 'F_III', '100 m', 21.8, 19.6, 17.7),
	(17, 35, 39, 'm', 'F_III', '100 m', 22.9, 20.7, 18.5),
	(17, 40, 44, 'm', 'F_III', '50 m', 12.5, 11.3, 10.0),
	(17, 45, 49, 'm', 'F_III', '50 m', 13.0, 11.6, 10.3),
	(17, 50, 54, 'm', 'F_III', '50 m', 13.4, 11.8, 10.7),
	(17, 55, 59, 'm', 'F_III', '50 m', 13.7, 12.2, 11.1),
	(17, 60, 64, 'm', 'F_III', '50 m', 14.0, 12.6, 11.4),
	(17, 65, 69, 'm', 'F_III', '50 m', 14.6, 13.3, 11.8),
	(17, 70, 74, 'm', 'F_III', '50 m', 15.2, 13.9, 12.5),
	(17, 75, 79, 'm', 'F_III', '50 m', 15.9, 14.6, 13.1),
	(17, 80, 84, 'm', 'F_III', '50 m', 16.9, 15.6, 14.2),
	(17, 85, 89, 'm', 'F_III', '50 m', 18.3, 17.0, 15.6),
	(17, 90, 200, 'm', 'F_III', '50 m', 20.2, 18.9, 17.4),
	(18, 0, 7, 'w', 'F_III', '', 55.8, 46.2, 36.6),
	(18, 8, 9, 'w', 'F_III', '', 50.4, 40.8, 33.6),
	(18, 10, 11, 'w', 'F_III', '', 46.8, 37.8, 30.6),
	(18, 12, 13, 'w', 'F_III', '', 42.0, 34.8, 28.2),
	(18, 14, 15, 'w', 'F_III', '', 39.6, 33.0, 25.8),
	(18, 16, 17, 'w', 'F_III', '', 36.6, 30.6, 24.0),
	(18, 18, 19, 'w', 'F_III', '', 35.4, 28.8, 22.2),
	(18, 20, 24, 'w', 'F_III', '', 34.8, 28.8, 22.2),
	(18, 25, 29, 'w', 'F_III', '', 36.0, 30.0, 23.4),
	(18, 30, 34, 'w', 'F_III', '', 39.0, 31.8, 25.2),
	(18, 35, 39, 'w', 'F_III', '', 43.2, 34.8, 26.4),
	(18, 40, 44, 'w', 'F_III', '', 48.0, 37.8, 28.2),
	(18, 45, 49, 'w', 'F_III', '', 52.8, 42.0, 30.0),
	(18, 50, 54, 'w', 'F_III', '', 57.6, 46.8, 33.6),
	(18, 55, 59, 'w', 'F_III', '', 61.8, 51.0, 36.6),
	(18, 60, 64, 'w', 'F_III', '', 65.4, 53.4, 39.0),
	(18, 65, 69, 'w', 'F_III', '', 67.8, 55.8, 41.4),
	(18, 70, 74, 'w', 'F_III', '', 70.8, 57.6, 43.2),
	(18, 75, 79, 'w', 'F_III', '', 73.2, 60.0, 45.6),
	(18, 80, 84, 'w', 'F_III', '', 76.2, 62.4, 48.0),
	(18, 85, 89, 'w', 'F_III', '', 78.6, 64.2, 49.8),
	(18, 90, 200, 'w', 'F_III', '', 79.8, 65.4, 51.0),
	(18, 0, 7, 'm', 'F_III', '', 55.2, 45.6, 36.0),
	(18, 8, 9, 'm', 'F_III', '', 49.2, 39.6, 31.2),
	(18, 10, 11, 'm', 'F_III', '', 43.2, 34.8, 27.0),
	(18, 12, 13, 'm', 'F_III', '', 39.6, 32.4, 25.2),
	(18, 14, 15, 'm', 'F_III', '', 37.2, 30.6, 24.0),
	(18, 16, 17, 'm', 'F_III', '', 35.4, 29.4, 22.8),
	(18, 18, 19, 'm', 'F_III', '', 33.6, 27.6, 21.0),
	(18, 20, 24, 'm', 'F_III', '', 32.4, 26.4, 18.6),
	(18, 25, 29, 'm', 'F_III', '', 34.8, 27.6, 19.8),
	(18, 30, 34, 'm', 'F_III', '', 37.8, 28.8, 20.4),
	(18, 35, 39, 'm', 'F_III', '', 42.0, 31.8, 22.2),
	(18, 40, 44, 'm', 'F_III', '', 46.2, 35.4, 22.8),
	(18, 45, 49, 'm', 'F_III', '', 50.4, 39.0, 24.6),
	(18, 50, 54, 'm', 'F_III', '', 54.0, 42.0, 27.6),
	(18, 55, 59, 'm', 'F_III', '', 58.8, 44.4, 30.0),
	(18, 60, 64, 'm', 'F_III', '', 61.2, 46.8, 32.4),
	(18, 65, 69, 'm', 'F_III', '', 63.0, 48.6, 34.2),
	(18, 70, 74, 'm', 'F_III', '', 66.0, 51.6, 37.2),
	(18, 75, 79, 'm', 'F_III', '', 69.0, 54.6, 40.2),
	(18, 80, 84, 'm', 'F_III', '', 70.8, 57.6, 43.2),
	(18, 85, 89, 'm', 'F_III', '', 71.4, 58.8, 45.6),
	(18, 90, 200, 'm', 'F_III', '', 72.0, 60.0, 48.0),
	(19, 8, 9, 'w', 'F_III', '', 49.2, 43.2, 37.2),
	(19, 10, 11, 'w', 'F_III', '', 44.4, 38.4, 32.4),
	(19, 12, 13, 'w', 'F_III', '', 37.2, 32.4, 28.2),
	(19, 14, 15, 'w', 'F_III', '', 32.4, 29.4, 25.8),
	(19, 16, 17, 'w', 'F_III', '', 30.0, 27.0, 24.0),
	(19, 18, 19, 'w', 'F_III', '', 28.8, 26.4, 23.4),
	(19, 20, 24, 'w', 'F_III', '', 29.4, 26.4, 23.4),
	(19, 25, 29, 'w', 'F_III', '', 30.0, 27.0, 24.0),
	(19, 30, 34, 'w', 'F_III', '', 31.2, 28.2, 25.8),
	(19, 35, 39, 'w', 'F_III', '', 33.0, 29.4, 26.4),
	(19, 40, 44, 'w', 'F_III', '', 34.8, 30.6, 27.0),
	(19, 45, 49, 'w', 'F_III', '', 36.6, 32.4, 27.6),
	(19, 50, 54, 'w', 'F_III', '', 38.4, 33.6, 28.2),
	(19, 55, 59, 'w', 'F_III', '', 40.2, 34.8, 28.8),
	(19, 60, 64, 'w', 'F_III', '', 42.0, 36.0, 30.0),
	(19, 65, 69, 'w', 'F_III', '', 43.2, 37.2, 30.6),
	(19, 70, 74, 'w', 'F_III', '', 45.6, 38.4, 31.8),
	(19, 75, 79, 'w', 'F_III', '', 46.8, 39.6, 33.0),
	(19, 80, 84, 'w', 'F_III', '', 48.6, 41.4, 34.2),
	(19, 85, 89, 'w', 'F_III', '', 50.4, 43.2, 36.0),
	(19, 90, 200, 'w', 'F_III', '', 53.4, 45.6, 37.8),
	(19, 8, 9, 'm', 'F_III', '', 45.6, 39.6, 33.6),
	(19, 10, 11, 'm', 'F_III', '', 42.0, 36.6, 31.2),
	(19, 12, 13, 'm', 'F_III', '', 35.4, 31.2, 27.0),
	(19, 14, 15, 'm', 'F_III', '', 28.8, 25.8, 22.8),
	(19, 16, 17, 'm', 'F_III', '', 26.4, 23.4, 20.4),
	(19, 18, 19, 'm', 'F_III', '', 24.6, 21.6, 18.6),
	(19, 20, 24, 'm', 'F_III', '', 24.0, 21.0, 18.0),
	(19, 25, 29, 'm', 'F_III', '', 25.2, 21.6, 18.0),
	(19, 30, 34, 'm', 'F_III', '', 27.0, 22.2, 18.0),
	(19, 35, 39, 'm', 'F_III', '', 28.8, 24.0, 18.6),
	(19, 40, 44, 'm', 'F_III', '', 31.8, 25.8, 19.8),
	(19, 45, 49, 'm', 'F_III', '', 34.2, 27.6, 20.4),
	(19, 50, 54, 'm', 'F_III', '', 36.0, 28.8, 21.6),
	(19, 55, 59, 'm', 'F_III', '', 38.4, 30.0, 22.2),
	(19, 60, 64, 'm', 'F_III', '', 40.2, 31.2, 22.8),
	(19, 65, 69, 'm', 'F_III', '', 42.0, 32.4, 23.4),
	(19, 70, 74, 'm', 'F_III', '', 43.2, 34.2, 24.0),
	(19, 75, 79, 'm', 'F_III', '', 45.0, 35.4, 25.8),
	(19, 80, 84, 'm', 'F_III', '', 46.8, 37.8, 27.6),
	(19, 85, 89, 'm', 'F_III', '', 49.2, 39.6, 29.4),
	(19, 90, 200, 'm', 'F_III', '', 52.2, 42.6, 32.4),
	(21, 10, 11, 'w', 'F_III', '', 0.64, 0.72, 0.8),
	(21, 12, 13, 'w', 'F_III', '', 0.72, 0.8, 0.88),
	(21, 14, 15, 'w', 'F_III', '', 0.76, 0.84, 0.92),
	(21, 16, 17, 'w', 'F_III', '', 0.84, 0.92, 1.0),
	(21, 18, 19, 'w', 'F_III', '', 0.88, 0.96, 1.04),
	(21, 20, 24, 'w', 'F_III', '', 0.88, 0.96, 1.04),
	(21, 25, 29, 'w', 'F_III', '', 0.84, 0.92, 1.0),
	(21, 30, 34, 'w', 'F_III', '', 0.8, 0.88, 0.96),
	(21, 35, 39, 'w', 'F_III', '', 0.76, 0.84, 0.92),
	(21, 40, 44, 'w', 'F_III', '', 0.72, 0.8, 0.88),
	(21, 45, 49, 'w', 'F_III', '', 0.72, 0.8, 0.88),
	(21, 50, 54, 'w', 'F_III', '', 0.68, 0.76, 0.84),
	(21, 55, 59, 'w', 'F_III', '', 0.64, 0.72, 0.8),
	(21, 60, 64, 'w', 'F_III', '', 0.6, 0.68, 0.76),
	(21, 65, 69, 'w', 'F_III', '', 0.6, 0.68, 0.76),
	(21, 70, 74, 'w', 'F_III', '', 0.56, 0.64, 0.72),
	(21, 75, 79, 'w', 'F_III', '', 0.52, 0.6, 0.68),
	(21, 80, 84, 'w', 'F_III', '', 0.52, 0.6, 0.68),
	(21, 85, 89, 'w', 'F_III', '', 0.48, 0.56, 0.64),
	(21, 90, 200, 'w', 'F_III', '', 0.44, 0.48, 0.52),
	(21, 10, 11, 'm', 'F_III', '', 0.68, 0.76, 0.84),
	(21, 12, 13, 'm', 'F_III', '', 0.76, 0.84, 0.92),
	(21, 14, 15, 'm', 'F_III', '', 0.88, 0.96, 1.04),
	(21, 16, 17, 'm', 'F_III', '', 0.96, 1.04, 1.12),
	(21, 18, 19, 'm', 'F_III', '', 1.04, 1.12, 1.2),
	(21, 20, 24, 'm', 'F_III', '', 1.08, 1.16, 1.24),
	(21, 25, 29, 'm', 'F_III', '', 1.04, 1.12, 1.2),
	(21, 30, 34, 'm', 'F_III', '', 1.04, 1.12, 1.2),
	(21, 35, 39, 'm', 'F_III', '', 1.0, 1.08, 1.16),
	(21, 40, 44, 'm', 'F_III', '', 0.96, 1.04, 1.12),
	(21, 45, 49, 'm', 'F_III', '', 0.92, 1.0, 1.08),
	(21, 50, 54, 'm', 'F_III', '', 0.84, 0.92, 1.0),
	(21, 55, 59, 'm', 'F_III', '', 0.8, 0.88, 0.96),
	(21, 60, 64, 'm', 'F_III', '', 0.76, 0.84, 0.92),
	(21, 65, 69, 'm', 'F_III', '', 0.68, 0.8, 0.88),
	(21, 70, 74, 'm', 'F_III', '', 0.64, 0.76, 0.84),
	(21, 75, 79, 'm', 'F_III', '', 0.6, 0.72, 0.8),
	(21, 80, 84, 'm', 'F_III', '', 0.6, 0.68, 0.76),
	(21, 85, 89, 'm', 'F_III', '', 0.56, 0.64, 0.72),
	(21, 90, 200, 'm', 'F_III', '', 0.52, 0.6, 0.68),
	(23, 0, 7, 'w', 'F_III', '', 1.44, 1.68, 1.92),
	(23, 8, 9, 'w', 'F_III', '', 1.64, 1.88, 2.12),
	(23, 10, 11, 'w', 'F_III', '', 1.84, 2.08, 2.32),
	(23, 12, 13, 'w', 'F_III', '', 2.24, 2.48, 2.72),
	(23, 14, 15, 'w', 'F_III', '', 2.56, 2.8, 3.04),
	(23, 16, 17, 'w', 'F_III', '', 2.72, 2.96, 3.2),
	(23, 18, 19, 'w', 'F_III', '', 2.72, 2.96, 3.2),
	(23, 20, 24, 'w', 'F_III', '', 2.72, 2.96, 3.2),
	(23, 25, 29, 'w', 'F_III', '', 2.64, 2.88, 3.12),
	(23, 30, 34, 'w', 'F_III', '', 2.56, 2.8, 3.04),
	(23, 35, 39, 'w', 'F_III', '', 2.48, 2.72, 2.96),
	(23, 40, 44, 'w', 'F_III', '', 2.4, 2.64, 2.88),
	(23, 45, 49, 'w', 'F_III', '', 2.24, 2.56, 2.8),
	(23, 50, 54, 'w', 'F_III', '', 2.08, 2.4, 2.72),
	(23, 55, 59, 'w', 'F_III', '', 2.0, 2.32, 2.64),
	(23, 60, 64, 'w', 'F_III', '', 1.92, 2.24, 2.56),
	(23, 65, 69, 'w', 'F_III', '', 1.84, 2.16, 2.48),
	(23, 70, 74, 'w', 'F_III', '', 1.68, 2.0, 2.32),
	(23, 75, 79, 'w', 'F_III', '', 1.44, 1.76, 2.08),
	(23, 80, 84, 'w', 'F_III', '', 1.28, 1.6, 1.92),
	(23, 85, 89, 'w', 'F_III', '', 1.04, 1.36, 1.68),
	(23, 90, 200, 'w', 'F_III', '', 0.88, 1.2, 1.52),
	(23, 0, 7, 'm', 'F_III', '', 1.68, 1.92, 2.16),
	(23, 8, 9, 'm', 'F_III', '', 1.88, 2.12, 2.36),
	(23, 10, 11, 'm', 'F_III', '', 2.08, 2.32, 2.56),
	(23, 12, 13, 'm', 'F_III', '', 2.56, 2.8, 3.04),
	(23, 14, 15, 'm', 'F_III', '', 3.04, 3.28, 3.52),
	(23, 16, 17, 'm', 'F_III', '', 3.44, 3.68, 3.92),
	(23, 18, 19, 'm', 'F_III', '', 3.6, 3.84, 4.08),
	(23, 20, 24, 'm', 'F_III', '', 3.52, 3.76, 4.0),
	(23, 25, 29, 'm', 'F_III', '', 3.44, 3.68, 3.92),
	(23, 30, 34, 'm', 'F_III', '', 3.36, 3.6, 3.84),
	(23, 35, 39, 'm', 'F_III', '', 3.28, 3.52, 3.76),
	(23, 40, 44, 'm', 'F_III', '', 3.12, 3.44, 3.68),
	(23, 45, 49, 'm', 'F_III', '', 2.96, 3.28, 3.6),
	(23, 50, 54, 'm', 'F_III', '', 2.88, 3.2, 3.52),
	(23, 55, 59, 'm', 'F_III', '', 2.72, 3.04, 3.36),
	(23, 60, 64, 'm', 'F_III', '', 2.56, 2.88, 3.2),
	(23, 65, 69, 'm', 'F_III', '', 2.32, 2.64, 2.96),
	(23, 70, 74, 'm', 'F_III', '', 2.16, 2.48, 2.8),
	(23, 75, 79, 'm', 'F_III', '', 1.92, 2.32, 2.64),
	(23, 80, 84, 'm', 'F_III', '', 1.68, 2.08, 2.48),
	(23, 85, 89, 'm', 'F_III', '', 1.52, 1.92, 2.32),
	(23, 90, 200, 'm', 'F_III', '', 1.28, 1.68, 2.08),
	(25, 12, 13, 'w', 'F_III', '', 15.3, 17.55, 19.8),
	(25, 14, 15, 'w', 'F_III', '', 17.55, 20.25, 22.95),
	(25, 16, 17, 'w', 'F_III', '', 19.8, 22.5, 25.2),
	(25, 18, 19, 'w', 'F_III', '', 21.15, 23.85, 26.1),
	(25, 20, 24, 'w', 'F_III', '', 21.6, 24.3, 26.55),
	(25, 25, 29, 'w', 'F_III', '', 21.6, 24.3, 26.55),
	(25, 30, 34, 'w', 'F_III', '', 19.8, 22.5, 24.75),
	(25, 35, 39, 'w', 'F_III', '', 18.9, 21.6, 23.85),
	(25, 40, 44, 'w', 'F_III', '', 17.55, 20.25, 22.5),
	(25, 45, 49, 'w', 'F_III', '', 16.65, 19.35, 21.6),
	(25, 50, 54, 'w', 'F_III', '', 14.85, 18.0, 20.7),
	(25, 55, 59, 'w', 'F_III', '', 13.95, 17.1, 19.8),
	(25, 60, 64, 'w', 'F_III', '', 13.05, 16.2, 18.9),
	(25, 65, 69, 'w', 'F_III', '', 12.15, 15.3, 18.0),
	(25, 70, 74, 'w', 'F_III', '', 11.7, 14.85, 17.55),
	(25, 75, 79, 'w', 'F_III', '', 10.8, 13.95, 16.65),
	(25, 80, 84, 'w', 'F_III', '', 9.9, 13.05, 15.75),
	(25, 85, 89, 'w', 'F_III', '', 8.55, 11.7, 14.4),
	(25, 90, 200, 'w', 'F_III', '', 6.75, 9.9, 12.6),
	(25, 12, 13, 'm', 'F_III', '', 17.55, 21.6, 24.75),
	(25, 14, 15, 'm', 'F_III', '', 21.15, 25.2, 28.8),
	(25, 16, 17, 'm', 'F_III', '', 24.75, 28.8, 32.85),
	(25, 18, 19, 'm', 'F_III', '', 28.35, 32.4, 36.45),
	(25, 20, 24, 'm', 'F_III', '', 29.7, 34.2, 37.8),
	(25, 25, 29, 'm', 'F_III', '', 29.25, 33.75, 37.35),
	(25, 30, 34, 'm', 'F_III', '', 27.0, 31.5, 36.0),
	(25, 35, 39, 'm', 'F_III', '', 25.65, 30.15, 34.65),
	(25, 40, 44, 'm', 'F_III', '', 25.2, 29.7, 34.2),
	(25, 45, 49, 'm', 'F_III', '', 24.3, 28.8, 33.75),
	(25, 50, 54, 'm', 'F_III', '', 22.95, 27.9, 32.85),
	(25, 55, 59, 'm', 'F_III', '', 21.15, 26.1, 31.5),
	(25, 60, 64, 'm', 'F_III', '', 20.25, 25.2, 30.6),
	(25, 65, 69, 'm', 'F_III', '', 18.0, 22.95, 27.45),
	(25, 70, 74, 'm', 'F_III', '', 16.65, 21.6, 26.1),
	(25, 75, 79, 'm', 'F_III', '', 14.4, 18.9, 23.4),
	(25, 80, 84, 'm', 'F_III', '', 12.6, 17.1, 21.6),
	(25, 85, 89, 'm', 'F_III', '', 10.8, 14.85, 18.9),
	(25, 90, 200, 'm', 'F_III', '', 9.45, 13.5, 17.55),
	(33, 0, 7, 'w', 'F_III', '', 5.6000000000000005, 8.4, 11.899999999999999),
	(33, 8, 9, 'w', 'F_III', '', 7.0, 10.500000000000002, 14.0),
	(33, 10, 11, 'w', 'F_III', '', 10.500000000000002, 14.0, 21.0),
	(33, 12, 13, 'w', 'F_III', '', 14.0, 21.0, 28.0),
	(33, 14, 15, 'w', 'F_III', '', 21.0, 28.0, 35.0),
	(33, 16, 17, 'w', 'F_III', '', 31.5, 42.0, 52.49999999999999),
	(33, 0, 7, 'm', 'F_III', '', 7.0, 10.500000000000002, 14.0),
	(33, 8, 9, 'm', 'F_III', '', 8.4, 11.899999999999999, 16.099999999999998),
	(33, 10, 11, 'm', 'F_III', '', 11.899999999999999, 17.5, 24.5),
	(33, 12, 13, 'm', 'F_III', '', 17.5, 24.5, 31.5),
	(33, 14, 15, 'm', 'F_III', '', 24.5, 31.5, 42.0),
	(33, 16, 17, 'm', 'F_III', '', 38.49999999999999, 49.0, 63.0),
	(39, 0, 7, 'w', 'F_III', '', 223.0, 248.0, 272.0),
	(39, 8, 9, 'w', 'F_III', '', 234.0, 260.0, 286.0),
	(39, 10, 11, 'w', 'F_III', '', 245.0, 273.0, 300.0),
	(39, 12, 13, 'w', 'F_III', '', 257.0, 285.0, 314.0),
	(39, 14, 15, 'w', 'F_III', '', 268.0, 298.0, 327.0),
	(39, 16, 17, 'w', 'F_III', '', 279.0, 310.0, 341.0),
	(39, 18, 19, 'w', 'F_III', '', 369.0, 410.0, 451.0),
	(39, 20, 24, 'w', 'F_III', '', 369.0, 410.0, 451.0),
	(39, 25, 29, 'w', 'F_III', '', 369.0, 410.0, 451.0),
	(39, 30, 34, 'w', 'F_III', '', 358.0, 398.0, 437.0),
	(39, 35, 39, 'w', 'F_III', '', 358.0, 398.0, 437.0),
	(39, 40, 44, 'w', 'F_III', '', 347.0, 385.0, 424.0),
	(39, 45, 49, 'w', 'F_III', '', 335.0, 373.0, 410.0),
	(39, 50, 54, 'w', 'F_III', '', 324.0, 360.0, 396.0),
	(39, 55, 59, 'w', 'F_III', '', 313.0, 348.0, 382.0),
	(39, 60, 64, 'w', 'F_III', '', 302.0, 335.0, 369.0),
	(39, 65, 69, 'w', 'F_III', '', 290.0, 323.0, 355.0),
	(39, 70, 74, 'w', 'F_III', '', 279.0, 310.0, 341.0),
	(39, 75, 79, 'w', 'F_III', '', 268.0, 298.0, 327.0),
	(39, 80, 84, 'w', 'F_III', '', 257.0, 285.0, 314.0),
	(39, 85, 89, 'w', 'F_III', '', 245.0, 273.0, 300.0),
	(39, 90, 200, 'w', 'F_III', '', 234.0, 260.0, 286.0),
	(39, 0, 7, 'm', 'F_III', '', 281.0, 313.0, 344.0),
	(39, 8, 9, 'm', 'F_III', '', 293.0, 325.0, 358.0),
	(39, 10, 11, 'm', 'F_III', '', 304.0, 338.0, 371.0),
	(39, 12, 13, 'm', 'F_III', '', 315.0, 350.0, 385.0),
	(39, 14, 15, 'm', 'F_III', '', 326.0, 363.0, 399.0),
	(39, 16, 17, 'm', 'F_III', '', 338.0, 375.0, 413.0),
	(39, 18, 19, 'm', 'F_III', '', 428.0, 475.0, 523.0),
	(39, 20, 24, 'm', 'F_III', '', 428.0, 475.0, 523.0),
	(39, 25, 29, 'm', 'F_III', '', 428.0, 475.0, 523.0),
	(39, 30, 34, 'm', 'F_III', '', 416.0, 463.0, 509.0),
	(39, 35, 39, 'm', 'F_III', '', 416.0, 463.0, 509.0),
	(39, 40, 44, 'm', 'F_III', '', 405.0, 450.0, 495.0),
	(39, 45, 49, 'm', 'F_III', '', 394.0, 438.0, 481.0),
	(39, 50, 54, 'm', 'F_III', '', 383.0, 425.0, 468.0),
	(39, 55, 59, 'm', 'F_III', '', 371.0, 413.0, 454.0),
	(39, 60, 64, 'm', 'F_III', '', 360.0, 400.0, 440.0),
	(39, 65, 69, 'm', 'F_III', '', 349.0, 388.0, 426.0),
	(39, 70, 74, 'm', 'F_III', '', 338.0, 375.0, 413.0),
	(39, 75, 79, 'm', 'F_III', '', 326.0, 363.0, 399.0),
	(39, 80, 84, 'm', 'F_III', '', 315.0, 350.0, 385.0),
	(39, 85, 89, 'm', 'F_III', '', 304.0, 338.0, 371.0),
	(39, 90, 200, 'm', 'F_III', '', 293.0, 325.0, 358.0),
	(40, 0, 7, 'w', 'F_III', '', 383.0, 425.0, 468.0),
	(40, 8, 9, 'w', 'F_III', '', 396.0, 440.0, 484.0),
	(40, 10, 11, 'w', 'F_III', '', 410.0, 455.0, 501.0),
	(40, 12, 13, 'w', 'F_III', '', 423.0, 470.0, 517.0),
	(40, 14, 15, 'w', 'F_III', '', 437.0, 485.0, 534.0),
	(40, 16, 17, 'w', 'F_III', '', 450.0, 500.0, 550.0),
	(40, 18, 19, 'w', 'F_III', '', 540.0, 600.0, 660.0),
	(40, 20, 24, 'w', 'F_III', '', 540.0, 600.0, 660.0),
	(40, 25, 29, 'w', 'F_III', '', 540.0, 600.0, 660.0),
	(40, 30, 34, 'w', 'F_III', '', 527.0, 585.0, 644.0),
	(40, 35, 39, 'w', 'F_III', '', 527.0, 585.0, 644.0),
	(40, 40, 44, 'w', 'F_III', '', 513.0, 570.0, 627.0),
	(40, 45, 49, 'w', 'F_III', '', 500.0, 555.0, 611.0),
	(40, 50, 54, 'w', 'F_III', '', 486.0, 540.0, 594.0),
	(40, 55, 59, 'w', 'F_III', '', 473.0, 525.0, 578.0),
	(40, 60, 64, 'w', 'F_III', '', 459.0, 510.0, 561.0),
	(40, 65, 69, 'w', 'F_III', '', 446.0, 495.0, 545.0),
	(40, 70, 74, 'w', 'F_III', '', 432.0, 480.0, 528.0),
	(40, 75, 79, 'w', 'F_III', '', 419.0, 465.0, 512.0),
	(40, 80, 84, 'w', 'F_III', '', 405.0, 450.0, 495.0),
	(40, 85, 89, 'w', 'F_III', '', 392.0, 435.0, 479.0),
	(40, 90, 200, 'w', 'F_III', '', 378.0, 420.0, 462.0),
	(40, 0, 7, 'm', 'F_III', '', 450.0, 500.0, 550.0),
	(40, 8, 9, 'm', 'F_III', '', 464.0, 515.0, 567.0),
	(40, 10, 11, 'm', 'F_III', '', 477.0, 530.0, 583.0),
	(40, 12, 13, 'm', 'F_III', '', 491.0, 545.0, 600.0),
	(40, 14, 15, 'm', 'F_III', '', 504.0, 560.0, 616.0),
	(40, 16, 17, 'm', 'F_III', '', 518.0, 575.0, 633.0),
	(40, 18, 19, 'm', 'F_III', '', 608.0, 675.0, 743.0),
	(40, 20, 24, 'm', 'F_III', '', 608.0, 675.0, 743.0),
	(40, 25, 29, 'm', 'F_III', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'F_III', '', 594.0, 660.0, 726.0),
	(40, 35, 39, 'm', 'F_III', '', 594.0, 660.0, 726.0),
	(40, 40, 44, 'm', 'F_III', '', 581.0, 645.0, 710.0),
	(40, 45, 49, 'm', 'F_III', '', 567.0, 630.0, 693.0),
	(40, 50, 54, 'm', 'F_III', '', 554.0, 615.0, 677.0),
	(40, 55, 59, 'm', 'F_III', '', 540.0, 600.0, 660.0),
	(40, 60, 64, 'm', 'F_III', '', 527.0, 585.0, 644.0),
	(40, 65, 69, 'm', 'F_III', '', 513.0, 570.0, 627.0),
	(40, 70, 74, 'm', 'F_III', '', 500.0, 555.0, 611.0),
	(40, 75, 79, 'm', 'F_III', '', 486.0, 540.0, 594.0),
	(40, 80, 84, 'm', 'F_III', '', 473.0, 525.0, 578.0),
	(40, 85, 89, 'm', 'F_III', '', 459.0, 510.0, 561.0),
	(40, 90, 200, 'm', 'F_III', '', 446.0, 495.0, 545.0),
	(41, 0, 7, 'w', 'F_III', '', 315.0, 350.0, 385.0),
	(41, 8, 9, 'w', 'F_III', '', 329.0, 365.0, 402.0),
	(41, 10, 11, 'w', 'F_III', '', 342.0, 380.0, 418.0),
	(41, 12, 13, 'w', 'F_III', '', 356.0, 395.0, 435.0),
	(41, 14, 15, 'w', 'F_III', '', 369.0, 410.0, 451.0),
	(41, 16, 17, 'w', 'F_III', '', 383.0, 425.0, 468.0),
	(41, 18, 19, 'w', 'F_III', '', 473.0, 525.0, 578.0),
	(41, 20, 24, 'w', 'F_III', '', 473.0, 525.0, 578.0),
	(41, 25, 29, 'w', 'F_III', '', 473.0, 525.0, 578.0),
	(41, 30, 34, 'w', 'F_III', '', 459.0, 510.0, 561.0),
	(41, 35, 39, 'w', 'F_III', '', 459.0, 510.0, 561.0),
	(41, 40, 44, 'w', 'F_III', '', 446.0, 495.0, 545.0),
	(41, 45, 49, 'w', 'F_III', '', 432.0, 480.0, 528.0),
	(41, 50, 54, 'w', 'F_III', '', 419.0, 465.0, 512.0),
	(41, 55, 59, 'w', 'F_III', '', 405.0, 450.0, 495.0),
	(41, 60, 64, 'w', 'F_III', '', 392.0, 435.0, 479.0),
	(41, 65, 69, 'w', 'F_III', '', 378.0, 420.0, 462.0),
	(41, 70, 74, 'w', 'F_III', '', 365.0, 405.0, 446.0),
	(41, 75, 79, 'w', 'F_III', '', 351.0, 390.0, 429.0),
	(41, 80, 84, 'w', 'F_III', '', 338.0, 375.0, 413.0),
	(41, 85, 89, 'w', 'F_III', '', 324.0, 360.0, 396.0),
	(41, 90, 200, 'w', 'F_III', '', 311.0, 345.0, 380.0),
	(41, 0, 7, 'm', 'F_III', '', 378.0, 420.0, 462.0),
	(41, 8, 9, 'm', 'F_III', '', 392.0, 435.0, 479.0),
	(41, 10, 11, 'm', 'F_III', '', 405.0, 450.0, 495.0),
	(41, 12, 13, 'm', 'F_III', '', 419.0, 465.0, 512.0),
	(41, 14, 15, 'm', 'F_III', '', 432.0, 480.0, 528.0),
	(41, 16, 17, 'm', 'F_III', '', 446.0, 495.0, 545.0),
	(41, 18, 19, 'm', 'F_III', '', 536.0, 595.0, 655.0),
	(41, 20, 24, 'm', 'F_III', '', 536.0, 595.0, 655.0),
	(41, 25, 29, 'm', 'F_III', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'F_III', '', 522.0, 580.0, 638.0),
	(41, 35, 39, 'm', 'F_III', '', 522.0, 580.0, 638.0),
	(41, 40, 44, 'm', 'F_III', '', 509.0, 565.0, 622.0),
	(41, 45, 49, 'm', 'F_III', '', 495.0, 550.0, 605.0),
	(41, 50, 54, 'm', 'F_III', '', 482.0, 535.0, 589.0),
	(41, 55, 59, 'm', 'F_III', '', 468.0, 520.0, 572.0),
	(41, 60, 64, 'm', 'F_III', '', 455.0, 505.0, 556.0),
	(41, 65, 69, 'm', 'F_III', '', 441.0, 490.0, 539.0),
	(41, 70, 74, 'm', 'F_III', '', 428.0, 475.0, 523.0),
	(41, 75, 79, 'm', 'F_III', '', 414.0, 460.0, 506.0),
	(41, 80, 84, 'm', 'F_III', '', 401.0, 445.0, 490.0),
	(41, 85, 89, 'm', 'F_III', '', 387.0, 430.0, 473.0),
	(41, 90, 200, 'm', 'F_III', '', 374.0, 415.0, 457.0),
	(42, 0, 7, 'w', 'F_III', '', 320.0, 355.0, 391.0),
	(42, 8, 9, 'w', 'F_III', '', 333.0, 370.0, 407.0),
	(42, 10, 11, 'w', 'F_III', '', 347.0, 385.0, 424.0),
	(42, 12, 13, 'w', 'F_III', '', 360.0, 400.0, 440.0),
	(42, 14, 15, 'w', 'F_III', '', 374.0, 415.0, 457.0),
	(42, 16, 17, 'w', 'F_III', '', 387.0, 430.0, 473.0),
	(42, 18, 19, 'w', 'F_III', '', 477.0, 530.0, 583.0),
	(42, 20, 24, 'w', 'F_III', '', 477.0, 530.0, 583.0),
	(42, 25, 29, 'w', 'F_III', '', 477.0, 530.0, 583.0),
	(42, 30, 34, 'w', 'F_III', '', 464.0, 515.0, 567.0),
	(42, 35, 39, 'w', 'F_III', '', 464.0, 515.0, 567.0),
	(42, 40, 44, 'w', 'F_III', '', 450.0, 500.0, 550.0),
	(42, 45, 49, 'w', 'F_III', '', 437.0, 485.0, 534.0),
	(42, 50, 54, 'w', 'F_III', '', 423.0, 470.0, 517.0),
	(42, 55, 59, 'w', 'F_III', '', 410.0, 455.0, 501.0),
	(42, 60, 64, 'w', 'F_III', '', 396.0, 440.0, 484.0),
	(42, 65, 69, 'w', 'F_III', '', 383.0, 425.0, 468.0),
	(42, 70, 74, 'w', 'F_III', '', 369.0, 410.0, 451.0),
	(42, 75, 79, 'w', 'F_III', '', 356.0, 395.0, 435.0),
	(42, 80, 84, 'w', 'F_III', '', 342.0, 380.0, 418.0),
	(42, 85, 89, 'w', 'F_III', '', 329.0, 365.0, 402.0),
	(42, 90, 200, 'w', 'F_III', '', 315.0, 350.0, 385.0),
	(42, 0, 7, 'm', 'F_III', '', 383.0, 425.0, 468.0),
	(42, 8, 9, 'm', 'F_III', '', 396.0, 440.0, 484.0),
	(42, 10, 11, 'm', 'F_III', '', 410.0, 455.0, 501.0),
	(42, 12, 13, 'm', 'F_III', '', 423.0, 470.0, 517.0),
	(42, 14, 15, 'm', 'F_III', '', 437.0, 485.0, 534.0),
	(42, 16, 17, 'm', 'F_III', '', 450.0, 500.0, 550.0),
	(42, 18, 19, 'm', 'F_III', '', 540.0, 600.0, 660.0),
	(42, 20, 24, 'm', 'F_III', '', 540.0, 600.0, 660.0),
	(42, 25, 29, 'm', 'F_III', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'F_III', '', 527.0, 585.0, 644.0),
	(42, 35, 39, 'm', 'F_III', '', 527.0, 585.0, 644.0),
	(42, 40, 44, 'm', 'F_III', '', 513.0, 570.0, 627.0),
	(42, 45, 49, 'm', 'F_III', '', 500.0, 555.0, 611.0),
	(42, 50, 54, 'm', 'F_III', '', 486.0, 540.0, 594.0),
	(42, 55, 59, 'm', 'F_III', '', 473.0, 525.0, 578.0),
	(42, 60, 64, 'm', 'F_III', '', 459.0, 510.0, 561.0),
	(42, 65, 69, 'm', 'F_III', '', 446.0, 495.0, 545.0),
	(42, 70, 74, 'm', 'F_III', '', 432.0, 480.0, 528.0),
	(42, 75, 79, 'm', 'F_III', '', 419.0, 465.0, 512.0),
	(42, 80, 84, 'm', 'F_III', '', 405.0, 450.0, 495.0),
	(42, 85, 89, 'm', 'F_III', '', 392.0, 435.0, 479.0),
	(42, 90, 200, 'm', 'F_III', '', 378.0, 420.0, 462.0),
	(44, 12, 13, 'w', 'F_III', '', 7.67, 8.48, 9.29),
	(44, 14, 15, 'w', 'F_III', '', 8.88, 9.69, 10.5),
	(44, 16, 17, 'w', 'F_III', '', 9.29, 10.09, 10.9),
	(44, 18, 19, 'w', 'F_III', '', 10.5, 11.31, 12.11),
	(44, 20, 24, 'w', 'F_III', '', 10.5, 11.31, 12.11),
	(44, 25, 29, 'w', 'F_III', '', 10.5, 11.31, 12.11),
	(44, 30, 34, 'w', 'F_III', '', 10.09, 10.9, 11.71),
	(44, 35, 39, 'w', 'F_III', '', 9.69, 10.5, 11.31),
	(44, 40, 44, 'w', 'F_III', '', 8.88, 9.69, 10.5),
	(44, 45, 49, 'w', 'F_III', '', 8.48, 9.29, 10.09),
	(44, 50, 54, 'w', 'F_III', '', 8.48, 9.69, 11.31),
	(44, 55, 59, 'w', 'F_III', '', 8.08, 9.29, 10.5),
	(44, 60, 64, 'w', 'F_III', '', 7.67, 8.88, 10.09),
	(44, 65, 69, 'w', 'F_III', '', 7.27, 8.48, 10.09),
	(44, 70, 74, 'w', 'F_III', '', 6.86, 8.08, 9.69),
	(44, 75, 79, 'w', 'F_III', '', 6.86, 8.48, 10.09),
	(44, 80, 84, 'w', 'F_III', '', 6.46, 8.08, 9.29),
	(44, 85, 89, 'w', 'F_III', '', 6.06, 7.27, 8.88),
	(44, 90, 200, 'w', 'F_III', '', 5.25, 6.86, 8.08),
	(44, 12, 13, 'm', 'F_III', '', 10.09, 10.9, 11.71),
	(44, 14, 15, 'm', 'F_III', '', 11.31, 12.11, 12.92),
	(44, 16, 17, 'm', 'F_III', '', 12.11, 12.92, 13.73),
	(44, 18, 19, 'm', 'F_III', '', 12.52, 13.32, 14.13),
	(44, 20, 24, 'm', 'F_III', '', 12.52, 13.73, 14.54),
	(44, 25, 29, 'm', 'F_III', '', 12.11, 13.32, 14.13),
	(44, 30, 34, 'm', 'F_III', '', 11.31, 12.52, 13.32),
	(44, 35, 39, 'm', 'F_III', '', 10.9, 11.71, 12.92),
	(44, 40, 44, 'm', 'F_III', '', 10.09, 11.31, 12.52),
	(44, 45, 49, 'm', 'F_III', '', 9.69, 10.9, 12.11),
	(44, 50, 54, 'm', 'F_III', '', 10.09, 11.31, 12.92),
	(44, 55, 59, 'm', 'F_III', '', 9.69, 10.9, 12.11),
	(44, 60, 64, 'm', 'F_III', '', 9.69, 11.31, 12.92),
	(44, 65, 69, 'm', 'F_III', '', 9.29, 10.9, 12.11),
	(44, 70, 74, 'm', 'F_III', '', 9.69, 10.9, 12.52),
	(44, 75, 79, 'm', 'F_III', '', 9.29, 10.5, 12.11),
	(44, 80, 84, 'm', 'F_III', '', 8.88, 10.09, 11.71),
	(44, 85, 89, 'm', 'F_III', '', 8.08, 9.69, 10.9),
	(44, 90, 200, 'm', 'F_III', '', 7.27, 8.48, 10.09),
	(53, 0, 7, 'w', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'F_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'F_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'F_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'F_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'F_III', '', 11.0, 14.0, 19.0),
	(57, 8, 9, 'w', 'F_III', '', 16.0, 19.0, 24.0),
	(57, 10, 11, 'w', 'F_III', '', 24.0, 27.0, 32.0),
	(57, 0, 7, 'm', 'F_III', '', 14.0, 16.0, 22.0),
	(57, 8, 9, 'm', 'F_III', '', 19.0, 24.0, 30.0),
	(57, 10, 11, 'm', 'F_III', '', 30.0, 35.0, 41.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'G_I', '', 10.766666666666667, 9.500000000000002, 8.066666666666665),
	(1, 8, 9, 'w', 'G_I', '', 10.6, 9.183333333333332, 7.916666666666666),
	(1, 10, 11, 'w', 'G_I', '', 10.133333333333333, 8.866666666666665, 7.6000000000000005),
	(1, 12, 13, 'w', 'G_I', '', 9.816666666666666, 8.383333333333335, 7.116666666666667),
	(1, 14, 15, 'w', 'G_I', '', 9.500000000000002, 8.233333333333334, 6.800000000000001),
	(1, 16, 17, 'w', 'G_I', '', 9.183333333333332, 7.75, 6.483333333333333),
	(1, 0, 7, 'm', 'G_I', '', 10.766666666666667, 9.500000000000002, 8.066666666666665),
	(1, 8, 9, 'm', 'G_I', '', 10.283333333333333, 8.866666666666665, 7.433333333333333),
	(1, 10, 11, 'm', 'G_I', '', 9.65, 8.233333333333334, 6.800000000000001),
	(1, 12, 13, 'm', 'G_I', '', 9.016666666666666, 7.6000000000000005, 6.166666666666666),
	(1, 14, 15, 'm', 'G_I', '', 8.233333333333334, 6.966666666666667, 5.7),
	(1, 16, 17, 'm', 'G_I', '', 7.75, 6.483333333333333, 5.216666666666667),
	(4, 8, 9, 'w', 'G_I', '5 km', 37.8, 33.6, 29.4),
	(4, 10, 11, 'w', 'G_I', '10 km', 70.7, 60.199999999999996, 49.7),
	(4, 12, 13, 'w', 'G_I', '10 km', 63.0, 55.3, 46.9),
	(4, 14, 15, 'w', 'G_I', '10 km', 53.199999999999996, 45.49999999999999, 39.9),
	(4, 16, 17, 'w', 'G_I', '10 km', 45.49999999999999, 39.9, 35.0),
	(4, 18, 19, 'w', 'G_I', '20 km', 80.5, 72.80000000000001, 65.10000000000001),
	(4, 20, 24, 'w', 'G_I', '20 km', 79.80000000000001, 72.10000000000001, 63.7),
	(4, 25, 29, 'w', 'G_I', '20 km', 78.39999999999999, 70.7, 63.0),
	(4, 30, 34, 'w', 'G_I', '20 km', 79.80000000000001, 72.10000000000001, 63.7),
	(4, 35, 39, 'w', 'G_I', '20 km', 84.0, 74.2, 65.80000000000001),
	(4, 40, 44, 'w', 'G_I', '20 km', 89.6, 77.7, 69.30000000000001),
	(4, 45, 49, 'w', 'G_I', '20 km', 93.80000000000001, 81.9, 72.10000000000001),
	(4, 50, 54, 'w', 'G_I', '20 km', 96.6, 85.39999999999999, 74.9),
	(4, 55, 59, 'w', 'G_I', '20 km', 100.10000000000001, 88.2, 77.7),
	(4, 60, 64, 'w', 'G_I', '20 km', 103.6, 91.0, 79.80000000000001),
	(4, 65, 69, 'w', 'G_I', '20 km', 105.7, 93.10000000000001, 81.9),
	(4, 70, 74, 'w', 'G_I', '20 km', 109.2, 95.9, 84.7),
	(4, 75, 79, 'w', 'G_I', '20 km', 114.10000000000001, 98.7, 88.2),
	(4, 80, 84, 'w', 'G_I', '20 km', 118.30000000000001, 105.0, 91.7),
	(4, 85, 89, 'w', 'G_I', '20 km', 125.30000000000001, 112.0, 96.6),
	(4, 90, 200, 'w', 'G_I', '20 km', 130.20000000000002, 116.2, 101.5),
	(4, 8, 9, 'm', 'G_I', '5 km', 37.1, 32.9, 28.700000000000003),
	(4, 10, 11, 'm', 'G_I', '10 km', 67.9, 57.400000000000006, 46.9),
	(4, 12, 13, 'm', 'G_I', '10 km', 60.199999999999996, 51.8, 44.1),
	(4, 14, 15, 'm', 'G_I', '10 km', 44.8, 39.199999999999996, 33.6),
	(4, 16, 17, 'm', 'G_I', '10 km', 37.8, 32.9, 28.700000000000003),
	(4, 18, 19, 'm', 'G_I', '20 km', 65.80000000000001, 59.49999999999999, 53.9),
	(4, 20, 24, 'm', 'G_I', '20 km', 65.10000000000001, 58.8, 52.49999999999999),
	(4, 25, 29, 'm', 'G_I', '20 km', 70.0, 62.3, 54.6),
	(4, 30, 34, 'm', 'G_I', '20 km', 74.9, 65.80000000000001, 56.7),
	(4, 35, 39, 'm', 'G_I', '20 km', 81.2, 70.0, 58.1),
	(4, 40, 44, 'm', 'G_I', '20 km', 88.2, 72.80000000000001, 60.9),
	(4, 45, 49, 'm', 'G_I', '20 km', 92.39999999999999, 77.0, 63.0),
	(4, 50, 54, 'm', 'G_I', '20 km', 95.9, 79.80000000000001, 65.10000000000001),
	(4, 55, 59, 'm', 'G_I', '20 km', 98.7, 81.9, 66.5),
	(4, 60, 64, 'm', 'G_I', '20 km', 100.10000000000001, 84.0, 67.2),
	(4, 65, 69, 'm', 'G_I', '20 km', 101.5, 84.7, 67.9),
	(4, 70, 74, 'm', 'G_I', '20 km', 102.9, 86.10000000000001, 69.30000000000001),
	(4, 75, 79, 'm', 'G_I', '20 km', 104.30000000000001, 88.2, 72.10000000000001),
	(4, 80, 84, 'm', 'G_I', '20 km', 106.39999999999999, 90.30000000000001, 74.2),
	(4, 85, 89, 'm', 'G_I', '20 km', 108.5, 93.10000000000001, 77.7),
	(4, 90, 200, 'm', 'G_I', '20 km', 110.6, 95.2, 81.2),
	(7, 0, 7, 'w', 'G_I', '200 m', 12.6, 10.733333333333333, 8.866666666666665),
	(7, 8, 9, 'w', 'G_I', '200 m', 11.2, 9.8, 8.283333333333333),
	(7, 10, 11, 'w', 'G_I', '200 m', 10.266666666666667, 8.983333333333333, 7.7),
	(7, 12, 13, 'w', 'G_I', '400 m', 20.76666666666667, 18.083333333333336, 15.4),
	(7, 14, 15, 'w', 'G_I', '400 m', 18.31666666666667, 16.333333333333332, 14.0),
	(7, 16, 17, 'w', 'G_I', '400 m', 16.566666666666666, 14.7, 12.716666666666667),
	(7, 18, 19, 'w', 'G_I', '800 m', 33.6, 29.633333333333333, 25.78333333333333),
	(7, 20, 24, 'w', 'G_I', '800 m', 33.016666666666666, 29.166666666666668, 25.200000000000003),
	(7, 25, 29, 'w', 'G_I', '800 m', 35.7, 29.516666666666666, 26.13333333333333),
	(7, 30, 34, 'w', 'G_I', '800 m', 40.36666666666667, 33.13333333333333, 27.3),
	(7, 35, 39, 'w', 'G_I', '800 m', 44.8, 35.81666666666667, 28.46666666666667),
	(7, 40, 44, 'w', 'G_I', '800 m', 47.6, 38.73333333333333, 29.866666666666667),
	(7, 45, 49, 'w', 'G_I', '800 m', 49.46666666666667, 40.6, 30.099999999999998),
	(7, 50, 54, 'w', 'G_I', '400 m', 25.200000000000003, 21.0, 16.099999999999998),
	(7, 55, 59, 'w', 'G_I', '400 m', 26.01666666666667, 21.46666666666667, 16.683333333333334),
	(7, 60, 64, 'w', 'G_I', '400 m', 26.599999999999998, 21.816666666666663, 17.03333333333333),
	(7, 65, 69, 'w', 'G_I', '400 m', 27.183333333333334, 22.05, 17.15),
	(7, 70, 74, 'w', 'G_I', '400 m', 27.76666666666667, 22.516666666666666, 17.733333333333334),
	(7, 75, 79, 'w', 'G_I', '200 m', 14.350000000000001, 11.666666666666668, 9.100000000000001),
	(7, 80, 84, 'w', 'G_I', '200 m', 14.583333333333332, 11.899999999999999, 9.45),
	(7, 85, 89, 'w', 'G_I', '200 m', 14.816666666666666, 12.25, 9.916666666666668),
	(7, 90, 200, 'w', 'G_I', '200 m', 15.049999999999999, 12.483333333333333, 10.266666666666667),
	(7, 0, 7, 'm', 'G_I', '200 m', 12.6, 10.266666666666667, 8.633333333333335),
	(7, 8, 9, 'm', 'G_I', '200 m', 11.2, 9.45, 7.933333333333333),
	(7, 10, 11, 'm', 'G_I', '200 m', 9.8, 8.866666666666665, 7.2333333333333325),
	(7, 12, 13, 'm', 'G_I', '400 m', 18.9, 16.099999999999998, 13.65),
	(7, 14, 15, 'm', 'G_I', '400 m', 16.8, 14.350000000000001, 12.366666666666667),
	(7, 16, 17, 'm', 'G_I', '400 m', 15.4, 13.533333333333333, 11.666666666666668),
	(7, 18, 19, 'm', 'G_I', '800 m', 31.616666666666667, 27.76666666666667, 23.8),
	(7, 20, 24, 'm', 'G_I', '800 m', 31.03333333333333, 27.3, 22.983333333333334),
	(7, 25, 29, 'm', 'G_I', '800 m', 32.43333333333333, 28.0, 23.8),
	(7, 30, 34, 'm', 'G_I', '800 m', 36.050000000000004, 30.099999999999998, 25.200000000000003),
	(7, 35, 39, 'm', 'G_I', '800 m', 40.36666666666667, 33.6, 26.95),
	(7, 40, 44, 'm', 'G_I', '800 m', 45.383333333333326, 36.98333333333334, 28.583333333333336),
	(7, 45, 49, 'm', 'G_I', '800 m', 48.3, 38.96666666666666, 28.93333333333333),
	(7, 50, 54, 'm', 'G_I', '400 m', 24.383333333333333, 20.066666666666666, 15.049999999999999),
	(7, 55, 59, 'm', 'G_I', '400 m', 24.966666666666665, 20.416666666666668, 15.866666666666665),
	(7, 60, 64, 'm', 'G_I', '400 m', 25.433333333333337, 20.650000000000002, 15.983333333333333),
	(7, 65, 69, 'm', 'G_I', '400 m', 25.78333333333333, 21.116666666666667, 16.099999999999998),
	(7, 70, 74, 'm', 'G_I', '400 m', 25.78333333333333, 21.35, 16.216666666666665),
	(7, 75, 79, 'm', 'G_I', '200 m', 13.183333333333332, 10.733333333333333, 8.516666666666667),
	(7, 80, 84, 'm', 'G_I', '200 m', 13.299999999999999, 10.966666666666667, 8.633333333333335),
	(7, 85, 89, 'm', 'G_I', '200 m', 13.299999999999999, 11.2, 8.983333333333333),
	(7, 90, 200, 'm', 'G_I', '200 m', 13.65, 11.433333333333334, 9.45),
	(8, 18, 19, 'w', 'G_I', '3 km', 42.400000000000006, 40.26666666666666, 37.81666666666667),
	(8, 20, 24, 'w', 'G_I', '3 km', 40.56666666666667, 38.43333333333333, 36.3),
	(8, 25, 29, 'w', 'G_I', '3 km', 40.866666666666674, 38.73333333333333, 36.6),
	(8, 30, 34, 'w', 'G_I', '3 km', 41.18333333333333, 39.03333333333334, 36.849999999999994),
	(8, 35, 39, 'w', 'G_I', '3 km', 42.7, 39.65, 37.050000000000004),
	(8, 40, 44, 'w', 'G_I', '3 km', 44.53333333333333, 40.866666666666674, 37.21666666666667),
	(8, 45, 49, 'w', 'G_I', '3 km', 46.050000000000004, 42.08333333333333, 37.81666666666667),
	(8, 50, 54, 'w', 'G_I', '3 km', 47.583333333333336, 43.31666666666666, 39.03333333333334),
	(8, 55, 59, 'w', 'G_I', '3 km', 48.8, 44.53333333333333, 40.26666666666666),
	(8, 60, 64, 'w', 'G_I', '3 km', 50.31666666666666, 45.45, 41.18333333333333),
	(8, 65, 69, 'w', 'G_I', '3 km', 51.400000000000006, 46.666666666666664, 42.7),
	(8, 70, 74, 'w', 'G_I', '3 km', 53.833333333333336, 48.18333333333333, 43.916666666666664),
	(8, 75, 79, 'w', 'G_I', '3 km', 56.43333333333333, 49.71666666666667, 45.45),
	(8, 80, 84, 'w', 'G_I', '3 km', 60.08333333333333, 52.0, 47.28333333333334),
	(8, 85, 89, 'w', 'G_I', '3 km', 63.43333333333333, 55.1, 50.016666666666666),
	(8, 90, 200, 'w', 'G_I', '3 km', 67.30000000000001, 58.56666666666667, 53.06666666666666),
	(8, 18, 19, 'm', 'G_I', '3 km', 35.68333333333333, 33.25, 30.8),
	(8, 20, 24, 'm', 'G_I', '3 km', 34.766666666666666, 32.333333333333336, 29.883333333333336),
	(8, 25, 29, 'm', 'G_I', '3 km', 35.68333333333333, 33.25, 30.8),
	(8, 30, 34, 'm', 'G_I', '3 km', 38.13333333333333, 34.766666666666666, 31.116666666666667),
	(8, 35, 39, 'm', 'G_I', '3 km', 39.65, 35.68333333333333, 32.63333333333334),
	(8, 40, 44, 'm', 'G_I', '3 km', 40.26666666666666, 36.9, 32.93333333333334),
	(8, 45, 49, 'm', 'G_I', '3 km', 41.78333333333333, 38.13333333333333, 33.55),
	(8, 50, 54, 'm', 'G_I', '3 km', 43.31666666666666, 39.03333333333334, 35.08333333333333),
	(8, 55, 59, 'm', 'G_I', '3 km', 44.53333333333333, 39.65, 35.98333333333334),
	(8, 60, 64, 'm', 'G_I', '3 km', 46.199999999999996, 41.18333333333333, 36.9),
	(8, 65, 69, 'm', 'G_I', '3 km', 47.68333333333333, 42.400000000000006, 37.81666666666667),
	(8, 70, 74, 'm', 'G_I', '3 km', 49.71666666666667, 43.916666666666664, 39.65),
	(8, 75, 79, 'm', 'G_I', '3 km', 52.56666666666667, 46.199999999999996, 43.916666666666664),
	(8, 80, 84, 'm', 'G_I', '3 km', 55.81666666666667, 48.65, 43.916666666666664),
	(8, 85, 89, 'm', 'G_I', '3 km', 58.56666666666667, 51.400000000000006, 46.050000000000004),
	(8, 90, 200, 'm', 'G_I', '3 km', 62.68333333333333, 54.49999999999999, 48.8),
	(10, 0, 7, 'w', 'G_I', '', 4.5, 6.75, 9.0),
	(10, 8, 9, 'w', 'G_I', '', 6.75, 9.0, 11.25),
	(10, 10, 11, 'w', 'G_I', '', 8.25, 11.25, 13.5),
	(10, 0, 7, 'm', 'G_I', '', 9.0, 11.25, 12.75),
	(10, 8, 9, 'm', 'G_I', '', 12.75, 15.0, 17.25),
	(10, 10, 11, 'm', 'G_I', '', 15.75, 18.75, 21.0),
	(11, 12, 13, 'w', 'G_I', '', 11.25, 13.5, 16.5),
	(11, 14, 15, 'w', 'G_I', '', 15.0, 18.0, 20.25),
	(11, 16, 17, 'w', 'G_I', '', 18.0, 20.25, 23.25),
	(11, 12, 13, 'm', 'G_I', '', 19.5, 22.5, 24.75),
	(11, 14, 15, 'm', 'G_I', '', 22.5, 25.5, 27.75),
	(11, 16, 17, 'm', 'G_I', '', 25.5, 28.5, 31.5),
	(13, 12, 13, 'w', 'G_I', '2 kg', 3.56, 3.94, 4.31),
	(13, 14, 15, 'w', 'G_I', '2 kg', 4.13, 4.5, 4.88),
	(13, 16, 17, 'w', 'G_I', '2 kg', 4.31, 4.69, 5.06),
	(13, 18, 19, 'w', 'G_I', '3 kg', 4.88, 5.25, 5.63),
	(13, 20, 24, 'w', 'G_I', '3 kg', 4.88, 5.25, 5.63),
	(13, 25, 29, 'w', 'G_I', '3 kg', 4.88, 5.25, 5.63),
	(13, 30, 34, 'w', 'G_I', '3 kg', 4.69, 5.06, 5.44),
	(13, 35, 39, 'w', 'G_I', '3 kg', 4.5, 4.88, 5.25),
	(13, 40, 44, 'w', 'G_I', '3 kg', 4.13, 4.5, 4.88),
	(13, 45, 49, 'w', 'G_I', '3 kg', 3.94, 4.31, 4.69),
	(13, 50, 54, 'w', 'G_I', '2 kg', 3.94, 4.5, 5.25),
	(13, 55, 59, 'w', 'G_I', '2 kg', 3.75, 4.31, 4.88),
	(13, 60, 64, 'w', 'G_I', '2 kg', 3.56, 4.13, 4.69),
	(13, 65, 69, 'w', 'G_I', '2 kg', 3.38, 3.94, 4.69),
	(13, 70, 74, 'w', 'G_I', '2 kg', 3.19, 3.75, 4.5),
	(13, 75, 79, 'w', 'G_I', '2 kg', 3.19, 3.94, 4.69),
	(13, 80, 84, 'w', 'G_I', '2 kg', 3.0, 3.75, 4.31),
	(13, 85, 89, 'w', 'G_I', '2 kg', 2.81, 3.38, 4.13),
	(13, 90, 200, 'w', 'G_I', '2 kg', 2.44, 3.19, 3.75),
	(13, 12, 13, 'm', 'G_I', '2 kg', 4.69, 5.06, 5.44),
	(13, 14, 15, 'm', 'G_I', '2 kg', 5.25, 5.63, 6.0),
	(13, 16, 17, 'm', 'G_I', '3 kg', 5.63, 6.0, 6.38),
	(13, 18, 19, 'm', 'G_I', '4 kg', 5.81, 6.19, 6.56),
	(13, 20, 24, 'm', 'G_I', '4 kg', 5.81, 6.38, 6.75),
	(13, 25, 29, 'm', 'G_I', '4 kg', 5.63, 6.19, 6.56),
	(13, 30, 34, 'm', 'G_I', '4 kg', 5.25, 5.81, 6.19),
	(13, 35, 39, 'm', 'G_I', '4 kg', 5.06, 5.44, 6.0),
	(13, 40, 44, 'm', 'G_I', '4 kg', 4.69, 5.25, 5.81),
	(13, 45, 49, 'm', 'G_I', '4 kg', 4.5, 5.06, 5.63),
	(13, 50, 54, 'm', 'G_I', '3 kg', 4.69, 5.25, 6.0),
	(13, 55, 59, 'm', 'G_I', '3 kg', 4.57, 5.16, 5.8),
	(13, 60, 64, 'm', 'G_I', '3 kg', 4.5, 5.1, 5.71),
	(13, 65, 69, 'm', 'G_I', '3 kg', 4.31, 5.06, 5.63),
	(13, 70, 74, 'm', 'G_I', '3 kg', 4.2, 4.95, 5.45),
	(13, 75, 79, 'm', 'G_I', '3 kg', 4.15, 4.88, 5.4),
	(13, 80, 84, 'm', 'G_I', '2 kg', 4.13, 4.69, 5.44),
	(13, 85, 89, 'm', 'G_I', '2 kg', 3.75, 4.5, 5.06),
	(13, 90, 200, 'm', 'G_I', '2 kg', 3.38, 3.94, 4.69),
	(15, 0, 7, 'w', 'G_I', '', 0.74, 0.88, 0.98),
	(15, 8, 9, 'w', 'G_I', '', 0.81, 0.91, 1.05),
	(15, 10, 11, 'w', 'G_I', '', 0.91, 1.02, 1.16),
	(15, 12, 13, 'w', 'G_I', '', 0.98, 1.12, 1.26),
	(15, 14, 15, 'w', 'G_I', '', 1.09, 1.19, 1.33),
	(15, 16, 17, 'w', 'G_I', '', 1.16, 1.26, 1.4),
	(15, 18, 19, 'w', 'G_I', '', 1.16, 1.3, 1.44),
	(15, 20, 24, 'w', 'G_I', '', 1.12, 1.26, 1.4),
	(15, 25, 29, 'w', 'G_I', '', 1.05, 1.19, 1.37),
	(15, 30, 34, 'w', 'G_I', '', 0.95, 1.12, 1.3),
	(15, 35, 39, 'w', 'G_I', '', 0.88, 1.05, 1.26),
	(15, 40, 44, 'w', 'G_I', '', 0.81, 0.98, 1.16),
	(15, 45, 49, 'w', 'G_I', '', 0.77, 0.95, 1.12),
	(15, 50, 54, 'w', 'G_I', '', 0.7, 0.91, 1.09),
	(15, 55, 59, 'w', 'G_I', '', 0.67, 0.84, 1.02),
	(15, 60, 64, 'w', 'G_I', '', 0.67, 0.84, 1.02),
	(15, 65, 69, 'w', 'G_I', '', 0.63, 0.81, 0.98),
	(15, 70, 74, 'w', 'G_I', '', 0.63, 0.81, 0.95),
	(15, 75, 79, 'w', 'G_I', '', 0.63, 0.81, 0.95),
	(15, 80, 84, 'w', 'G_I', '', 0.63, 0.77, 0.91),
	(15, 85, 89, 'w', 'G_I', '', 0.6, 0.74, 0.88),
	(15, 90, 200, 'w', 'G_I', '', 0.56, 0.7, 0.84),
	(15, 0, 7, 'm', 'G_I', '', 0.81, 0.95, 1.05),
	(15, 8, 9, 'm', 'G_I', '', 0.91, 1.05, 1.16),
	(15, 10, 11, 'm', 'G_I', '', 1.05, 1.19, 1.3),
	(15, 12, 13, 'm', 'G_I', '', 1.19, 1.33, 1.44),
	(15, 14, 15, 'm', 'G_I', '', 1.33, 1.44, 1.58),
	(15, 16, 17, 'm', 'G_I', '', 1.44, 1.54, 1.68),
	(15, 18, 19, 'm', 'G_I', '', 1.47, 1.61, 1.75),
	(15, 20, 24, 'm', 'G_I', '', 1.47, 1.61, 1.75),
	(15, 25, 29, 'm', 'G_I', '', 1.44, 1.58, 1.72),
	(15, 30, 34, 'm', 'G_I', '', 1.3, 1.47, 1.65),
	(15, 35, 39, 'm', 'G_I', '', 1.16, 1.37, 1.58),
	(15, 40, 44, 'm', 'G_I', '', 1.09, 1.3, 1.51),
	(15, 45, 49, 'm', 'G_I', '', 1.02, 1.23, 1.44),
	(15, 50, 54, 'm', 'G_I', '', 0.98, 1.19, 1.4),
	(15, 55, 59, 'm', 'G_I', '', 0.95, 1.16, 1.37),
	(15, 60, 64, 'm', 'G_I', '', 0.91, 1.12, 1.33),
	(15, 65, 69, 'm', 'G_I', '', 0.91, 1.12, 1.33),
	(15, 70, 74, 'm', 'G_I', '', 0.88, 1.09, 1.3),
	(15, 75, 79, 'm', 'G_I', '', 0.84, 1.05, 1.26),
	(15, 80, 84, 'm', 'G_I', '', 0.81, 1.02, 1.23),
	(15, 85, 89, 'm', 'G_I', '', 0.7, 0.91, 1.12),
	(15, 90, 200, 'm', 'G_I', '', 0.63, 0.84, 1.05),
	(17, 0, 7, 'w', 'G_I', '30 m', 15.2, 13.5, 12.0),
	(17, 8, 9, 'w', 'G_I', '30 m', 14.1, 12.5, 10.8),
	(17, 10, 11, 'w', 'G_I', '50 m', 20.9, 19.2, 17.3),
	(17, 12, 13, 'w', 'G_I', '50 m', 20.1, 18.2, 16.2),
	(17, 14, 15, 'w', 'G_I', '100 m', 35.3, 32.3, 29.5),
	(17, 16, 17, 'w', 'G_I', '100 m', 33.4, 31.0, 28.5),
	(17, 18, 19, 'w', 'G_I', '100 m', 34.6, 31.4, 29.1),
	(17, 20, 24, 'w', 'G_I', '100 m', 35.2, 31.9, 29.6),
	(17, 25, 29, 'w', 'G_I', '100 m', 35.9, 32.7, 30.4),
	(17, 30, 34, 'w', 'G_I', '100 m', 37.2, 33.8, 31.2),
	(17, 35, 39, 'w', 'G_I', '100 m', 38.8, 35.3, 32.3),
	(17, 40, 44, 'w', 'G_I', '50 m', 20.9, 18.8, 16.7),
	(17, 45, 49, 'w', 'G_I', '50 m', 21.9, 19.6, 17.3),
	(17, 50, 54, 'w', 'G_I', '50 m', 22.6, 20.3, 18.1),
	(17, 55, 59, 'w', 'G_I', '50 m', 23.6, 21.3, 18.8),
	(17, 60, 64, 'w', 'G_I', '50 m', 23.9, 21.7, 19.4),
	(17, 65, 69, 'w', 'G_I', '50 m', 24.3, 22.0, 19.8),
	(17, 70, 74, 'w', 'G_I', '50 m', 24.7, 22.4, 20.1),
	(17, 75, 79, 'w', 'G_I', '50 m', 25.7, 23.4, 21.1),
	(17, 80, 84, 'w', 'G_I', '50 m', 27.2, 24.9, 22.8),
	(17, 85, 89, 'w', 'G_I', '50 m', 29.5, 27.2, 25.1),
	(17, 90, 200, 'w', 'G_I', '50 m', 32.5, 30.2, 28.1),
	(17, 0, 7, 'm', 'G_I', '30 m', 14.6, 12.9, 11.4),
	(17, 8, 9, 'm', 'G_I', '30 m', 13.7, 12.2, 10.8),
	(17, 10, 11, 'm', 'G_I', '50 m', 19.6, 17.7, 16.0),
	(17, 12, 13, 'm', 'G_I', '50 m', 18.4, 16.9, 15.4),
	(17, 14, 15, 'm', 'G_I', '100 m', 32.3, 29.3, 26.8),
	(17, 16, 17, 'm', 'G_I', '100 m', 31.0, 28.1, 25.7),
	(17, 18, 19, 'm', 'G_I', '100 m', 30.4, 27.7, 25.1),
	(17, 20, 24, 'm', 'G_I', '100 m', 30.0, 27.4, 24.7),
	(17, 25, 29, 'm', 'G_I', '100 m', 31.0, 28.1, 25.3),
	(17, 30, 34, 'm', 'G_I', '100 m', 31.9, 28.7, 25.8),
	(17, 35, 39, 'm', 'G_I', '100 m', 33.4, 30.2, 27.0),
	(17, 40, 44, 'm', 'G_I', '50 m', 18.2, 16.5, 14.6),
	(17, 45, 49, 'm', 'G_I', '50 m', 19.0, 16.9, 15.0),
	(17, 50, 54, 'm', 'G_I', '50 m', 19.6, 17.3, 15.6),
	(17, 55, 59, 'm', 'G_I', '50 m', 20.0, 17.9, 16.2),
	(17, 60, 64, 'm', 'G_I', '50 m', 20.5, 18.4, 16.7),
	(17, 65, 69, 'm', 'G_I', '50 m', 21.3, 19.4, 17.3),
	(17, 70, 74, 'm', 'G_I', '50 m', 22.2, 20.3, 18.2),
	(17, 75, 79, 'm', 'G_I', '50 m', 23.2, 21.3, 19.2),
	(17, 80, 84, 'm', 'G_I', '50 m', 24.7, 22.8, 20.7),
	(17, 85, 89, 'm', 'G_I', '50 m', 26.8, 24.9, 22.8),
	(17, 90, 200, 'm', 'G_I', '50 m', 29.5, 27.6, 25.5),
	(18, 0, 7, 'w', 'G_I', '', 65.1, 53.9, 42.7),
	(18, 8, 9, 'w', 'G_I', '', 58.8, 47.6, 39.2),
	(18, 10, 11, 'w', 'G_I', '', 54.6, 44.1, 35.7),
	(18, 12, 13, 'w', 'G_I', '', 49.0, 40.6, 32.9),
	(18, 14, 15, 'w', 'G_I', '', 46.2, 38.5, 30.1),
	(18, 16, 17, 'w', 'G_I', '', 42.7, 35.7, 28.0),
	(18, 18, 19, 'w', 'G_I', '', 41.3, 33.6, 25.9),
	(18, 20, 24, 'w', 'G_I', '', 40.6, 33.6, 25.9),
	(18, 25, 29, 'w', 'G_I', '', 42.0, 35.0, 27.3),
	(18, 30, 34, 'w', 'G_I', '', 45.5, 37.1, 29.4),
	(18, 35, 39, 'w', 'G_I', '', 50.4, 40.6, 30.8),
	(18, 40, 44, 'w', 'G_I', '', 56.0, 44.1, 32.9),
	(18, 45, 49, 'w', 'G_I', '', 61.6, 49.0, 35.0),
	(18, 50, 54, 'w', 'G_I', '', 67.2, 54.6, 39.2),
	(18, 55, 59, 'w', 'G_I', '', 72.1, 59.5, 42.7),
	(18, 60, 64, 'w', 'G_I', '', 76.3, 62.3, 45.5),
	(18, 65, 69, 'w', 'G_I', '', 79.1, 65.1, 48.3),
	(18, 70, 74, 'w', 'G_I', '', 82.6, 67.2, 50.4),
	(18, 75, 79, 'w', 'G_I', '', 85.4, 70.0, 53.2),
	(18, 80, 84, 'w', 'G_I', '', 88.9, 72.8, 56.0),
	(18, 85, 89, 'w', 'G_I', '', 91.7, 74.9, 58.1),
	(18, 90, 200, 'w', 'G_I', '', 93.1, 76.3, 59.5),
	(18, 0, 7, 'm', 'G_I', '', 64.4, 53.2, 42.0),
	(18, 8, 9, 'm', 'G_I', '', 57.4, 46.2, 36.4),
	(18, 10, 11, 'm', 'G_I', '', 50.4, 40.6, 31.5),
	(18, 12, 13, 'm', 'G_I', '', 46.2, 37.8, 29.4),
	(18, 14, 15, 'm', 'G_I', '', 43.4, 35.7, 28.0),
	(18, 16, 17, 'm', 'G_I', '', 41.3, 34.3, 26.6),
	(18, 18, 19, 'm', 'G_I', '', 39.2, 32.2, 24.5),
	(18, 20, 24, 'm', 'G_I', '', 37.8, 30.8, 21.7),
	(18, 25, 29, 'm', 'G_I', '', 40.6, 32.2, 23.1),
	(18, 30, 34, 'm', 'G_I', '', 44.1, 33.6, 23.8),
	(18, 35, 39, 'm', 'G_I', '', 49.0, 37.1, 25.9),
	(18, 40, 44, 'm', 'G_I', '', 53.9, 41.3, 26.6),
	(18, 45, 49, 'm', 'G_I', '', 58.8, 45.5, 28.7),
	(18, 50, 54, 'm', 'G_I', '', 63.0, 49.0, 32.2),
	(18, 55, 59, 'm', 'G_I', '', 68.6, 51.8, 35.0),
	(18, 60, 64, 'm', 'G_I', '', 71.4, 54.6, 37.8),
	(18, 65, 69, 'm', 'G_I', '', 73.5, 56.7, 39.9),
	(18, 70, 74, 'm', 'G_I', '', 77.0, 60.2, 43.4),
	(18, 75, 79, 'm', 'G_I', '', 80.5, 63.7, 46.9),
	(18, 80, 84, 'm', 'G_I', '', 82.6, 67.2, 50.4),
	(18, 85, 89, 'm', 'G_I', '', 83.3, 68.6, 53.2),
	(18, 90, 200, 'm', 'G_I', '', 84.0, 70.0, 56.0),
	(19, 8, 9, 'w', 'G_I', '', 53.3, 46.8, 40.3),
	(19, 10, 11, 'w', 'G_I', '', 48.1, 41.6, 35.1),
	(19, 12, 13, 'w', 'G_I', '', 40.3, 35.1, 30.6),
	(19, 14, 15, 'w', 'G_I', '', 35.1, 31.9, 28.0),
	(19, 16, 17, 'w', 'G_I', '', 32.5, 29.3, 26.0),
	(19, 18, 19, 'w', 'G_I', '', 31.2, 28.6, 25.4),
	(19, 20, 24, 'w', 'G_I', '', 31.9, 28.6, 25.4),
	(19, 25, 29, 'w', 'G_I', '', 32.5, 29.3, 26.0),
	(19, 30, 34, 'w', 'G_I', '', 33.8, 30.6, 28.0),
	(19, 35, 39, 'w', 'G_I', '', 35.8, 31.9, 28.6),
	(19, 40, 44, 'w', 'G_I', '', 37.7, 33.2, 29.3),
	(19, 45, 49, 'w', 'G_I', '', 39.7, 35.1, 29.9),
	(19, 50, 54, 'w', 'G_I', '', 41.6, 36.4, 30.6),
	(19, 55, 59, 'w', 'G_I', '', 43.6, 37.7, 31.2),
	(19, 60, 64, 'w', 'G_I', '', 45.5, 39.0, 32.5),
	(19, 65, 69, 'w', 'G_I', '', 46.8, 40.3, 33.2),
	(19, 70, 74, 'w', 'G_I', '', 49.4, 41.6, 34.5),
	(19, 75, 79, 'w', 'G_I', '', 50.7, 42.9, 35.8),
	(19, 80, 84, 'w', 'G_I', '', 52.7, 44.9, 37.1),
	(19, 85, 89, 'w', 'G_I', '', 54.6, 46.8, 39.0),
	(19, 90, 200, 'w', 'G_I', '', 57.9, 49.4, 41.0),
	(19, 8, 9, 'm', 'G_I', '', 49.4, 42.9, 36.4),
	(19, 10, 11, 'm', 'G_I', '', 45.5, 39.7, 33.8),
	(19, 12, 13, 'm', 'G_I', '', 38.4, 33.8, 29.3),
	(19, 14, 15, 'm', 'G_I', '', 31.2, 28.0, 24.7),
	(19, 16, 17, 'm', 'G_I', '', 28.6, 25.4, 22.1),
	(19, 18, 19, 'm', 'G_I', '', 26.7, 23.4, 20.2),
	(19, 20, 24, 'm', 'G_I', '', 26.0, 22.8, 19.5),
	(19, 25, 29, 'm', 'G_I', '', 27.3, 23.4, 19.5),
	(19, 30, 34, 'm', 'G_I', '', 29.3, 24.1, 19.5),
	(19, 35, 39, 'm', 'G_I', '', 31.2, 26.0, 20.2),
	(19, 40, 44, 'm', 'G_I', '', 34.5, 28.0, 21.5),
	(19, 45, 49, 'm', 'G_I', '', 37.1, 29.9, 22.1),
	(19, 50, 54, 'm', 'G_I', '', 39.0, 31.2, 23.4),
	(19, 55, 59, 'm', 'G_I', '', 41.6, 32.5, 24.1),
	(19, 60, 64, 'm', 'G_I', '', 43.6, 33.8, 24.7),
	(19, 65, 69, 'm', 'G_I', '', 45.5, 35.1, 25.4),
	(19, 70, 74, 'm', 'G_I', '', 46.8, 37.1, 26.0),
	(19, 75, 79, 'm', 'G_I', '', 48.8, 38.4, 28.0),
	(19, 80, 84, 'm', 'G_I', '', 50.7, 41.0, 29.9),
	(19, 85, 89, 'm', 'G_I', '', 53.3, 42.9, 31.9),
	(19, 90, 200, 'm', 'G_I', '', 56.6, 46.2, 35.1),
	(21, 10, 11, 'w', 'G_I', '', 0.56, 0.63, 0.7),
	(21, 12, 13, 'w', 'G_I', '', 0.63, 0.7, 0.77),
	(21, 14, 15, 'w', 'G_I', '', 0.67, 0.74, 0.81),
	(21, 16, 17, 'w', 'G_I', '', 0.74, 0.81, 0.88),
	(21, 18, 19, 'w', 'G_I', '', 0.77, 0.84, 0.91),
	(21, 20, 24, 'w', 'G_I', '', 0.77, 0.84, 0.91),
	(21, 25, 29, 'w', 'G_I', '', 0.74, 0.81, 0.88),
	(21, 30, 34, 'w', 'G_I', '', 0.7, 0.77, 0.84),
	(21, 35, 39, 'w', 'G_I', '', 0.67, 0.74, 0.81),
	(21, 40, 44, 'w', 'G_I', '', 0.63, 0.7, 0.77),
	(21, 45, 49, 'w', 'G_I', '', 0.63, 0.7, 0.77),
	(21, 50, 54, 'w', 'G_I', '', 0.6, 0.67, 0.74),
	(21, 55, 59, 'w', 'G_I', '', 0.56, 0.63, 0.7),
	(21, 60, 64, 'w', 'G_I', '', 0.53, 0.6, 0.67),
	(21, 65, 69, 'w', 'G_I', '', 0.53, 0.6, 0.67),
	(21, 70, 74, 'w', 'G_I', '', 0.49, 0.56, 0.63),
	(21, 75, 79, 'w', 'G_I', '', 0.46, 0.53, 0.6),
	(21, 80, 84, 'w', 'G_I', '', 0.46, 0.53, 0.6),
	(21, 85, 89, 'w', 'G_I', '', 0.42, 0.49, 0.56),
	(21, 90, 200, 'w', 'G_I', '', 0.39, 0.42, 0.46),
	(21, 10, 11, 'm', 'G_I', '', 0.6, 0.67, 0.74),
	(21, 12, 13, 'm', 'G_I', '', 0.67, 0.74, 0.81),
	(21, 14, 15, 'm', 'G_I', '', 0.77, 0.84, 0.91),
	(21, 16, 17, 'm', 'G_I', '', 0.84, 0.91, 0.98),
	(21, 18, 19, 'm', 'G_I', '', 0.91, 0.98, 1.05),
	(21, 20, 24, 'm', 'G_I', '', 0.95, 1.02, 1.09),
	(21, 25, 29, 'm', 'G_I', '', 0.91, 0.98, 1.05),
	(21, 30, 34, 'm', 'G_I', '', 0.91, 0.98, 1.05),
	(21, 35, 39, 'm', 'G_I', '', 0.88, 0.95, 1.02),
	(21, 40, 44, 'm', 'G_I', '', 0.84, 0.91, 0.98),
	(21, 45, 49, 'm', 'G_I', '', 0.81, 0.88, 0.95),
	(21, 50, 54, 'm', 'G_I', '', 0.74, 0.81, 0.88),
	(21, 55, 59, 'm', 'G_I', '', 0.7, 0.77, 0.84),
	(21, 60, 64, 'm', 'G_I', '', 0.67, 0.74, 0.81),
	(21, 65, 69, 'm', 'G_I', '', 0.6, 0.7, 0.77),
	(21, 70, 74, 'm', 'G_I', '', 0.56, 0.67, 0.74),
	(21, 75, 79, 'm', 'G_I', '', 0.53, 0.63, 0.7),
	(21, 80, 84, 'm', 'G_I', '', 0.53, 0.6, 0.67),
	(21, 85, 89, 'm', 'G_I', '', 0.49, 0.56, 0.63),
	(21, 90, 200, 'm', 'G_I', '', 0.46, 0.53, 0.6),
	(23, 0, 7, 'w', 'G_I', '', 1.21, 1.42, 1.63),
	(23, 8, 9, 'w', 'G_I', '', 1.41, 1.62, 1.83),
	(23, 10, 11, 'w', 'G_I', '', 1.61, 1.82, 2.03),
	(23, 12, 13, 'w', 'G_I', '', 1.96, 2.17, 2.38),
	(23, 14, 15, 'w', 'G_I', '', 2.24, 2.45, 2.66),
	(23, 16, 17, 'w', 'G_I', '', 2.38, 2.59, 2.8),
	(23, 18, 19, 'w', 'G_I', '', 2.38, 2.59, 2.8),
	(23, 20, 24, 'w', 'G_I', '', 2.38, 2.59, 2.8),
	(23, 25, 29, 'w', 'G_I', '', 2.31, 2.52, 2.73),
	(23, 30, 34, 'w', 'G_I', '', 2.24, 2.45, 2.66),
	(23, 35, 39, 'w', 'G_I', '', 2.17, 2.38, 2.59),
	(23, 40, 44, 'w', 'G_I', '', 2.1, 2.31, 2.52),
	(23, 45, 49, 'w', 'G_I', '', 1.96, 2.24, 2.45),
	(23, 50, 54, 'w', 'G_I', '', 1.82, 2.1, 2.38),
	(23, 55, 59, 'w', 'G_I', '', 1.75, 2.03, 2.31),
	(23, 60, 64, 'w', 'G_I', '', 1.68, 1.96, 2.24),
	(23, 65, 69, 'w', 'G_I', '', 1.61, 1.89, 2.17),
	(23, 70, 74, 'w', 'G_I', '', 1.47, 1.75, 2.03),
	(23, 75, 79, 'w', 'G_I', '', 1.26, 1.54, 1.82),
	(23, 80, 84, 'w', 'G_I', '', 1.12, 1.4, 1.68),
	(23, 85, 89, 'w', 'G_I', '', 0.91, 1.19, 1.47),
	(23, 90, 200, 'w', 'G_I', '', 0.77, 1.05, 1.33),
	(23, 0, 7, 'm', 'G_I', '', 1.42, 1.63, 1.84),
	(23, 8, 9, 'm', 'G_I', '', 1.62, 1.83, 2.04),
	(23, 10, 11, 'm', 'G_I', '', 1.82, 2.03, 2.24),
	(23, 12, 13, 'm', 'G_I', '', 2.24, 2.45, 2.66),
	(23, 14, 15, 'm', 'G_I', '', 2.66, 2.87, 3.08),
	(23, 16, 17, 'm', 'G_I', '', 3.01, 3.22, 3.43),
	(23, 18, 19, 'm', 'G_I', '', 3.15, 3.36, 3.57),
	(23, 20, 24, 'm', 'G_I', '', 3.08, 3.29, 3.5),
	(23, 25, 29, 'm', 'G_I', '', 3.01, 3.22, 3.43),
	(23, 30, 34, 'm', 'G_I', '', 2.94, 3.15, 3.36),
	(23, 35, 39, 'm', 'G_I', '', 2.87, 3.08, 3.29),
	(23, 40, 44, 'm', 'G_I', '', 2.73, 3.01, 3.22),
	(23, 45, 49, 'm', 'G_I', '', 2.59, 2.87, 3.15),
	(23, 50, 54, 'm', 'G_I', '', 2.52, 2.8, 3.08),
	(23, 55, 59, 'm', 'G_I', '', 2.38, 2.66, 2.94),
	(23, 60, 64, 'm', 'G_I', '', 2.24, 2.52, 2.8),
	(23, 65, 69, 'm', 'G_I', '', 2.03, 2.31, 2.59),
	(23, 70, 74, 'm', 'G_I', '', 1.89, 2.17, 2.45),
	(23, 75, 79, 'm', 'G_I', '', 1.68, 2.03, 2.31),
	(23, 80, 84, 'm', 'G_I', '', 1.47, 1.82, 2.17),
	(23, 85, 89, 'm', 'G_I', '', 1.33, 1.68, 2.03),
	(23, 90, 200, 'm', 'G_I', '', 1.12, 1.47, 1.82),
	(32, 18, 19, 'w', 'G_I', '', 17.916666666666668, 16.200000000000003, 14.483333333333333),
	(32, 20, 24, 'w', 'G_I', '', 17.48333333333333, 15.766666666666667, 14.049999999999999),
	(32, 25, 29, 'w', 'G_I', '', 17.76666666666667, 16.05, 14.333333333333332),
	(32, 30, 34, 'w', 'G_I', '', 18.48333333333333, 16.76666666666667, 15.049999999999999),
	(32, 35, 39, 'w', 'G_I', '', 18.916666666666668, 17.200000000000003, 15.483333333333333),
	(32, 40, 44, 'w', 'G_I', '', 19.633333333333333, 17.76666666666667, 15.916666666666668),
	(32, 45, 49, 'w', 'G_I', '', 20.5, 18.48333333333333, 16.200000000000003),
	(32, 50, 54, 'w', 'G_I', '', 21.35, 19.066666666666666, 16.48333333333333),
	(32, 55, 59, 'w', 'G_I', '', 22.216666666666665, 19.633333333333333, 17.05),
	(32, 60, 64, 'w', 'G_I', '', 22.78333333333333, 20.216666666666665, 17.633333333333333),
	(32, 65, 69, 'w', 'G_I', '', 23.366666666666664, 20.78333333333333, 18.200000000000003),
	(32, 70, 74, 'w', 'G_I', '', 23.8, 21.216666666666665, 18.633333333333333),
	(32, 75, 79, 'w', 'G_I', '', 24.516666666666666, 21.93333333333333, 19.35),
	(32, 80, 84, 'w', 'G_I', '', 25.516666666666666, 22.93333333333333, 20.35),
	(32, 85, 89, 'w', 'G_I', '', 26.666666666666664, 24.083333333333336, 21.5),
	(32, 90, 200, 'w', 'G_I', '', 27.95, 25.366666666666664, 22.78333333333333),
	(32, 18, 19, 'm', 'G_I', '', 15.333333333333332, 13.616666666666665, 11.899999999999999),
	(32, 20, 24, 'm', 'G_I', '', 14.899999999999999, 13.183333333333332, 11.466666666666665),
	(32, 25, 29, 'm', 'G_I', '', 15.2, 13.466666666666665, 11.749999999999998),
	(32, 30, 34, 'm', 'G_I', '', 15.916666666666668, 14.183333333333332, 12.466666666666665),
	(32, 35, 39, 'm', 'G_I', '', 17.05, 14.899999999999999, 12.899999999999999),
	(32, 40, 44, 'm', 'G_I', '', 18.066666666666666, 15.916666666666668, 13.616666666666665),
	(32, 45, 49, 'm', 'G_I', '', 19.066666666666666, 16.76666666666667, 14.183333333333332),
	(32, 50, 54, 'm', 'G_I', '', 20.066666666666666, 17.48333333333333, 14.899999999999999),
	(32, 55, 59, 'm', 'G_I', '', 20.5, 17.916666666666668, 15.333333333333332),
	(32, 60, 64, 'm', 'G_I', '', 21.066666666666666, 18.48333333333333, 15.916666666666668),
	(32, 65, 69, 'm', 'G_I', '', 21.5, 18.916666666666668, 16.333333333333332),
	(32, 70, 74, 'm', 'G_I', '', 21.78333333333333, 19.200000000000003, 16.633333333333333),
	(32, 75, 79, 'm', 'G_I', '', 22.366666666666664, 19.78333333333333, 17.200000000000003),
	(32, 80, 84, 'm', 'G_I', '', 22.78333333333333, 20.216666666666665, 17.633333333333333),
	(32, 85, 89, 'm', 'G_I', '', 23.650000000000002, 21.066666666666666, 18.48333333333333),
	(32, 90, 200, 'm', 'G_I', '', 25.650000000000002, 23.083333333333336, 20.5),
	(33, 0, 7, 'w', 'G_I', '', 4.800000000000001, 7.2, 10.2),
	(33, 8, 9, 'w', 'G_I', '', 6.0, 9.0, 12.0),
	(33, 10, 11, 'w', 'G_I', '', 9.0, 12.0, 18.0),
	(33, 12, 13, 'w', 'G_I', '', 12.0, 18.0, 24.0),
	(33, 14, 15, 'w', 'G_I', '', 18.0, 24.0, 30.0),
	(33, 16, 17, 'w', 'G_I', '', 27.0, 36.0, 45.0),
	(33, 0, 7, 'm', 'G_I', '', 6.0, 9.0, 12.0),
	(33, 8, 9, 'm', 'G_I', '', 7.2, 10.2, 13.8),
	(33, 10, 11, 'm', 'G_I', '', 10.2, 15.0, 21.0),
	(33, 12, 13, 'm', 'G_I', '', 15.0, 21.0, 27.0),
	(33, 14, 15, 'm', 'G_I', '', 21.0, 27.0, 36.0),
	(33, 16, 17, 'm', 'G_I', '', 33.0, 42.0, 54.0),
	(39, 0, 7, 'w', 'G_I', '', 128.0, 143.0, 157.0),
	(39, 8, 9, 'w', 'G_I', '', 140.0, 155.0, 171.0),
	(39, 10, 11, 'w', 'G_I', '', 151.0, 168.0, 184.0),
	(39, 12, 13, 'w', 'G_I', '', 162.0, 180.0, 198.0),
	(39, 14, 15, 'w', 'G_I', '', 173.0, 193.0, 212.0),
	(39, 16, 17, 'w', 'G_I', '', 185.0, 205.0, 226.0),
	(39, 18, 19, 'w', 'G_I', '', 275.0, 305.0, 336.0),
	(39, 20, 24, 'w', 'G_I', '', 275.0, 305.0, 336.0),
	(39, 25, 29, 'w', 'G_I', '', 275.0, 305.0, 336.0),
	(39, 30, 34, 'w', 'G_I', '', 263.0, 293.0, 322.0),
	(39, 35, 39, 'w', 'G_I', '', 263.0, 293.0, 322.0),
	(39, 40, 44, 'w', 'G_I', '', 252.0, 280.0, 308.0),
	(39, 45, 49, 'w', 'G_I', '', 241.0, 268.0, 294.0),
	(39, 50, 54, 'w', 'G_I', '', 230.0, 255.0, 281.0),
	(39, 55, 59, 'w', 'G_I', '', 218.0, 243.0, 267.0),
	(39, 60, 64, 'w', 'G_I', '', 207.0, 230.0, 253.0),
	(39, 65, 69, 'w', 'G_I', '', 196.0, 218.0, 239.0),
	(39, 70, 74, 'w', 'G_I', '', 185.0, 205.0, 226.0),
	(39, 75, 79, 'w', 'G_I', '', 173.0, 193.0, 212.0),
	(39, 80, 84, 'w', 'G_I', '', 162.0, 180.0, 198.0),
	(39, 85, 89, 'w', 'G_I', '', 151.0, 168.0, 184.0),
	(39, 90, 200, 'w', 'G_I', '', 140.0, 155.0, 171.0),
	(39, 0, 7, 'm', 'G_I', '', 187.0, 208.0, 228.0),
	(39, 8, 9, 'm', 'G_I', '', 198.0, 220.0, 242.0),
	(39, 10, 11, 'm', 'G_I', '', 209.0, 233.0, 256.0),
	(39, 12, 13, 'm', 'G_I', '', 221.0, 245.0, 270.0),
	(39, 14, 15, 'm', 'G_I', '', 232.0, 258.0, 283.0),
	(39, 16, 17, 'm', 'G_I', '', 243.0, 270.0, 297.0),
	(39, 18, 19, 'm', 'G_I', '', 333.0, 370.0, 407.0),
	(39, 20, 24, 'm', 'G_I', '', 333.0, 370.0, 407.0),
	(39, 25, 29, 'm', 'G_I', '', 333.0, 370.0, 407.0),
	(39, 30, 34, 'm', 'G_I', '', 322.0, 358.0, 393.0),
	(39, 35, 39, 'm', 'G_I', '', 322.0, 358.0, 393.0),
	(39, 40, 44, 'm', 'G_I', '', 311.0, 345.0, 380.0),
	(39, 45, 49, 'm', 'G_I', '', 299.0, 333.0, 366.0),
	(39, 50, 54, 'm', 'G_I', '', 288.0, 320.0, 352.0),
	(39, 55, 59, 'm', 'G_I', '', 277.0, 308.0, 338.0),
	(39, 60, 64, 'm', 'G_I', '', 266.0, 295.0, 325.0),
	(39, 65, 69, 'm', 'G_I', '', 254.0, 283.0, 311.0),
	(39, 70, 74, 'm', 'G_I', '', 243.0, 270.0, 297.0),
	(39, 75, 79, 'm', 'G_I', '', 232.0, 258.0, 283.0),
	(39, 80, 84, 'm', 'G_I', '', 221.0, 245.0, 270.0),
	(39, 85, 89, 'm', 'G_I', '', 209.0, 233.0, 256.0),
	(39, 90, 200, 'm', 'G_I', '', 198.0, 220.0, 242.0),
	(40, 0, 7, 'w', 'G_I', '', 288.0, 320.0, 352.0),
	(40, 8, 9, 'w', 'G_I', '', 302.0, 335.0, 369.0),
	(40, 10, 11, 'w', 'G_I', '', 315.0, 350.0, 385.0),
	(40, 12, 13, 'w', 'G_I', '', 329.0, 365.0, 402.0),
	(40, 14, 15, 'w', 'G_I', '', 342.0, 380.0, 418.0),
	(40, 16, 17, 'w', 'G_I', '', 356.0, 395.0, 435.0),
	(40, 18, 19, 'w', 'G_I', '', 446.0, 495.0, 545.0),
	(40, 20, 24, 'w', 'G_I', '', 446.0, 495.0, 545.0),
	(40, 25, 29, 'w', 'G_I', '', 446.0, 495.0, 545.0),
	(40, 30, 34, 'w', 'G_I', '', 432.0, 480.0, 528.0),
	(40, 35, 39, 'w', 'G_I', '', 432.0, 480.0, 528.0),
	(40, 40, 44, 'w', 'G_I', '', 419.0, 465.0, 512.0),
	(40, 45, 49, 'w', 'G_I', '', 405.0, 450.0, 495.0),
	(40, 50, 54, 'w', 'G_I', '', 392.0, 435.0, 479.0),
	(40, 55, 59, 'w', 'G_I', '', 378.0, 420.0, 462.0),
	(40, 60, 64, 'w', 'G_I', '', 365.0, 405.0, 446.0),
	(40, 65, 69, 'w', 'G_I', '', 351.0, 390.0, 429.0),
	(40, 70, 74, 'w', 'G_I', '', 338.0, 375.0, 413.0),
	(40, 75, 79, 'w', 'G_I', '', 324.0, 360.0, 396.0),
	(40, 80, 84, 'w', 'G_I', '', 311.0, 345.0, 380.0),
	(40, 85, 89, 'w', 'G_I', '', 297.0, 330.0, 363.0),
	(40, 90, 200, 'w', 'G_I', '', 284.0, 315.0, 347.0),
	(40, 0, 7, 'm', 'G_I', '', 356.0, 395.0, 435.0),
	(40, 8, 9, 'm', 'G_I', '', 369.0, 410.0, 451.0),
	(40, 10, 11, 'm', 'G_I', '', 383.0, 425.0, 468.0),
	(40, 12, 13, 'm', 'G_I', '', 396.0, 440.0, 484.0),
	(40, 14, 15, 'm', 'G_I', '', 410.0, 455.0, 501.0),
	(40, 16, 17, 'm', 'G_I', '', 423.0, 470.0, 517.0),
	(40, 18, 19, 'm', 'G_I', '', 513.0, 570.0, 627.0),
	(40, 20, 24, 'm', 'G_I', '', 513.0, 570.0, 627.0),
	(40, 25, 29, 'm', 'G_I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'G_I', '', 500.0, 555.0, 611.0),
	(40, 35, 39, 'm', 'G_I', '', 500.0, 555.0, 611.0),
	(40, 40, 44, 'm', 'G_I', '', 486.0, 540.0, 594.0),
	(40, 45, 49, 'm', 'G_I', '', 473.0, 525.0, 578.0),
	(40, 50, 54, 'm', 'G_I', '', 459.0, 510.0, 561.0),
	(40, 55, 59, 'm', 'G_I', '', 446.0, 495.0, 545.0),
	(40, 60, 64, 'm', 'G_I', '', 432.0, 480.0, 528.0),
	(40, 65, 69, 'm', 'G_I', '', 419.0, 465.0, 512.0),
	(40, 70, 74, 'm', 'G_I', '', 405.0, 450.0, 495.0),
	(40, 75, 79, 'm', 'G_I', '', 392.0, 435.0, 479.0),
	(40, 80, 84, 'm', 'G_I', '', 378.0, 420.0, 462.0),
	(40, 85, 89, 'm', 'G_I', '', 365.0, 405.0, 446.0),
	(40, 90, 200, 'm', 'G_I', '', 351.0, 390.0, 429.0),
	(41, 0, 7, 'w', 'G_I', '', 221.0, 245.0, 270.0),
	(41, 8, 9, 'w', 'G_I', '', 234.0, 260.0, 286.0),
	(41, 10, 11, 'w', 'G_I', '', 248.0, 275.0, 303.0),
	(41, 12, 13, 'w', 'G_I', '', 261.0, 290.0, 319.0),
	(41, 14, 15, 'w', 'G_I', '', 275.0, 305.0, 336.0),
	(41, 16, 17, 'w', 'G_I', '', 288.0, 320.0, 352.0),
	(41, 18, 19, 'w', 'G_I', '', 378.0, 420.0, 462.0),
	(41, 20, 24, 'w', 'G_I', '', 378.0, 420.0, 462.0),
	(41, 25, 29, 'w', 'G_I', '', 378.0, 420.0, 462.0),
	(41, 30, 34, 'w', 'G_I', '', 365.0, 405.0, 446.0),
	(41, 35, 39, 'w', 'G_I', '', 365.0, 405.0, 446.0),
	(41, 40, 44, 'w', 'G_I', '', 351.0, 390.0, 429.0),
	(41, 45, 49, 'w', 'G_I', '', 338.0, 375.0, 413.0),
	(41, 50, 54, 'w', 'G_I', '', 324.0, 360.0, 396.0),
	(41, 55, 59, 'w', 'G_I', '', 311.0, 345.0, 380.0),
	(41, 60, 64, 'w', 'G_I', '', 297.0, 330.0, 363.0),
	(41, 65, 69, 'w', 'G_I', '', 284.0, 315.0, 347.0),
	(41, 70, 74, 'w', 'G_I', '', 270.0, 300.0, 330.0),
	(41, 75, 79, 'w', 'G_I', '', 257.0, 285.0, 314.0),
	(41, 80, 84, 'w', 'G_I', '', 243.0, 270.0, 297.0),
	(41, 85, 89, 'w', 'G_I', '', 230.0, 255.0, 281.0),
	(41, 90, 200, 'w', 'G_I', '', 216.0, 240.0, 264.0),
	(41, 0, 7, 'm', 'G_I', '', 284.0, 315.0, 347.0),
	(41, 8, 9, 'm', 'G_I', '', 297.0, 330.0, 363.0),
	(41, 10, 11, 'm', 'G_I', '', 311.0, 345.0, 380.0),
	(41, 12, 13, 'm', 'G_I', '', 324.0, 360.0, 396.0),
	(41, 14, 15, 'm', 'G_I', '', 338.0, 375.0, 413.0),
	(41, 16, 17, 'm', 'G_I', '', 351.0, 390.0, 429.0),
	(41, 18, 19, 'm', 'G_I', '', 441.0, 490.0, 539.0),
	(41, 20, 24, 'm', 'G_I', '', 441.0, 490.0, 539.0),
	(41, 25, 29, 'm', 'G_I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'G_I', '', 428.0, 475.0, 523.0),
	(41, 35, 39, 'm', 'G_I', '', 428.0, 475.0, 523.0),
	(41, 40, 44, 'm', 'G_I', '', 414.0, 460.0, 506.0),
	(41, 45, 49, 'm', 'G_I', '', 401.0, 445.0, 490.0),
	(41, 50, 54, 'm', 'G_I', '', 387.0, 430.0, 473.0),
	(41, 55, 59, 'm', 'G_I', '', 374.0, 415.0, 457.0),
	(41, 60, 64, 'm', 'G_I', '', 360.0, 400.0, 440.0),
	(41, 65, 69, 'm', 'G_I', '', 347.0, 385.0, 424.0),
	(41, 70, 74, 'm', 'G_I', '', 333.0, 370.0, 407.0),
	(41, 75, 79, 'm', 'G_I', '', 320.0, 355.0, 391.0),
	(41, 80, 84, 'm', 'G_I', '', 306.0, 340.0, 374.0),
	(41, 85, 89, 'm', 'G_I', '', 293.0, 325.0, 358.0),
	(41, 90, 200, 'm', 'G_I', '', 279.0, 310.0, 341.0),
	(42, 0, 7, 'w', 'G_I', '', 225.0, 250.0, 275.0),
	(42, 8, 9, 'w', 'G_I', '', 239.0, 265.0, 292.0),
	(42, 10, 11, 'w', 'G_I', '', 252.0, 280.0, 308.0),
	(42, 12, 13, 'w', 'G_I', '', 266.0, 295.0, 325.0),
	(42, 14, 15, 'w', 'G_I', '', 279.0, 310.0, 341.0),
	(42, 16, 17, 'w', 'G_I', '', 293.0, 325.0, 358.0),
	(42, 18, 19, 'w', 'G_I', '', 383.0, 425.0, 468.0),
	(42, 20, 24, 'w', 'G_I', '', 383.0, 425.0, 468.0),
	(42, 25, 29, 'w', 'G_I', '', 383.0, 425.0, 468.0),
	(42, 30, 34, 'w', 'G_I', '', 369.0, 410.0, 451.0),
	(42, 35, 39, 'w', 'G_I', '', 369.0, 410.0, 451.0),
	(42, 40, 44, 'w', 'G_I', '', 356.0, 395.0, 435.0),
	(42, 45, 49, 'w', 'G_I', '', 342.0, 380.0, 418.0),
	(42, 50, 54, 'w', 'G_I', '', 329.0, 365.0, 402.0),
	(42, 55, 59, 'w', 'G_I', '', 315.0, 350.0, 385.0),
	(42, 60, 64, 'w', 'G_I', '', 302.0, 335.0, 369.0),
	(42, 65, 69, 'w', 'G_I', '', 288.0, 320.0, 352.0),
	(42, 70, 74, 'w', 'G_I', '', 275.0, 305.0, 336.0),
	(42, 75, 79, 'w', 'G_I', '', 261.0, 290.0, 319.0),
	(42, 80, 84, 'w', 'G_I', '', 248.0, 275.0, 303.0),
	(42, 85, 89, 'w', 'G_I', '', 234.0, 260.0, 286.0),
	(42, 90, 200, 'w', 'G_I', '', 221.0, 245.0, 270.0),
	(42, 0, 7, 'm', 'G_I', '', 288.0, 320.0, 352.0),
	(42, 8, 9, 'm', 'G_I', '', 302.0, 335.0, 369.0),
	(42, 10, 11, 'm', 'G_I', '', 315.0, 350.0, 385.0),
	(42, 12, 13, 'm', 'G_I', '', 329.0, 365.0, 402.0),
	(42, 14, 15, 'm', 'G_I', '', 342.0, 380.0, 418.0),
	(42, 16, 17, 'm', 'G_I', '', 356.0, 395.0, 435.0),
	(42, 18, 19, 'm', 'G_I', '', 446.0, 495.0, 545.0),
	(42, 20, 24, 'm', 'G_I', '', 446.0, 495.0, 545.0),
	(42, 25, 29, 'm', 'G_I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'G_I', '', 432.0, 480.0, 528.0),
	(42, 35, 39, 'm', 'G_I', '', 432.0, 480.0, 528.0),
	(42, 40, 44, 'm', 'G_I', '', 419.0, 465.0, 512.0),
	(42, 45, 49, 'm', 'G_I', '', 405.0, 450.0, 495.0),
	(42, 50, 54, 'm', 'G_I', '', 392.0, 435.0, 479.0),
	(42, 55, 59, 'm', 'G_I', '', 378.0, 420.0, 462.0),
	(42, 60, 64, 'm', 'G_I', '', 365.0, 405.0, 446.0),
	(42, 65, 69, 'm', 'G_I', '', 351.0, 390.0, 429.0),
	(42, 70, 74, 'm', 'G_I', '', 338.0, 375.0, 413.0),
	(42, 75, 79, 'm', 'G_I', '', 324.0, 360.0, 396.0),
	(42, 80, 84, 'm', 'G_I', '', 311.0, 345.0, 380.0),
	(42, 85, 89, 'm', 'G_I', '', 297.0, 330.0, 363.0),
	(42, 90, 200, 'm', 'G_I', '', 284.0, 315.0, 347.0),
	(44, 12, 13, 'w', 'G_I', '', 6.06, 6.69, 7.33),
	(44, 14, 15, 'w', 'G_I', '', 7.01, 7.65, 8.29),
	(44, 16, 17, 'w', 'G_I', '', 7.33, 7.97, 8.61),
	(44, 18, 19, 'w', 'G_I', '', 8.29, 8.93, 9.56),
	(44, 20, 24, 'w', 'G_I', '', 8.29, 8.93, 9.56),
	(44, 25, 29, 'w', 'G_I', '', 8.29, 8.93, 9.56),
	(44, 30, 34, 'w', 'G_I', '', 7.97, 8.61, 9.24),
	(44, 35, 39, 'w', 'G_I', '', 7.65, 8.29, 8.93),
	(44, 40, 44, 'w', 'G_I', '', 7.01, 7.65, 8.29),
	(44, 45, 49, 'w', 'G_I', '', 6.69, 7.33, 7.97),
	(44, 50, 54, 'w', 'G_I', '', 6.69, 7.65, 8.93),
	(44, 55, 59, 'w', 'G_I', '', 6.38, 7.33, 8.29),
	(44, 60, 64, 'w', 'G_I', '', 6.06, 7.01, 7.97),
	(44, 65, 69, 'w', 'G_I', '', 5.74, 6.69, 7.97),
	(44, 70, 74, 'w', 'G_I', '', 5.42, 6.38, 7.65),
	(44, 75, 79, 'w', 'G_I', '', 5.42, 6.69, 7.97),
	(44, 80, 84, 'w', 'G_I', '', 5.1, 6.38, 7.33),
	(44, 85, 89, 'w', 'G_I', '', 4.78, 5.74, 7.01),
	(44, 90, 200, 'w', 'G_I', '', 4.14, 5.42, 6.38),
	(44, 12, 13, 'm', 'G_I', '', 7.97, 8.61, 9.24),
	(44, 14, 15, 'm', 'G_I', '', 8.93, 9.56, 10.2),
	(44, 16, 17, 'm', 'G_I', '', 9.56, 10.2, 10.84),
	(44, 18, 19, 'm', 'G_I', '', 9.88, 10.52, 11.16),
	(44, 20, 24, 'm', 'G_I', '', 9.88, 10.84, 11.48),
	(44, 25, 29, 'm', 'G_I', '', 9.56, 10.52, 11.16),
	(44, 30, 34, 'm', 'G_I', '', 8.93, 9.88, 10.52),
	(44, 35, 39, 'm', 'G_I', '', 8.61, 9.24, 10.2),
	(44, 40, 44, 'm', 'G_I', '', 7.97, 8.93, 9.88),
	(44, 45, 49, 'm', 'G_I', '', 7.65, 8.61, 9.56),
	(44, 50, 54, 'm', 'G_I', '', 7.97, 8.93, 10.2),
	(44, 55, 59, 'm', 'G_I', '', 7.77, 8.78, 9.85),
	(44, 60, 64, 'm', 'G_I', '', 7.65, 8.67, 9.71),
	(44, 65, 69, 'm', 'G_I', '', 7.33, 8.61, 9.56),
	(44, 70, 74, 'm', 'G_I', '', 7.14, 8.42, 9.27),
	(44, 75, 79, 'm', 'G_I', '', 7.06, 8.29, 9.17),
	(44, 80, 84, 'm', 'G_I', '', 7.01, 7.97, 9.24),
	(44, 85, 89, 'm', 'G_I', '', 6.38, 7.65, 8.61),
	(44, 90, 200, 'm', 'G_I', '', 5.74, 6.69, 7.97),
	(46, 18, 19, 'w', 'G_I', '', 16.45, 18.55, 20.3),
	(46, 20, 24, 'w', 'G_I', '', 16.8, 18.9, 20.65),
	(46, 25, 29, 'w', 'G_I', '', 16.8, 18.9, 20.65),
	(46, 30, 34, 'w', 'G_I', '', 15.4, 17.5, 19.25),
	(46, 35, 39, 'w', 'G_I', '', 14.7, 16.8, 18.55),
	(46, 40, 44, 'w', 'G_I', '', 13.65, 15.75, 17.5),
	(46, 45, 49, 'w', 'G_I', '', 12.95, 15.05, 16.8),
	(46, 50, 54, 'w', 'G_I', '', 11.55, 14.0, 16.1),
	(46, 55, 59, 'w', 'G_I', '', 10.85, 13.3, 15.4),
	(46, 60, 64, 'w', 'G_I', '', 10.15, 12.6, 14.7),
	(46, 65, 69, 'w', 'G_I', '', 9.45, 11.9, 14.0),
	(46, 70, 74, 'w', 'G_I', '', 9.1, 11.55, 13.65),
	(46, 75, 79, 'w', 'G_I', '', 8.4, 10.85, 12.95),
	(46, 80, 84, 'w', 'G_I', '', 7.7, 10.15, 12.25),
	(46, 85, 89, 'w', 'G_I', '', 6.65, 9.1, 11.2),
	(46, 90, 200, 'w', 'G_I', '', 5.25, 7.7, 9.8),
	(46, 18, 19, 'm', 'G_I', '', 22.05, 25.2, 28.35),
	(46, 20, 24, 'm', 'G_I', '', 23.1, 26.6, 29.4),
	(46, 25, 29, 'm', 'G_I', '', 22.75, 26.25, 29.05),
	(46, 30, 34, 'm', 'G_I', '', 21.0, 24.5, 28.0),
	(46, 35, 39, 'm', 'G_I', '', 19.95, 23.45, 26.95),
	(46, 40, 44, 'm', 'G_I', '', 19.6, 23.1, 26.6),
	(46, 45, 49, 'm', 'G_I', '', 18.9, 22.4, 26.25),
	(46, 50, 54, 'm', 'G_I', '', 17.85, 21.7, 25.55),
	(46, 55, 59, 'm', 'G_I', '', 16.45, 20.3, 24.5),
	(46, 60, 64, 'm', 'G_I', '', 15.75, 19.6, 23.8),
	(46, 65, 69, 'm', 'G_I', '', 14.0, 17.85, 21.35),
	(46, 70, 74, 'm', 'G_I', '', 12.95, 16.8, 20.3),
	(46, 75, 79, 'm', 'G_I', '', 11.2, 14.7, 18.2),
	(46, 80, 84, 'm', 'G_I', '', 9.8, 13.3, 16.8),
	(46, 85, 89, 'm', 'G_I', '', 8.4, 11.55, 14.7),
	(46, 90, 200, 'm', 'G_I', '', 7.35, 10.5, 13.65),
	(53, 0, 7, 'w', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'G_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'G_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'G_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'G_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'G_I', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'G_I', '', 1.0, 2.0, 3.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'G_II', '', 12.466666666666665, 11.0, 9.350000000000001),
	(1, 8, 9, 'w', 'G_II', '', 12.283333333333333, 10.633333333333335, 9.166666666666666),
	(1, 10, 11, 'w', 'G_II', '', 11.733333333333333, 10.266666666666667, 8.8),
	(1, 12, 13, 'w', 'G_II', '', 11.366666666666667, 9.716666666666667, 8.25),
	(1, 14, 15, 'w', 'G_II', '', 11.0, 9.533333333333333, 7.883333333333334),
	(1, 16, 17, 'w', 'G_II', '', 10.633333333333335, 8.983333333333333, 7.516666666666666),
	(1, 0, 7, 'm', 'G_II', '', 12.466666666666665, 11.0, 9.350000000000001),
	(1, 8, 9, 'm', 'G_II', '', 11.916666666666668, 10.266666666666667, 8.616666666666665),
	(1, 10, 11, 'm', 'G_II', '', 11.183333333333332, 9.533333333333333, 7.883333333333334),
	(1, 12, 13, 'm', 'G_II', '', 10.45, 8.8, 7.1499999999999995),
	(1, 14, 15, 'm', 'G_II', '', 9.533333333333333, 8.066666666666665, 6.6000000000000005),
	(1, 16, 17, 'm', 'G_II', '', 8.983333333333333, 7.516666666666666, 6.050000000000001),
	(4, 8, 9, 'w', 'G_II', '2,5 km', 43.199999999999996, 38.400000000000006, 33.6),
	(4, 10, 11, 'w', 'G_II', '5 km', 80.80000000000001, 68.80000000000001, 56.8),
	(4, 12, 13, 'w', 'G_II', '5 km', 72.0, 63.199999999999996, 53.6),
	(4, 14, 15, 'w', 'G_II', '5 km', 60.8, 52.0, 45.6),
	(4, 16, 17, 'w', 'G_II', '5 km', 52.0, 45.6, 40.0),
	(4, 18, 19, 'w', 'G_II', '10 km', 56.93333333333334, 51.483333333333334, 46.03333333333334),
	(4, 20, 24, 'w', 'G_II', '10 km', 56.43333333333333, 50.98333333333334, 45.050000000000004),
	(4, 25, 29, 'w', 'G_II', '10 km', 55.43333333333333, 50.0, 44.55),
	(4, 30, 34, 'w', 'G_II', '10 km', 56.43333333333333, 50.98333333333334, 45.050000000000004),
	(4, 35, 39, 'w', 'G_II', '10 km', 59.400000000000006, 52.46666666666667, 46.53333333333333),
	(4, 40, 44, 'w', 'G_II', '10 km', 63.36666666666667, 54.95, 49.0),
	(4, 45, 49, 'w', 'G_II', '10 km', 66.33333333333334, 57.916666666666664, 50.98333333333334),
	(4, 50, 54, 'w', 'G_II', '10 km', 68.31666666666666, 60.383333333333326, 52.96666666666666),
	(4, 55, 59, 'w', 'G_II', '10 km', 70.78333333333333, 62.36666666666667, 54.95),
	(4, 60, 64, 'w', 'G_II', '10 km', 73.26666666666667, 64.35, 56.43333333333333),
	(4, 65, 69, 'w', 'G_II', '10 km', 74.75, 65.83333333333333, 57.916666666666664),
	(4, 70, 74, 'w', 'G_II', '10 km', 77.21666666666665, 67.81666666666666, 59.9),
	(4, 75, 79, 'w', 'G_II', '10 km', 80.68333333333332, 69.80000000000001, 62.36666666666667),
	(4, 80, 84, 'w', 'G_II', '10 km', 83.65, 74.25000000000001, 64.85000000000001),
	(4, 85, 89, 'w', 'G_II', '10 km', 88.6, 79.2, 68.31666666666666),
	(4, 90, 200, 'w', 'G_II', '10 km', 92.06666666666668, 82.16666666666666, 71.76666666666665),
	(4, 8, 9, 'm', 'G_II', '2,5 km', 42.400000000000006, 37.6, 32.8),
	(4, 10, 11, 'm', 'G_II', '5 km', 77.6, 65.6, 53.6),
	(4, 12, 13, 'm', 'G_II', '5 km', 68.80000000000001, 59.199999999999996, 50.400000000000006),
	(4, 14, 15, 'm', 'G_II', '5 km', 51.199999999999996, 44.8, 38.400000000000006),
	(4, 16, 17, 'm', 'G_II', '5 km', 43.199999999999996, 37.6, 32.8),
	(4, 18, 19, 'm', 'G_II', '10 km', 46.53333333333333, 42.08333333333333, 38.11666666666667),
	(4, 20, 24, 'm', 'G_II', '10 km', 46.03333333333334, 41.583333333333336, 37.11666666666667),
	(4, 25, 29, 'm', 'G_II', '10 km', 49.49999999999999, 44.050000000000004, 38.61666666666666),
	(4, 30, 34, 'm', 'G_II', '10 km', 52.96666666666666, 46.53333333333333, 40.1),
	(4, 35, 39, 'm', 'G_II', '10 km', 57.416666666666664, 49.49999999999999, 41.08333333333333),
	(4, 40, 44, 'm', 'G_II', '10 km', 62.36666666666667, 51.483333333333334, 43.06666666666666),
	(4, 45, 49, 'm', 'G_II', '10 km', 65.33333333333334, 54.45, 44.55),
	(4, 50, 54, 'm', 'G_II', '10 km', 67.81666666666666, 56.43333333333333, 46.03333333333334),
	(4, 55, 59, 'm', 'G_II', '10 km', 69.80000000000001, 57.916666666666664, 47.016666666666666),
	(4, 60, 64, 'm', 'G_II', '10 km', 70.78333333333333, 59.400000000000006, 47.51666666666667),
	(4, 65, 69, 'm', 'G_II', '10 km', 71.76666666666665, 59.9, 48.016666666666666),
	(4, 70, 74, 'm', 'G_II', '10 km', 72.76666666666665, 60.88333333333333, 49.0),
	(4, 75, 79, 'm', 'G_II', '10 km', 73.75, 62.36666666666667, 50.98333333333334),
	(4, 80, 84, 'm', 'G_II', '10 km', 75.23333333333333, 63.849999999999994, 52.46666666666667),
	(4, 85, 89, 'm', 'G_II', '10 km', 76.73333333333333, 65.83333333333333, 54.95),
	(4, 90, 200, 'm', 'G_II', '10 km', 78.21666666666665, 67.31666666666666, 57.416666666666664),
	(7, 0, 7, 'w', 'G_II', '200 m', 14.4, 12.266666666666667, 10.133333333333333),
	(7, 8, 9, 'w', 'G_II', '200 m', 12.8, 11.2, 9.466666666666665),
	(7, 10, 11, 'w', 'G_II', '200 m', 11.733333333333333, 10.266666666666667, 8.8),
	(7, 12, 13, 'w', 'G_II', '400 m', 23.733333333333334, 20.666666666666664, 17.599999999999998),
	(7, 14, 15, 'w', 'G_II', '400 m', 20.93333333333333, 18.666666666666664, 16.0),
	(7, 16, 17, 'w', 'G_II', '400 m', 18.93333333333333, 16.8, 14.533333333333333),
	(7, 18, 19, 'w', 'G_II', '800 m', 38.400000000000006, 33.866666666666674, 29.46666666666667),
	(7, 20, 24, 'w', 'G_II', '800 m', 37.73333333333333, 33.333333333333336, 28.8),
	(7, 25, 29, 'w', 'G_II', '800 m', 40.8, 33.73333333333333, 29.866666666666667),
	(7, 30, 34, 'w', 'G_II', '800 m', 46.13333333333333, 37.866666666666674, 31.200000000000003),
	(7, 35, 39, 'w', 'G_II', '800 m', 51.199999999999996, 40.93333333333334, 32.53333333333333),
	(7, 40, 44, 'w', 'G_II', '800 m', 54.400000000000006, 44.26666666666666, 34.13333333333333),
	(7, 45, 49, 'w', 'G_II', '800 m', 56.53333333333333, 46.400000000000006, 34.400000000000006),
	(7, 50, 54, 'w', 'G_II', '400 m', 28.8, 24.0, 18.4),
	(7, 55, 59, 'w', 'G_II', '400 m', 29.733333333333334, 24.533333333333335, 19.066666666666666),
	(7, 60, 64, 'w', 'G_II', '400 m', 30.4, 24.93333333333333, 19.46666666666667),
	(7, 65, 69, 'w', 'G_II', '400 m', 31.066666666666666, 25.200000000000003, 19.599999999999998),
	(7, 70, 74, 'w', 'G_II', '400 m', 31.733333333333334, 25.733333333333334, 20.266666666666666),
	(7, 75, 79, 'w', 'G_II', '200 m', 16.4, 13.333333333333332, 10.4),
	(7, 80, 84, 'w', 'G_II', '200 m', 16.666666666666664, 13.6, 10.8),
	(7, 85, 89, 'w', 'G_II', '200 m', 16.93333333333333, 14.0, 11.333333333333332),
	(7, 90, 200, 'w', 'G_II', '200 m', 17.200000000000003, 14.266666666666667, 11.733333333333333),
	(7, 0, 7, 'm', 'G_II', '200 m', 14.4, 11.733333333333333, 9.866666666666665),
	(7, 8, 9, 'm', 'G_II', '200 m', 12.8, 10.8, 9.066666666666665),
	(7, 10, 11, 'm', 'G_II', '200 m', 11.2, 10.133333333333333, 8.266666666666667),
	(7, 12, 13, 'm', 'G_II', '400 m', 21.599999999999998, 18.4, 15.6),
	(7, 14, 15, 'm', 'G_II', '400 m', 19.200000000000003, 16.4, 14.133333333333333),
	(7, 16, 17, 'm', 'G_II', '400 m', 17.599999999999998, 15.466666666666665, 13.333333333333332),
	(7, 18, 19, 'm', 'G_II', '800 m', 36.13333333333333, 31.733333333333334, 27.200000000000003),
	(7, 20, 24, 'm', 'G_II', '800 m', 35.46666666666667, 31.200000000000003, 26.266666666666666),
	(7, 25, 29, 'm', 'G_II', '800 m', 37.06666666666666, 32.0, 27.200000000000003),
	(7, 30, 34, 'm', 'G_II', '800 m', 41.199999999999996, 34.400000000000006, 28.8),
	(7, 35, 39, 'm', 'G_II', '800 m', 46.13333333333333, 38.400000000000006, 30.8),
	(7, 40, 44, 'm', 'G_II', '800 m', 51.866666666666674, 42.26666666666666, 32.666666666666664),
	(7, 45, 49, 'm', 'G_II', '800 m', 55.199999999999996, 44.53333333333333, 33.06666666666666),
	(7, 50, 54, 'm', 'G_II', '400 m', 27.866666666666667, 22.93333333333333, 17.200000000000003),
	(7, 55, 59, 'm', 'G_II', '400 m', 28.533333333333335, 23.333333333333332, 18.13333333333333),
	(7, 60, 64, 'm', 'G_II', '400 m', 29.066666666666666, 23.599999999999998, 18.266666666666666),
	(7, 65, 69, 'm', 'G_II', '400 m', 29.46666666666667, 24.13333333333333, 18.4),
	(7, 70, 74, 'm', 'G_II', '400 m', 29.46666666666667, 24.4, 18.533333333333335),
	(7, 75, 79, 'm', 'G_II', '200 m', 15.066666666666665, 12.266666666666667, 9.733333333333333),
	(7, 80, 84, 'm', 'G_II', '200 m', 15.2, 12.533333333333333, 9.866666666666665),
	(7, 85, 89, 'm', 'G_II', '200 m', 15.2, 12.8, 10.266666666666667),
	(7, 90, 200, 'm', 'G_II', '200 m', 15.6, 13.066666666666665, 10.8),
	(8, 18, 19, 'w', 'G_II', '3 km', 48.65, 46.199999999999996, 43.400000000000006),
	(8, 20, 24, 'w', 'G_II', '3 km', 46.55, 44.1, 41.65),
	(8, 25, 29, 'w', 'G_II', '3 km', 46.9, 44.45, 42.0),
	(8, 30, 34, 'w', 'G_II', '3 km', 47.25, 44.8, 42.28333333333334),
	(8, 35, 39, 'w', 'G_II', '3 km', 49.0, 45.49999999999999, 42.51666666666667),
	(8, 40, 44, 'w', 'G_II', '3 km', 51.1, 46.9, 42.7),
	(8, 45, 49, 'w', 'G_II', '3 km', 52.849999999999994, 48.3, 43.400000000000006),
	(8, 50, 54, 'w', 'G_II', '3 km', 54.6, 49.7, 44.8),
	(8, 55, 59, 'w', 'G_II', '3 km', 56.0, 51.1, 46.199999999999996),
	(8, 60, 64, 'w', 'G_II', '3 km', 57.75000000000001, 52.150000000000006, 47.25),
	(8, 65, 69, 'w', 'G_II', '3 km', 58.96666666666666, 53.55, 49.0),
	(8, 70, 74, 'w', 'G_II', '3 km', 61.78333333333333, 55.3, 50.400000000000006),
	(8, 75, 79, 'w', 'G_II', '3 km', 64.75, 57.050000000000004, 52.150000000000006),
	(8, 80, 84, 'w', 'G_II', '3 km', 68.94999999999999, 59.68333333333333, 54.25),
	(8, 85, 89, 'w', 'G_II', '3 km', 72.80000000000001, 63.233333333333334, 57.400000000000006),
	(8, 90, 200, 'w', 'G_II', '3 km', 77.23333333333333, 67.2, 60.9),
	(8, 18, 19, 'm', 'G_II', '3 km', 40.95, 38.150000000000006, 35.35),
	(8, 20, 24, 'm', 'G_II', '3 km', 39.9, 37.1, 34.3),
	(8, 25, 29, 'm', 'G_II', '3 km', 40.95, 38.150000000000006, 35.35),
	(8, 30, 34, 'm', 'G_II', '3 km', 43.75000000000001, 39.9, 35.7),
	(8, 35, 39, 'm', 'G_II', '3 km', 45.49999999999999, 40.95, 37.45),
	(8, 40, 44, 'm', 'G_II', '3 km', 46.199999999999996, 42.35, 37.8),
	(8, 45, 49, 'm', 'G_II', '3 km', 47.95, 43.75000000000001, 38.49999999999999),
	(8, 50, 54, 'm', 'G_II', '3 km', 49.7, 44.8, 40.25),
	(8, 55, 59, 'm', 'G_II', '3 km', 51.1, 45.49999999999999, 41.3),
	(8, 60, 64, 'm', 'G_II', '3 km', 53.03333333333334, 47.25, 42.35),
	(8, 65, 69, 'm', 'G_II', '3 km', 54.71666666666667, 48.65, 43.400000000000006),
	(8, 70, 74, 'm', 'G_II', '3 km', 57.050000000000004, 50.400000000000006, 45.49999999999999),
	(8, 75, 79, 'm', 'G_II', '3 km', 60.31666666666666, 53.03333333333334, 50.400000000000006),
	(8, 80, 84, 'm', 'G_II', '3 km', 64.05, 55.833333333333336, 50.400000000000006),
	(8, 85, 89, 'm', 'G_II', '3 km', 67.2, 58.96666666666666, 52.849999999999994),
	(8, 90, 200, 'm', 'G_II', '3 km', 71.93333333333334, 62.53333333333333, 56.0),
	(10, 0, 7, 'w', 'G_II', '', 3.9, 5.85, 7.8),
	(10, 8, 9, 'w', 'G_II', '', 5.85, 7.8, 9.75),
	(10, 10, 11, 'w', 'G_II', '', 7.15, 9.75, 11.7),
	(10, 0, 7, 'm', 'G_II', '', 7.8, 9.75, 11.05),
	(10, 8, 9, 'm', 'G_II', '', 11.05, 13.0, 14.95),
	(10, 10, 11, 'm', 'G_II', '', 13.65, 16.25, 18.2),
	(11, 12, 13, 'w', 'G_II', '', 9.75, 11.7, 14.3),
	(11, 14, 15, 'w', 'G_II', '', 13.0, 15.6, 17.55),
	(11, 16, 17, 'w', 'G_II', '', 15.6, 17.55, 20.15),
	(11, 12, 13, 'm', 'G_II', '', 16.9, 19.5, 21.45),
	(11, 14, 15, 'm', 'G_II', '', 19.5, 22.1, 24.05),
	(11, 16, 17, 'm', 'G_II', '', 22.1, 24.7, 27.3),
	(13, 12, 13, 'w', 'G_II', '2 kg', 3.09, 3.41, 3.74),
	(13, 14, 15, 'w', 'G_II', '2 kg', 3.58, 3.9, 4.23),
	(13, 16, 17, 'w', 'G_II', '2 kg', 3.74, 4.06, 4.39),
	(13, 18, 19, 'w', 'G_II', '3 kg', 4.23, 4.55, 4.88),
	(13, 20, 24, 'w', 'G_II', '3 kg', 4.23, 4.55, 4.88),
	(13, 25, 29, 'w', 'G_II', '3 kg', 4.23, 4.55, 4.88),
	(13, 30, 34, 'w', 'G_II', '3 kg', 4.06, 4.39, 4.71),
	(13, 35, 39, 'w', 'G_II', '3 kg', 3.9, 4.23, 4.55),
	(13, 40, 44, 'w', 'G_II', '3 kg', 3.58, 3.9, 4.23),
	(13, 45, 49, 'w', 'G_II', '3 kg', 3.41, 3.74, 4.06),
	(13, 50, 54, 'w', 'G_II', '2 kg', 3.41, 3.9, 4.55),
	(13, 55, 59, 'w', 'G_II', '2 kg', 3.25, 3.74, 4.23),
	(13, 60, 64, 'w', 'G_II', '2 kg', 3.09, 3.58, 4.06),
	(13, 65, 69, 'w', 'G_II', '2 kg', 2.93, 3.41, 4.06),
	(13, 70, 74, 'w', 'G_II', '2 kg', 2.76, 3.25, 3.9),
	(13, 75, 79, 'w', 'G_II', '2 kg', 2.76, 3.41, 4.06),
	(13, 80, 84, 'w', 'G_II', '2 kg', 2.6, 3.25, 3.74),
	(13, 85, 89, 'w', 'G_II', '2 kg', 2.44, 2.93, 3.58),
	(13, 90, 200, 'w', 'G_II', '2 kg', 2.11, 2.76, 3.25),
	(13, 12, 13, 'm', 'G_II', '2 kg', 4.06, 4.39, 4.71),
	(13, 14, 15, 'm', 'G_II', '2 kg', 4.55, 4.88, 5.2),
	(13, 16, 17, 'm', 'G_II', '3 kg', 4.88, 5.2, 5.53),
	(13, 18, 19, 'm', 'G_II', '4 kg', 5.04, 5.36, 5.69),
	(13, 20, 24, 'm', 'G_II', '4 kg', 5.04, 5.53, 5.85),
	(13, 25, 29, 'm', 'G_II', '4 kg', 4.88, 5.36, 5.69),
	(13, 30, 34, 'm', 'G_II', '4 kg', 4.55, 5.04, 5.36),
	(13, 35, 39, 'm', 'G_II', '4 kg', 4.39, 4.71, 5.2),
	(13, 40, 44, 'm', 'G_II', '4 kg', 4.06, 4.55, 5.04),
	(13, 45, 49, 'm', 'G_II', '4 kg', 3.9, 4.39, 4.88),
	(13, 50, 54, 'm', 'G_II', '3 kg', 4.06, 4.55, 5.2),
	(13, 55, 59, 'm', 'G_II', '3 kg', 3.97, 4.49, 5.05),
	(13, 60, 64, 'm', 'G_II', '3 kg', 3.9, 4.45, 4.91),
	(13, 65, 69, 'm', 'G_II', '3 kg', 3.74, 4.39, 4.88),
	(13, 70, 74, 'm', 'G_II', '3 kg', 3.6, 4.28, 4.68),
	(13, 75, 79, 'm', 'G_II', '3 kg', 3.58, 4.23, 4.65),
	(13, 80, 84, 'm', 'G_II', '2 kg', 3.58, 4.06, 4.71),
	(13, 85, 89, 'm', 'G_II', '2 kg', 3.25, 3.9, 4.39),
	(13, 90, 200, 'm', 'G_II', '2 kg', 2.93, 3.41, 4.06),
	(15, 0, 7, 'w', 'G_II', '', 0.63, 0.75, 0.84),
	(15, 8, 9, 'w', 'G_II', '', 0.69, 0.78, 0.9),
	(15, 10, 11, 'w', 'G_II', '', 0.78, 0.87, 0.99),
	(15, 12, 13, 'w', 'G_II', '', 0.84, 0.96, 1.08),
	(15, 14, 15, 'w', 'G_II', '', 0.93, 1.02, 1.14),
	(15, 16, 17, 'w', 'G_II', '', 0.99, 1.08, 1.2),
	(15, 18, 19, 'w', 'G_II', '', 0.99, 1.11, 1.23),
	(15, 20, 24, 'w', 'G_II', '', 0.96, 1.08, 1.2),
	(15, 25, 29, 'w', 'G_II', '', 0.9, 1.02, 1.17),
	(15, 30, 34, 'w', 'G_II', '', 0.81, 0.96, 1.11),
	(15, 35, 39, 'w', 'G_II', '', 0.75, 0.9, 1.08),
	(15, 40, 44, 'w', 'G_II', '', 0.69, 0.84, 0.99),
	(15, 45, 49, 'w', 'G_II', '', 0.66, 0.81, 0.96),
	(15, 50, 54, 'w', 'G_II', '', 0.6, 0.78, 0.93),
	(15, 55, 59, 'w', 'G_II', '', 0.57, 0.72, 0.87),
	(15, 60, 64, 'w', 'G_II', '', 0.57, 0.72, 0.87),
	(15, 65, 69, 'w', 'G_II', '', 0.54, 0.69, 0.84),
	(15, 70, 74, 'w', 'G_II', '', 0.54, 0.69, 0.81),
	(15, 75, 79, 'w', 'G_II', '', 0.54, 0.69, 0.81),
	(15, 80, 84, 'w', 'G_II', '', 0.54, 0.66, 0.78),
	(15, 85, 89, 'w', 'G_II', '', 0.51, 0.63, 0.75),
	(15, 90, 200, 'w', 'G_II', '', 0.48, 0.6, 0.72),
	(15, 0, 7, 'm', 'G_II', '', 0.69, 0.81, 0.9),
	(15, 8, 9, 'm', 'G_II', '', 0.78, 0.9, 0.99),
	(15, 10, 11, 'm', 'G_II', '', 0.9, 1.02, 1.11),
	(15, 12, 13, 'm', 'G_II', '', 1.02, 1.14, 1.23),
	(15, 14, 15, 'm', 'G_II', '', 1.14, 1.23, 1.35),
	(15, 16, 17, 'm', 'G_II', '', 1.23, 1.32, 1.44),
	(15, 18, 19, 'm', 'G_II', '', 1.26, 1.38, 1.5),
	(15, 20, 24, 'm', 'G_II', '', 1.26, 1.38, 1.5),
	(15, 25, 29, 'm', 'G_II', '', 1.23, 1.35, 1.47),
	(15, 30, 34, 'm', 'G_II', '', 1.11, 1.26, 1.41),
	(15, 35, 39, 'm', 'G_II', '', 0.99, 1.17, 1.35),
	(15, 40, 44, 'm', 'G_II', '', 0.93, 1.11, 1.29),
	(15, 45, 49, 'm', 'G_II', '', 0.87, 1.05, 1.23),
	(15, 50, 54, 'm', 'G_II', '', 0.84, 1.02, 1.2),
	(15, 55, 59, 'm', 'G_II', '', 0.81, 0.99, 1.17),
	(15, 60, 64, 'm', 'G_II', '', 0.78, 0.96, 1.14),
	(15, 65, 69, 'm', 'G_II', '', 0.78, 0.96, 1.14),
	(15, 70, 74, 'm', 'G_II', '', 0.75, 0.93, 1.11),
	(15, 75, 79, 'm', 'G_II', '', 0.72, 0.9, 1.08),
	(15, 80, 84, 'm', 'G_II', '', 0.69, 0.87, 1.05),
	(15, 85, 89, 'm', 'G_II', '', 0.6, 0.78, 0.96),
	(15, 90, 200, 'm', 'G_II', '', 0.54, 0.72, 0.9),
	(17, 0, 7, 'w', 'G_II', '30 m', 17.6, 15.6, 13.9),
	(17, 8, 9, 'w', 'G_II', '30 m', 16.3, 14.5, 12.5),
	(17, 10, 11, 'w', 'G_II', '50 m', 24.2, 22.2, 20.0),
	(17, 12, 13, 'w', 'G_II', '50 m', 23.3, 21.1, 18.7),
	(17, 14, 15, 'w', 'G_II', '100 m', 40.9, 37.4, 34.1),
	(17, 16, 17, 'w', 'G_II', '100 m', 38.7, 35.9, 33.0),
	(17, 18, 19, 'w', 'G_II', '100 m', 40.0, 36.3, 33.7),
	(17, 20, 24, 'w', 'G_II', '100 m', 40.7, 37.0, 34.3),
	(17, 25, 29, 'w', 'G_II', '100 m', 41.6, 37.8, 35.2),
	(17, 30, 34, 'w', 'G_II', '100 m', 43.1, 39.2, 36.1),
	(17, 35, 39, 'w', 'G_II', '100 m', 44.9, 40.9, 37.4),
	(17, 40, 44, 'w', 'G_II', '50 m', 24.2, 21.8, 19.4),
	(17, 45, 49, 'w', 'G_II', '50 m', 25.3, 22.7, 20.0),
	(17, 50, 54, 'w', 'G_II', '50 m', 26.2, 23.5, 20.9),
	(17, 55, 59, 'w', 'G_II', '50 m', 27.3, 24.6, 21.8),
	(17, 60, 64, 'w', 'G_II', '50 m', 27.7, 25.1, 22.4),
	(17, 65, 69, 'w', 'G_II', '50 m', 28.2, 25.5, 22.9),
	(17, 70, 74, 'w', 'G_II', '50 m', 28.6, 26.0, 23.3),
	(17, 75, 79, 'w', 'G_II', '50 m', 29.7, 27.1, 24.4),
	(17, 80, 84, 'w', 'G_II', '50 m', 31.5, 28.8, 26.4),
	(17, 85, 89, 'w', 'G_II', '50 m', 34.1, 31.5, 29.0),
	(17, 90, 200, 'w', 'G_II', '50 m', 37.6, 35.0, 32.6),
	(17, 0, 7, 'm', 'G_II', '30 m', 16.9, 15.0, 13.2),
	(17, 8, 9, 'm', 'G_II', '30 m', 15.8, 14.1, 12.5),
	(17, 10, 11, 'm', 'G_II', '50 m', 22.7, 20.5, 18.5),
	(17, 12, 13, 'm', 'G_II', '50 m', 21.3, 19.6, 17.8),
	(17, 14, 15, 'm', 'G_II', '100 m', 37.4, 33.9, 31.0),
	(17, 16, 17, 'm', 'G_II', '100 m', 35.9, 32.6, 29.7),
	(17, 18, 19, 'm', 'G_II', '100 m', 35.2, 32.1, 29.0),
	(17, 20, 24, 'm', 'G_II', '100 m', 34.8, 31.7, 28.6),
	(17, 25, 29, 'm', 'G_II', '100 m', 35.9, 32.6, 29.3),
	(17, 30, 34, 'm', 'G_II', '100 m', 37.0, 33.2, 29.9),
	(17, 35, 39, 'm', 'G_II', '100 m', 38.7, 35.0, 31.2),
	(17, 40, 44, 'm', 'G_II', '50 m', 21.1, 19.1, 16.9),
	(17, 45, 49, 'm', 'G_II', '50 m', 22.0, 19.6, 17.4),
	(17, 50, 54, 'm', 'G_II', '50 m', 22.7, 20.0, 18.0),
	(17, 55, 59, 'm', 'G_II', '50 m', 23.1, 20.7, 18.7),
	(17, 60, 64, 'm', 'G_II', '50 m', 23.8, 21.3, 19.4),
	(17, 65, 69, 'm', 'G_II', '50 m', 24.6, 22.4, 20.0),
	(17, 70, 74, 'm', 'G_II', '50 m', 25.7, 23.5, 21.1),
	(17, 75, 79, 'm', 'G_II', '50 m', 26.8, 24.6, 22.2),
	(17, 80, 84, 'm', 'G_II', '50 m', 28.6, 26.4, 24.0),
	(17, 85, 89, 'm', 'G_II', '50 m', 31.0, 28.8, 26.4),
	(17, 90, 200, 'm', 'G_II', '50 m', 34.1, 31.9, 29.5),
	(18, 0, 7, 'w', 'G_II', '', 74.4, 61.6, 48.8),
	(18, 8, 9, 'w', 'G_II', '', 67.2, 54.4, 44.8),
	(18, 10, 11, 'w', 'G_II', '', 62.4, 50.4, 40.8),
	(18, 12, 13, 'w', 'G_II', '', 56.0, 46.4, 37.6),
	(18, 14, 15, 'w', 'G_II', '', 52.8, 44.0, 34.4),
	(18, 16, 17, 'w', 'G_II', '', 48.8, 40.8, 32.0),
	(18, 18, 19, 'w', 'G_II', '', 47.2, 38.4, 29.6),
	(18, 20, 24, 'w', 'G_II', '', 46.4, 38.4, 29.6),
	(18, 25, 29, 'w', 'G_II', '', 48.0, 40.0, 31.2),
	(18, 30, 34, 'w', 'G_II', '', 52.0, 42.4, 33.6),
	(18, 35, 39, 'w', 'G_II', '', 57.6, 46.4, 35.2),
	(18, 40, 44, 'w', 'G_II', '', 64.0, 50.4, 37.6),
	(18, 45, 49, 'w', 'G_II', '', 70.4, 56.0, 40.0),
	(18, 50, 54, 'w', 'G_II', '', 76.8, 62.4, 44.8),
	(18, 55, 59, 'w', 'G_II', '', 82.4, 68.0, 48.8),
	(18, 60, 64, 'w', 'G_II', '', 87.2, 71.2, 52.0),
	(18, 65, 69, 'w', 'G_II', '', 90.4, 74.4, 55.2),
	(18, 70, 74, 'w', 'G_II', '', 94.4, 76.8, 57.6),
	(18, 75, 79, 'w', 'G_II', '', 97.6, 80.0, 60.8),
	(18, 80, 84, 'w', 'G_II', '', 101.6, 83.2, 64.0),
	(18, 85, 89, 'w', 'G_II', '', 104.8, 85.6, 66.4),
	(18, 90, 200, 'w', 'G_II', '', 106.4, 87.2, 68.0),
	(18, 0, 7, 'm', 'G_II', '', 73.6, 60.8, 48.0),
	(18, 8, 9, 'm', 'G_II', '', 65.6, 52.8, 41.6),
	(18, 10, 11, 'm', 'G_II', '', 57.6, 46.4, 36.0),
	(18, 12, 13, 'm', 'G_II', '', 52.8, 43.2, 33.6),
	(18, 14, 15, 'm', 'G_II', '', 49.6, 40.8, 32.0),
	(18, 16, 17, 'm', 'G_II', '', 47.2, 39.2, 30.4),
	(18, 18, 19, 'm', 'G_II', '', 44.8, 36.8, 28.0),
	(18, 20, 24, 'm', 'G_II', '', 43.2, 35.2, 24.8),
	(18, 25, 29, 'm', 'G_II', '', 46.4, 36.8, 26.4),
	(18, 30, 34, 'm', 'G_II', '', 50.4, 38.4, 27.2),
	(18, 35, 39, 'm', 'G_II', '', 56.0, 42.4, 29.6),
	(18, 40, 44, 'm', 'G_II', '', 61.6, 47.2, 30.4),
	(18, 45, 49, 'm', 'G_II', '', 67.2, 52.0, 32.8),
	(18, 50, 54, 'm', 'G_II', '', 72.0, 56.0, 36.8),
	(18, 55, 59, 'm', 'G_II', '', 78.4, 59.2, 40.0),
	(18, 60, 64, 'm', 'G_II', '', 81.6, 62.4, 43.2),
	(18, 65, 69, 'm', 'G_II', '', 84.0, 64.8, 45.6),
	(18, 70, 74, 'm', 'G_II', '', 88.0, 68.8, 49.6),
	(18, 75, 79, 'm', 'G_II', '', 92.0, 72.8, 53.6),
	(18, 80, 84, 'm', 'G_II', '', 94.4, 76.8, 57.6),
	(18, 85, 89, 'm', 'G_II', '', 95.2, 78.4, 60.8),
	(18, 90, 200, 'm', 'G_II', '', 96.0, 80.0, 64.0),
	(19, 8, 9, 'w', 'G_II', '', 61.5, 54.0, 46.5),
	(19, 10, 11, 'w', 'G_II', '', 55.5, 48.0, 40.5),
	(19, 12, 13, 'w', 'G_II', '', 46.5, 40.5, 35.3),
	(19, 14, 15, 'w', 'G_II', '', 40.5, 36.8, 32.3),
	(19, 16, 17, 'w', 'G_II', '', 37.5, 33.8, 30.0),
	(19, 18, 19, 'w', 'G_II', '', 36.0, 33.0, 29.3),
	(19, 20, 24, 'w', 'G_II', '', 36.8, 33.0, 29.3),
	(19, 25, 29, 'w', 'G_II', '', 37.5, 33.8, 30.0),
	(19, 30, 34, 'w', 'G_II', '', 39.0, 35.3, 32.3),
	(19, 35, 39, 'w', 'G_II', '', 41.3, 36.8, 33.0),
	(19, 40, 44, 'w', 'G_II', '', 43.5, 38.3, 33.8),
	(19, 45, 49, 'w', 'G_II', '', 45.8, 40.5, 34.5),
	(19, 50, 54, 'w', 'G_II', '', 48.0, 42.0, 35.3),
	(19, 55, 59, 'w', 'G_II', '', 50.3, 43.5, 36.0),
	(19, 60, 64, 'w', 'G_II', '', 52.5, 45.0, 37.5),
	(19, 65, 69, 'w', 'G_II', '', 54.0, 46.5, 38.3),
	(19, 70, 74, 'w', 'G_II', '', 57.0, 48.0, 39.8),
	(19, 75, 79, 'w', 'G_II', '', 58.5, 49.5, 41.3),
	(19, 80, 84, 'w', 'G_II', '', 60.8, 51.8, 42.8),
	(19, 85, 89, 'w', 'G_II', '', 63.0, 54.0, 45.0),
	(19, 90, 200, 'w', 'G_II', '', 66.8, 57.0, 47.3),
	(19, 8, 9, 'm', 'G_II', '', 57.0, 49.5, 42.0),
	(19, 10, 11, 'm', 'G_II', '', 52.5, 45.8, 39.0),
	(19, 12, 13, 'm', 'G_II', '', 44.3, 39.0, 33.8),
	(19, 14, 15, 'm', 'G_II', '', 36.0, 32.3, 28.5),
	(19, 16, 17, 'm', 'G_II', '', 33.0, 29.3, 25.5),
	(19, 18, 19, 'm', 'G_II', '', 30.8, 27.0, 23.3),
	(19, 20, 24, 'm', 'G_II', '', 30.0, 26.3, 22.5),
	(19, 25, 29, 'm', 'G_II', '', 31.5, 27.0, 22.5),
	(19, 30, 34, 'm', 'G_II', '', 33.8, 27.8, 22.5),
	(19, 35, 39, 'm', 'G_II', '', 36.0, 30.0, 23.3),
	(19, 40, 44, 'm', 'G_II', '', 39.8, 32.3, 24.8),
	(19, 45, 49, 'm', 'G_II', '', 42.8, 34.5, 25.5),
	(19, 50, 54, 'm', 'G_II', '', 45.0, 36.0, 27.0),
	(19, 55, 59, 'm', 'G_II', '', 48.0, 37.5, 27.8),
	(19, 60, 64, 'm', 'G_II', '', 50.3, 39.0, 28.5),
	(19, 65, 69, 'm', 'G_II', '', 52.5, 40.5, 29.3),
	(19, 70, 74, 'm', 'G_II', '', 54.0, 42.8, 30.0),
	(19, 75, 79, 'm', 'G_II', '', 56.3, 44.3, 32.3),
	(19, 80, 84, 'm', 'G_II', '', 58.5, 47.3, 34.5),
	(19, 85, 89, 'm', 'G_II', '', 61.5, 49.5, 36.8),
	(19, 90, 200, 'm', 'G_II', '', 65.3, 53.3, 40.5),
	(21, 10, 11, 'w', 'G_II', '', 0.48, 0.54, 0.6),
	(21, 12, 13, 'w', 'G_II', '', 0.54, 0.6, 0.66),
	(21, 14, 15, 'w', 'G_II', '', 0.57, 0.63, 0.69),
	(21, 16, 17, 'w', 'G_II', '', 0.63, 0.69, 0.75),
	(21, 18, 19, 'w', 'G_II', '', 0.66, 0.72, 0.78),
	(21, 20, 24, 'w', 'G_II', '', 0.66, 0.72, 0.78),
	(21, 25, 29, 'w', 'G_II', '', 0.63, 0.69, 0.75),
	(21, 30, 34, 'w', 'G_II', '', 0.6, 0.66, 0.72),
	(21, 35, 39, 'w', 'G_II', '', 0.57, 0.63, 0.69),
	(21, 40, 44, 'w', 'G_II', '', 0.54, 0.6, 0.66),
	(21, 45, 49, 'w', 'G_II', '', 0.54, 0.6, 0.66),
	(21, 50, 54, 'w', 'G_II', '', 0.51, 0.57, 0.63),
	(21, 55, 59, 'w', 'G_II', '', 0.48, 0.54, 0.6),
	(21, 60, 64, 'w', 'G_II', '', 0.45, 0.51, 0.57),
	(21, 65, 69, 'w', 'G_II', '', 0.45, 0.51, 0.57),
	(21, 70, 74, 'w', 'G_II', '', 0.42, 0.48, 0.54),
	(21, 75, 79, 'w', 'G_II', '', 0.39, 0.45, 0.51),
	(21, 80, 84, 'w', 'G_II', '', 0.39, 0.45, 0.51),
	(21, 85, 89, 'w', 'G_II', '', 0.36, 0.42, 0.48),
	(21, 90, 200, 'w', 'G_II', '', 0.33, 0.36, 0.39),
	(21, 10, 11, 'm', 'G_II', '', 0.51, 0.57, 0.63),
	(21, 12, 13, 'm', 'G_II', '', 0.57, 0.63, 0.69),
	(21, 14, 15, 'm', 'G_II', '', 0.66, 0.72, 0.78),
	(21, 16, 17, 'm', 'G_II', '', 0.72, 0.78, 0.84),
	(21, 18, 19, 'm', 'G_II', '', 0.78, 0.84, 0.9),
	(21, 20, 24, 'm', 'G_II', '', 0.81, 0.87, 0.93),
	(21, 25, 29, 'm', 'G_II', '', 0.78, 0.84, 0.9),
	(21, 30, 34, 'm', 'G_II', '', 0.78, 0.84, 0.9),
	(21, 35, 39, 'm', 'G_II', '', 0.75, 0.81, 0.87),
	(21, 40, 44, 'm', 'G_II', '', 0.72, 0.78, 0.84),
	(21, 45, 49, 'm', 'G_II', '', 0.69, 0.75, 0.81),
	(21, 50, 54, 'm', 'G_II', '', 0.63, 0.69, 0.75),
	(21, 55, 59, 'm', 'G_II', '', 0.6, 0.66, 0.72),
	(21, 60, 64, 'm', 'G_II', '', 0.57, 0.63, 0.69),
	(21, 65, 69, 'm', 'G_II', '', 0.51, 0.6, 0.66),
	(21, 70, 74, 'm', 'G_II', '', 0.48, 0.57, 0.63),
	(21, 75, 79, 'm', 'G_II', '', 0.45, 0.54, 0.6),
	(21, 80, 84, 'm', 'G_II', '', 0.45, 0.51, 0.57),
	(21, 85, 89, 'm', 'G_II', '', 0.42, 0.48, 0.54),
	(21, 90, 200, 'm', 'G_II', '', 0.39, 0.45, 0.51),
	(23, 0, 7, 'w', 'G_II', '', 0.98, 1.16, 1.34),
	(23, 8, 9, 'w', 'G_II', '', 1.18, 1.36, 1.54),
	(23, 10, 11, 'w', 'G_II', '', 1.38, 1.56, 1.74),
	(23, 12, 13, 'w', 'G_II', '', 1.68, 1.86, 2.04),
	(23, 14, 15, 'w', 'G_II', '', 1.92, 2.1, 2.28),
	(23, 16, 17, 'w', 'G_II', '', 2.04, 2.22, 2.4),
	(23, 18, 19, 'w', 'G_II', '', 2.04, 2.22, 2.4),
	(23, 20, 24, 'w', 'G_II', '', 2.04, 2.22, 2.4),
	(23, 25, 29, 'w', 'G_II', '', 1.98, 2.16, 2.34),
	(23, 30, 34, 'w', 'G_II', '', 1.92, 2.1, 2.28),
	(23, 35, 39, 'w', 'G_II', '', 1.86, 2.04, 2.22),
	(23, 40, 44, 'w', 'G_II', '', 1.8, 1.98, 2.16),
	(23, 45, 49, 'w', 'G_II', '', 1.68, 1.92, 2.1),
	(23, 50, 54, 'w', 'G_II', '', 1.56, 1.8, 2.04),
	(23, 55, 59, 'w', 'G_II', '', 1.5, 1.74, 1.98),
	(23, 60, 64, 'w', 'G_II', '', 1.44, 1.68, 1.92),
	(23, 65, 69, 'w', 'G_II', '', 1.38, 1.62, 1.86),
	(23, 70, 74, 'w', 'G_II', '', 1.26, 1.5, 1.74),
	(23, 75, 79, 'w', 'G_II', '', 1.08, 1.32, 1.56),
	(23, 80, 84, 'w', 'G_II', '', 0.96, 1.2, 1.44),
	(23, 85, 89, 'w', 'G_II', '', 0.78, 1.02, 1.26),
	(23, 90, 200, 'w', 'G_II', '', 0.66, 0.9, 1.14),
	(23, 0, 7, 'm', 'G_II', '', 1.16, 1.34, 1.52),
	(23, 8, 9, 'm', 'G_II', '', 1.36, 1.54, 1.72),
	(23, 10, 11, 'm', 'G_II', '', 1.56, 1.74, 1.92),
	(23, 12, 13, 'm', 'G_II', '', 1.92, 2.1, 2.28),
	(23, 14, 15, 'm', 'G_II', '', 2.28, 2.46, 2.64),
	(23, 16, 17, 'm', 'G_II', '', 2.58, 2.76, 2.94),
	(23, 18, 19, 'm', 'G_II', '', 2.7, 2.88, 3.06),
	(23, 20, 24, 'm', 'G_II', '', 2.64, 2.82, 3.0),
	(23, 25, 29, 'm', 'G_II', '', 2.58, 2.76, 2.94),
	(23, 30, 34, 'm', 'G_II', '', 2.52, 2.7, 2.88),
	(23, 35, 39, 'm', 'G_II', '', 2.46, 2.64, 2.82),
	(23, 40, 44, 'm', 'G_II', '', 2.34, 2.58, 2.76),
	(23, 45, 49, 'm', 'G_II', '', 2.22, 2.46, 2.7),
	(23, 50, 54, 'm', 'G_II', '', 2.16, 2.4, 2.64),
	(23, 55, 59, 'm', 'G_II', '', 2.04, 2.28, 2.52),
	(23, 60, 64, 'm', 'G_II', '', 1.92, 2.16, 2.4),
	(23, 65, 69, 'm', 'G_II', '', 1.74, 1.98, 2.22),
	(23, 70, 74, 'm', 'G_II', '', 1.62, 1.86, 2.1),
	(23, 75, 79, 'm', 'G_II', '', 1.44, 1.74, 1.98),
	(23, 80, 84, 'm', 'G_II', '', 1.26, 1.56, 1.86),
	(23, 85, 89, 'm', 'G_II', '', 1.14, 1.44, 1.74),
	(23, 90, 200, 'm', 'G_II', '', 0.96, 1.26, 1.56),
	(32, 18, 19, 'w', 'G_II', '', 20.616666666666667, 18.650000000000002, 16.666666666666664),
	(32, 20, 24, 'w', 'G_II', '', 20.13333333333333, 18.15, 16.166666666666668),
	(32, 25, 29, 'w', 'G_II', '', 20.46666666666667, 18.48333333333333, 16.5),
	(32, 30, 34, 'w', 'G_II', '', 21.283333333333335, 19.3, 17.31666666666667),
	(32, 35, 39, 'w', 'G_II', '', 21.78333333333333, 19.8, 17.816666666666663),
	(32, 40, 44, 'w', 'G_II', '', 22.599999999999998, 20.46666666666667, 18.31666666666667),
	(32, 45, 49, 'w', 'G_II', '', 23.599999999999998, 21.283333333333335, 18.650000000000002),
	(32, 50, 54, 'w', 'G_II', '', 24.583333333333336, 21.95, 18.983333333333334),
	(32, 55, 59, 'w', 'G_II', '', 25.583333333333336, 22.599999999999998, 19.633333333333333),
	(32, 60, 64, 'w', 'G_II', '', 26.233333333333334, 23.266666666666666, 20.3),
	(32, 65, 69, 'w', 'G_II', '', 26.9, 23.93333333333333, 20.95),
	(32, 70, 74, 'w', 'G_II', '', 27.383333333333333, 24.416666666666668, 21.45),
	(32, 75, 79, 'w', 'G_II', '', 28.216666666666665, 25.249999999999996, 22.266666666666666),
	(32, 80, 84, 'w', 'G_II', '', 29.366666666666664, 26.4, 23.433333333333337),
	(32, 85, 89, 'w', 'G_II', '', 30.683333333333334, 27.716666666666665, 24.75),
	(32, 90, 200, 'w', 'G_II', '', 32.16666666666667, 29.200000000000003, 26.233333333333334),
	(32, 18, 19, 'm', 'G_II', '', 17.650000000000002, 15.683333333333334, 13.7),
	(32, 20, 24, 'm', 'G_II', '', 17.166666666666668, 15.183333333333332, 13.2),
	(32, 25, 29, 'm', 'G_II', '', 17.48333333333333, 15.516666666666667, 13.533333333333333),
	(32, 30, 34, 'm', 'G_II', '', 18.31666666666667, 16.333333333333332, 14.350000000000001),
	(32, 35, 39, 'm', 'G_II', '', 19.633333333333333, 17.166666666666668, 14.85),
	(32, 40, 44, 'm', 'G_II', '', 20.78333333333333, 18.31666666666667, 15.683333333333334),
	(32, 45, 49, 'm', 'G_II', '', 21.95, 19.3, 16.333333333333332),
	(32, 50, 54, 'm', 'G_II', '', 23.099999999999998, 20.13333333333333, 17.166666666666668),
	(32, 55, 59, 'm', 'G_II', '', 23.599999999999998, 20.616666666666667, 17.650000000000002),
	(32, 60, 64, 'm', 'G_II', '', 24.249999999999996, 21.283333333333335, 18.31666666666667),
	(32, 65, 69, 'm', 'G_II', '', 24.75, 21.78333333333333, 18.816666666666663),
	(32, 70, 74, 'm', 'G_II', '', 25.083333333333336, 22.116666666666667, 19.13333333333333),
	(32, 75, 79, 'm', 'G_II', '', 25.733333333333334, 22.76666666666667, 19.8),
	(32, 80, 84, 'm', 'G_II', '', 26.233333333333334, 23.266666666666666, 20.3),
	(32, 85, 89, 'm', 'G_II', '', 27.233333333333334, 24.249999999999996, 21.283333333333335),
	(32, 90, 200, 'm', 'G_II', '', 29.533333333333335, 26.566666666666666, 23.599999999999998),
	(33, 0, 7, 'w', 'G_II', '', 4.0, 6.0, 8.500000000000002),
	(33, 8, 9, 'w', 'G_II', '', 5.0, 7.5, 10.0),
	(33, 10, 11, 'w', 'G_II', '', 7.5, 10.0, 15.0),
	(33, 12, 13, 'w', 'G_II', '', 10.0, 15.0, 20.0),
	(33, 14, 15, 'w', 'G_II', '', 15.0, 20.0, 25.0),
	(33, 16, 17, 'w', 'G_II', '', 22.5, 30.0, 37.49999999999999),
	(33, 0, 7, 'm', 'G_II', '', 5.0, 7.5, 10.0),
	(33, 8, 9, 'm', 'G_II', '', 6.0, 8.500000000000002, 11.500000000000002),
	(33, 10, 11, 'm', 'G_II', '', 8.500000000000002, 12.500000000000002, 17.5),
	(33, 12, 13, 'm', 'G_II', '', 12.500000000000002, 17.5, 22.5),
	(33, 14, 15, 'm', 'G_II', '', 17.5, 22.5, 30.0),
	(33, 16, 17, 'm', 'G_II', '', 27.5, 35.0, 45.0),
	(39, 0, 7, 'w', 'G_II', '', 115.0, 128.0, 140.0),
	(39, 8, 9, 'w', 'G_II', '', 126.0, 140.0, 154.0),
	(39, 10, 11, 'w', 'G_II', '', 137.0, 153.0, 168.0),
	(39, 12, 13, 'w', 'G_II', '', 149.0, 165.0, 182.0),
	(39, 14, 15, 'w', 'G_II', '', 160.0, 178.0, 195.0),
	(39, 16, 17, 'w', 'G_II', '', 171.0, 190.0, 209.0),
	(39, 18, 19, 'w', 'G_II', '', 261.0, 290.0, 319.0),
	(39, 20, 24, 'w', 'G_II', '', 261.0, 290.0, 319.0),
	(39, 25, 29, 'w', 'G_II', '', 261.0, 290.0, 319.0),
	(39, 30, 34, 'w', 'G_II', '', 250.0, 278.0, 305.0),
	(39, 35, 39, 'w', 'G_II', '', 250.0, 278.0, 305.0),
	(39, 40, 44, 'w', 'G_II', '', 239.0, 265.0, 292.0),
	(39, 45, 49, 'w', 'G_II', '', 227.0, 253.0, 278.0),
	(39, 50, 54, 'w', 'G_II', '', 216.0, 240.0, 264.0),
	(39, 55, 59, 'w', 'G_II', '', 205.0, 228.0, 250.0),
	(39, 60, 64, 'w', 'G_II', '', 194.0, 215.0, 237.0),
	(39, 65, 69, 'w', 'G_II', '', 182.0, 203.0, 223.0),
	(39, 70, 74, 'w', 'G_II', '', 171.0, 190.0, 209.0),
	(39, 75, 79, 'w', 'G_II', '', 160.0, 178.0, 195.0),
	(39, 80, 84, 'w', 'G_II', '', 149.0, 165.0, 182.0),
	(39, 85, 89, 'w', 'G_II', '', 137.0, 153.0, 168.0),
	(39, 90, 200, 'w', 'G_II', '', 126.0, 140.0, 154.0),
	(39, 0, 7, 'm', 'G_II', '', 173.0, 193.0, 212.0),
	(39, 8, 9, 'm', 'G_II', '', 185.0, 205.0, 226.0),
	(39, 10, 11, 'm', 'G_II', '', 196.0, 218.0, 239.0),
	(39, 12, 13, 'm', 'G_II', '', 207.0, 230.0, 253.0),
	(39, 14, 15, 'm', 'G_II', '', 218.0, 243.0, 267.0),
	(39, 16, 17, 'm', 'G_II', '', 230.0, 255.0, 281.0),
	(39, 18, 19, 'm', 'G_II', '', 320.0, 355.0, 391.0),
	(39, 20, 24, 'm', 'G_II', '', 320.0, 355.0, 391.0),
	(39, 25, 29, 'm', 'G_II', '', 320.0, 355.0, 391.0),
	(39, 30, 34, 'm', 'G_II', '', 308.0, 343.0, 377.0),
	(39, 35, 39, 'm', 'G_II', '', 308.0, 343.0, 377.0),
	(39, 40, 44, 'm', 'G_II', '', 297.0, 330.0, 363.0),
	(39, 45, 49, 'm', 'G_II', '', 286.0, 318.0, 349.0),
	(39, 50, 54, 'm', 'G_II', '', 275.0, 305.0, 336.0),
	(39, 55, 59, 'm', 'G_II', '', 263.0, 293.0, 322.0),
	(39, 60, 64, 'm', 'G_II', '', 252.0, 280.0, 308.0),
	(39, 65, 69, 'm', 'G_II', '', 241.0, 268.0, 294.0),
	(39, 70, 74, 'm', 'G_II', '', 230.0, 255.0, 281.0),
	(39, 75, 79, 'm', 'G_II', '', 218.0, 243.0, 267.0),
	(39, 80, 84, 'm', 'G_II', '', 207.0, 230.0, 253.0),
	(39, 85, 89, 'm', 'G_II', '', 196.0, 218.0, 239.0),
	(39, 90, 200, 'm', 'G_II', '', 185.0, 205.0, 226.0),
	(40, 0, 7, 'w', 'G_II', '', 275.0, 305.0, 336.0),
	(40, 8, 9, 'w', 'G_II', '', 288.0, 320.0, 352.0),
	(40, 10, 11, 'w', 'G_II', '', 302.0, 335.0, 369.0),
	(40, 12, 13, 'w', 'G_II', '', 315.0, 350.0, 385.0),
	(40, 14, 15, 'w', 'G_II', '', 329.0, 365.0, 402.0),
	(40, 16, 17, 'w', 'G_II', '', 342.0, 380.0, 418.0),
	(40, 18, 19, 'w', 'G_II', '', 432.0, 480.0, 528.0),
	(40, 20, 24, 'w', 'G_II', '', 432.0, 480.0, 528.0),
	(40, 25, 29, 'w', 'G_II', '', 432.0, 480.0, 528.0),
	(40, 30, 34, 'w', 'G_II', '', 419.0, 465.0, 512.0),
	(40, 35, 39, 'w', 'G_II', '', 419.0, 465.0, 512.0),
	(40, 40, 44, 'w', 'G_II', '', 405.0, 450.0, 495.0),
	(40, 45, 49, 'w', 'G_II', '', 392.0, 435.0, 479.0),
	(40, 50, 54, 'w', 'G_II', '', 378.0, 420.0, 462.0),
	(40, 55, 59, 'w', 'G_II', '', 365.0, 405.0, 446.0),
	(40, 60, 64, 'w', 'G_II', '', 351.0, 390.0, 429.0),
	(40, 65, 69, 'w', 'G_II', '', 338.0, 375.0, 413.0),
	(40, 70, 74, 'w', 'G_II', '', 324.0, 360.0, 396.0),
	(40, 75, 79, 'w', 'G_II', '', 311.0, 345.0, 380.0),
	(40, 80, 84, 'w', 'G_II', '', 297.0, 330.0, 363.0),
	(40, 85, 89, 'w', 'G_II', '', 284.0, 315.0, 347.0),
	(40, 90, 200, 'w', 'G_II', '', 270.0, 300.0, 330.0),
	(40, 0, 7, 'm', 'G_II', '', 342.0, 380.0, 418.0),
	(40, 8, 9, 'm', 'G_II', '', 356.0, 395.0, 435.0),
	(40, 10, 11, 'm', 'G_II', '', 369.0, 410.0, 451.0),
	(40, 12, 13, 'm', 'G_II', '', 383.0, 425.0, 468.0),
	(40, 14, 15, 'm', 'G_II', '', 396.0, 440.0, 484.0),
	(40, 16, 17, 'm', 'G_II', '', 410.0, 455.0, 501.0),
	(40, 18, 19, 'm', 'G_II', '', 500.0, 555.0, 611.0),
	(40, 20, 24, 'm', 'G_II', '', 500.0, 555.0, 611.0),
	(40, 25, 29, 'm', 'G_II', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'G_II', '', 486.0, 540.0, 594.0),
	(40, 35, 39, 'm', 'G_II', '', 486.0, 540.0, 594.0),
	(40, 40, 44, 'm', 'G_II', '', 473.0, 525.0, 578.0),
	(40, 45, 49, 'm', 'G_II', '', 459.0, 510.0, 561.0),
	(40, 50, 54, 'm', 'G_II', '', 446.0, 495.0, 545.0),
	(40, 55, 59, 'm', 'G_II', '', 432.0, 480.0, 528.0),
	(40, 60, 64, 'm', 'G_II', '', 419.0, 465.0, 512.0),
	(40, 65, 69, 'm', 'G_II', '', 405.0, 450.0, 495.0),
	(40, 70, 74, 'm', 'G_II', '', 392.0, 435.0, 479.0),
	(40, 75, 79, 'm', 'G_II', '', 378.0, 420.0, 462.0),
	(40, 80, 84, 'm', 'G_II', '', 365.0, 405.0, 446.0),
	(40, 85, 89, 'm', 'G_II', '', 351.0, 390.0, 429.0),
	(40, 90, 200, 'm', 'G_II', '', 338.0, 375.0, 413.0),
	(41, 0, 7, 'w', 'G_II', '', 207.0, 230.0, 253.0),
	(41, 8, 9, 'w', 'G_II', '', 221.0, 245.0, 270.0),
	(41, 10, 11, 'w', 'G_II', '', 234.0, 260.0, 286.0),
	(41, 12, 13, 'w', 'G_II', '', 248.0, 275.0, 303.0),
	(41, 14, 15, 'w', 'G_II', '', 261.0, 290.0, 319.0),
	(41, 16, 17, 'w', 'G_II', '', 275.0, 305.0, 336.0),
	(41, 18, 19, 'w', 'G_II', '', 365.0, 405.0, 446.0),
	(41, 20, 24, 'w', 'G_II', '', 365.0, 405.0, 446.0),
	(41, 25, 29, 'w', 'G_II', '', 365.0, 405.0, 446.0),
	(41, 30, 34, 'w', 'G_II', '', 351.0, 390.0, 429.0),
	(41, 35, 39, 'w', 'G_II', '', 351.0, 390.0, 429.0),
	(41, 40, 44, 'w', 'G_II', '', 338.0, 375.0, 413.0),
	(41, 45, 49, 'w', 'G_II', '', 324.0, 360.0, 396.0),
	(41, 50, 54, 'w', 'G_II', '', 311.0, 345.0, 380.0),
	(41, 55, 59, 'w', 'G_II', '', 297.0, 330.0, 363.0),
	(41, 60, 64, 'w', 'G_II', '', 284.0, 315.0, 347.0),
	(41, 65, 69, 'w', 'G_II', '', 270.0, 300.0, 330.0),
	(41, 70, 74, 'w', 'G_II', '', 257.0, 285.0, 314.0),
	(41, 75, 79, 'w', 'G_II', '', 243.0, 270.0, 297.0),
	(41, 80, 84, 'w', 'G_II', '', 230.0, 255.0, 281.0),
	(41, 85, 89, 'w', 'G_II', '', 216.0, 240.0, 264.0),
	(41, 90, 200, 'w', 'G_II', '', 203.0, 225.0, 248.0),
	(41, 0, 7, 'm', 'G_II', '', 270.0, 300.0, 330.0),
	(41, 8, 9, 'm', 'G_II', '', 284.0, 315.0, 347.0),
	(41, 10, 11, 'm', 'G_II', '', 297.0, 330.0, 363.0),
	(41, 12, 13, 'm', 'G_II', '', 311.0, 345.0, 380.0),
	(41, 14, 15, 'm', 'G_II', '', 324.0, 360.0, 396.0),
	(41, 16, 17, 'm', 'G_II', '', 338.0, 375.0, 413.0),
	(41, 18, 19, 'm', 'G_II', '', 428.0, 475.0, 523.0),
	(41, 20, 24, 'm', 'G_II', '', 428.0, 475.0, 523.0),
	(41, 25, 29, 'm', 'G_II', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'G_II', '', 414.0, 460.0, 506.0),
	(41, 35, 39, 'm', 'G_II', '', 414.0, 460.0, 506.0),
	(41, 40, 44, 'm', 'G_II', '', 401.0, 445.0, 490.0),
	(41, 45, 49, 'm', 'G_II', '', 387.0, 430.0, 473.0),
	(41, 50, 54, 'm', 'G_II', '', 374.0, 415.0, 457.0),
	(41, 55, 59, 'm', 'G_II', '', 360.0, 400.0, 440.0),
	(41, 60, 64, 'm', 'G_II', '', 347.0, 385.0, 424.0),
	(41, 65, 69, 'm', 'G_II', '', 333.0, 370.0, 407.0),
	(41, 70, 74, 'm', 'G_II', '', 320.0, 355.0, 391.0),
	(41, 75, 79, 'm', 'G_II', '', 306.0, 340.0, 374.0),
	(41, 80, 84, 'm', 'G_II', '', 293.0, 325.0, 358.0),
	(41, 85, 89, 'm', 'G_II', '', 279.0, 310.0, 341.0),
	(41, 90, 200, 'm', 'G_II', '', 266.0, 295.0, 325.0),
	(42, 0, 7, 'w', 'G_II', '', 212.0, 235.0, 259.0),
	(42, 8, 9, 'w', 'G_II', '', 225.0, 250.0, 275.0),
	(42, 10, 11, 'w', 'G_II', '', 239.0, 265.0, 292.0),
	(42, 12, 13, 'w', 'G_II', '', 252.0, 280.0, 308.0),
	(42, 14, 15, 'w', 'G_II', '', 266.0, 295.0, 325.0),
	(42, 16, 17, 'w', 'G_II', '', 279.0, 310.0, 341.0),
	(42, 18, 19, 'w', 'G_II', '', 369.0, 410.0, 451.0),
	(42, 20, 24, 'w', 'G_II', '', 369.0, 410.0, 451.0),
	(42, 25, 29, 'w', 'G_II', '', 369.0, 410.0, 451.0),
	(42, 30, 34, 'w', 'G_II', '', 356.0, 395.0, 435.0),
	(42, 35, 39, 'w', 'G_II', '', 356.0, 395.0, 435.0),
	(42, 40, 44, 'w', 'G_II', '', 342.0, 380.0, 418.0),
	(42, 45, 49, 'w', 'G_II', '', 329.0, 365.0, 402.0),
	(42, 50, 54, 'w', 'G_II', '', 315.0, 350.0, 385.0),
	(42, 55, 59, 'w', 'G_II', '', 302.0, 335.0, 369.0),
	(42, 60, 64, 'w', 'G_II', '', 288.0, 320.0, 352.0),
	(42, 65, 69, 'w', 'G_II', '', 275.0, 305.0, 336.0),
	(42, 70, 74, 'w', 'G_II', '', 261.0, 290.0, 319.0),
	(42, 75, 79, 'w', 'G_II', '', 248.0, 275.0, 303.0),
	(42, 80, 84, 'w', 'G_II', '', 234.0, 260.0, 286.0),
	(42, 85, 89, 'w', 'G_II', '', 221.0, 245.0, 270.0),
	(42, 90, 200, 'w', 'G_II', '', 207.0, 230.0, 253.0),
	(42, 0, 7, 'm', 'G_II', '', 275.0, 305.0, 336.0),
	(42, 8, 9, 'm', 'G_II', '', 288.0, 320.0, 352.0),
	(42, 10, 11, 'm', 'G_II', '', 302.0, 335.0, 369.0),
	(42, 12, 13, 'm', 'G_II', '', 315.0, 350.0, 385.0),
	(42, 14, 15, 'm', 'G_II', '', 329.0, 365.0, 402.0),
	(42, 16, 17, 'm', 'G_II', '', 342.0, 380.0, 418.0),
	(42, 18, 19, 'm', 'G_II', '', 432.0, 480.0, 528.0),
	(42, 20, 24, 'm', 'G_II', '', 432.0, 480.0, 528.0),
	(42, 25, 29, 'm', 'G_II', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'G_II', '', 419.0, 465.0, 512.0),
	(42, 35, 39, 'm', 'G_II', '', 419.0, 465.0, 512.0),
	(42, 40, 44, 'm', 'G_II', '', 405.0, 450.0, 495.0),
	(42, 45, 49, 'm', 'G_II', '', 392.0, 435.0, 479.0),
	(42, 50, 54, 'm', 'G_II', '', 378.0, 420.0, 462.0),
	(42, 55, 59, 'm', 'G_II', '', 365.0, 405.0, 446.0),
	(42, 60, 64, 'm', 'G_II', '', 351.0, 390.0, 429.0),
	(42, 65, 69, 'm', 'G_II', '', 338.0, 375.0, 413.0),
	(42, 70, 74, 'm', 'G_II', '', 324.0, 360.0, 396.0),
	(42, 75, 79, 'm', 'G_II', '', 311.0, 345.0, 380.0),
	(42, 80, 84, 'm', 'G_II', '', 297.0, 330.0, 363.0),
	(42, 85, 89, 'm', 'G_II', '', 284.0, 315.0, 347.0),
	(42, 90, 200, 'm', 'G_II', '', 270.0, 300.0, 330.0),
	(44, 12, 13, 'w', 'G_II', '', 5.25, 5.8, 6.35),
	(44, 14, 15, 'w', 'G_II', '', 6.08, 6.63, 7.18),
	(44, 16, 17, 'w', 'G_II', '', 6.35, 6.91, 7.46),
	(44, 18, 19, 'w', 'G_II', '', 7.18, 7.74, 8.29),
	(44, 20, 24, 'w', 'G_II', '', 7.18, 7.74, 8.29),
	(44, 25, 29, 'w', 'G_II', '', 7.18, 7.74, 8.29),
	(44, 30, 34, 'w', 'G_II', '', 6.91, 7.46, 8.01),
	(44, 35, 39, 'w', 'G_II', '', 6.63, 7.18, 7.74),
	(44, 40, 44, 'w', 'G_II', '', 6.08, 6.63, 7.18),
	(44, 45, 49, 'w', 'G_II', '', 5.8, 6.35, 6.91),
	(44, 50, 54, 'w', 'G_II', '', 5.8, 6.63, 7.74),
	(44, 55, 59, 'w', 'G_II', '', 5.53, 6.35, 7.18),
	(44, 60, 64, 'w', 'G_II', '', 5.25, 6.08, 6.91),
	(44, 65, 69, 'w', 'G_II', '', 4.97, 5.8, 6.91),
	(44, 70, 74, 'w', 'G_II', '', 4.7, 5.53, 6.63),
	(44, 75, 79, 'w', 'G_II', '', 4.7, 5.8, 6.91),
	(44, 80, 84, 'w', 'G_II', '', 4.42, 5.53, 6.35),
	(44, 85, 89, 'w', 'G_II', '', 4.14, 4.97, 6.08),
	(44, 90, 200, 'w', 'G_II', '', 3.59, 4.7, 5.53),
	(44, 12, 13, 'm', 'G_II', '', 6.91, 7.46, 8.01),
	(44, 14, 15, 'm', 'G_II', '', 7.74, 8.29, 8.84),
	(44, 16, 17, 'm', 'G_II', '', 8.29, 8.84, 9.39),
	(44, 18, 19, 'm', 'G_II', '', 8.56, 9.12, 9.67),
	(44, 20, 24, 'm', 'G_II', '', 8.56, 9.39, 9.95),
	(44, 25, 29, 'm', 'G_II', '', 8.29, 9.12, 9.67),
	(44, 30, 34, 'm', 'G_II', '', 7.74, 8.56, 9.12),
	(44, 35, 39, 'm', 'G_II', '', 7.46, 8.01, 8.84),
	(44, 40, 44, 'm', 'G_II', '', 6.91, 7.74, 8.56),
	(44, 45, 49, 'm', 'G_II', '', 6.63, 7.46, 8.29),
	(44, 50, 54, 'm', 'G_II', '', 6.91, 7.74, 8.84),
	(44, 55, 59, 'm', 'G_II', '', 6.75, 7.63, 8.58),
	(44, 60, 64, 'm', 'G_II', '', 6.63, 7.57, 8.35),
	(44, 65, 69, 'm', 'G_II', '', 6.35, 7.46, 8.29),
	(44, 70, 74, 'm', 'G_II', '', 6.12, 7.27, 7.95),
	(44, 75, 79, 'm', 'G_II', '', 6.08, 7.18, 7.9),
	(44, 80, 84, 'm', 'G_II', '', 6.08, 6.91, 8.01),
	(44, 85, 89, 'm', 'G_II', '', 5.53, 6.63, 7.46),
	(44, 90, 200, 'm', 'G_II', '', 4.97, 5.8, 6.91),
	(46, 18, 19, 'w', 'G_II', '', 14.1, 15.9, 17.4),
	(46, 20, 24, 'w', 'G_II', '', 14.4, 16.2, 17.7),
	(46, 25, 29, 'w', 'G_II', '', 14.4, 16.2, 17.7),
	(46, 30, 34, 'w', 'G_II', '', 13.2, 15.0, 16.5),
	(46, 35, 39, 'w', 'G_II', '', 12.6, 14.4, 15.9),
	(46, 40, 44, 'w', 'G_II', '', 11.7, 13.5, 15.0),
	(46, 45, 49, 'w', 'G_II', '', 11.1, 12.9, 14.4),
	(46, 50, 54, 'w', 'G_II', '', 9.9, 12.0, 13.8),
	(46, 55, 59, 'w', 'G_II', '', 9.3, 11.4, 13.2),
	(46, 60, 64, 'w', 'G_II', '', 8.7, 10.8, 12.6),
	(46, 65, 69, 'w', 'G_II', '', 8.1, 10.2, 12.0),
	(46, 70, 74, 'w', 'G_II', '', 7.8, 9.9, 11.7),
	(46, 75, 79, 'w', 'G_II', '', 7.2, 9.3, 11.1),
	(46, 80, 84, 'w', 'G_II', '', 6.6, 8.7, 10.5),
	(46, 85, 89, 'w', 'G_II', '', 5.7, 7.8, 9.6),
	(46, 90, 200, 'w', 'G_II', '', 4.5, 6.6, 8.4),
	(46, 18, 19, 'm', 'G_II', '', 18.9, 21.6, 24.3),
	(46, 20, 24, 'm', 'G_II', '', 19.8, 22.8, 25.2),
	(46, 25, 29, 'm', 'G_II', '', 19.5, 22.5, 24.9),
	(46, 30, 34, 'm', 'G_II', '', 18.0, 21.0, 24.0),
	(46, 35, 39, 'm', 'G_II', '', 17.1, 20.1, 23.1),
	(46, 40, 44, 'm', 'G_II', '', 16.8, 19.8, 22.8),
	(46, 45, 49, 'm', 'G_II', '', 16.2, 19.2, 22.5),
	(46, 50, 54, 'm', 'G_II', '', 15.3, 18.6, 21.9),
	(46, 55, 59, 'm', 'G_II', '', 14.1, 17.4, 21.0),
	(46, 60, 64, 'm', 'G_II', '', 13.5, 16.8, 20.4),
	(46, 65, 69, 'm', 'G_II', '', 12.0, 15.3, 18.3),
	(46, 70, 74, 'm', 'G_II', '', 11.1, 14.4, 17.4),
	(46, 75, 79, 'm', 'G_II', '', 9.6, 12.6, 15.6),
	(46, 80, 84, 'm', 'G_II', '', 8.4, 11.4, 14.4),
	(46, 85, 89, 'm', 'G_II', '', 7.2, 9.9, 12.6),
	(46, 90, 200, 'm', 'G_II', '', 6.3, 9.0, 11.7),
	(53, 0, 7, 'w', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'G_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'G_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'G_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'G_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'G_II', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'G_II', '', 1.0, 2.0, 3.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 18, 19, 'w', 'G_III', '', 8.333333333333332, 7.533333333333334, 6.733333333333334),
	(1, 20, 24, 'w', 'G_III', '', 8.133333333333333, 7.333333333333334, 6.533333333333334),
	(1, 25, 29, 'w', 'G_III', '', 8.266666666666667, 7.466666666666667, 6.666666666666667),
	(1, 30, 34, 'w', 'G_III', '', 8.6, 7.800000000000001, 7.0),
	(1, 35, 39, 'w', 'G_III', '', 8.8, 8.0, 7.2),
	(1, 40, 44, 'w', 'G_III', '', 9.133333333333333, 8.266666666666667, 7.4),
	(1, 45, 49, 'w', 'G_III', '', 9.533333333333333, 8.6, 7.533333333333334),
	(1, 50, 54, 'w', 'G_III', '', 9.933333333333334, 8.866666666666665, 7.666666666666667),
	(1, 55, 59, 'w', 'G_III', '', 10.333333333333332, 9.133333333333333, 7.933333333333333),
	(1, 60, 64, 'w', 'G_III', '', 10.6, 9.4, 8.2),
	(1, 65, 69, 'w', 'G_III', '', 10.866666666666665, 9.666666666666668, 8.466666666666665),
	(1, 70, 74, 'w', 'G_III', '', 11.066666666666665, 9.866666666666665, 8.666666666666668),
	(1, 75, 79, 'w', 'G_III', '', 11.4, 10.2, 9.0),
	(1, 80, 84, 'w', 'G_III', '', 11.866666666666665, 10.666666666666668, 9.466666666666665),
	(1, 85, 89, 'w', 'G_III', '', 12.4, 11.2, 10.0),
	(1, 90, 200, 'w', 'G_III', '', 13.0, 11.8, 10.6),
	(1, 18, 19, 'm', 'G_III', '', 7.133333333333334, 6.333333333333334, 5.533333333333334),
	(1, 20, 24, 'm', 'G_III', '', 6.933333333333333, 6.133333333333334, 5.333333333333334),
	(1, 25, 29, 'm', 'G_III', '', 7.066666666666666, 6.266666666666667, 5.466666666666667),
	(1, 30, 34, 'm', 'G_III', '', 7.4, 6.6000000000000005, 5.800000000000001),
	(1, 35, 39, 'm', 'G_III', '', 7.933333333333333, 6.933333333333333, 6.0),
	(1, 40, 44, 'm', 'G_III', '', 8.4, 7.4, 6.333333333333334),
	(1, 45, 49, 'm', 'G_III', '', 8.866666666666665, 7.800000000000001, 6.6000000000000005),
	(1, 50, 54, 'm', 'G_III', '', 9.333333333333332, 8.133333333333333, 6.933333333333333),
	(1, 55, 59, 'm', 'G_III', '', 9.533333333333333, 8.333333333333332, 7.133333333333334),
	(1, 60, 64, 'm', 'G_III', '', 9.8, 8.6, 7.4),
	(1, 65, 69, 'm', 'G_III', '', 10.0, 8.8, 7.6000000000000005),
	(1, 70, 74, 'm', 'G_III', '', 10.133333333333333, 8.933333333333334, 7.733333333333334),
	(1, 75, 79, 'm', 'G_III', '', 10.4, 9.2, 8.0),
	(1, 80, 84, 'm', 'G_III', '', 10.6, 9.4, 8.2),
	(1, 85, 89, 'm', 'G_III', '', 11.0, 9.8, 8.6),
	(1, 90, 200, 'm', 'G_III', '', 11.933333333333334, 10.733333333333333, 9.533333333333333),
	(4, 8, 9, 'w', 'G_III', '1 km', 13.500000000000002, 12.0, 10.500000000000002),
	(4, 10, 11, 'w', 'G_III', '2 km', 25.249999999999996, 21.5, 17.75),
	(4, 12, 13, 'w', 'G_III', '2 km', 22.5, 19.75, 16.75),
	(4, 14, 15, 'w', 'G_III', '2 km', 19.0, 16.249999999999996, 14.25),
	(4, 16, 17, 'w', 'G_III', '2 km', 16.249999999999996, 14.25, 12.500000000000002),
	(4, 18, 19, 'w', 'G_III', '3 km', 17.249999999999996, 15.6, 13.950000000000001),
	(4, 20, 24, 'w', 'G_III', '3 km', 17.099999999999998, 15.45, 13.65),
	(4, 25, 29, 'w', 'G_III', '3 km', 16.8, 15.15, 13.500000000000002),
	(4, 30, 34, 'w', 'G_III', '3 km', 17.099999999999998, 15.45, 13.65),
	(4, 35, 39, 'w', 'G_III', '3 km', 18.0, 15.899999999999999, 14.100000000000001),
	(4, 40, 44, 'w', 'G_III', '3 km', 19.200000000000003, 16.650000000000002, 14.85),
	(4, 45, 49, 'w', 'G_III', '3 km', 20.099999999999998, 17.549999999999997, 15.45),
	(4, 50, 54, 'w', 'G_III', '3 km', 20.700000000000003, 18.3, 16.05),
	(4, 55, 59, 'w', 'G_III', '3 km', 21.45, 18.9, 16.650000000000002),
	(4, 60, 64, 'w', 'G_III', '3 km', 22.200000000000003, 19.5, 17.099999999999998),
	(4, 65, 69, 'w', 'G_III', '3 km', 22.650000000000002, 19.95, 17.549999999999997),
	(4, 70, 74, 'w', 'G_III', '3 km', 23.4, 20.549999999999997, 18.15),
	(4, 75, 79, 'w', 'G_III', '3 km', 24.45, 21.15, 18.9),
	(4, 80, 84, 'w', 'G_III', '3 km', 25.35, 22.5, 19.650000000000002),
	(4, 85, 89, 'w', 'G_III', '3 km', 26.85, 24.0, 20.700000000000003),
	(4, 90, 200, 'w', 'G_III', '3 km', 27.9, 24.9, 21.75),
	(4, 8, 9, 'm', 'G_III', '1 km', 13.25, 11.749999999999998, 10.25),
	(4, 10, 11, 'm', 'G_III', '2 km', 24.249999999999996, 20.5, 16.75),
	(4, 12, 13, 'm', 'G_III', '2 km', 21.5, 18.5, 15.749999999999998),
	(4, 14, 15, 'm', 'G_III', '2 km', 16.0, 14.0, 12.0),
	(4, 16, 17, 'm', 'G_III', '2 km', 13.500000000000002, 11.749999999999998, 10.25),
	(4, 18, 19, 'm', 'G_III', '3 km', 14.100000000000001, 12.749999999999998, 11.55),
	(4, 20, 24, 'm', 'G_III', '3 km', 13.950000000000001, 12.6, 11.25),
	(4, 25, 29, 'm', 'G_III', '3 km', 15.0, 13.350000000000001, 11.7),
	(4, 30, 34, 'm', 'G_III', '3 km', 16.05, 14.100000000000001, 12.15),
	(4, 35, 39, 'm', 'G_III', '3 km', 17.4, 15.0, 12.45),
	(4, 40, 44, 'm', 'G_III', '3 km', 18.9, 15.6, 13.049999999999999),
	(4, 45, 49, 'm', 'G_III', '3 km', 19.8, 17.599999999999998, 14.4),
	(4, 50, 54, 'm', 'G_III', '3 km', 20.549999999999997, 18.233333333333334, 14.883333333333333),
	(4, 55, 59, 'm', 'G_III', '3 km', 21.15, 18.716666666666665, 15.2),
	(4, 60, 64, 'm', 'G_III', '3 km', 21.45, 19.200000000000003, 15.366666666666667),
	(4, 65, 69, 'm', 'G_III', '3 km', 21.75, 19.366666666666664, 15.516666666666667),
	(4, 70, 74, 'm', 'G_III', '3 km', 22.05, 19.683333333333334, 15.833333333333334),
	(4, 75, 79, 'm', 'G_III', '3 km', 22.35, 18.9, 15.45),
	(4, 80, 84, 'm', 'G_III', '3 km', 22.8, 19.35, 15.899999999999999),
	(4, 85, 89, 'm', 'G_III', '3 km', 23.249999999999996, 19.95, 16.650000000000002),
	(4, 90, 200, 'm', 'G_III', '3 km', 23.700000000000003, 20.4, 17.4),
	(7, 0, 7, 'w', 'G_III', '100 m', 8.100000000000001, 6.9, 5.7),
	(7, 8, 9, 'w', 'G_III', '100 m', 7.2, 6.3, 5.333333333333334),
	(7, 10, 11, 'w', 'G_III', '100 m', 6.6000000000000005, 5.783333333333333, 4.95),
	(7, 12, 13, 'w', 'G_III', '200 m', 13.350000000000001, 11.616666666666665, 9.899999999999999),
	(7, 14, 15, 'w', 'G_III', '200 m', 11.766666666666667, 10.500000000000002, 9.0),
	(7, 16, 17, 'w', 'G_III', '200 m', 10.65, 9.45, 8.183333333333332),
	(7, 18, 19, 'w', 'G_III', '400 m', 21.599999999999998, 19.05, 16.583333333333336),
	(7, 20, 24, 'w', 'G_III', '400 m', 21.216666666666665, 18.75, 16.200000000000003),
	(7, 25, 29, 'w', 'G_III', '400 m', 22.95, 18.966666666666665, 16.8),
	(7, 30, 34, 'w', 'G_III', '400 m', 25.95, 21.3, 17.549999999999997),
	(7, 35, 39, 'w', 'G_III', '400 m', 28.8, 23.03333333333333, 18.3),
	(7, 40, 44, 'w', 'G_III', '400 m', 30.599999999999998, 24.9, 19.200000000000003),
	(7, 45, 49, 'w', 'G_III', '400 m', 31.8, 26.099999999999998, 19.35),
	(7, 50, 54, 'w', 'G_III', '200 m', 16.200000000000003, 13.500000000000002, 10.350000000000001),
	(7, 55, 59, 'w', 'G_III', '200 m', 16.716666666666665, 13.8, 10.716666666666667),
	(7, 60, 64, 'w', 'G_III', '200 m', 17.099999999999998, 14.033333333333333, 10.950000000000001),
	(7, 65, 69, 'w', 'G_III', '200 m', 17.48333333333333, 14.183333333333332, 11.016666666666666),
	(7, 70, 74, 'w', 'G_III', '200 m', 17.85, 14.466666666666665, 11.4),
	(7, 75, 79, 'w', 'G_III', '100 m', 9.216666666666669, 7.5, 5.85),
	(7, 80, 84, 'w', 'G_III', '100 m', 9.366666666666667, 7.6499999999999995, 6.066666666666666),
	(7, 85, 89, 'w', 'G_III', '100 m', 9.516666666666667, 7.866666666666666, 6.366666666666666),
	(7, 90, 200, 'w', 'G_III', '100 m', 9.683333333333334, 8.016666666666666, 6.6000000000000005),
	(7, 0, 7, 'm', 'G_III', '100 m', 8.100000000000001, 6.6000000000000005, 5.55),
	(7, 8, 9, 'm', 'G_III', '100 m', 7.2, 6.066666666666666, 5.1),
	(7, 10, 11, 'm', 'G_III', '100 m', 6.3, 5.7, 4.6499999999999995),
	(7, 12, 13, 'm', 'G_III', '200 m', 12.15, 10.350000000000001, 8.783333333333335),
	(7, 14, 15, 'm', 'G_III', '200 m', 10.8, 9.216666666666669, 7.95),
	(7, 16, 17, 'm', 'G_III', '200 m', 9.899999999999999, 8.7, 7.5),
	(7, 18, 19, 'm', 'G_III', '400 m', 20.333333333333332, 17.85, 15.299999999999999),
	(7, 20, 24, 'm', 'G_III', '400 m', 19.95, 17.549999999999997, 14.783333333333335),
	(7, 25, 29, 'm', 'G_III', '400 m', 20.85, 18.0, 15.299999999999999),
	(7, 30, 34, 'm', 'G_III', '400 m', 23.183333333333334, 19.35, 16.200000000000003),
	(7, 35, 39, 'm', 'G_III', '400 m', 25.95, 21.599999999999998, 17.333333333333332),
	(7, 40, 44, 'm', 'G_III', '400 m', 29.183333333333334, 23.78333333333333, 18.383333333333333),
	(7, 45, 49, 'm', 'G_III', '400 m', 31.05, 25.05, 18.599999999999998),
	(7, 50, 54, 'm', 'G_III', '200 m', 15.683333333333334, 12.899999999999999, 9.683333333333334),
	(7, 55, 59, 'm', 'G_III', '200 m', 16.05, 13.133333333333333, 10.2),
	(7, 60, 64, 'm', 'G_III', '200 m', 16.35, 13.266666666666667, 10.266666666666667),
	(7, 65, 69, 'm', 'G_III', '200 m', 16.583333333333336, 13.583333333333332, 10.350000000000001),
	(7, 70, 74, 'm', 'G_III', '200 m', 16.583333333333336, 13.716666666666667, 10.433333333333334),
	(7, 75, 79, 'm', 'G_III', '100 m', 8.466666666666665, 6.9, 5.483333333333333),
	(7, 80, 84, 'm', 'G_III', '100 m', 8.55, 7.050000000000001, 5.55),
	(7, 85, 89, 'm', 'G_III', '100 m', 8.55, 7.2, 5.783333333333333),
	(7, 90, 200, 'm', 'G_III', '100 m', 8.783333333333335, 7.35, 6.066666666666666),
	(8, 18, 19, 'w', 'G_III', '1,5 km', 22.233333333333334, 21.116666666666667, 19.833333333333332),
	(8, 20, 24, 'w', 'G_III', '1,5 km', 21.283333333333335, 20.166666666666668, 19.03333333333333),
	(8, 25, 29, 'w', 'G_III', '1,5 km', 21.433333333333337, 20.31666666666667, 19.200000000000003),
	(8, 30, 34, 'w', 'G_III', '1,5 km', 21.599999999999998, 20.48333333333333, 19.333333333333332),
	(8, 35, 39, 'w', 'G_III', '1,5 km', 22.4, 20.8, 19.433333333333337),
	(8, 40, 44, 'w', 'G_III', '1,5 km', 23.366666666666664, 21.433333333333337, 19.516666666666666),
	(8, 45, 49, 'w', 'G_III', '1,5 km', 24.166666666666668, 22.083333333333336, 19.833333333333332),
	(8, 50, 54, 'w', 'G_III', '1,5 km', 24.966666666666665, 22.716666666666665, 20.48333333333333),
	(8, 55, 59, 'w', 'G_III', '1,5 km', 25.599999999999998, 23.366666666666664, 21.116666666666667),
	(8, 60, 64, 'w', 'G_III', '1,5 km', 26.4, 23.833333333333332, 21.599999999999998),
	(8, 65, 69, 'w', 'G_III', '1,5 km', 26.966666666666665, 24.48333333333333, 22.4),
	(8, 70, 74, 'w', 'G_III', '1,5 km', 28.233333333333334, 25.283333333333335, 23.03333333333333),
	(8, 75, 79, 'w', 'G_III', '1,5 km', 29.599999999999998, 26.083333333333336, 23.833333333333332),
	(8, 80, 84, 'w', 'G_III', '1,5 km', 31.516666666666666, 27.283333333333335, 24.8),
	(8, 85, 89, 'w', 'G_III', '1,5 km', 33.28333333333334, 28.9, 26.233333333333334),
	(8, 90, 200, 'w', 'G_III', '1,5 km', 35.3, 30.716666666666665, 27.833333333333332),
	(8, 18, 19, 'm', 'G_III', '1,5 km', 18.716666666666665, 17.433333333333337, 16.166666666666668),
	(8, 20, 24, 'm', 'G_III', '1,5 km', 18.233333333333334, 16.966666666666665, 15.683333333333334),
	(8, 25, 29, 'm', 'G_III', '1,5 km', 18.716666666666665, 17.433333333333337, 16.166666666666668),
	(8, 30, 34, 'm', 'G_III', '1,5 km', 20.0, 18.233333333333334, 16.31666666666667),
	(8, 35, 39, 'm', 'G_III', '1,5 km', 20.8, 18.716666666666665, 17.116666666666667),
	(8, 40, 44, 'm', 'G_III', '1,5 km', 21.116666666666667, 19.366666666666664, 17.283333333333335),
	(8, 45, 49, 'm', 'G_III', '1,5 km', 21.916666666666668, 18.75, 16.5),
	(8, 50, 54, 'm', 'G_III', '1,5 km', 21.3, 19.200000000000003, 17.249999999999996),
	(8, 55, 59, 'm', 'G_III', '1,5 km', 21.9, 19.5, 17.700000000000003),
	(8, 60, 64, 'm', 'G_III', '1,5 km', 22.733333333333334, 20.249999999999996, 18.15),
	(8, 65, 69, 'm', 'G_III', '1,5 km', 23.45, 20.85, 18.599999999999998),
	(8, 70, 74, 'm', 'G_III', '1,5 km', 24.45, 21.599999999999998, 19.5),
	(8, 75, 79, 'm', 'G_III', '1,5 km', 27.566666666666666, 24.233333333333334, 23.03333333333333),
	(8, 80, 84, 'm', 'G_III', '1,5 km', 29.283333333333335, 25.516666666666666, 23.03333333333333),
	(8, 85, 89, 'm', 'G_III', '1,5 km', 30.716666666666665, 26.966666666666665, 24.166666666666668),
	(8, 90, 200, 'm', 'G_III', '1,5 km', 32.88333333333333, 28.583333333333336, 25.599999999999998),
	(10, 0, 7, 'w', 'G_III', '', 2.7, 4.05, 5.4),
	(10, 8, 9, 'w', 'G_III', '', 4.05, 5.4, 6.75),
	(10, 10, 11, 'w', 'G_III', '', 4.95, 6.75, 8.1),
	(10, 0, 7, 'm', 'G_III', '', 5.4, 6.75, 7.65),
	(10, 8, 9, 'm', 'G_III', '', 7.65, 9.0, 10.35),
	(10, 10, 11, 'm', 'G_III', '', 9.45, 11.25, 12.6),
	(11, 12, 13, 'w', 'G_III', '', 6.75, 8.1, 9.9),
	(11, 14, 15, 'w', 'G_III', '', 9.0, 10.8, 12.15),
	(11, 16, 17, 'w', 'G_III', '', 10.8, 12.15, 13.95),
	(11, 12, 13, 'm', 'G_III', '', 11.7, 13.5, 14.85),
	(11, 14, 15, 'm', 'G_III', '', 13.5, 15.3, 16.65),
	(11, 16, 17, 'm', 'G_III', '', 15.3, 17.1, 18.9),
	(13, 12, 13, 'w', 'G_III', '2 kg', 2.14, 2.36, 2.59),
	(13, 14, 15, 'w', 'G_III', '2 kg', 2.48, 2.7, 2.93),
	(13, 16, 17, 'w', 'G_III', '2 kg', 2.59, 2.81, 3.04),
	(13, 18, 19, 'w', 'G_III', '2  kg', 2.93, 3.15, 3.38),
	(13, 20, 24, 'w', 'G_III', '2  kg', 2.93, 3.15, 3.38),
	(13, 25, 29, 'w', 'G_III', '2  kg', 2.93, 3.15, 3.38),
	(13, 30, 34, 'w', 'G_III', '2  kg', 2.81, 3.04, 3.26),
	(13, 35, 39, 'w', 'G_III', '2  kg', 2.7, 2.93, 3.15),
	(13, 40, 44, 'w', 'G_III', '2  kg', 2.48, 2.7, 2.93),
	(13, 45, 49, 'w', 'G_III', '2 kg', 2.36, 2.59, 2.81),
	(13, 50, 54, 'w', 'G_III', '2 kg', 2.32, 2.7, 3.15),
	(13, 55, 59, 'w', 'G_III', '2 kg', 2.25, 2.59, 2.93),
	(13, 60, 64, 'w', 'G_III', '2 kg', 2.1, 2.48, 2.81),
	(13, 65, 69, 'w', 'G_III', '2 kg', 1.99, 2.36, 2.81),
	(13, 70, 74, 'w', 'G_III', '2 kg', 1.87, 2.25, 2.7),
	(13, 75, 79, 'w', 'G_III', '2 kg', 1.87, 2.36, 2.81),
	(13, 80, 84, 'w', 'G_III', '2 kg', 1.8, 2.25, 2.59),
	(13, 85, 89, 'w', 'G_III', '2 kg', 1.69, 2.03, 2.48),
	(13, 90, 200, 'w', 'G_III', '2 kg', 1.46, 1.91, 2.25),
	(13, 12, 13, 'm', 'G_III', '2 kg', 2.81, 3.04, 3.26),
	(13, 14, 15, 'm', 'G_III', '2 kg', 3.15, 3.38, 3.6),
	(13, 16, 17, 'm', 'G_III', '2 kg', 3.38, 3.6, 3.83),
	(13, 18, 19, 'm', 'G_III', '2 kg', 3.49, 3.71, 3.94),
	(13, 20, 24, 'm', 'G_III', '2 kg', 3.49, 3.83, 4.05),
	(13, 25, 29, 'm', 'G_III', '2 kg', 3.38, 3.71, 3.94),
	(13, 30, 34, 'm', 'G_III', '2 kg', 3.15, 3.49, 3.71),
	(13, 35, 39, 'm', 'G_III', '2 kg', 3.04, 3.26, 3.6),
	(13, 40, 44, 'm', 'G_III', '2 kg', 2.81, 3.15, 3.49),
	(13, 45, 49, 'm', 'G_III', '2 kg', 2.7, 3.04, 3.38),
	(13, 50, 54, 'm', 'G_III', '2 kg', 2.66, 3.0, 3.34),
	(13, 55, 59, 'm', 'G_III', '2 kg', 2.62, 2.96, 3.3),
	(13, 60, 64, 'm', 'G_III', '2 kg', 2.58, 2.92, 3.26),
	(13, 65, 69, 'm', 'G_III', '2 kg', 2.54, 2.88, 3.22),
	(13, 70, 74, 'm', 'G_III', '2 kg', 2.5, 2.84, 3.18),
	(13, 75, 79, 'm', 'G_III', '2 kg', 2.46, 2.8, 3.14),
	(13, 80, 84, 'm', 'G_III', '2 kg', 2.42, 2.76, 3.1),
	(13, 85, 89, 'm', 'G_III', '2 kg', 2.38, 2.72, 3.06),
	(13, 90, 200, 'm', 'G_III', '2 kg', 2.34, 2.68, 3.02),
	(15, 0, 7, 'w', 'G_III', '', 0.42, 0.5, 0.56),
	(15, 8, 9, 'w', 'G_III', '', 0.46, 0.52, 0.6),
	(15, 10, 11, 'w', 'G_III', '', 0.52, 0.58, 0.66),
	(15, 12, 13, 'w', 'G_III', '', 0.56, 0.64, 0.72),
	(15, 14, 15, 'w', 'G_III', '', 0.62, 0.68, 0.76),
	(15, 16, 17, 'w', 'G_III', '', 0.66, 0.72, 0.8),
	(15, 18, 19, 'w', 'G_III', '', 0.66, 0.74, 0.82),
	(15, 20, 24, 'w', 'G_III', '', 0.64, 0.72, 0.8),
	(15, 25, 29, 'w', 'G_III', '', 0.6, 0.68, 0.78),
	(15, 30, 34, 'w', 'G_III', '', 0.54, 0.64, 0.74),
	(15, 35, 39, 'w', 'G_III', '', 0.5, 0.6, 0.72),
	(15, 40, 44, 'w', 'G_III', '', 0.46, 0.56, 0.66),
	(15, 45, 49, 'w', 'G_III', '', 0.44, 0.54, 0.64),
	(15, 50, 54, 'w', 'G_III', '', 0.4, 0.52, 0.62),
	(15, 55, 59, 'w', 'G_III', '', 0.38, 0.48, 0.58),
	(15, 60, 64, 'w', 'G_III', '', 0.38, 0.48, 0.58),
	(15, 65, 69, 'w', 'G_III', '', 0.36, 0.46, 0.56),
	(15, 70, 74, 'w', 'G_III', '', 0.36, 0.46, 0.54),
	(15, 75, 79, 'w', 'G_III', '', 0.36, 0.46, 0.54),
	(15, 80, 84, 'w', 'G_III', '', 0.36, 0.44, 0.52),
	(15, 85, 89, 'w', 'G_III', '', 0.34, 0.42, 0.5),
	(15, 90, 200, 'w', 'G_III', '', 0.32, 0.4, 0.48),
	(15, 0, 7, 'm', 'G_III', '', 0.46, 0.54, 0.6),
	(15, 8, 9, 'm', 'G_III', '', 0.52, 0.6, 0.66),
	(15, 10, 11, 'm', 'G_III', '', 0.6, 0.68, 0.74),
	(15, 12, 13, 'm', 'G_III', '', 0.68, 0.76, 0.82),
	(15, 14, 15, 'm', 'G_III', '', 0.76, 0.82, 0.9),
	(15, 16, 17, 'm', 'G_III', '', 0.82, 0.88, 0.96),
	(15, 18, 19, 'm', 'G_III', '', 0.84, 0.92, 1.0),
	(15, 20, 24, 'm', 'G_III', '', 0.84, 0.92, 1.0),
	(15, 25, 29, 'm', 'G_III', '', 0.82, 0.9, 0.98),
	(15, 30, 34, 'm', 'G_III', '', 0.74, 0.84, 0.94),
	(15, 35, 39, 'm', 'G_III', '', 0.66, 0.78, 0.9),
	(15, 40, 44, 'm', 'G_III', '', 0.62, 0.74, 0.86),
	(15, 45, 49, 'm', 'G_III', '', 0.58, 0.7, 0.82),
	(15, 50, 54, 'm', 'G_III', '', 0.56, 0.68, 0.8),
	(15, 55, 59, 'm', 'G_III', '', 0.54, 0.66, 0.78),
	(15, 60, 64, 'm', 'G_III', '', 0.52, 0.64, 0.76),
	(15, 65, 69, 'm', 'G_III', '', 0.52, 0.64, 0.76),
	(15, 70, 74, 'm', 'G_III', '', 0.5, 0.62, 0.74),
	(15, 75, 79, 'm', 'G_III', '', 0.48, 0.6, 0.72),
	(15, 80, 84, 'm', 'G_III', '', 0.46, 0.58, 0.7),
	(15, 85, 89, 'm', 'G_III', '', 0.4, 0.52, 0.64),
	(15, 90, 200, 'm', 'G_III', '', 0.36, 0.48, 0.6),
	(17, 0, 7, 'w', 'G_III', '30 m', 22.4, 19.9, 17.6),
	(17, 8, 9, 'w', 'G_III', '30 m', 20.7, 18.5, 16.0),
	(17, 10, 11, 'w', 'G_III', '50 m', 30.8, 28.3, 25.5),
	(17, 12, 13, 'w', 'G_III', '50 m', 29.7, 26.9, 23.8),
	(17, 14, 15, 'w', 'G_III', '100 m', 52.1, 47.6, 43.4),
	(17, 16, 17, 'w', 'G_III', '100 m', 49.3, 45.6, 42.0),
	(17, 18, 19, 'w', 'G_III', '100 m', 51.0, 46.2, 42.8),
	(17, 20, 24, 'w', 'G_III', '100 m', 51.8, 47.0, 43.7),
	(17, 25, 29, 'w', 'G_III', '100 m', 52.9, 48.2, 44.8),
	(17, 30, 34, 'w', 'G_III', '100 m', 54.9, 49.8, 45.9),
	(17, 35, 39, 'w', 'G_III', '100 m', 57.1, 52.1, 47.6),
	(17, 40, 44, 'w', 'G_III', '50 m', 30.8, 27.7, 24.6),
	(17, 45, 49, 'w', 'G_III', '50 m', 32.2, 28.8, 25.5),
	(17, 50, 54, 'w', 'G_III', '50 m', 33.3, 30.0, 26.6),
	(17, 55, 59, 'w', 'G_III', '50 m', 34.7, 31.4, 27.7),
	(17, 60, 64, 'w', 'G_III', '50 m', 35.3, 31.9, 28.6),
	(17, 65, 69, 'w', 'G_III', '50 m', 35.8, 32.5, 29.1),
	(17, 70, 74, 'w', 'G_III', '50 m', 36.4, 33.0, 29.7),
	(17, 75, 79, 'w', 'G_III', '50 m', 37.8, 34.4, 31.1),
	(17, 80, 84, 'w', 'G_III', '50 m', 40.0, 36.7, 33.6),
	(17, 85, 89, 'w', 'G_III', '50 m', 43.4, 40.0, 37.0),
	(17, 90, 200, 'w', 'G_III', '50 m', 47.9, 44.5, 41.4),
	(17, 0, 7, 'm', 'G_III', '30 m', 21.6, 19.0, 16.8),
	(17, 8, 9, 'm', 'G_III', '30 m', 20.2, 17.9, 16.0),
	(17, 10, 11, 'm', 'G_III', '50 m', 28.8, 26.0, 23.5),
	(17, 12, 13, 'm', 'G_III', '50 m', 27.2, 24.9, 22.7),
	(17, 14, 15, 'm', 'G_III', '100 m', 47.6, 43.1, 39.5),
	(17, 16, 17, 'm', 'G_III', '100 m', 45.6, 41.4, 37.8),
	(17, 18, 19, 'm', 'G_III', '100 m', 44.8, 40.9, 37.0),
	(17, 20, 24, 'm', 'G_III', '100 m', 44.2, 40.3, 36.4),
	(17, 25, 29, 'm', 'G_III', '100 m', 45.6, 41.4, 37.2),
	(17, 30, 34, 'm', 'G_III', '100 m', 47.0, 42.3, 38.1),
	(17, 35, 39, 'm', 'G_III', '100 m', 49.3, 44.5, 39.8),
	(17, 40, 44, 'm', 'G_III', '50 m', 26.9, 24.4, 21.6),
	(17, 45, 49, 'm', 'G_III', '50 m', 28.0, 24.9, 22.1),
	(17, 50, 54, 'm', 'G_III', '50 m', 28.8, 25.5, 23.0),
	(17, 55, 59, 'm', 'G_III', '50 m', 29.4, 26.3, 23.8),
	(17, 60, 64, 'm', 'G_III', '50 m', 30.2, 27.2, 24.6),
	(17, 65, 69, 'm', 'G_III', '50 m', 31.4, 28.6, 25.5),
	(17, 70, 74, 'm', 'G_III', '50 m', 32.8, 30.0, 26.9),
	(17, 75, 79, 'm', 'G_III', '50 m', 34.2, 31.4, 28.3),
	(17, 80, 84, 'm', 'G_III', '50 m', 36.4, 33.6, 30.5),
	(17, 85, 89, 'm', 'G_III', '50 m', 39.5, 36.7, 33.6),
	(17, 90, 200, 'm', 'G_III', '50 m', 43.4, 40.6, 37.5),
	(18, 0, 7, 'w', 'G_III', '', 88.4, 73.2, 58.0),
	(18, 8, 9, 'w', 'G_III', '', 79.8, 64.6, 53.2),
	(18, 10, 11, 'w', 'G_III', '', 74.1, 59.9, 48.5),
	(18, 12, 13, 'w', 'G_III', '', 66.5, 55.1, 44.7),
	(18, 14, 15, 'w', 'G_III', '', 62.7, 52.3, 40.9),
	(18, 16, 17, 'w', 'G_III', '', 58.0, 48.5, 38.0),
	(18, 18, 19, 'w', 'G_III', '', 56.1, 45.6, 35.2),
	(18, 20, 24, 'w', 'G_III', '', 55.1, 45.6, 35.2),
	(18, 25, 29, 'w', 'G_III', '', 57.0, 47.5, 37.1),
	(18, 30, 34, 'w', 'G_III', '', 61.8, 50.4, 39.9),
	(18, 35, 39, 'w', 'G_III', '', 68.4, 55.1, 41.8),
	(18, 40, 44, 'w', 'G_III', '', 76.0, 59.9, 44.7),
	(18, 45, 49, 'w', 'G_III', '', 83.6, 66.5, 47.5),
	(18, 50, 54, 'w', 'G_III', '', 91.2, 74.1, 53.2),
	(18, 55, 59, 'w', 'G_III', '', 97.9, 80.8, 58.0),
	(18, 60, 64, 'w', 'G_III', '', 103.6, 84.6, 61.8),
	(18, 65, 69, 'w', 'G_III', '', 107.4, 88.4, 65.6),
	(18, 70, 74, 'w', 'G_III', '', 112.1, 91.2, 68.4),
	(18, 75, 79, 'w', 'G_III', '', 115.9, 95.0, 72.2),
	(18, 80, 84, 'w', 'G_III', '', 120.7, 98.8, 76.0),
	(18, 85, 89, 'w', 'G_III', '', 124.5, 101.7, 78.9),
	(18, 90, 200, 'w', 'G_III', '', 126.4, 103.6, 80.8),
	(18, 0, 7, 'm', 'G_III', '', 87.4, 72.2, 57.0),
	(18, 8, 9, 'm', 'G_III', '', 77.9, 62.7, 49.4),
	(18, 10, 11, 'm', 'G_III', '', 68.4, 55.1, 42.8),
	(18, 12, 13, 'm', 'G_III', '', 62.7, 51.3, 39.9),
	(18, 14, 15, 'm', 'G_III', '', 58.9, 48.5, 38.0),
	(18, 16, 17, 'm', 'G_III', '', 56.1, 46.6, 36.1),
	(18, 18, 19, 'm', 'G_III', '', 53.2, 43.7, 33.3),
	(18, 20, 24, 'm', 'G_III', '', 51.3, 41.8, 29.5),
	(18, 25, 29, 'm', 'G_III', '', 55.1, 43.7, 31.4),
	(18, 30, 34, 'm', 'G_III', '', 59.9, 45.6, 32.3),
	(18, 35, 39, 'm', 'G_III', '', 66.5, 50.4, 35.2),
	(18, 40, 44, 'm', 'G_III', '', 73.2, 56.1, 36.1),
	(18, 45, 49, 'm', 'G_III', '', 79.8, 61.8, 39.0),
	(18, 50, 54, 'm', 'G_III', '', 85.5, 66.5, 43.7),
	(18, 55, 59, 'm', 'G_III', '', 93.1, 70.3, 47.5),
	(18, 60, 64, 'm', 'G_III', '', 96.9, 74.1, 51.3),
	(18, 65, 69, 'm', 'G_III', '', 99.8, 77.0, 54.2),
	(18, 70, 74, 'm', 'G_III', '', 104.5, 81.7, 58.9),
	(18, 75, 79, 'm', 'G_III', '', 109.3, 86.5, 63.7),
	(18, 80, 84, 'm', 'G_III', '', 112.1, 91.2, 68.4),
	(18, 85, 89, 'm', 'G_III', '', 113.1, 93.1, 72.2),
	(18, 90, 200, 'm', 'G_III', '', 114.0, 95.0, 76.0),
	(19, 8, 9, 'w', 'G_III', '', 73.8, 64.8, 55.8),
	(19, 10, 11, 'w', 'G_III', '', 66.6, 57.6, 48.6),
	(19, 12, 13, 'w', 'G_III', '', 55.8, 48.6, 42.3),
	(19, 14, 15, 'w', 'G_III', '', 48.6, 44.1, 38.7),
	(19, 16, 17, 'w', 'G_III', '', 45.0, 40.5, 36.0),
	(19, 18, 19, 'w', 'G_III', '', 43.2, 39.6, 35.1),
	(19, 20, 24, 'w', 'G_III', '', 44.1, 39.6, 35.1),
	(19, 25, 29, 'w', 'G_III', '', 45.0, 40.5, 36.0),
	(19, 30, 34, 'w', 'G_III', '', 46.8, 42.3, 38.7),
	(19, 35, 39, 'w', 'G_III', '', 49.5, 44.1, 39.6),
	(19, 40, 44, 'w', 'G_III', '', 52.2, 45.9, 40.5),
	(19, 45, 49, 'w', 'G_III', '', 54.9, 48.6, 41.4),
	(19, 50, 54, 'w', 'G_III', '', 57.6, 50.4, 42.3),
	(19, 55, 59, 'w', 'G_III', '', 60.3, 52.2, 43.2),
	(19, 60, 64, 'w', 'G_III', '', 63.0, 54.0, 45.0),
	(19, 65, 69, 'w', 'G_III', '', 64.8, 55.8, 45.9),
	(19, 70, 74, 'w', 'G_III', '', 68.4, 57.6, 47.7),
	(19, 75, 79, 'w', 'G_III', '', 70.2, 59.4, 49.5),
	(19, 80, 84, 'w', 'G_III', '', 72.9, 62.1, 51.3),
	(19, 85, 89, 'w', 'G_III', '', 75.6, 64.8, 54.0),
	(19, 90, 200, 'w', 'G_III', '', 80.1, 68.4, 56.7),
	(19, 8, 9, 'm', 'G_III', '', 68.4, 59.4, 50.4),
	(19, 10, 11, 'm', 'G_III', '', 63.0, 54.9, 46.8),
	(19, 12, 13, 'm', 'G_III', '', 53.1, 46.8, 40.5),
	(19, 14, 15, 'm', 'G_III', '', 43.2, 38.7, 34.2),
	(19, 16, 17, 'm', 'G_III', '', 39.6, 35.1, 30.6),
	(19, 18, 19, 'm', 'G_III', '', 36.9, 32.4, 27.9),
	(19, 20, 24, 'm', 'G_III', '', 36.0, 31.5, 27.0),
	(19, 25, 29, 'm', 'G_III', '', 37.8, 32.4, 27.0),
	(19, 30, 34, 'm', 'G_III', '', 40.5, 33.3, 27.0),
	(19, 35, 39, 'm', 'G_III', '', 43.2, 36.0, 27.9),
	(19, 40, 44, 'm', 'G_III', '', 47.7, 38.7, 29.7),
	(19, 45, 49, 'm', 'G_III', '', 51.3, 41.4, 30.6),
	(19, 50, 54, 'm', 'G_III', '', 54.0, 43.2, 32.4),
	(19, 55, 59, 'm', 'G_III', '', 57.6, 45.0, 33.3),
	(19, 60, 64, 'm', 'G_III', '', 60.3, 46.8, 34.2),
	(19, 65, 69, 'm', 'G_III', '', 63.0, 48.6, 35.1),
	(19, 70, 74, 'm', 'G_III', '', 64.8, 51.3, 36.0),
	(19, 75, 79, 'm', 'G_III', '', 67.5, 53.1, 38.7),
	(19, 80, 84, 'm', 'G_III', '', 70.2, 56.7, 41.4),
	(19, 85, 89, 'm', 'G_III', '', 73.8, 59.4, 44.1),
	(19, 90, 200, 'm', 'G_III', '', 78.3, 63.9, 48.6),
	(23, 0, 7, 'w', 'G_III', '', 0.52, 0.64, 0.76),
	(23, 8, 9, 'w', 'G_III', '', 0.72, 0.84, 0.96),
	(23, 10, 11, 'w', 'G_III', '', 0.92, 1.04, 1.16),
	(23, 12, 13, 'w', 'G_III', '', 1.12, 1.24, 1.36),
	(23, 14, 15, 'w', 'G_III', '', 1.28, 1.4, 1.52),
	(23, 16, 17, 'w', 'G_III', '', 1.36, 1.48, 1.6),
	(23, 18, 19, 'w', 'G_III', '', 1.36, 1.48, 1.6),
	(23, 20, 24, 'w', 'G_III', '', 1.36, 1.48, 1.6),
	(23, 25, 29, 'w', 'G_III', '', 1.32, 1.44, 1.56),
	(23, 30, 34, 'w', 'G_III', '', 1.28, 1.4, 1.52),
	(23, 35, 39, 'w', 'G_III', '', 1.24, 1.36, 1.48),
	(23, 40, 44, 'w', 'G_III', '', 1.2, 1.32, 1.44),
	(23, 45, 49, 'w', 'G_III', '', 1.12, 1.28, 1.4),
	(23, 50, 54, 'w', 'G_III', '', 1.04, 1.2, 1.36),
	(23, 55, 59, 'w', 'G_III', '', 1.0, 1.16, 1.32),
	(23, 60, 64, 'w', 'G_III', '', 0.96, 1.12, 1.28),
	(23, 65, 69, 'w', 'G_III', '', 0.92, 1.08, 1.24),
	(23, 70, 74, 'w', 'G_III', '', 0.84, 1.0, 1.16),
	(23, 75, 79, 'w', 'G_III', '', 0.72, 0.88, 1.04),
	(23, 80, 84, 'w', 'G_III', '', 0.64, 0.8, 0.96),
	(23, 85, 89, 'w', 'G_III', '', 0.52, 0.68, 0.84),
	(23, 90, 200, 'w', 'G_III', '', 0.44, 0.6, 0.76),
	(23, 0, 7, 'm', 'G_III', '', 0.64, 0.76, 0.88),
	(23, 8, 9, 'm', 'G_III', '', 0.84, 0.96, 1.08),
	(23, 10, 11, 'm', 'G_III', '', 1.04, 1.16, 1.28),
	(23, 12, 13, 'm', 'G_III', '', 1.28, 1.4, 1.52),
	(23, 14, 15, 'm', 'G_III', '', 1.52, 1.64, 1.76),
	(23, 16, 17, 'm', 'G_III', '', 1.72, 1.84, 1.96),
	(23, 18, 19, 'm', 'G_III', '', 1.8, 1.92, 2.04),
	(23, 20, 24, 'm', 'G_III', '', 1.76, 1.88, 2.0),
	(23, 25, 29, 'm', 'G_III', '', 1.72, 1.84, 1.96),
	(23, 30, 34, 'm', 'G_III', '', 1.68, 1.8, 1.92),
	(23, 35, 39, 'm', 'G_III', '', 1.64, 1.76, 1.88),
	(23, 40, 44, 'm', 'G_III', '', 1.56, 1.72, 1.84),
	(23, 45, 49, 'm', 'G_III', '', 1.48, 1.64, 1.8),
	(23, 50, 54, 'm', 'G_III', '', 1.44, 1.6, 1.76),
	(23, 55, 59, 'm', 'G_III', '', 1.36, 1.52, 1.68),
	(23, 60, 64, 'm', 'G_III', '', 1.28, 1.44, 1.6),
	(23, 65, 69, 'm', 'G_III', '', 1.16, 1.32, 1.48),
	(23, 70, 74, 'm', 'G_III', '', 1.08, 1.24, 1.4),
	(23, 75, 79, 'm', 'G_III', '', 0.96, 1.16, 1.32),
	(23, 80, 84, 'm', 'G_III', '', 0.84, 1.04, 1.24),
	(23, 85, 89, 'm', 'G_III', '', 0.76, 0.96, 1.16),
	(23, 90, 200, 'm', 'G_III', '', 0.64, 0.84, 1.04),
	(33, 0, 7, 'w', 'G_III', '', 2.4000000000000004, 3.5999999999999996, 5.1),
	(33, 8, 9, 'w', 'G_III', '', 3.0, 4.5, 6.0),
	(33, 10, 11, 'w', 'G_III', '', 4.5, 6.0, 9.0),
	(33, 12, 13, 'w', 'G_III', '', 6.0, 9.0, 12.0),
	(33, 14, 15, 'w', 'G_III', '', 9.0, 12.0, 15.0),
	(33, 16, 17, 'w', 'G_III', '', 13.500000000000002, 18.0, 22.5),
	(33, 0, 7, 'm', 'G_III', '', 3.0, 4.5, 6.0),
	(33, 8, 9, 'm', 'G_III', '', 3.5999999999999996, 5.1, 6.9),
	(33, 10, 11, 'm', 'G_III', '', 5.1, 7.5, 10.500000000000002),
	(33, 12, 13, 'm', 'G_III', '', 7.5, 10.500000000000002, 13.500000000000002),
	(33, 14, 15, 'm', 'G_III', '', 10.500000000000002, 13.500000000000002, 18.0),
	(33, 16, 17, 'm', 'G_III', '', 16.5, 21.0, 27.0),
	(39, 0, 7, 'w', 'G_III', '', 74.0, 83.0, 91.0),
	(39, 8, 9, 'w', 'G_III', '', 86.0, 95.0, 105.0),
	(39, 10, 11, 'w', 'G_III', '', 97.0, 108.0, 118.0),
	(39, 12, 13, 'w', 'G_III', '', 108.0, 120.0, 132.0),
	(39, 14, 15, 'w', 'G_III', '', 119.0, 133.0, 146.0),
	(39, 16, 17, 'w', 'G_III', '', 131.0, 145.0, 160.0),
	(39, 18, 19, 'w', 'G_III', '', 221.0, 245.0, 270.0),
	(39, 20, 24, 'w', 'G_III', '', 221.0, 245.0, 270.0),
	(39, 25, 29, 'w', 'G_III', '', 221.0, 245.0, 270.0),
	(39, 30, 34, 'w', 'G_III', '', 209.0, 233.0, 256.0),
	(39, 35, 39, 'w', 'G_III', '', 209.0, 233.0, 256.0),
	(39, 40, 44, 'w', 'G_III', '', 198.0, 220.0, 242.0),
	(39, 45, 49, 'w', 'G_III', '', 187.0, 208.0, 228.0),
	(39, 50, 54, 'w', 'G_III', '', 176.0, 195.0, 215.0),
	(39, 55, 59, 'w', 'G_III', '', 164.0, 183.0, 201.0),
	(39, 60, 64, 'w', 'G_III', '', 153.0, 170.0, 187.0),
	(39, 65, 69, 'w', 'G_III', '', 142.0, 158.0, 173.0),
	(39, 70, 74, 'w', 'G_III', '', 131.0, 145.0, 160.0),
	(39, 75, 79, 'w', 'G_III', '', 119.0, 133.0, 146.0),
	(39, 80, 84, 'w', 'G_III', '', 108.0, 120.0, 132.0),
	(39, 85, 89, 'w', 'G_III', '', 97.0, 108.0, 118.0),
	(39, 90, 200, 'w', 'G_III', '', 86.0, 95.0, 105.0),
	(39, 0, 7, 'm', 'G_III', '', 146.0, 163.0, 179.0),
	(39, 8, 9, 'm', 'G_III', '', 158.0, 175.0, 193.0),
	(39, 10, 11, 'm', 'G_III', '', 169.0, 188.0, 206.0),
	(39, 12, 13, 'm', 'G_III', '', 180.0, 200.0, 220.0),
	(39, 14, 15, 'm', 'G_III', '', 191.0, 213.0, 234.0),
	(39, 16, 17, 'm', 'G_III', '', 203.0, 225.0, 248.0),
	(39, 18, 19, 'm', 'G_III', '', 293.0, 325.0, 358.0),
	(39, 20, 24, 'm', 'G_III', '', 293.0, 325.0, 358.0),
	(39, 25, 29, 'm', 'G_III', '', 293.0, 325.0, 358.0),
	(39, 30, 34, 'm', 'G_III', '', 281.0, 313.0, 344.0),
	(39, 35, 39, 'm', 'G_III', '', 281.0, 313.0, 344.0),
	(39, 40, 44, 'm', 'G_III', '', 270.0, 300.0, 330.0),
	(39, 45, 49, 'm', 'G_III', '', 259.0, 288.0, 316.0),
	(39, 50, 54, 'm', 'G_III', '', 248.0, 275.0, 303.0),
	(39, 55, 59, 'm', 'G_III', '', 236.0, 263.0, 289.0),
	(39, 60, 64, 'm', 'G_III', '', 225.0, 250.0, 275.0),
	(39, 65, 69, 'm', 'G_III', '', 214.0, 238.0, 261.0),
	(39, 70, 74, 'm', 'G_III', '', 203.0, 225.0, 248.0),
	(39, 75, 79, 'm', 'G_III', '', 191.0, 213.0, 234.0),
	(39, 80, 84, 'm', 'G_III', '', 180.0, 200.0, 220.0),
	(39, 85, 89, 'm', 'G_III', '', 169.0, 188.0, 206.0),
	(39, 90, 200, 'm', 'G_III', '', 158.0, 175.0, 193.0),
	(40, 0, 7, 'w', 'G_III', '', 234.0, 260.0, 286.0),
	(40, 8, 9, 'w', 'G_III', '', 248.0, 275.0, 303.0),
	(40, 10, 11, 'w', 'G_III', '', 261.0, 290.0, 319.0),
	(40, 12, 13, 'w', 'G_III', '', 275.0, 305.0, 336.0),
	(40, 14, 15, 'w', 'G_III', '', 288.0, 320.0, 352.0),
	(40, 16, 17, 'w', 'G_III', '', 302.0, 335.0, 369.0),
	(40, 18, 19, 'w', 'G_III', '', 392.0, 435.0, 479.0),
	(40, 20, 24, 'w', 'G_III', '', 392.0, 435.0, 479.0),
	(40, 25, 29, 'w', 'G_III', '', 392.0, 435.0, 479.0),
	(40, 30, 34, 'w', 'G_III', '', 378.0, 420.0, 462.0),
	(40, 35, 39, 'w', 'G_III', '', 378.0, 420.0, 462.0),
	(40, 40, 44, 'w', 'G_III', '', 365.0, 405.0, 446.0),
	(40, 45, 49, 'w', 'G_III', '', 351.0, 390.0, 429.0),
	(40, 50, 54, 'w', 'G_III', '', 338.0, 375.0, 413.0),
	(40, 55, 59, 'w', 'G_III', '', 324.0, 360.0, 396.0),
	(40, 60, 64, 'w', 'G_III', '', 311.0, 345.0, 380.0),
	(40, 65, 69, 'w', 'G_III', '', 297.0, 330.0, 363.0),
	(40, 70, 74, 'w', 'G_III', '', 284.0, 315.0, 347.0),
	(40, 75, 79, 'w', 'G_III', '', 270.0, 300.0, 330.0),
	(40, 80, 84, 'w', 'G_III', '', 257.0, 285.0, 314.0),
	(40, 85, 89, 'w', 'G_III', '', 243.0, 270.0, 297.0),
	(40, 90, 200, 'w', 'G_III', '', 230.0, 255.0, 281.0),
	(40, 0, 7, 'm', 'G_III', '', 315.0, 350.0, 385.0),
	(40, 8, 9, 'm', 'G_III', '', 329.0, 365.0, 402.0),
	(40, 10, 11, 'm', 'G_III', '', 342.0, 380.0, 418.0),
	(40, 12, 13, 'm', 'G_III', '', 356.0, 395.0, 435.0),
	(40, 14, 15, 'm', 'G_III', '', 369.0, 410.0, 451.0),
	(40, 16, 17, 'm', 'G_III', '', 383.0, 425.0, 468.0),
	(40, 18, 19, 'm', 'G_III', '', 473.0, 525.0, 578.0),
	(40, 20, 24, 'm', 'G_III', '', 473.0, 525.0, 578.0),
	(40, 25, 29, 'm', 'G_III', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'G_III', '', 459.0, 510.0, 561.0),
	(40, 35, 39, 'm', 'G_III', '', 459.0, 510.0, 561.0),
	(40, 40, 44, 'm', 'G_III', '', 446.0, 495.0, 545.0),
	(40, 45, 49, 'm', 'G_III', '', 432.0, 480.0, 528.0),
	(40, 50, 54, 'm', 'G_III', '', 419.0, 465.0, 512.0),
	(40, 55, 59, 'm', 'G_III', '', 405.0, 450.0, 495.0),
	(40, 60, 64, 'm', 'G_III', '', 392.0, 435.0, 479.0),
	(40, 65, 69, 'm', 'G_III', '', 378.0, 420.0, 462.0),
	(40, 70, 74, 'm', 'G_III', '', 365.0, 405.0, 446.0),
	(40, 75, 79, 'm', 'G_III', '', 351.0, 390.0, 429.0),
	(40, 80, 84, 'm', 'G_III', '', 338.0, 375.0, 413.0),
	(40, 85, 89, 'm', 'G_III', '', 324.0, 360.0, 396.0),
	(40, 90, 200, 'm', 'G_III', '', 311.0, 345.0, 380.0),
	(41, 0, 7, 'w', 'G_III', '', 167.0, 185.0, 204.0),
	(41, 8, 9, 'w', 'G_III', '', 180.0, 200.0, 220.0),
	(41, 10, 11, 'w', 'G_III', '', 194.0, 215.0, 237.0),
	(41, 12, 13, 'w', 'G_III', '', 207.0, 230.0, 253.0),
	(41, 14, 15, 'w', 'G_III', '', 221.0, 245.0, 270.0),
	(41, 16, 17, 'w', 'G_III', '', 234.0, 260.0, 286.0),
	(41, 18, 19, 'w', 'G_III', '', 324.0, 360.0, 396.0),
	(41, 20, 24, 'w', 'G_III', '', 324.0, 360.0, 396.0),
	(41, 25, 29, 'w', 'G_III', '', 324.0, 360.0, 396.0),
	(41, 30, 34, 'w', 'G_III', '', 311.0, 345.0, 380.0),
	(41, 35, 39, 'w', 'G_III', '', 311.0, 345.0, 380.0),
	(41, 40, 44, 'w', 'G_III', '', 297.0, 330.0, 363.0),
	(41, 45, 49, 'w', 'G_III', '', 284.0, 315.0, 347.0),
	(41, 50, 54, 'w', 'G_III', '', 270.0, 300.0, 330.0),
	(41, 55, 59, 'w', 'G_III', '', 257.0, 285.0, 314.0),
	(41, 60, 64, 'w', 'G_III', '', 243.0, 270.0, 297.0),
	(41, 65, 69, 'w', 'G_III', '', 230.0, 255.0, 281.0),
	(41, 70, 74, 'w', 'G_III', '', 216.0, 240.0, 264.0),
	(41, 75, 79, 'w', 'G_III', '', 203.0, 225.0, 248.0),
	(41, 80, 84, 'w', 'G_III', '', 189.0, 210.0, 231.0),
	(41, 85, 89, 'w', 'G_III', '', 176.0, 195.0, 215.0),
	(41, 90, 200, 'w', 'G_III', '', 162.0, 180.0, 198.0),
	(41, 0, 7, 'm', 'G_III', '', 243.0, 270.0, 297.0),
	(41, 8, 9, 'm', 'G_III', '', 257.0, 285.0, 314.0),
	(41, 10, 11, 'm', 'G_III', '', 270.0, 300.0, 330.0),
	(41, 12, 13, 'm', 'G_III', '', 284.0, 315.0, 347.0),
	(41, 14, 15, 'm', 'G_III', '', 297.0, 330.0, 363.0),
	(41, 16, 17, 'm', 'G_III', '', 311.0, 345.0, 380.0),
	(41, 18, 19, 'm', 'G_III', '', 401.0, 445.0, 490.0),
	(41, 20, 24, 'm', 'G_III', '', 401.0, 445.0, 490.0),
	(41, 25, 29, 'm', 'G_III', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'G_III', '', 387.0, 430.0, 473.0),
	(41, 35, 39, 'm', 'G_III', '', 387.0, 430.0, 473.0),
	(41, 40, 44, 'm', 'G_III', '', 374.0, 415.0, 457.0),
	(41, 45, 49, 'm', 'G_III', '', 360.0, 400.0, 440.0),
	(41, 50, 54, 'm', 'G_III', '', 347.0, 385.0, 424.0),
	(41, 55, 59, 'm', 'G_III', '', 333.0, 370.0, 407.0),
	(41, 60, 64, 'm', 'G_III', '', 320.0, 355.0, 391.0),
	(41, 65, 69, 'm', 'G_III', '', 306.0, 340.0, 374.0),
	(41, 70, 74, 'm', 'G_III', '', 293.0, 325.0, 358.0),
	(41, 75, 79, 'm', 'G_III', '', 279.0, 310.0, 341.0),
	(41, 80, 84, 'm', 'G_III', '', 266.0, 295.0, 325.0),
	(41, 85, 89, 'm', 'G_III', '', 252.0, 280.0, 308.0),
	(41, 90, 200, 'm', 'G_III', '', 239.0, 265.0, 292.0),
	(42, 0, 7, 'w', 'G_III', '', 234.0, 260.0, 286.0),
	(42, 8, 9, 'w', 'G_III', '', 248.0, 275.0, 303.0),
	(42, 10, 11, 'w', 'G_III', '', 261.0, 290.0, 319.0),
	(42, 12, 13, 'w', 'G_III', '', 275.0, 305.0, 336.0),
	(42, 14, 15, 'w', 'G_III', '', 288.0, 320.0, 352.0),
	(42, 16, 17, 'w', 'G_III', '', 302.0, 335.0, 369.0),
	(42, 18, 19, 'w', 'G_III', '', 329.0, 365.0, 402.0),
	(42, 20, 24, 'w', 'G_III', '', 329.0, 365.0, 402.0),
	(42, 25, 29, 'w', 'G_III', '', 329.0, 365.0, 402.0),
	(42, 30, 34, 'w', 'G_III', '', 315.0, 350.0, 385.0),
	(42, 35, 39, 'w', 'G_III', '', 315.0, 350.0, 385.0),
	(42, 40, 44, 'w', 'G_III', '', 302.0, 335.0, 369.0),
	(42, 45, 49, 'w', 'G_III', '', 288.0, 320.0, 352.0),
	(42, 50, 54, 'w', 'G_III', '', 275.0, 305.0, 336.0),
	(42, 55, 59, 'w', 'G_III', '', 261.0, 290.0, 319.0),
	(42, 60, 64, 'w', 'G_III', '', 248.0, 275.0, 303.0),
	(42, 65, 69, 'w', 'G_III', '', 234.0, 260.0, 286.0),
	(42, 70, 74, 'w', 'G_III', '', 221.0, 245.0, 270.0),
	(42, 75, 79, 'w', 'G_III', '', 207.0, 230.0, 253.0),
	(42, 80, 84, 'w', 'G_III', '', 194.0, 215.0, 237.0),
	(42, 85, 89, 'w', 'G_III', '', 180.0, 200.0, 220.0),
	(42, 90, 200, 'w', 'G_III', '', 167.0, 185.0, 204.0),
	(42, 0, 7, 'm', 'G_III', '', 315.0, 350.0, 385.0),
	(42, 8, 9, 'm', 'G_III', '', 329.0, 365.0, 402.0),
	(42, 10, 11, 'm', 'G_III', '', 342.0, 380.0, 418.0),
	(42, 12, 13, 'm', 'G_III', '', 356.0, 395.0, 435.0),
	(42, 14, 15, 'm', 'G_III', '', 369.0, 410.0, 451.0),
	(42, 16, 17, 'm', 'G_III', '', 383.0, 425.0, 468.0),
	(42, 18, 19, 'm', 'G_III', '', 405.0, 450.0, 495.0),
	(42, 20, 24, 'm', 'G_III', '', 405.0, 450.0, 495.0),
	(42, 25, 29, 'm', 'G_III', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'G_III', '', 392.0, 435.0, 479.0),
	(42, 35, 39, 'm', 'G_III', '', 392.0, 435.0, 479.0),
	(42, 40, 44, 'm', 'G_III', '', 378.0, 420.0, 462.0),
	(42, 45, 49, 'm', 'G_III', '', 365.0, 405.0, 446.0),
	(42, 50, 54, 'm', 'G_III', '', 351.0, 390.0, 429.0),
	(42, 55, 59, 'm', 'G_III', '', 338.0, 375.0, 413.0),
	(42, 60, 64, 'm', 'G_III', '', 324.0, 360.0, 396.0),
	(42, 65, 69, 'm', 'G_III', '', 311.0, 345.0, 380.0),
	(42, 70, 74, 'm', 'G_III', '', 297.0, 330.0, 363.0),
	(42, 75, 79, 'm', 'G_III', '', 284.0, 315.0, 347.0),
	(42, 80, 84, 'm', 'G_III', '', 270.0, 300.0, 330.0),
	(42, 85, 89, 'm', 'G_III', '', 257.0, 285.0, 314.0),
	(42, 90, 200, 'm', 'G_III', '', 243.0, 270.0, 297.0),
	(43, 0, 7, 'w', 'G_III', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'w', 'G_III', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'w', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'w', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'w', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'w', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'w', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'w', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'w', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 0, 7, 'm', 'G_III', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'm', 'G_III', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'm', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'm', 'G_III', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'm', 'G_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'm', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'm', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'm', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'm', 'G_III', '', 10.0, 12.500000000000002, 15.0),
	(44, 12, 13, 'w', 'G_III', '', 3.63, 4.02, 4.4),
	(44, 14, 15, 'w', 'G_III', '', 4.21, 4.59, 4.97),
	(44, 16, 17, 'w', 'G_III', '', 4.4, 4.78, 5.16),
	(44, 18, 19, 'w', 'G_III', '', 4.97, 5.36, 5.74),
	(44, 20, 24, 'w', 'G_III', '', 4.97, 5.36, 5.74),
	(44, 25, 29, 'w', 'G_III', '', 4.97, 5.36, 5.74),
	(44, 30, 34, 'w', 'G_III', '', 4.78, 5.16, 5.55),
	(44, 35, 39, 'w', 'G_III', '', 4.59, 4.97, 5.36),
	(44, 40, 44, 'w', 'G_III', '', 4.21, 4.59, 4.97),
	(44, 45, 49, 'w', 'G_III', '', 4.02, 4.4, 4.78),
	(44, 50, 54, 'w', 'G_III', '', 3.95, 4.59, 5.36),
	(44, 55, 59, 'w', 'G_III', '', 3.83, 4.4, 4.97),
	(44, 60, 64, 'w', 'G_III', '', 3.57, 4.21, 4.78),
	(44, 65, 69, 'w', 'G_III', '', 3.37, 4.02, 4.78),
	(44, 70, 74, 'w', 'G_III', '', 3.18, 3.83, 4.59),
	(44, 75, 79, 'w', 'G_III', '', 3.18, 4.02, 4.78),
	(44, 80, 84, 'w', 'G_III', '', 3.06, 3.83, 4.4),
	(44, 85, 89, 'w', 'G_III', '', 2.87, 3.44, 4.21),
	(44, 90, 200, 'w', 'G_III', '', 2.49, 3.25, 3.83),
	(44, 12, 13, 'm', 'G_III', '', 4.78, 5.16, 5.55),
	(44, 14, 15, 'm', 'G_III', '', 5.36, 5.74, 6.12),
	(44, 16, 17, 'm', 'G_III', '', 5.74, 6.12, 6.5),
	(44, 18, 19, 'm', 'G_III', '', 5.93, 6.31, 6.69),
	(44, 20, 24, 'm', 'G_III', '', 5.93, 6.5, 6.89),
	(44, 25, 29, 'm', 'G_III', '', 5.74, 6.31, 6.69),
	(44, 30, 34, 'm', 'G_III', '', 5.36, 5.93, 6.31),
	(44, 35, 39, 'm', 'G_III', '', 5.16, 5.55, 6.12),
	(44, 40, 44, 'm', 'G_III', '', 4.78, 5.36, 5.93),
	(44, 45, 49, 'm', 'G_III', '', 4.59, 5.16, 5.74),
	(44, 50, 54, 'm', 'G_III', '', 4.52, 5.1, 5.67),
	(44, 55, 59, 'm', 'G_III', '', 4.45, 5.03, 5.6),
	(44, 60, 64, 'm', 'G_III', '', 4.39, 4.96, 5.53),
	(44, 65, 69, 'm', 'G_III', '', 4.32, 4.89, 5.47),
	(44, 70, 74, 'm', 'G_III', '', 4.25, 4.82, 5.4),
	(44, 75, 79, 'm', 'G_III', '', 4.18, 4.76, 5.33),
	(44, 80, 84, 'm', 'G_III', '', 4.11, 4.69, 5.26),
	(44, 85, 89, 'm', 'G_III', '', 4.05, 4.62, 5.19),
	(44, 90, 200, 'm', 'G_III', '', 3.98, 4.55, 5.13),
	(46, 18, 19, 'w', 'G_III', '', 9.4, 10.6, 11.6),
	(46, 20, 24, 'w', 'G_III', '', 9.6, 10.8, 11.8),
	(46, 25, 29, 'w', 'G_III', '', 9.6, 10.8, 11.8),
	(46, 30, 34, 'w', 'G_III', '', 8.8, 10.0, 11.0),
	(46, 35, 39, 'w', 'G_III', '', 8.4, 9.6, 10.6),
	(46, 40, 44, 'w', 'G_III', '', 7.8, 9.0, 10.0),
	(46, 45, 49, 'w', 'G_III', '', 7.4, 8.6, 9.6),
	(46, 50, 54, 'w', 'G_III', '', 6.6, 8.0, 9.2),
	(46, 55, 59, 'w', 'G_III', '', 6.2, 7.6, 8.8),
	(46, 60, 64, 'w', 'G_III', '', 5.8, 7.2, 8.4),
	(46, 65, 69, 'w', 'G_III', '', 5.4, 6.8, 8.0),
	(46, 70, 74, 'w', 'G_III', '', 5.2, 6.6, 7.8),
	(46, 75, 79, 'w', 'G_III', '', 4.8, 6.2, 7.4),
	(46, 80, 84, 'w', 'G_III', '', 4.4, 5.8, 7.0),
	(46, 85, 89, 'w', 'G_III', '', 3.8, 5.2, 6.4),
	(46, 90, 200, 'w', 'G_III', '', 3.0, 4.4, 5.6),
	(46, 18, 19, 'm', 'G_III', '', 12.6, 14.4, 16.2),
	(46, 20, 24, 'm', 'G_III', '', 13.2, 15.2, 16.8),
	(46, 25, 29, 'm', 'G_III', '', 13.0, 15.0, 16.6),
	(46, 30, 34, 'm', 'G_III', '', 12.0, 14.0, 16.0),
	(46, 35, 39, 'm', 'G_III', '', 11.4, 13.4, 15.4),
	(46, 40, 44, 'm', 'G_III', '', 11.2, 13.2, 15.2),
	(46, 45, 49, 'm', 'G_III', '', 10.8, 12.8, 15.0),
	(46, 50, 54, 'm', 'G_III', '', 10.2, 12.4, 14.6),
	(46, 55, 59, 'm', 'G_III', '', 9.4, 11.6, 14.0),
	(46, 60, 64, 'm', 'G_III', '', 9.0, 11.2, 13.6),
	(46, 65, 69, 'm', 'G_III', '', 8.0, 10.2, 12.2),
	(46, 70, 74, 'm', 'G_III', '', 7.4, 9.6, 11.6),
	(46, 75, 79, 'm', 'G_III', '', 6.4, 8.4, 10.4),
	(46, 80, 84, 'm', 'G_III', '', 5.6, 7.6, 9.6),
	(46, 85, 89, 'm', 'G_III', '', 4.8, 6.6, 8.4),
	(46, 90, 200, 'm', 'G_III', '', 4.2, 6.0, 7.8),
	(53, 0, 7, 'w', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'G_III', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'G_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'G_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'G_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(55, 0, 7, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'w', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 0, 7, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 8, 9, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 10, 11, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 12, 13, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 14, 15, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 16, 17, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 18, 19, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 20, 24, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 25, 29, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 30, 34, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 35, 39, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 40, 44, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 45, 49, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 50, 54, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 55, 59, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 60, 64, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 65, 69, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 70, 74, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 75, 79, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 80, 84, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 85, 89, 'm', 'G_III', '', 1.0, 2.0, 3.0),
	(55, 90, 200, 'm', 'G_III', '', 1.0, 2.0, 3.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(7, 0, 7, 'w', 'H_I', '100 m', 7.250000000000001, 5.366666666666666, 4.433333333333333),
	(7, 8, 9, 'w', 'H_I', '100 m', 6.433333333333333, 4.9, 4.1499999999999995),
	(7, 10, 11, 'w', 'H_I', '100 m', 5.9, 4.5, 3.8499999999999996),
	(7, 12, 13, 'w', 'H_I', '200 m', 11.933333333333334, 9.033333333333333, 7.7),
	(7, 14, 15, 'w', 'H_I', '200 m', 10.533333333333333, 8.166666666666666, 7.0),
	(7, 16, 17, 'w', 'H_I', '200 m', 9.533333333333333, 7.35, 6.366666666666666),
	(7, 18, 19, 'w', 'H_I', '400 m', 19.31666666666667, 14.816666666666666, 12.883333333333333),
	(7, 20, 24, 'w', 'H_I', '400 m', 18.983333333333334, 14.583333333333332, 12.6),
	(7, 25, 29, 'w', 'H_I', '400 m', 20.533333333333335, 14.766666666666667, 13.066666666666665),
	(7, 30, 34, 'w', 'H_I', '400 m', 23.216666666666665, 16.566666666666666, 13.65),
	(7, 35, 39, 'w', 'H_I', '400 m', 25.76666666666667, 17.916666666666668, 14.233333333333334),
	(7, 40, 44, 'w', 'H_I', '400 m', 27.366666666666664, 19.366666666666664, 14.933333333333334),
	(7, 45, 49, 'w', 'H_I', '400 m', 28.45, 20.3, 15.049999999999999),
	(7, 50, 54, 'w', 'H_I', '200 m', 14.483333333333333, 10.500000000000002, 8.049999999999999),
	(7, 55, 59, 'w', 'H_I', '200 m', 14.966666666666667, 10.733333333333333, 8.333333333333332),
	(7, 60, 64, 'w', 'H_I', '200 m', 15.299999999999999, 10.899999999999999, 8.516666666666667),
	(7, 65, 69, 'w', 'H_I', '200 m', 15.633333333333335, 11.016666666666666, 8.566666666666666),
	(7, 70, 74, 'w', 'H_I', '200 m', 15.966666666666667, 11.25, 8.866666666666665),
	(7, 75, 79, 'w', 'H_I', '100 m', 8.25, 5.833333333333333, 4.55),
	(7, 80, 84, 'w', 'H_I', '100 m', 8.383333333333335, 5.95, 4.733333333333334),
	(7, 85, 89, 'w', 'H_I', '100 m', 8.516666666666667, 6.116666666666667, 4.966666666666667),
	(7, 90, 200, 'w', 'H_I', '100 m', 8.65, 6.2333333333333325, 5.133333333333334),
	(7, 0, 7, 'm', 'H_I', '100 m', 7.250000000000001, 5.133333333333334, 4.316666666666667),
	(7, 8, 9, 'm', 'H_I', '100 m', 6.433333333333333, 4.733333333333334, 3.966666666666667),
	(7, 10, 11, 'm', 'H_I', '100 m', 5.633333333333333, 4.433333333333333, 3.616666666666667),
	(7, 12, 13, 'm', 'H_I', '200 m', 10.866666666666665, 8.049999999999999, 6.816666666666667),
	(7, 14, 15, 'm', 'H_I', '200 m', 9.666666666666668, 7.166666666666666, 6.183333333333334),
	(7, 16, 17, 'm', 'H_I', '200 m', 8.85, 6.766666666666667, 5.833333333333333),
	(7, 18, 19, 'm', 'H_I', '400 m', 18.183333333333334, 13.883333333333333, 11.899999999999999),
	(7, 20, 24, 'm', 'H_I', '400 m', 17.85, 13.65, 11.500000000000002),
	(7, 25, 29, 'm', 'H_I', '400 m', 18.650000000000002, 14.0, 11.899999999999999),
	(7, 30, 34, 'm', 'H_I', '400 m', 20.733333333333334, 15.049999999999999, 12.6),
	(7, 35, 39, 'm', 'H_I', '400 m', 23.216666666666665, 16.8, 13.466666666666665),
	(7, 40, 44, 'm', 'H_I', '400 m', 26.099999999999998, 18.5, 14.299999999999999),
	(7, 45, 49, 'm', 'H_I', '400 m', 27.76666666666667, 19.48333333333333, 14.466666666666665),
	(7, 50, 54, 'm', 'H_I', '200 m', 14.016666666666666, 10.033333333333333, 7.516666666666666),
	(7, 55, 59, 'm', 'H_I', '200 m', 14.350000000000001, 10.2, 7.933333333333333),
	(7, 60, 64, 'm', 'H_I', '200 m', 14.616666666666665, 10.316666666666666, 8.983333333333333),
	(7, 65, 69, 'm', 'H_I', '200 m', 14.833333333333334, 10.55, 8.049999999999999),
	(7, 70, 74, 'm', 'H_I', '200 m', 14.833333333333334, 10.666666666666668, 8.116666666666667),
	(7, 75, 79, 'm', 'H_I', '100 m', 7.583333333333333, 5.366666666666666, 4.250000000000001),
	(7, 80, 84, 'm', 'H_I', '100 m', 7.6499999999999995, 5.483333333333333, 4.316666666666667),
	(7, 85, 89, 'm', 'H_I', '100 m', 7.6499999999999995, 5.6000000000000005, 4.5),
	(7, 90, 200, 'm', 'H_I', '100 m', 7.85, 5.716666666666666, 4.733333333333334),
	(10, 0, 7, 'w', 'H_I', '', 2.8, 5.0, 6.6),
	(10, 8, 9, 'w', 'H_I', '', 4.2, 6.6, 8.3),
	(10, 10, 11, 'w', 'H_I', '', 5.1, 8.3, 9.9),
	(10, 12, 13, 'w', 'H_I', '', 7.0, 9.9, 12.1),
	(10, 0, 7, 'm', 'H_I', '', 5.6, 8.3, 9.4),
	(10, 8, 9, 'm', 'H_I', '', 7.9, 11.0, 12.7),
	(10, 10, 11, 'm', 'H_I', '', 9.8, 13.8, 15.4),
	(11, 14, 15, 'w', 'H_I', '', 9.4, 13.2, 14.9),
	(11, 16, 17, 'w', 'H_I', '', 11.2, 14.9, 17.1),
	(11, 18, 19, 'w', 'H_I', '', 13.0, 17.2, 18.9),
	(11, 20, 24, 'w', 'H_I', '', 13.3, 17.6, 19.2),
	(11, 25, 29, 'w', 'H_I', '', 13.3, 17.6, 19.2),
	(11, 30, 34, 'w', 'H_I', '', 12.2, 16.3, 17.9),
	(11, 35, 39, 'w', 'H_I', '', 11.6, 15.6, 17.2),
	(11, 40, 44, 'w', 'H_I', '', 10.8, 14.6, 16.3),
	(11, 45, 49, 'w', 'H_I', '', 10.2, 14.0, 15.6),
	(11, 50, 54, 'w', 'H_I', '', 9.1, 13.0, 15.0),
	(11, 55, 59, 'w', 'H_I', '', 8.6, 12.4, 14.3),
	(11, 60, 64, 'w', 'H_I', '', 8.0, 11.7, 13.7),
	(11, 65, 69, 'w', 'H_I', '', 7.5, 11.1, 13.0),
	(11, 70, 74, 'w', 'H_I', '', 7.2, 10.7, 12.7),
	(11, 75, 79, 'w', 'H_I', '', 6.6, 10.1, 12.0),
	(11, 80, 84, 'w', 'H_I', '', 6.1, 9.4, 11.4),
	(11, 85, 89, 'w', 'H_I', '', 5.2, 8.5, 10.4),
	(11, 90, 200, 'w', 'H_I', '', 4.1, 7.2, 9.1),
	(11, 12, 13, 'm', 'H_I', '', 12.2, 16.5, 18.2),
	(11, 14, 15, 'm', 'H_I', '', 14.0, 18.7, 20.4),
	(11, 16, 17, 'm', 'H_I', '', 15.9, 20.9, 23.1),
	(11, 18, 19, 'm', 'H_I', '', 17.4, 23.4, 26.3),
	(11, 20, 24, 'm', 'H_I', '', 18.2, 24.7, 27.3),
	(11, 25, 29, 'm', 'H_I', '', 18.0, 24.4, 27.0),
	(11, 30, 34, 'm', 'H_I', '', 16.6, 22.8, 26.0),
	(11, 35, 39, 'm', 'H_I', '', 15.7, 21.8, 25.0),
	(11, 40, 44, 'm', 'H_I', '', 15.5, 21.5, 24.7),
	(11, 45, 49, 'm', 'H_I', '', 14.9, 20.8, 24.4),
	(11, 50, 54, 'm', 'H_I', '', 14.1, 20.2, 23.7),
	(11, 55, 59, 'm', 'H_I', '', 13.0, 18.9, 22.8),
	(11, 60, 64, 'm', 'H_I', '', 12.4, 18.2, 22.1),
	(11, 65, 69, 'm', 'H_I', '', 11.1, 16.6, 19.8),
	(11, 70, 74, 'm', 'H_I', '', 10.2, 15.6, 18.9),
	(11, 75, 79, 'm', 'H_I', '', 8.8, 13.7, 16.9),
	(11, 80, 84, 'm', 'H_I', '', 7.7, 12.4, 15.6),
	(11, 85, 89, 'm', 'H_I', '', 6.6, 10.7, 13.7),
	(11, 90, 200, 'm', 'H_I', '', 5.8, 9.8, 12.7),
	(13, 12, 13, 'w', 'H_I', '2 kg', 2.2, 2.9, 3.2),
	(13, 14, 15, 'w', 'H_I', '2 kg', 2.6, 3.3, 3.6),
	(13, 16, 17, 'w', 'H_I', '2 kg', 2.7, 3.4, 3.7),
	(13, 18, 19, 'w', 'H_I', '3 kg', 3.0, 3.9, 4.1),
	(13, 20, 24, 'w', 'H_I', '3 kg', 3.0, 3.9, 4.1),
	(13, 25, 29, 'w', 'H_I', '3 kg', 3.0, 3.9, 4.1),
	(13, 30, 34, 'w', 'H_I', '3 kg', 2.9, 3.7, 4.0),
	(13, 35, 39, 'w', 'H_I', '3 kg', 2.8, 3.6, 3.9),
	(13, 40, 44, 'w', 'H_I', '3 kg', 2.6, 3.3, 3.6),
	(13, 45, 49, 'w', 'H_I', '3 kg', 2.5, 3.2, 3.4),
	(13, 50, 54, 'w', 'H_I', '2 kg', 2.5, 3.3, 3.9),
	(13, 55, 59, 'w', 'H_I', '2 kg', 2.3, 3.2, 3.6),
	(13, 60, 64, 'w', 'H_I', '2 kg', 2.2, 3.0, 3.4),
	(13, 65, 69, 'w', 'H_I', '2 kg', 2.1, 2.9, 3.4),
	(13, 70, 74, 'w', 'H_I', '2 kg', 2.0, 2.8, 3.3),
	(13, 75, 79, 'w', 'H_I', '2 kg', 2.0, 2.9, 3.4),
	(13, 80, 84, 'w', 'H_I', '2 kg', 1.9, 2.8, 3.2),
	(13, 85, 89, 'w', 'H_I', '2 kg', 1.8, 2.5, 3.0),
	(13, 90, 200, 'w', 'H_I', '2 kg', 1.5, 2.3, 2.8),
	(13, 12, 13, 'm', 'H_I', '2 kg', 2.9, 3.7, 4.0),
	(13, 14, 15, 'm', 'H_I', '2 kg', 3.3, 4.1, 4.4),
	(13, 16, 17, 'm', 'H_I', '3 kg', 3.5, 4.4, 4.7),
	(13, 18, 19, 'm', 'H_I', '4 kg', 3.6, 4.5, 4.8),
	(13, 20, 24, 'm', 'H_I', '4 kg', 3.6, 4.7, 5.0),
	(13, 25, 29, 'm', 'H_I', '4 kg', 3.5, 4.5, 4.8),
	(13, 30, 34, 'm', 'H_I', '4 kg', 3.3, 4.3, 4.5),
	(13, 35, 39, 'm', 'H_I', '4 kg', 3.2, 4.0, 4.4),
	(13, 40, 44, 'm', 'H_I', '4 kg', 2.9, 3.9, 4.3),
	(13, 45, 49, 'm', 'H_I', '4 kg', 2.8, 3.7, 4.1),
	(13, 50, 54, 'm', 'H_I', '3 kg', 2.9, 3.9, 4.4),
	(13, 55, 59, 'm', 'H_I', '3 kg', 2.8, 3.7, 4.1),
	(13, 60, 64, 'm', 'H_I', '3 kg', 2.8, 3.9, 4.4),
	(13, 65, 69, 'm', 'H_I', '3 kg', 2.7, 3.7, 4.1),
	(13, 70, 74, 'm', 'H_I', '3 kg', 2.8, 3.7, 4.3),
	(13, 75, 79, 'm', 'H_I', '3 kg', 2.7, 3.6, 4.1),
	(13, 80, 84, 'm', 'H_I', '2 kg', 2.6, 3.4, 4.0),
	(13, 85, 89, 'm', 'H_I', '2 kg', 2.3, 3.3, 3.7),
	(13, 90, 200, 'm', 'H_I', '2 kg', 2.1, 2.9, 3.4),
	(18, 0, 7, 'w', 'H_I', '', 1.57, 1.24, 1.07),
	(18, 8, 9, 'w', 'H_I', '', 1.46, 1.14, 1.01),
	(18, 10, 11, 'w', 'H_I', '', 1.38, 1.09, 0.56),
	(18, 12, 13, 'w', 'H_I', '', 1.28, 1.03, 0.51),
	(18, 14, 15, 'w', 'H_I', '', 1.23, 1.0, 0.47),
	(18, 16, 17, 'w', 'H_I', '', 1.17, 0.56, 0.44),
	(18, 18, 19, 'w', 'H_I', '', 1.14, 0.52, 0.4),
	(18, 20, 24, 'w', 'H_I', '', 1.13, 0.52, 0.4),
	(18, 25, 29, 'w', 'H_I', '', 1.15, 0.55, 0.42),
	(18, 30, 34, 'w', 'H_I', '', 1.22, 0.58, 0.46),
	(18, 35, 39, 'w', 'H_I', '', 1.31, 1.03, 0.48),
	(18, 40, 44, 'w', 'H_I', '', 1.41, 1.09, 0.51),
	(18, 45, 49, 'w', 'H_I', '', 1.51, 1.17, 0.55),
	(18, 50, 54, 'w', 'H_I', '', 2.01, 1.25, 1.01),
	(18, 55, 59, 'w', 'H_I', '', 2.1, 1.33, 1.07),
	(18, 60, 64, 'w', 'H_I', '', 2.17, 1.37, 1.11),
	(18, 65, 69, 'w', 'H_I', '', 2.22, 1.42, 1.15),
	(18, 70, 74, 'w', 'H_I', '', 2.29, 1.45, 1.19),
	(18, 75, 79, 'w', 'H_I', '', 2.34, 1.5, 1.23),
	(18, 80, 84, 'w', 'H_I', '', 2.4, 1.54, 1.28),
	(18, 85, 89, 'w', 'H_I', '', 2.45, 1.57, 1.31),
	(18, 90, 200, 'w', 'H_I', '', 2.48, 1.59, 1.33),
	(18, 0, 7, 'm', 'H_I', '', 1.56, 1.23, 1.06),
	(18, 8, 9, 'm', 'H_I', '', 1.43, 1.12, 0.57),
	(18, 10, 11, 'm', 'H_I', '', 1.31, 1.03, 0.49),
	(18, 12, 13, 'm', 'H_I', '', 1.23, 0.59, 0.46),
	(18, 14, 15, 'm', 'H_I', '', 1.18, 0.56, 0.44),
	(18, 16, 17, 'm', 'H_I', '', 1.14, 0.53, 0.41),
	(18, 18, 19, 'm', 'H_I', '', 1.1, 0.5, 0.38),
	(18, 20, 24, 'm', 'H_I', '', 1.08, 0.48, 0.34),
	(18, 25, 29, 'm', 'H_I', '', 1.13, 0.5, 0.36),
	(18, 30, 34, 'm', 'H_I', '', 1.19, 0.52, 0.37),
	(18, 35, 39, 'm', 'H_I', '', 1.28, 0.58, 0.4),
	(18, 40, 44, 'm', 'H_I', '', 1.37, 1.04, 0.41),
	(18, 45, 49, 'm', 'H_I', '', 1.46, 1.11, 0.45),
	(18, 50, 54, 'm', 'H_I', '', 1.53, 1.17, 0.5),
	(18, 55, 59, 'm', 'H_I', '', 2.03, 1.21, 0.55),
	(18, 60, 64, 'm', 'H_I', '', 2.09, 1.25, 0.59),
	(18, 65, 69, 'm', 'H_I', '', 2.12, 1.29, 1.02),
	(18, 70, 74, 'm', 'H_I', '', 2.19, 1.34, 1.08),
	(18, 75, 79, 'm', 'H_I', '', 2.25, 1.4, 1.13),
	(18, 80, 84, 'm', 'H_I', '', 2.29, 1.45, 1.19),
	(18, 85, 89, 'm', 'H_I', '', 2.3, 1.47, 1.23),
	(18, 90, 200, 'm', 'H_I', '', 2.31, 1.5, 1.28),
	(29, 0, 7, 'w', 'H_I', '', 11.083333333333334, 8.500000000000002, 7.216666666666667),
	(29, 8, 9, 'w', 'H_I', '', 10.916666666666668, 8.216666666666669, 7.083333333333333),
	(29, 10, 11, 'w', 'H_I', '', 10.433333333333334, 7.933333333333333, 6.800000000000001),
	(29, 12, 13, 'w', 'H_I', '', 10.100000000000001, 7.5, 6.366666666666666),
	(29, 14, 15, 'w', 'H_I', '', 9.766666666666667, 7.366666666666666, 6.083333333333333),
	(29, 16, 17, 'w', 'H_I', '', 9.45, 6.933333333333333, 5.800000000000001),
	(29, 0, 7, 'm', 'H_I', '', 11.083333333333334, 8.500000000000002, 7.216666666666667),
	(29, 8, 9, 'm', 'H_I', '', 10.583333333333332, 7.933333333333333, 6.6499999999999995),
	(29, 10, 11, 'm', 'H_I', '', 9.933333333333334, 7.366666666666666, 6.083333333333333),
	(29, 12, 13, 'm', 'H_I', '', 9.283333333333333, 6.800000000000001, 5.533333333333334),
	(29, 14, 15, 'm', 'H_I', '', 8.466666666666665, 6.2333333333333325, 5.1),
	(29, 16, 17, 'm', 'H_I', '', 7.983333333333333, 5.800000000000001, 4.666666666666667),
	(31, 18, 19, 'w', 'H_I', '', 14.366666666666667, 11.299999999999999, 10.100000000000001),
	(31, 20, 24, 'w', 'H_I', '', 14.033333333333333, 11.0, 9.8),
	(31, 25, 29, 'w', 'H_I', '', 14.266666666666667, 11.2, 10.0),
	(31, 30, 34, 'w', 'H_I', '', 14.833333333333334, 11.7, 10.500000000000002),
	(31, 35, 39, 'w', 'H_I', '', 15.183333333333332, 12.0, 10.8),
	(31, 40, 44, 'w', 'H_I', '', 15.749999999999998, 12.4, 11.100000000000001),
	(31, 45, 49, 'w', 'H_I', '', 16.45, 12.899999999999999, 11.299999999999999),
	(31, 50, 54, 'w', 'H_I', '', 17.13333333333333, 13.299999999999999, 11.500000000000002),
	(31, 55, 59, 'w', 'H_I', '', 17.816666666666663, 13.7, 11.899999999999999),
	(31, 60, 64, 'w', 'H_I', '', 18.283333333333335, 14.100000000000001, 12.299999999999999),
	(31, 65, 69, 'w', 'H_I', '', 18.75, 14.500000000000002, 12.7),
	(31, 70, 74, 'w', 'H_I', '', 19.083333333333336, 14.8, 13.0),
	(31, 75, 79, 'w', 'H_I', '', 19.666666666666664, 15.299999999999999, 13.500000000000002),
	(31, 80, 84, 'w', 'H_I', '', 20.46666666666667, 16.0, 14.2),
	(31, 85, 89, 'w', 'H_I', '', 21.383333333333333, 16.8, 15.0),
	(31, 90, 200, 'w', 'H_I', '', 22.416666666666668, 17.700000000000003, 15.899999999999999),
	(31, 18, 19, 'm', 'H_I', '', 12.299999999999999, 9.500000000000002, 8.299999999999999),
	(31, 20, 24, 'm', 'H_I', '', 11.966666666666667, 9.2, 8.0),
	(31, 25, 29, 'm', 'H_I', '', 12.183333333333332, 9.4, 8.2),
	(31, 30, 34, 'm', 'H_I', '', 12.766666666666667, 9.899999999999999, 8.7),
	(31, 35, 39, 'm', 'H_I', '', 13.683333333333334, 10.4, 9.0),
	(31, 40, 44, 'm', 'H_I', '', 14.483333333333333, 11.100000000000001, 9.500000000000002),
	(31, 45, 49, 'm', 'H_I', '', 15.299999999999999, 11.7, 9.899999999999999),
	(31, 50, 54, 'm', 'H_I', '', 16.099999999999998, 12.2, 10.4),
	(31, 55, 59, 'm', 'H_I', '', 16.45, 12.500000000000002, 10.7),
	(31, 60, 64, 'm', 'H_I', '', 16.9, 12.899999999999999, 11.100000000000001),
	(31, 65, 69, 'm', 'H_I', '', 17.249999999999996, 13.2, 11.4),
	(31, 70, 74, 'm', 'H_I', '', 17.48333333333333, 13.4, 11.6),
	(31, 75, 79, 'm', 'H_I', '', 17.93333333333333, 13.8, 12.0),
	(31, 80, 84, 'm', 'H_I', '', 18.283333333333335, 14.100000000000001, 12.299999999999999),
	(31, 85, 89, 'm', 'H_I', '', 18.966666666666665, 14.7, 12.899999999999999),
	(31, 90, 200, 'm', 'H_I', '', 20.583333333333336, 16.099999999999998, 14.299999999999999),
	(34, 0, 7, 'w', 'H_I', '', 8.0, 12.0, 17.0),
	(34, 8, 9, 'w', 'H_I', '', 10.0, 15.0, 20.0),
	(34, 10, 11, 'w', 'H_I', '', 15.0, 20.0, 30.0),
	(34, 12, 13, 'w', 'H_I', '', 20.0, 30.0, 40.0),
	(34, 14, 15, 'w', 'H_I', '', 30.0, 40.0, 50.0),
	(34, 16, 17, 'w', 'H_I', '', 45.0, 60.0, 75.0),
	(34, 0, 7, 'm', 'H_I', '', 8.0, 12.0, 17.0),
	(34, 8, 9, 'm', 'H_I', '', 10.0, 15.0, 20.0),
	(34, 10, 11, 'm', 'H_I', '', 15.0, 20.0, 30.0),
	(34, 12, 13, 'm', 'H_I', '', 20.0, 30.0, 40.0),
	(34, 14, 15, 'm', 'H_I', '', 30.0, 40.0, 50.0),
	(34, 16, 17, 'm', 'H_I', '', 45.0, 60.0, 75.0),
	(35, 0, 7, 'w', 'H_I', '5 km', 60.88333333333333, 48.199999999999996, 42.63333333333334),
	(35, 8, 9, 'w', 'H_I', '5 km', 55.88333333333333, 43.199999999999996, 37.8),
	(35, 10, 11, 'w', 'H_I', '10 km', 104.53333333333332, 77.39999999999999, 63.9),
	(35, 12, 13, 'w', 'H_I', '10 km', 93.15, 71.10000000000001, 60.3),
	(35, 14, 15, 'w', 'H_I', '10 km', 78.66666666666667, 58.49999999999999, 51.3),
	(35, 16, 17, 'w', 'H_I', '10 km', 67.26666666666667, 51.3, 45.0),
	(35, 18, 19, 'w', 'H_I', '20 km', 119.01666666666668, 93.6, 83.7),
	(35, 20, 24, 'w', 'H_I', '20 km', 117.98333333333333, 92.7, 81.9),
	(35, 25, 29, 'w', 'H_I', '20 km', 115.91666666666666, 90.9, 81.0),
	(35, 30, 34, 'w', 'H_I', '20 km', 117.98333333333333, 92.7, 81.9),
	(35, 35, 39, 'w', 'H_I', '20 km', 124.2, 95.39999999999999, 84.6),
	(35, 40, 44, 'w', 'H_I', '20 km', 132.48333333333332, 99.9, 89.10000000000001),
	(35, 45, 49, 'w', 'H_I', '20 km', 138.68333333333334, 105.30000000000001, 92.7),
	(35, 50, 54, 'w', 'H_I', '20 km', 142.83333333333334, 109.80000000000001, 96.30000000000001),
	(35, 55, 59, 'w', 'H_I', '20 km', 148.0, 113.39999999999999, 99.9),
	(35, 60, 64, 'w', 'H_I', '20 km', 153.18333333333337, 117.0, 102.6),
	(35, 65, 69, 'w', 'H_I', '20 km', 156.2833333333333, 119.7, 105.30000000000001),
	(35, 70, 74, 'w', 'H_I', '20 km', 161.46666666666667, 123.30000000000001, 108.9),
	(35, 75, 79, 'w', 'H_I', '20 km', 168.7, 126.9, 113.39999999999999),
	(35, 80, 84, 'w', 'H_I', '20 km', 174.91666666666669, 135.0, 117.9),
	(35, 85, 89, 'w', 'H_I', '20 km', 185.26666666666665, 144.0, 124.2),
	(35, 90, 200, 'w', 'H_I', '20 km', 192.51666666666668, 149.4, 130.50000000000003),
	(35, 0, 7, 'm', 'H_I', '5 km', 59.849999999999994, 47.3, 41.9),
	(35, 8, 9, 'm', 'H_I', '5 km', 54.849999999999994, 42.3, 36.9),
	(35, 10, 11, 'm', 'H_I', '10 km', 100.39999999999999, 73.80000000000001, 60.3),
	(35, 12, 13, 'm', 'H_I', '10 km', 89.01666666666668, 66.6, 56.7),
	(35, 14, 15, 'm', 'H_I', '10 km', 66.23333333333333, 50.400000000000006, 43.199999999999996),
	(35, 16, 17, 'm', 'H_I', '10 km', 55.88333333333333, 42.3, 36.9),
	(35, 18, 19, 'm', 'H_I', '20 km', 97.28333333333333, 76.5, 69.30000000000001),
	(35, 20, 24, 'm', 'H_I', '20 km', 96.25000000000001, 75.6, 67.5),
	(35, 25, 29, 'm', 'H_I', '20 km', 103.5, 80.10000000000001, 70.2),
	(35, 30, 34, 'm', 'H_I', '20 km', 110.75, 84.6, 72.9),
	(35, 35, 39, 'm', 'H_I', '20 km', 120.06666666666668, 90.0, 74.7),
	(35, 40, 44, 'm', 'H_I', '20 km', 130.41666666666666, 93.6, 78.30000000000001),
	(35, 45, 49, 'm', 'H_I', '20 km', 136.61666666666667, 99.0, 81.0),
	(35, 50, 54, 'm', 'H_I', '20 km', 141.79999999999998, 102.6, 83.7),
	(35, 55, 59, 'm', 'H_I', '20 km', 145.93333333333334, 105.30000000000001, 85.5),
	(35, 60, 64, 'm', 'H_I', '20 km', 148.0, 108.0, 86.39999999999999),
	(35, 65, 69, 'm', 'H_I', '20 km', 150.06666666666666, 108.9, 87.30000000000001),
	(35, 70, 74, 'm', 'H_I', '20 km', 152.15, 110.7, 89.10000000000001),
	(35, 75, 79, 'm', 'H_I', '20 km', 154.21666666666667, 113.39999999999999, 92.7),
	(35, 80, 84, 'm', 'H_I', '20 km', 157.31666666666666, 116.10000000000001, 95.39999999999999),
	(35, 85, 89, 'm', 'H_I', '20 km', 160.41666666666666, 119.7, 99.9),
	(35, 90, 200, 'm', 'H_I', '20 km', 163.53333333333333, 122.39999999999999, 104.39999999999999),
	(39, 0, 7, 'w', 'H_I', '', 109.0, 143.0, 157.0),
	(39, 8, 9, 'w', 'H_I', '', 119.0, 155.0, 171.0),
	(39, 10, 11, 'w', 'H_I', '', 128.0, 168.0, 184.0),
	(39, 12, 13, 'w', 'H_I', '', 138.0, 180.0, 198.0),
	(39, 14, 15, 'w', 'H_I', '', 147.0, 193.0, 212.0),
	(39, 16, 17, 'w', 'H_I', '', 157.0, 205.0, 226.0),
	(39, 18, 19, 'w', 'H_I', '', 233.0, 305.0, 336.0),
	(39, 20, 24, 'w', 'H_I', '', 233.0, 305.0, 336.0),
	(39, 25, 29, 'w', 'H_I', '', 233.0, 305.0, 336.0),
	(39, 30, 34, 'w', 'H_I', '', 224.0, 293.0, 322.0),
	(39, 35, 39, 'w', 'H_I', '', 224.0, 293.0, 322.0),
	(39, 40, 44, 'w', 'H_I', '', 214.0, 280.0, 308.0),
	(39, 45, 49, 'w', 'H_I', '', 205.0, 268.0, 294.0),
	(39, 50, 54, 'w', 'H_I', '', 195.0, 255.0, 281.0),
	(39, 55, 59, 'w', 'H_I', '', 186.0, 243.0, 267.0),
	(39, 60, 64, 'w', 'H_I', '', 176.0, 230.0, 253.0),
	(39, 65, 69, 'w', 'H_I', '', 166.0, 218.0, 239.0),
	(39, 70, 74, 'w', 'H_I', '', 157.0, 205.0, 226.0),
	(39, 75, 79, 'w', 'H_I', '', 147.0, 193.0, 212.0),
	(39, 80, 84, 'w', 'H_I', '', 138.0, 180.0, 198.0),
	(39, 85, 89, 'w', 'H_I', '', 128.0, 168.0, 184.0),
	(39, 90, 200, 'w', 'H_I', '', 119.0, 155.0, 171.0),
	(39, 0, 7, 'm', 'H_I', '', 159.0, 208.0, 228.0),
	(39, 8, 9, 'm', 'H_I', '', 168.0, 220.0, 242.0),
	(39, 10, 11, 'm', 'H_I', '', 178.0, 233.0, 256.0),
	(39, 12, 13, 'm', 'H_I', '', 187.0, 245.0, 270.0),
	(39, 14, 15, 'm', 'H_I', '', 197.0, 258.0, 283.0),
	(39, 16, 17, 'm', 'H_I', '', 207.0, 270.0, 297.0),
	(39, 18, 19, 'm', 'H_I', '', 283.0, 370.0, 407.0),
	(39, 20, 24, 'm', 'H_I', '', 283.0, 370.0, 407.0),
	(39, 25, 29, 'm', 'H_I', '', 283.0, 370.0, 407.0),
	(39, 30, 34, 'm', 'H_I', '', 273.0, 358.0, 393.0),
	(39, 35, 39, 'm', 'H_I', '', 273.0, 358.0, 393.0),
	(39, 40, 44, 'm', 'H_I', '', 264.0, 345.0, 380.0),
	(39, 45, 49, 'm', 'H_I', '', 254.0, 333.0, 366.0),
	(39, 50, 54, 'm', 'H_I', '', 245.0, 320.0, 352.0),
	(39, 55, 59, 'm', 'H_I', '', 235.0, 308.0, 338.0),
	(39, 60, 64, 'm', 'H_I', '', 226.0, 295.0, 325.0),
	(39, 65, 69, 'm', 'H_I', '', 216.0, 283.0, 311.0),
	(39, 70, 74, 'm', 'H_I', '', 207.0, 270.0, 297.0),
	(39, 75, 79, 'm', 'H_I', '', 197.0, 258.0, 283.0),
	(39, 80, 84, 'm', 'H_I', '', 187.0, 245.0, 270.0),
	(39, 85, 89, 'm', 'H_I', '', 178.0, 233.0, 256.0),
	(39, 90, 200, 'm', 'H_I', '', 168.0, 220.0, 242.0),
	(40, 0, 7, 'w', 'H_I', '', 245.0, 320.0, 352.0),
	(40, 8, 9, 'w', 'H_I', '', 256.0, 335.0, 369.0),
	(40, 10, 11, 'w', 'H_I', '', 268.0, 350.0, 385.0),
	(40, 12, 13, 'w', 'H_I', '', 279.0, 365.0, 402.0),
	(40, 14, 15, 'w', 'H_I', '', 291.0, 380.0, 418.0),
	(40, 16, 17, 'w', 'H_I', '', 302.0, 395.0, 435.0),
	(40, 18, 19, 'w', 'H_I', '', 379.0, 495.0, 545.0),
	(40, 20, 24, 'w', 'H_I', '', 379.0, 495.0, 545.0),
	(40, 25, 29, 'w', 'H_I', '', 379.0, 495.0, 545.0),
	(40, 30, 34, 'w', 'H_I', '', 367.0, 480.0, 528.0),
	(40, 35, 39, 'w', 'H_I', '', 367.0, 480.0, 528.0),
	(40, 40, 44, 'w', 'H_I', '', 356.0, 465.0, 512.0),
	(40, 45, 49, 'w', 'H_I', '', 344.0, 450.0, 495.0),
	(40, 50, 54, 'w', 'H_I', '', 333.0, 435.0, 479.0),
	(40, 55, 59, 'w', 'H_I', '', 321.0, 420.0, 462.0),
	(40, 60, 64, 'w', 'H_I', '', 310.0, 405.0, 446.0),
	(40, 65, 69, 'w', 'H_I', '', 298.0, 390.0, 429.0),
	(40, 70, 74, 'w', 'H_I', '', 287.0, 375.0, 413.0),
	(40, 75, 79, 'w', 'H_I', '', 275.0, 360.0, 396.0),
	(40, 80, 84, 'w', 'H_I', '', 264.0, 345.0, 380.0),
	(40, 85, 89, 'w', 'H_I', '', 252.0, 330.0, 363.0),
	(40, 90, 200, 'w', 'H_I', '', 241.0, 315.0, 347.0),
	(40, 0, 7, 'm', 'H_I', '', 302.0, 395.0, 435.0),
	(40, 8, 9, 'm', 'H_I', '', 314.0, 410.0, 451.0),
	(40, 10, 11, 'm', 'H_I', '', 325.0, 425.0, 468.0),
	(40, 12, 13, 'm', 'H_I', '', 337.0, 440.0, 484.0),
	(40, 14, 15, 'm', 'H_I', '', 348.0, 455.0, 501.0),
	(40, 16, 17, 'm', 'H_I', '', 360.0, 470.0, 517.0),
	(40, 18, 19, 'm', 'H_I', '', 436.0, 570.0, 627.0),
	(40, 20, 24, 'm', 'H_I', '', 436.0, 570.0, 627.0),
	(40, 25, 29, 'm', 'H_I', '', 493.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'H_I', '', 425.0, 555.0, 611.0),
	(40, 35, 39, 'm', 'H_I', '', 425.0, 555.0, 611.0),
	(40, 40, 44, 'm', 'H_I', '', 413.0, 540.0, 594.0),
	(40, 45, 49, 'm', 'H_I', '', 402.0, 525.0, 578.0),
	(40, 50, 54, 'm', 'H_I', '', 390.0, 510.0, 561.0),
	(40, 55, 59, 'm', 'H_I', '', 379.0, 495.0, 545.0),
	(40, 60, 64, 'm', 'H_I', '', 367.0, 480.0, 528.0),
	(40, 65, 69, 'm', 'H_I', '', 356.0, 465.0, 512.0),
	(40, 70, 74, 'm', 'H_I', '', 344.0, 450.0, 495.0),
	(40, 75, 79, 'm', 'H_I', '', 333.0, 435.0, 479.0),
	(40, 80, 84, 'm', 'H_I', '', 321.0, 420.0, 462.0),
	(40, 85, 89, 'm', 'H_I', '', 310.0, 405.0, 446.0),
	(40, 90, 200, 'm', 'H_I', '', 298.0, 390.0, 429.0),
	(41, 0, 7, 'w', 'H_I', '', 187.0, 245.0, 270.0),
	(41, 8, 9, 'w', 'H_I', '', 199.0, 260.0, 286.0),
	(41, 10, 11, 'w', 'H_I', '', 210.0, 275.0, 303.0),
	(41, 12, 13, 'w', 'H_I', '', 222.0, 290.0, 319.0),
	(41, 14, 15, 'w', 'H_I', '', 233.0, 305.0, 336.0),
	(41, 16, 17, 'w', 'H_I', '', 245.0, 320.0, 352.0),
	(41, 18, 19, 'w', 'H_I', '', 321.0, 420.0, 462.0),
	(41, 20, 24, 'w', 'H_I', '', 321.0, 420.0, 462.0),
	(41, 25, 29, 'w', 'H_I', '', 321.0, 420.0, 462.0),
	(41, 30, 34, 'w', 'H_I', '', 310.0, 405.0, 446.0),
	(41, 35, 39, 'w', 'H_I', '', 310.0, 405.0, 446.0),
	(41, 40, 44, 'w', 'H_I', '', 298.0, 390.0, 429.0),
	(41, 45, 49, 'w', 'H_I', '', 287.0, 375.0, 413.0),
	(41, 50, 54, 'w', 'H_I', '', 275.0, 360.0, 396.0),
	(41, 55, 59, 'w', 'H_I', '', 264.0, 345.0, 380.0),
	(41, 60, 64, 'w', 'H_I', '', 252.0, 330.0, 363.0),
	(41, 65, 69, 'w', 'H_I', '', 241.0, 315.0, 347.0),
	(41, 70, 74, 'w', 'H_I', '', 230.0, 300.0, 330.0),
	(41, 75, 79, 'w', 'H_I', '', 218.0, 285.0, 314.0),
	(41, 80, 84, 'w', 'H_I', '', 207.0, 270.0, 297.0),
	(41, 85, 89, 'w', 'H_I', '', 195.0, 255.0, 281.0),
	(41, 90, 200, 'w', 'H_I', '', 184.0, 240.0, 264.0),
	(41, 0, 7, 'm', 'H_I', '', 241.0, 315.0, 347.0),
	(41, 8, 9, 'm', 'H_I', '', 252.0, 330.0, 363.0),
	(41, 10, 11, 'm', 'H_I', '', 264.0, 345.0, 380.0),
	(41, 12, 13, 'm', 'H_I', '', 275.0, 360.0, 396.0),
	(41, 14, 15, 'm', 'H_I', '', 287.0, 375.0, 413.0),
	(41, 16, 17, 'm', 'H_I', '', 298.0, 390.0, 429.0),
	(41, 18, 19, 'm', 'H_I', '', 375.0, 490.0, 539.0),
	(41, 20, 24, 'm', 'H_I', '', 375.0, 490.0, 539.0),
	(41, 25, 29, 'm', 'H_I', '', 432.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'H_I', '', 363.0, 475.0, 523.0),
	(41, 35, 39, 'm', 'H_I', '', 363.0, 475.0, 523.0),
	(41, 40, 44, 'm', 'H_I', '', 352.0, 460.0, 506.0),
	(41, 45, 49, 'm', 'H_I', '', 340.0, 445.0, 490.0),
	(41, 50, 54, 'm', 'H_I', '', 329.0, 430.0, 473.0),
	(41, 55, 59, 'm', 'H_I', '', 317.0, 415.0, 457.0),
	(41, 60, 64, 'm', 'H_I', '', 306.0, 400.0, 440.0),
	(41, 65, 69, 'm', 'H_I', '', 295.0, 385.0, 424.0),
	(41, 70, 74, 'm', 'H_I', '', 283.0, 370.0, 407.0),
	(41, 75, 79, 'm', 'H_I', '', 272.0, 355.0, 391.0),
	(41, 80, 84, 'm', 'H_I', '', 260.0, 340.0, 374.0),
	(41, 85, 89, 'm', 'H_I', '', 249.0, 325.0, 358.0),
	(41, 90, 200, 'm', 'H_I', '', 237.0, 310.0, 341.0),
	(42, 0, 7, 'w', 'H_I', '', 191.0, 250.0, 275.0),
	(42, 8, 9, 'w', 'H_I', '', 203.0, 265.0, 292.0),
	(42, 10, 11, 'w', 'H_I', '', 214.0, 280.0, 308.0),
	(42, 12, 13, 'w', 'H_I', '', 226.0, 295.0, 325.0),
	(42, 14, 15, 'w', 'H_I', '', 237.0, 310.0, 341.0),
	(42, 16, 17, 'w', 'H_I', '', 249.0, 325.0, 358.0),
	(42, 18, 19, 'w', 'H_I', '', 325.0, 425.0, 468.0),
	(42, 20, 24, 'w', 'H_I', '', 325.0, 425.0, 468.0),
	(42, 25, 29, 'w', 'H_I', '', 325.0, 425.0, 468.0),
	(42, 30, 34, 'w', 'H_I', '', 314.0, 410.0, 451.0),
	(42, 35, 39, 'w', 'H_I', '', 314.0, 410.0, 451.0),
	(42, 40, 44, 'w', 'H_I', '', 302.0, 395.0, 435.0),
	(42, 45, 49, 'w', 'H_I', '', 291.0, 380.0, 418.0),
	(42, 50, 54, 'w', 'H_I', '', 279.0, 365.0, 402.0),
	(42, 55, 59, 'w', 'H_I', '', 268.0, 350.0, 385.0),
	(42, 60, 64, 'w', 'H_I', '', 256.0, 335.0, 369.0),
	(42, 65, 69, 'w', 'H_I', '', 245.0, 320.0, 352.0),
	(42, 70, 74, 'w', 'H_I', '', 233.0, 305.0, 336.0),
	(42, 75, 79, 'w', 'H_I', '', 222.0, 290.0, 319.0),
	(42, 80, 84, 'w', 'H_I', '', 210.0, 275.0, 303.0),
	(42, 85, 89, 'w', 'H_I', '', 199.0, 260.0, 286.0),
	(42, 90, 200, 'w', 'H_I', '', 187.0, 245.0, 270.0),
	(42, 0, 7, 'm', 'H_I', '', 245.0, 320.0, 352.0),
	(42, 8, 9, 'm', 'H_I', '', 256.0, 335.0, 369.0),
	(42, 10, 11, 'm', 'H_I', '', 268.0, 350.0, 385.0),
	(42, 12, 13, 'm', 'H_I', '', 279.0, 365.0, 402.0),
	(42, 14, 15, 'm', 'H_I', '', 291.0, 380.0, 418.0),
	(42, 16, 17, 'm', 'H_I', '', 302.0, 395.0, 435.0),
	(42, 18, 19, 'm', 'H_I', '', 379.0, 495.0, 545.0),
	(42, 20, 24, 'm', 'H_I', '', 379.0, 495.0, 545.0),
	(42, 25, 29, 'm', 'H_I', '', 436.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'H_I', '', 367.0, 480.0, 528.0),
	(42, 35, 39, 'm', 'H_I', '', 367.0, 480.0, 528.0),
	(42, 40, 44, 'm', 'H_I', '', 356.0, 465.0, 512.0),
	(42, 45, 49, 'm', 'H_I', '', 344.0, 450.0, 495.0),
	(42, 50, 54, 'm', 'H_I', '', 333.0, 435.0, 479.0),
	(42, 55, 59, 'm', 'H_I', '', 321.0, 420.0, 462.0),
	(42, 60, 64, 'm', 'H_I', '', 310.0, 405.0, 446.0),
	(42, 65, 69, 'm', 'H_I', '', 298.0, 390.0, 429.0),
	(42, 70, 74, 'm', 'H_I', '', 287.0, 375.0, 413.0),
	(42, 75, 79, 'm', 'H_I', '', 275.0, 360.0, 396.0),
	(42, 80, 84, 'm', 'H_I', '', 264.0, 345.0, 380.0),
	(42, 85, 89, 'm', 'H_I', '', 252.0, 330.0, 363.0),
	(42, 90, 200, 'm', 'H_I', '', 241.0, 315.0, 347.0),
	(44, 12, 13, 'w', 'H_I', '', 3.7, 4.9, 5.4),
	(44, 14, 15, 'w', 'H_I', '', 4.4, 5.6, 6.1),
	(44, 16, 17, 'w', 'H_I', '', 4.6, 5.8, 6.3),
	(44, 18, 19, 'w', 'H_I', '', 5.1, 6.6, 7.0),
	(44, 20, 24, 'w', 'H_I', '', 5.1, 6.6, 7.0),
	(44, 25, 29, 'w', 'H_I', '', 5.1, 6.6, 7.0),
	(44, 30, 34, 'w', 'H_I', '', 4.9, 6.3, 6.8),
	(44, 35, 39, 'w', 'H_I', '', 4.8, 6.1, 6.6),
	(44, 40, 44, 'w', 'H_I', '', 4.4, 5.6, 6.1),
	(44, 45, 49, 'w', 'H_I', '', 4.3, 5.4, 5.8),
	(44, 50, 54, 'w', 'H_I', '', 4.3, 5.6, 6.6),
	(44, 55, 59, 'w', 'H_I', '', 3.9, 5.4, 6.1),
	(44, 60, 64, 'w', 'H_I', '', 3.7, 5.1, 5.8),
	(44, 65, 69, 'w', 'H_I', '', 3.6, 4.9, 5.8),
	(44, 70, 74, 'w', 'H_I', '', 3.4, 4.8, 5.6),
	(44, 75, 79, 'w', 'H_I', '', 3.4, 4.9, 5.8),
	(44, 80, 84, 'w', 'H_I', '', 3.2, 4.8, 5.4),
	(44, 85, 89, 'w', 'H_I', '', 3.1, 4.3, 5.1),
	(44, 90, 200, 'w', 'H_I', '', 2.6, 3.9, 4.8),
	(44, 12, 13, 'm', 'H_I', '', 4.9, 6.3, 6.8),
	(44, 14, 15, 'm', 'H_I', '', 5.6, 7.0, 7.5),
	(44, 16, 17, 'm', 'H_I', '', 6.0, 7.5, 8.0),
	(44, 18, 19, 'm', 'H_I', '', 6.1, 7.7, 8.2),
	(44, 20, 24, 'm', 'H_I', '', 6.1, 8.0, 8.5),
	(44, 25, 29, 'm', 'H_I', '', 6.0, 7.7, 8.2),
	(44, 30, 34, 'm', 'H_I', '', 5.6, 7.3, 7.7),
	(44, 35, 39, 'm', 'H_I', '', 5.4, 6.8, 7.5),
	(44, 40, 44, 'm', 'H_I', '', 4.9, 6.6, 7.3),
	(44, 45, 49, 'm', 'H_I', '', 4.8, 6.3, 7.0),
	(44, 50, 54, 'm', 'H_I', '', 4.9, 6.6, 7.5),
	(44, 55, 59, 'm', 'H_I', '', 4.8, 6.3, 7.0),
	(44, 60, 64, 'm', 'H_I', '', 4.8, 6.6, 7.5),
	(44, 65, 69, 'm', 'H_I', '', 4.6, 6.3, 7.0),
	(44, 70, 74, 'm', 'H_I', '', 4.8, 6.3, 7.3),
	(44, 75, 79, 'm', 'H_I', '', 4.6, 6.1, 7.0),
	(44, 80, 84, 'm', 'H_I', '', 4.4, 5.8, 6.8),
	(44, 85, 89, 'm', 'H_I', '', 3.9, 5.6, 6.3),
	(44, 90, 200, 'm', 'H_I', '', 3.6, 4.9, 5.8),
	(46, 0, 7, 'w', 'H_I', '', 2.3, 4.5, 6.1),
	(46, 8, 9, 'w', 'H_I', '', 3.7, 6.1, 7.8),
	(46, 10, 11, 'w', 'H_I', '', 4.6, 7.8, 9.4),
	(46, 12, 13, 'w', 'H_I', '', 6.0, 8.9, 11.1),
	(46, 14, 15, 'w', 'H_I', '', 8.4, 12.2, 13.9),
	(46, 16, 17, 'w', 'H_I', '', 10.2, 13.9, 16.1),
	(46, 18, 19, 'w', 'H_I', '', 12.0, 16.2, 17.9),
	(46, 20, 24, 'w', 'H_I', '', 12.3, 16.6, 18.2),
	(46, 25, 29, 'w', 'H_I', '', 12.3, 16.6, 18.2),
	(46, 30, 34, 'w', 'H_I', '', 11.2, 15.3, 16.9),
	(46, 35, 39, 'w', 'H_I', '', 10.6, 14.6, 16.2),
	(46, 40, 44, 'w', 'H_I', '', 9.8, 13.6, 15.3),
	(46, 45, 49, 'w', 'H_I', '', 9.2, 13.0, 14.6),
	(46, 50, 54, 'w', 'H_I', '', 8.1, 12.0, 14.0),
	(46, 55, 59, 'w', 'H_I', '', 7.6, 11.4, 13.3),
	(46, 60, 64, 'w', 'H_I', '', 7.0, 10.7, 12.7),
	(46, 65, 69, 'w', 'H_I', '', 6.5, 10.1, 12.0),
	(46, 70, 74, 'w', 'H_I', '', 6.2, 9.7, 11.7),
	(46, 75, 79, 'w', 'H_I', '', 5.6, 9.1, 11.0),
	(46, 80, 84, 'w', 'H_I', '', 5.1, 8.4, 10.4),
	(46, 85, 89, 'w', 'H_I', '', 4.2, 7.5, 9.4),
	(46, 90, 200, 'w', 'H_I', '', 3.1, 6.2, 8.1),
	(46, 0, 7, 'm', 'H_I', '', 5.1, 7.8, 8.9),
	(46, 8, 9, 'm', 'H_I', '', 7.4, 10.5, 12.2),
	(46, 10, 11, 'm', 'H_I', '', 9.3, 13.3, 14.9),
	(46, 12, 13, 'm', 'H_I', '', 11.2, 15.5, 17.2),
	(46, 14, 15, 'm', 'H_I', '', 13.0, 17.7, 19.4),
	(46, 16, 17, 'm', 'H_I', '', 14.9, 19.9, 22.1),
	(46, 18, 19, 'm', 'H_I', '', 16.4, 22.4, 25.3),
	(46, 20, 24, 'm', 'H_I', '', 17.2, 23.7, 26.3),
	(46, 25, 29, 'm', 'H_I', '', 17.0, 23.4, 26.0),
	(46, 30, 34, 'm', 'H_I', '', 15.6, 21.8, 25.0),
	(46, 35, 39, 'm', 'H_I', '', 14.7, 20.8, 24.0),
	(46, 40, 44, 'm', 'H_I', '', 14.5, 20.5, 23.7),
	(46, 45, 49, 'm', 'H_I', '', 13.9, 19.8, 23.4),
	(46, 50, 54, 'm', 'H_I', '', 13.1, 19.2, 22.7),
	(46, 55, 59, 'm', 'H_I', '', 12.0, 17.9, 21.8),
	(46, 60, 64, 'm', 'H_I', '', 11.4, 17.2, 21.1),
	(46, 65, 69, 'm', 'H_I', '', 10.1, 15.6, 18.8),
	(46, 70, 74, 'm', 'H_I', '', 9.2, 14.6, 17.9),
	(46, 75, 79, 'm', 'H_I', '', 7.8, 12.7, 15.9),
	(46, 80, 84, 'm', 'H_I', '', 6.7, 11.4, 14.6),
	(46, 85, 89, 'm', 'H_I', '', 5.6, 9.7, 12.7),
	(46, 90, 200, 'm', 'H_I', '', 4.8, 8.8, 11.7),
	(48, 0, 7, 'w', 'H_I', '30 m', 17.5, 13.5, 12.0),
	(48, 8, 9, 'w', 'H_I', '30 m', 16.2, 12.5, 10.8),
	(48, 10, 11, 'w', 'H_I', '50 m', 24.0, 19.2, 17.3),
	(48, 12, 13, 'w', 'H_I', '50 m', 23.2, 18.2, 16.2),
	(48, 14, 15, 'w', 'H_I', '100 m', 40.6, 32.3, 29.5),
	(48, 16, 17, 'w', 'H_I', '100 m', 38.5, 31.0, 28.5),
	(48, 18, 19, 'w', 'H_I', '100 m', 39.8, 31.4, 29.1),
	(48, 20, 24, 'w', 'H_I', '100 m', 40.4, 31.9, 29.6),
	(48, 25, 29, 'w', 'H_I', '100 m', 41.3, 32.7, 30.4),
	(48, 30, 34, 'w', 'H_I', '100 m', 42.8, 33.8, 31.2),
	(48, 35, 39, 'w', 'H_I', '100 m', 44.6, 35.3, 32.3),
	(48, 40, 44, 'w', 'H_I', '50 m', 24.0, 18.8, 16.7),
	(48, 45, 49, 'w', 'H_I', '50 m', 25.1, 19.6, 17.3),
	(48, 50, 54, 'w', 'H_I', '50 m', 26.0, 20.3, 18.1),
	(48, 55, 59, 'w', 'H_I', '50 m', 27.1, 21.3, 18.8),
	(48, 60, 64, 'w', 'H_I', '50 m', 27.5, 21.7, 19.4),
	(48, 65, 69, 'w', 'H_I', '50 m', 28.0, 22.0, 19.8),
	(48, 70, 74, 'w', 'H_I', '50 m', 28.4, 22.4, 20.1),
	(48, 75, 79, 'w', 'H_I', '50 m', 29.5, 23.4, 21.1),
	(48, 80, 84, 'w', 'H_I', '50 m', 31.2, 24.9, 22.8),
	(48, 85, 89, 'w', 'H_I', '50 m', 33.9, 27.2, 25.1),
	(48, 90, 200, 'w', 'H_I', '50 m', 37.4, 30.2, 28.1),
	(48, 0, 7, 'm', 'H_I', '30 m', 16.8, 12.9, 11.4),
	(48, 8, 9, 'm', 'H_I', '30 m', 15.7, 12.2, 10.8),
	(48, 10, 11, 'm', 'H_I', '50 m', 22.5, 17.7, 16.0),
	(48, 12, 13, 'm', 'H_I', '50 m', 21.2, 16.9, 15.4),
	(48, 14, 15, 'm', 'H_I', '100 m', 37.1, 29.3, 26.8),
	(48, 16, 17, 'm', 'H_I', '100 m', 35.6, 28.1, 25.7),
	(48, 18, 19, 'm', 'H_I', '100 m', 35.0, 27.7, 25.1),
	(48, 20, 24, 'm', 'H_I', '100 m', 34.5, 27.4, 24.7),
	(48, 25, 29, 'm', 'H_I', '100 m', 35.6, 28.1, 25.3),
	(48, 30, 34, 'm', 'H_I', '100 m', 36.7, 28.7, 25.8),
	(48, 35, 39, 'm', 'H_I', '100 m', 38.5, 30.2, 27.0),
	(48, 40, 44, 'm', 'H_I', '50 m', 21.0, 16.5, 14.6),
	(48, 45, 49, 'm', 'H_I', '50 m', 21.9, 16.9, 15.0),
	(48, 50, 54, 'm', 'H_I', '50 m', 22.5, 17.3, 15.6),
	(48, 55, 59, 'm', 'H_I', '50 m', 22.9, 17.9, 16.2),
	(48, 60, 64, 'm', 'H_I', '50 m', 23.6, 18.4, 16.7),
	(48, 65, 69, 'm', 'H_I', '50 m', 24.5, 19.4, 17.3),
	(48, 70, 74, 'm', 'H_I', '50 m', 25.6, 20.3, 18.2),
	(48, 75, 79, 'm', 'H_I', '50 m', 26.7, 21.3, 19.2),
	(48, 80, 84, 'm', 'H_I', '50 m', 28.4, 22.8, 20.7),
	(48, 85, 89, 'm', 'H_I', '50 m', 30.8, 24.9, 22.8),
	(48, 90, 200, 'm', 'H_I', '50 m', 33.9, 27.6, 25.5),
	(50, 0, 7, 'w', 'H_I', '', 1.3, 1.14, 1.06),
	(50, 8, 9, 'w', 'H_I', '', 1.1, 0.54, 0.46),
	(50, 10, 11, 'w', 'H_I', '', 1.03, 0.48, 0.4),
	(50, 12, 13, 'w', 'H_I', '', 0.53, 0.4, 0.35),
	(50, 14, 15, 'w', 'H_I', '', 0.46, 0.36, 0.32),
	(50, 16, 17, 'w', 'H_I', '', 0.43, 0.33, 0.3),
	(50, 18, 19, 'w', 'H_I', '', 0.41, 0.33, 0.29),
	(50, 20, 24, 'w', 'H_I', '', 0.42, 0.33, 0.29),
	(50, 25, 29, 'w', 'H_I', '', 0.43, 0.33, 0.3),
	(50, 30, 34, 'w', 'H_I', '', 0.44, 0.35, 0.32),
	(50, 35, 39, 'w', 'H_I', '', 0.47, 0.36, 0.33),
	(50, 40, 44, 'w', 'H_I', '', 0.5, 0.38, 0.33),
	(50, 45, 49, 'w', 'H_I', '', 0.52, 0.4, 0.34),
	(50, 50, 54, 'w', 'H_I', '', 0.55, 0.42, 0.35),
	(50, 55, 59, 'w', 'H_I', '', 0.57, 0.43, 0.36),
	(50, 60, 64, 'w', 'H_I', '', 1.0, 0.45, 0.37),
	(50, 65, 69, 'w', 'H_I', '', 1.02, 0.46, 0.38),
	(50, 70, 74, 'w', 'H_I', '', 1.05, 0.48, 0.39),
	(50, 75, 79, 'w', 'H_I', '', 1.07, 0.49, 0.41),
	(50, 80, 84, 'w', 'H_I', '', 1.09, 0.51, 0.42),
	(50, 85, 89, 'w', 'H_I', '', 1.12, 0.54, 0.45),
	(50, 90, 200, 'w', 'H_I', '', 1.16, 0.57, 0.47),
	(50, 0, 7, 'm', 'H_I', '', 1.25, 1.09, 1.02),
	(50, 8, 9, 'm', 'H_I', '', 1.05, 0.49, 0.42),
	(50, 10, 11, 'm', 'H_I', '', 1.0, 0.45, 0.39),
	(50, 12, 13, 'm', 'H_I', '', 0.5, 0.39, 0.33),
	(50, 14, 15, 'm', 'H_I', '', 0.41, 0.32, 0.28),
	(50, 16, 17, 'm', 'H_I', '', 0.37, 0.29, 0.25),
	(50, 18, 19, 'm', 'H_I', '', 0.35, 0.27, 0.23),
	(50, 20, 24, 'm', 'H_I', '', 0.34, 0.26, 0.22),
	(50, 25, 29, 'm', 'H_I', '', 0.36, 0.27, 0.22),
	(50, 30, 34, 'm', 'H_I', '', 0.38, 0.27, 0.22),
	(50, 35, 39, 'm', 'H_I', '', 0.41, 0.3, 0.23),
	(50, 40, 44, 'm', 'H_I', '', 0.45, 0.32, 0.24),
	(50, 45, 49, 'm', 'H_I', '', 0.49, 0.34, 0.25),
	(50, 50, 54, 'm', 'H_I', '', 0.51, 0.36, 0.27),
	(50, 55, 59, 'm', 'H_I', '', 0.55, 0.37, 0.27),
	(50, 60, 64, 'm', 'H_I', '', 0.57, 0.39, 0.28),
	(50, 65, 69, 'm', 'H_I', '', 1.0, 0.4, 0.29),
	(50, 70, 74, 'm', 'H_I', '', 1.02, 0.42, 0.3),
	(50, 75, 79, 'm', 'H_I', '', 1.04, 0.44, 0.32),
	(50, 80, 84, 'm', 'H_I', '', 1.07, 0.47, 0.34),
	(50, 85, 89, 'm', 'H_I', '', 1.1, 0.49, 0.36),
	(50, 90, 200, 'm', 'H_I', '', 1.15, 0.53, 0.4),
	(53, 0, 7, 'w', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'H_I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'H_I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'H_I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'H_I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(56, 0, 7, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'w', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 0, 7, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'm', 'H_I', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'm', 'H_I', '', 1.0, 2.0, 3.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(7, 0, 7, 'w', 'H_II', '100 m', 9.316666666666666, 6.9, 5.7),
	(7, 8, 9, 'w', 'H_II', '100 m', 8.283333333333333, 6.3, 5.333333333333334),
	(7, 10, 11, 'w', 'H_II', '100 m', 7.583333333333333, 5.783333333333333, 4.95),
	(7, 12, 13, 'w', 'H_II', '200 m', 15.350000000000001, 11.616666666666665, 9.899999999999999),
	(7, 14, 15, 'w', 'H_II', '200 m', 13.533333333333333, 10.500000000000002, 9.0),
	(7, 16, 17, 'w', 'H_II', '200 m', 12.25, 9.45, 8.183333333333332),
	(7, 18, 19, 'w', 'H_II', '400 m', 24.833333333333332, 19.05, 16.583333333333336),
	(7, 20, 24, 'w', 'H_II', '400 m', 24.416666666666668, 18.75, 16.200000000000003),
	(7, 25, 29, 'w', 'H_II', '400 m', 26.4, 18.966666666666665, 16.8),
	(7, 30, 34, 'w', 'H_II', '400 m', 29.85, 21.3, 17.549999999999997),
	(7, 35, 39, 'w', 'H_II', '400 m', 33.11666666666667, 23.03333333333333, 18.3),
	(7, 40, 44, 'w', 'H_II', '400 m', 35.18333333333333, 24.9, 19.200000000000003),
	(7, 45, 49, 'w', 'H_II', '400 m', 36.56666666666667, 26.099999999999998, 19.35),
	(7, 50, 54, 'w', 'H_II', '200 m', 18.633333333333333, 13.500000000000002, 10.350000000000001),
	(7, 55, 59, 'w', 'H_II', '200 m', 19.233333333333334, 13.8, 10.716666666666667),
	(7, 60, 64, 'w', 'H_II', '200 m', 19.666666666666664, 14.033333333333333, 10.950000000000001),
	(7, 65, 69, 'w', 'H_II', '200 m', 20.099999999999998, 14.183333333333332, 11.016666666666666),
	(7, 70, 74, 'w', 'H_II', '200 m', 20.533333333333335, 14.466666666666665, 11.4),
	(7, 75, 79, 'w', 'H_II', '100 m', 10.616666666666665, 7.5, 5.85),
	(7, 80, 84, 'w', 'H_II', '100 m', 10.783333333333335, 7.6499999999999995, 6.066666666666666),
	(7, 85, 89, 'w', 'H_II', '100 m', 10.950000000000001, 7.866666666666666, 6.366666666666666),
	(7, 90, 200, 'w', 'H_II', '100 m', 11.133333333333333, 8.016666666666666, 6.6000000000000005),
	(7, 0, 7, 'm', 'H_II', '100 m', 9.316666666666666, 6.6000000000000005, 5.55),
	(7, 8, 9, 'm', 'H_II', '100 m', 8.283333333333333, 6.066666666666666, 5.1),
	(7, 10, 11, 'm', 'H_II', '100 m', 7.250000000000001, 5.7, 4.6499999999999995),
	(7, 12, 13, 'm', 'H_II', '200 m', 13.966666666666667, 10.350000000000001, 8.783333333333335),
	(7, 14, 15, 'm', 'H_II', '200 m', 12.416666666666666, 9.216666666666669, 7.95),
	(7, 16, 17, 'm', 'H_II', '200 m', 11.383333333333335, 8.7, 7.5),
	(7, 18, 19, 'm', 'H_II', '400 m', 23.366666666666664, 17.85, 15.299999999999999),
	(7, 20, 24, 'm', 'H_II', '400 m', 22.95, 17.549999999999997, 14.783333333333335),
	(7, 25, 29, 'm', 'H_II', '400 m', 23.983333333333334, 18.0, 15.299999999999999),
	(7, 30, 34, 'm', 'H_II', '400 m', 26.650000000000002, 19.35, 16.200000000000003),
	(7, 35, 39, 'm', 'H_II', '400 m', 29.85, 21.599999999999998, 17.333333333333332),
	(7, 40, 44, 'm', 'H_II', '400 m', 33.55, 23.78333333333333, 18.383333333333333),
	(7, 45, 49, 'm', 'H_II', '400 m', 35.7, 25.05, 18.599999999999998),
	(7, 50, 54, 'm', 'H_II', '200 m', 18.03333333333333, 12.899999999999999, 9.683333333333334),
	(7, 55, 59, 'm', 'H_II', '200 m', 18.45, 13.133333333333333, 10.2),
	(7, 60, 64, 'm', 'H_II', '200 m', 18.8, 13.266666666666667, 10.266666666666667),
	(7, 65, 69, 'm', 'H_II', '200 m', 19.066666666666666, 13.583333333333332, 10.350000000000001),
	(7, 70, 74, 'm', 'H_II', '200 m', 19.066666666666666, 13.716666666666667, 10.433333333333334),
	(7, 75, 79, 'm', 'H_II', '100 m', 9.749999999999998, 6.9, 5.483333333333333),
	(7, 80, 84, 'm', 'H_II', '100 m', 9.833333333333334, 7.050000000000001, 5.55),
	(7, 85, 89, 'm', 'H_II', '100 m', 9.833333333333334, 7.2, 5.783333333333333),
	(7, 90, 200, 'm', 'H_II', '100 m', 10.083333333333334, 7.35, 6.066666666666666),
	(10, 0, 7, 'w', 'H_II', '', 2.3, 4.1, 5.4),
	(10, 8, 9, 'w', 'H_II', '', 3.4, 5.4, 6.8),
	(10, 10, 11, 'w', 'H_II', '', 4.2, 6.8, 8.1),
	(10, 12, 13, 'w', 'H_II', '', 5.7, 8.1, 9.9),
	(10, 0, 7, 'm', 'H_II', '', 4.6, 6.8, 7.7),
	(10, 8, 9, 'm', 'H_II', '', 6.5, 9.0, 10.4),
	(10, 10, 11, 'm', 'H_II', '', 8.0, 11.3, 12.6),
	(11, 14, 15, 'w', 'H_II', '', 7.7, 10.8, 12.2),
	(11, 16, 17, 'w', 'H_II', '', 9.2, 12.2, 14.0),
	(11, 18, 19, 'w', 'H_II', '', 10.0, 13.3, 14.5),
	(11, 20, 24, 'w', 'H_II', '', 10.2, 13.5, 14.8),
	(11, 25, 29, 'w', 'H_II', '', 10.2, 13.5, 14.8),
	(11, 30, 34, 'w', 'H_II', '', 9.4, 12.5, 13.8),
	(11, 35, 39, 'w', 'H_II', '', 8.9, 12.0, 13.3),
	(11, 40, 44, 'w', 'H_II', '', 8.3, 11.3, 12.5),
	(11, 45, 49, 'w', 'H_II', '', 7.9, 10.8, 12.0),
	(11, 50, 54, 'w', 'H_II', '', 7.0, 10.0, 11.5),
	(11, 55, 59, 'w', 'H_II', '', 6.6, 9.5, 11.0),
	(11, 60, 64, 'w', 'H_II', '', 6.2, 9.0, 10.5),
	(11, 65, 69, 'w', 'H_II', '', 5.7, 8.5, 10.0),
	(11, 70, 74, 'w', 'H_II', '', 5.5, 8.3, 9.8),
	(11, 75, 79, 'w', 'H_II', '', 5.1, 7.8, 9.3),
	(11, 80, 84, 'w', 'H_II', '', 4.7, 7.3, 8.8),
	(11, 85, 89, 'w', 'H_II', '', 4.0, 6.5, 8.0),
	(11, 90, 200, 'w', 'H_II', '', 3.2, 5.5, 7.0),
	(11, 12, 13, 'm', 'H_II', '', 9.9, 13.5, 14.9),
	(11, 14, 15, 'm', 'H_II', '', 11.5, 15.3, 16.7),
	(11, 16, 17, 'm', 'H_II', '', 13.0, 17.1, 18.9),
	(11, 18, 19, 'm', 'H_II', '', 13.4, 18.0, 20.3),
	(11, 20, 24, 'm', 'H_II', '', 14.0, 19.0, 21.0),
	(11, 25, 29, 'm', 'H_II', '', 13.8, 18.8, 20.8),
	(11, 30, 34, 'm', 'H_II', '', 12.8, 17.5, 20.0),
	(11, 35, 39, 'm', 'H_II', '', 12.1, 16.8, 19.3),
	(11, 40, 44, 'm', 'H_II', '', 11.9, 16.5, 19.0),
	(11, 45, 49, 'm', 'H_II', '', 11.5, 16.0, 18.8),
	(11, 50, 54, 'm', 'H_II', '', 10.8, 15.5, 18.3),
	(11, 55, 59, 'm', 'H_II', '', 10.0, 14.5, 17.5),
	(11, 60, 64, 'm', 'H_II', '', 9.6, 14.0, 17.0),
	(11, 65, 69, 'm', 'H_II', '', 8.5, 12.8, 15.3),
	(11, 70, 74, 'm', 'H_II', '', 7.9, 12.0, 14.5),
	(11, 75, 79, 'm', 'H_II', '', 6.8, 10.5, 13.0),
	(11, 80, 84, 'm', 'H_II', '', 6.0, 9.5, 12.0),
	(11, 85, 89, 'm', 'H_II', '', 5.1, 8.3, 10.5),
	(11, 90, 200, 'm', 'H_II', '', 4.5, 7.5, 9.8),
	(13, 12, 13, 'w', 'H_II', '2 kg', 1.8, 2.4, 2.6),
	(13, 14, 15, 'w', 'H_II', '2 kg', 2.1, 2.7, 2.9),
	(13, 16, 17, 'w', 'H_II', '2 kg', 2.2, 2.8, 3.0),
	(13, 18, 19, 'w', 'H_II', '3 kg', 2.5, 3.2, 3.4),
	(13, 20, 24, 'w', 'H_II', '3 kg', 2.5, 3.2, 3.4),
	(13, 25, 29, 'w', 'H_II', '3 kg', 2.5, 3.2, 3.4),
	(13, 30, 34, 'w', 'H_II', '3 kg', 2.4, 3.0, 3.3),
	(13, 35, 39, 'w', 'H_II', '3 kg', 2.3, 2.9, 3.2),
	(13, 40, 44, 'w', 'H_II', '3 kg', 2.1, 2.7, 2.9),
	(13, 45, 49, 'w', 'H_II', '3 kg', 2.0, 2.6, 2.8),
	(13, 50, 54, 'w', 'H_II', '2 kg', 2.0, 2.7, 3.2),
	(13, 55, 59, 'w', 'H_II', '2 kg', 1.9, 2.6, 2.9),
	(13, 60, 64, 'w', 'H_II', '2 kg', 1.8, 2.5, 2.8),
	(13, 65, 69, 'w', 'H_II', '2 kg', 1.7, 2.4, 2.8),
	(13, 70, 74, 'w', 'H_II', '2 kg', 1.6, 2.3, 2.7),
	(13, 75, 79, 'w', 'H_II', '2 kg', 1.6, 2.4, 2.8),
	(13, 80, 84, 'w', 'H_II', '2 kg', 1.5, 2.3, 2.6),
	(13, 85, 89, 'w', 'H_II', '2 kg', 1.4, 2.0, 2.5),
	(13, 90, 200, 'w', 'H_II', '2 kg', 1.2, 1.9, 2.3),
	(13, 12, 13, 'm', 'H_II', '2 kg', 2.4, 3.0, 3.3),
	(13, 14, 15, 'm', 'H_II', '2 kg', 2.7, 3.4, 3.6),
	(13, 16, 17, 'm', 'H_II', '3 kg', 2.9, 3.6, 3.8),
	(13, 18, 19, 'm', 'H_II', '4 kg', 3.0, 3.7, 3.9),
	(13, 20, 24, 'm', 'H_II', '4 kg', 3.0, 3.8, 4.1),
	(13, 25, 29, 'm', 'H_II', '4 kg', 2.9, 3.7, 3.9),
	(13, 30, 34, 'm', 'H_II', '4 kg', 2.7, 3.5, 3.7),
	(13, 35, 39, 'm', 'H_II', '4 kg', 2.6, 3.3, 3.6),
	(13, 40, 44, 'm', 'H_II', '4 kg', 2.4, 3.2, 3.5),
	(13, 45, 49, 'm', 'H_II', '4 kg', 2.3, 3.0, 3.4),
	(13, 50, 54, 'm', 'H_II', '3 kg', 2.4, 3.2, 3.6),
	(13, 55, 59, 'm', 'H_II', '3 kg', 2.3, 3.0, 3.4),
	(13, 60, 64, 'm', 'H_II', '3 kg', 2.3, 3.2, 3.6),
	(13, 65, 69, 'm', 'H_II', '3 kg', 2.2, 3.0, 3.4),
	(13, 70, 74, 'm', 'H_II', '3 kg', 2.3, 3.0, 3.5),
	(13, 75, 79, 'm', 'H_II', '3 kg', 2.2, 2.9, 3.4),
	(13, 80, 84, 'm', 'H_II', '2 kg', 2.1, 2.8, 3.3),
	(13, 85, 89, 'm', 'H_II', '2 kg', 1.9, 2.7, 3.0),
	(13, 90, 200, 'm', 'H_II', '2 kg', 1.7, 2.4, 2.8),
	(18, 0, 7, 'w', 'H_II', '', 2.08, 1.32, 1.13),
	(18, 8, 9, 'w', 'H_II', '', 1.55, 1.21, 1.07),
	(18, 10, 11, 'w', 'H_II', '', 1.47, 1.15, 1.01),
	(18, 12, 13, 'w', 'H_II', '', 1.36, 1.09, 0.56),
	(18, 14, 15, 'w', 'H_II', '', 1.31, 1.06, 0.51),
	(18, 16, 17, 'w', 'H_II', '', 1.24, 1.01, 0.48),
	(18, 18, 19, 'w', 'H_II', '', 1.21, 0.57, 0.44),
	(18, 20, 24, 'w', 'H_II', '', 1.2, 0.57, 0.44),
	(18, 25, 29, 'w', 'H_II', '', 1.22, 1.0, 0.46),
	(18, 30, 34, 'w', 'H_II', '', 1.29, 1.03, 0.5),
	(18, 35, 39, 'w', 'H_II', '', 1.39, 1.09, 0.52),
	(18, 40, 44, 'w', 'H_II', '', 1.5, 1.15, 0.56),
	(18, 45, 49, 'w', 'H_II', '', 2.01, 1.24, 1.0),
	(18, 50, 54, 'w', 'H_II', '', 2.12, 1.33, 1.07),
	(18, 55, 59, 'w', 'H_II', '', 2.22, 1.42, 1.13),
	(18, 60, 64, 'w', 'H_II', '', 2.3, 1.46, 1.18),
	(18, 65, 69, 'w', 'H_II', '', 2.35, 1.51, 1.22),
	(18, 70, 74, 'w', 'H_II', '', 2.42, 1.55, 1.26),
	(18, 75, 79, 'w', 'H_II', '', 2.48, 2.0, 1.31),
	(18, 80, 84, 'w', 'H_II', '', 2.55, 2.04, 1.36),
	(18, 85, 89, 'w', 'H_II', '', 3.0, 2.08, 1.39),
	(18, 90, 200, 'w', 'H_II', '', 3.03, 2.1, 1.42),
	(18, 0, 7, 'm', 'H_II', '', 2.06, 1.31, 1.12),
	(18, 8, 9, 'm', 'H_II', '', 1.53, 1.19, 1.02),
	(18, 10, 11, 'm', 'H_II', '', 1.39, 1.09, 0.54),
	(18, 12, 13, 'm', 'H_II', '', 1.31, 1.04, 0.5),
	(18, 14, 15, 'm', 'H_II', '', 1.25, 1.01, 0.48),
	(18, 16, 17, 'm', 'H_II', '', 1.21, 0.58, 0.45),
	(18, 18, 19, 'm', 'H_II', '', 1.17, 0.55, 0.42),
	(18, 20, 24, 'm', 'H_II', '', 1.14, 0.52, 0.37),
	(18, 25, 29, 'm', 'H_II', '', 1.2, 0.55, 0.39),
	(18, 30, 34, 'm', 'H_II', '', 1.26, 0.57, 0.4),
	(18, 35, 39, 'm', 'H_II', '', 1.36, 1.03, 0.44),
	(18, 40, 44, 'm', 'H_II', '', 1.46, 1.1, 0.45),
	(18, 45, 49, 'm', 'H_II', '', 1.55, 1.18, 0.49),
	(18, 50, 54, 'm', 'H_II', '', 2.04, 1.24, 0.55),
	(18, 55, 59, 'm', 'H_II', '', 2.15, 1.28, 1.0),
	(18, 60, 64, 'm', 'H_II', '', 2.2, 1.33, 1.04),
	(18, 65, 69, 'm', 'H_II', '', 2.24, 1.37, 1.08),
	(18, 70, 74, 'm', 'H_II', '', 2.31, 1.43, 1.14),
	(18, 75, 79, 'm', 'H_II', '', 2.38, 1.49, 1.2),
	(18, 80, 84, 'm', 'H_II', '', 2.42, 1.55, 1.26),
	(18, 85, 89, 'm', 'H_II', '', 2.44, 1.57, 1.31),
	(18, 90, 200, 'm', 'H_II', '', 2.45, 2.0, 1.36),
	(29, 0, 7, 'w', 'H_II', '', 12.383333333333335, 9.500000000000002, 8.066666666666665),
	(29, 8, 9, 'w', 'H_II', '', 12.2, 9.183333333333332, 7.916666666666666),
	(29, 10, 11, 'w', 'H_II', '', 11.65, 8.866666666666665, 7.6000000000000005),
	(29, 12, 13, 'w', 'H_II', '', 11.283333333333333, 8.383333333333335, 7.116666666666667),
	(29, 14, 15, 'w', 'H_II', '', 10.916666666666668, 8.233333333333334, 6.800000000000001),
	(29, 16, 17, 'w', 'H_II', '', 10.566666666666666, 7.75, 6.483333333333333),
	(29, 0, 7, 'm', 'H_II', '', 12.383333333333335, 9.500000000000002, 8.066666666666665),
	(29, 8, 9, 'm', 'H_II', '', 11.833333333333334, 8.866666666666665, 7.433333333333333),
	(29, 10, 11, 'm', 'H_II', '', 11.100000000000001, 8.233333333333334, 6.800000000000001),
	(29, 12, 13, 'm', 'H_II', '', 10.383333333333335, 7.6000000000000005, 6.166666666666666),
	(29, 14, 15, 'm', 'H_II', '', 9.466666666666665, 6.966666666666667, 5.7),
	(29, 16, 17, 'm', 'H_II', '', 8.916666666666668, 6.483333333333333, 5.216666666666667),
	(31, 18, 19, 'w', 'H_II', '', 19.166666666666668, 15.066666666666665, 13.466666666666665),
	(31, 20, 24, 'w', 'H_II', '', 18.700000000000003, 14.666666666666668, 13.066666666666665),
	(31, 25, 29, 'w', 'H_II', '', 19.01666666666667, 14.933333333333334, 13.333333333333332),
	(31, 30, 34, 'w', 'H_II', '', 19.78333333333333, 15.6, 14.0),
	(31, 35, 39, 'w', 'H_II', '', 20.233333333333334, 16.0, 14.4),
	(31, 40, 44, 'w', 'H_II', '', 21.0, 16.533333333333335, 14.8),
	(31, 45, 49, 'w', 'H_II', '', 21.93333333333333, 17.200000000000003, 15.066666666666665),
	(31, 50, 54, 'w', 'H_II', '', 22.85, 17.733333333333334, 15.333333333333332),
	(31, 55, 59, 'w', 'H_II', '', 23.76666666666667, 18.266666666666666, 15.866666666666665),
	(31, 60, 64, 'w', 'H_II', '', 24.383333333333333, 18.8, 16.4),
	(31, 65, 69, 'w', 'H_II', '', 25.0, 19.333333333333332, 16.93333333333333),
	(31, 70, 74, 'w', 'H_II', '', 25.45, 19.733333333333334, 17.333333333333332),
	(31, 75, 79, 'w', 'H_II', '', 26.216666666666665, 20.4, 18.0),
	(31, 80, 84, 'w', 'H_II', '', 27.3, 21.333333333333332, 18.93333333333333),
	(31, 85, 89, 'w', 'H_II', '', 28.516666666666666, 22.4, 20.0),
	(31, 90, 200, 'w', 'H_II', '', 29.9, 23.599999999999998, 21.200000000000003),
	(31, 18, 19, 'm', 'H_II', '', 16.4, 12.666666666666668, 11.066666666666665),
	(31, 20, 24, 'm', 'H_II', '', 15.950000000000001, 12.266666666666667, 10.666666666666668),
	(31, 25, 29, 'm', 'H_II', '', 16.249999999999996, 12.533333333333333, 10.933333333333334),
	(31, 30, 34, 'm', 'H_II', '', 17.01666666666667, 13.2, 11.6),
	(31, 35, 39, 'm', 'H_II', '', 18.249999999999996, 13.866666666666665, 12.0),
	(31, 40, 44, 'm', 'H_II', '', 19.31666666666667, 14.8, 12.666666666666668),
	(31, 45, 49, 'm', 'H_II', '', 20.4, 15.6, 13.2),
	(31, 50, 54, 'm', 'H_II', '', 21.46666666666667, 16.266666666666666, 13.866666666666665),
	(31, 55, 59, 'm', 'H_II', '', 21.93333333333333, 16.666666666666664, 14.266666666666667),
	(31, 60, 64, 'm', 'H_II', '', 22.533333333333335, 17.200000000000003, 14.8),
	(31, 65, 69, 'm', 'H_II', '', 23.0, 17.599999999999998, 15.2),
	(31, 70, 74, 'm', 'H_II', '', 23.3, 17.866666666666667, 15.466666666666665),
	(31, 75, 79, 'm', 'H_II', '', 23.916666666666668, 18.4, 16.0),
	(31, 80, 84, 'm', 'H_II', '', 24.383333333333333, 18.8, 16.4),
	(31, 85, 89, 'm', 'H_II', '', 25.3, 19.599999999999998, 17.200000000000003),
	(31, 90, 200, 'm', 'H_II', '', 27.45, 21.46666666666667, 19.066666666666666),
	(34, 0, 7, 'w', 'H_II', '', 8.0, 12.0, 17.0),
	(34, 8, 9, 'w', 'H_II', '', 10.0, 15.0, 20.0),
	(34, 10, 11, 'w', 'H_II', '', 15.0, 20.0, 30.0),
	(34, 12, 13, 'w', 'H_II', '', 20.0, 30.0, 40.0),
	(34, 14, 15, 'w', 'H_II', '', 30.0, 40.0, 50.0),
	(34, 16, 17, 'w', 'H_II', '', 45.0, 60.0, 75.0),
	(34, 0, 7, 'm', 'H_II', '', 8.0, 12.0, 17.0),
	(34, 8, 9, 'm', 'H_II', '', 10.0, 15.0, 20.0),
	(34, 10, 11, 'm', 'H_II', '', 15.0, 20.0, 30.0),
	(34, 12, 13, 'm', 'H_II', '', 20.0, 30.0, 40.0),
	(34, 14, 15, 'm', 'H_II', '', 30.0, 40.0, 50.0),
	(34, 16, 17, 'm', 'H_II', '', 45.0, 60.0, 75.0),
	(35, 0, 7, 'w', 'H_II', '2,5 km', 34.050000000000004, 27.0, 24.0),
	(35, 8, 9, 'w', 'H_II', '2,5 km', 31.05, 24.0, 21.0),
	(35, 10, 11, 'w', 'H_II', '5 km', 58.08333333333333, 43.0, 35.49999999999999),
	(35, 12, 13, 'w', 'H_II', '5 km', 51.75000000000001, 39.49999999999999, 33.49999999999999),
	(35, 14, 15, 'w', 'H_II', '5 km', 43.7, 32.49999999999999, 28.5),
	(35, 16, 17, 'w', 'H_II', '5 km', 37.36666666666667, 28.5, 25.0),
	(35, 18, 19, 'w', 'H_II', '10 km', 66.13333333333333, 52.0, 46.49999999999999),
	(35, 20, 24, 'w', 'H_II', '10 km', 65.55, 51.49999999999999, 45.49999999999999),
	(35, 25, 29, 'w', 'H_II', '10 km', 64.39999999999999, 50.49999999999999, 45.0),
	(35, 30, 34, 'w', 'H_II', '10 km', 65.55, 51.49999999999999, 45.49999999999999),
	(35, 35, 39, 'w', 'H_II', '10 km', 69.0, 53.0, 47.0),
	(35, 40, 44, 'w', 'H_II', '10 km', 73.6, 55.49999999999999, 49.49999999999999),
	(35, 45, 49, 'w', 'H_II', '10 km', 77.05, 58.49999999999999, 51.49999999999999),
	(35, 50, 54, 'w', 'H_II', '10 km', 79.35, 61.0, 53.49999999999999),
	(35, 55, 59, 'w', 'H_II', '10 km', 82.21666666666665, 63.0, 55.49999999999999),
	(35, 60, 64, 'w', 'H_II', '10 km', 85.10000000000001, 65.0, 57.0),
	(35, 65, 69, 'w', 'H_II', '10 km', 86.81666666666666, 66.5, 58.49999999999999),
	(35, 70, 74, 'w', 'H_II', '10 km', 89.7, 68.5, 60.49999999999999),
	(35, 75, 79, 'w', 'H_II', '10 km', 93.73333333333333, 70.5, 63.0),
	(35, 80, 84, 'w', 'H_II', '10 km', 97.18333333333334, 75.0, 65.5),
	(35, 85, 89, 'w', 'H_II', '10 km', 102.91666666666666, 80.0, 69.0),
	(35, 90, 200, 'w', 'H_II', '10 km', 106.94999999999999, 83.0, 72.5),
	(35, 0, 7, 'm', 'H_II', '2,5 km', 33.46666666666667, 26.5, 23.5),
	(35, 8, 9, 'm', 'H_II', '2,5 km', 30.46666666666667, 23.5, 20.5),
	(35, 10, 11, 'm', 'H_II', '5 km', 55.766666666666666, 41.0, 33.49999999999999),
	(35, 12, 13, 'm', 'H_II', '5 km', 49.45, 37.0, 31.5),
	(35, 14, 15, 'm', 'H_II', '5 km', 36.8, 28.0, 24.0),
	(35, 16, 17, 'm', 'H_II', '5 km', 31.05, 23.5, 20.5),
	(35, 18, 19, 'm', 'H_II', '10 km', 54.050000000000004, 42.49999999999999, 38.49999999999999),
	(35, 20, 24, 'm', 'H_II', '10 km', 53.483333333333334, 42.0, 37.49999999999999),
	(35, 25, 29, 'm', 'H_II', '10 km', 57.49999999999999, 44.49999999999999, 39.0),
	(35, 30, 34, 'm', 'H_II', '10 km', 61.51666666666667, 47.0, 40.49999999999999),
	(35, 35, 39, 'm', 'H_II', '10 km', 66.7, 50.0, 41.49999999999999),
	(35, 40, 44, 'm', 'H_II', '10 km', 72.44999999999999, 52.0, 43.49999999999999),
	(35, 45, 49, 'm', 'H_II', '10 km', 75.9, 55.0, 45.0),
	(35, 50, 54, 'm', 'H_II', '10 km', 78.78333333333333, 57.0, 46.49999999999999),
	(35, 55, 59, 'm', 'H_II', '10 km', 81.06666666666668, 58.49999999999999, 47.49999999999999),
	(35, 60, 64, 'm', 'H_II', '10 km', 82.21666666666665, 60.0, 48.0),
	(35, 65, 69, 'm', 'H_II', '10 km', 83.36666666666666, 60.49999999999999, 48.49999999999999),
	(35, 70, 74, 'm', 'H_II', '10 km', 84.53333333333332, 61.49999999999999, 49.49999999999999),
	(35, 75, 79, 'm', 'H_II', '10 km', 85.68333333333332, 63.0, 51.49999999999999),
	(35, 80, 84, 'm', 'H_II', '10 km', 87.39999999999999, 64.5, 53.0),
	(35, 85, 89, 'm', 'H_II', '10 km', 89.13333333333333, 66.5, 55.49999999999999),
	(35, 90, 200, 'm', 'H_II', '10 km', 90.85000000000001, 68.0, 58.0),
	(39, 0, 7, 'w', 'H_II', '', 98.0, 128.0, 140.0),
	(39, 8, 9, 'w', 'H_II', '', 107.0, 140.0, 154.0),
	(39, 10, 11, 'w', 'H_II', '', 117.0, 153.0, 168.0),
	(39, 12, 13, 'w', 'H_II', '', 126.0, 165.0, 182.0),
	(39, 14, 15, 'w', 'H_II', '', 136.0, 178.0, 195.0),
	(39, 16, 17, 'w', 'H_II', '', 145.0, 190.0, 209.0),
	(39, 18, 19, 'w', 'H_II', '', 222.0, 290.0, 319.0),
	(39, 20, 24, 'w', 'H_II', '', 222.0, 290.0, 319.0),
	(39, 25, 29, 'w', 'H_II', '', 222.0, 290.0, 319.0),
	(39, 30, 34, 'w', 'H_II', '', 212.0, 278.0, 305.0),
	(39, 35, 39, 'w', 'H_II', '', 212.0, 278.0, 305.0),
	(39, 40, 44, 'w', 'H_II', '', 203.0, 265.0, 292.0),
	(39, 45, 49, 'w', 'H_II', '', 193.0, 253.0, 278.0),
	(39, 50, 54, 'w', 'H_II', '', 184.0, 240.0, 264.0),
	(39, 55, 59, 'w', 'H_II', '', 174.0, 228.0, 250.0),
	(39, 60, 64, 'w', 'H_II', '', 164.0, 215.0, 237.0),
	(39, 65, 69, 'w', 'H_II', '', 155.0, 203.0, 223.0),
	(39, 70, 74, 'w', 'H_II', '', 145.0, 190.0, 209.0),
	(39, 75, 79, 'w', 'H_II', '', 136.0, 178.0, 195.0),
	(39, 80, 84, 'w', 'H_II', '', 126.0, 165.0, 182.0),
	(39, 85, 89, 'w', 'H_II', '', 117.0, 153.0, 168.0),
	(39, 90, 200, 'w', 'H_II', '', 107.0, 140.0, 154.0),
	(39, 0, 7, 'm', 'H_II', '', 147.0, 193.0, 212.0),
	(39, 8, 9, 'm', 'H_II', '', 157.0, 205.0, 226.0),
	(39, 10, 11, 'm', 'H_II', '', 166.0, 218.0, 239.0),
	(39, 12, 13, 'm', 'H_II', '', 176.0, 230.0, 253.0),
	(39, 14, 15, 'm', 'H_II', '', 186.0, 243.0, 267.0),
	(39, 16, 17, 'm', 'H_II', '', 195.0, 255.0, 281.0),
	(39, 18, 19, 'm', 'H_II', '', 272.0, 355.0, 391.0),
	(39, 20, 24, 'm', 'H_II', '', 272.0, 355.0, 391.0),
	(39, 25, 29, 'm', 'H_II', '', 272.0, 355.0, 391.0),
	(39, 30, 34, 'm', 'H_II', '', 262.0, 343.0, 377.0),
	(39, 35, 39, 'm', 'H_II', '', 262.0, 343.0, 377.0),
	(39, 40, 44, 'm', 'H_II', '', 252.0, 330.0, 363.0),
	(39, 45, 49, 'm', 'H_II', '', 243.0, 318.0, 349.0),
	(39, 50, 54, 'm', 'H_II', '', 233.0, 305.0, 336.0),
	(39, 55, 59, 'm', 'H_II', '', 224.0, 293.0, 322.0),
	(39, 60, 64, 'm', 'H_II', '', 214.0, 280.0, 308.0),
	(39, 65, 69, 'm', 'H_II', '', 205.0, 268.0, 294.0),
	(39, 70, 74, 'm', 'H_II', '', 195.0, 255.0, 281.0),
	(39, 75, 79, 'm', 'H_II', '', 186.0, 243.0, 267.0),
	(39, 80, 84, 'm', 'H_II', '', 176.0, 230.0, 253.0),
	(39, 85, 89, 'm', 'H_II', '', 166.0, 218.0, 239.0),
	(39, 90, 200, 'm', 'H_II', '', 157.0, 205.0, 226.0),
	(40, 0, 7, 'w', 'H_II', '', 233.0, 305.0, 336.0),
	(40, 8, 9, 'w', 'H_II', '', 245.0, 320.0, 352.0),
	(40, 10, 11, 'w', 'H_II', '', 256.0, 335.0, 369.0),
	(40, 12, 13, 'w', 'H_II', '', 268.0, 350.0, 385.0),
	(40, 14, 15, 'w', 'H_II', '', 279.0, 365.0, 402.0),
	(40, 16, 17, 'w', 'H_II', '', 291.0, 380.0, 418.0),
	(40, 18, 19, 'w', 'H_II', '', 367.0, 480.0, 528.0),
	(40, 20, 24, 'w', 'H_II', '', 367.0, 480.0, 528.0),
	(40, 25, 29, 'w', 'H_II', '', 367.0, 480.0, 528.0),
	(40, 30, 34, 'w', 'H_II', '', 356.0, 465.0, 512.0),
	(40, 35, 39, 'w', 'H_II', '', 356.0, 465.0, 512.0),
	(40, 40, 44, 'w', 'H_II', '', 344.0, 450.0, 495.0),
	(40, 45, 49, 'w', 'H_II', '', 333.0, 435.0, 479.0),
	(40, 50, 54, 'w', 'H_II', '', 321.0, 420.0, 462.0),
	(40, 55, 59, 'w', 'H_II', '', 310.0, 405.0, 446.0),
	(40, 60, 64, 'w', 'H_II', '', 298.0, 390.0, 429.0),
	(40, 65, 69, 'w', 'H_II', '', 287.0, 375.0, 413.0),
	(40, 70, 74, 'w', 'H_II', '', 275.0, 360.0, 396.0),
	(40, 75, 79, 'w', 'H_II', '', 264.0, 345.0, 380.0),
	(40, 80, 84, 'w', 'H_II', '', 252.0, 330.0, 363.0),
	(40, 85, 89, 'w', 'H_II', '', 241.0, 315.0, 347.0),
	(40, 90, 200, 'w', 'H_II', '', 230.0, 300.0, 330.0),
	(40, 0, 7, 'm', 'H_II', '', 291.0, 380.0, 418.0),
	(40, 8, 9, 'm', 'H_II', '', 302.0, 395.0, 435.0),
	(40, 10, 11, 'm', 'H_II', '', 314.0, 410.0, 451.0),
	(40, 12, 13, 'm', 'H_II', '', 325.0, 425.0, 468.0),
	(40, 14, 15, 'm', 'H_II', '', 337.0, 440.0, 484.0),
	(40, 16, 17, 'm', 'H_II', '', 348.0, 455.0, 501.0),
	(40, 18, 19, 'm', 'H_II', '', 425.0, 555.0, 611.0),
	(40, 20, 24, 'm', 'H_II', '', 425.0, 555.0, 611.0),
	(40, 25, 29, 'm', 'H_II', '', 493.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'H_II', '', 413.0, 540.0, 594.0),
	(40, 35, 39, 'm', 'H_II', '', 413.0, 540.0, 594.0),
	(40, 40, 44, 'm', 'H_II', '', 402.0, 525.0, 578.0),
	(40, 45, 49, 'm', 'H_II', '', 390.0, 510.0, 561.0),
	(40, 50, 54, 'm', 'H_II', '', 379.0, 495.0, 545.0),
	(40, 55, 59, 'm', 'H_II', '', 367.0, 480.0, 528.0),
	(40, 60, 64, 'm', 'H_II', '', 356.0, 465.0, 512.0),
	(40, 65, 69, 'm', 'H_II', '', 344.0, 450.0, 495.0),
	(40, 70, 74, 'm', 'H_II', '', 333.0, 435.0, 479.0),
	(40, 75, 79, 'm', 'H_II', '', 321.0, 420.0, 462.0),
	(40, 80, 84, 'm', 'H_II', '', 310.0, 405.0, 446.0),
	(40, 85, 89, 'm', 'H_II', '', 298.0, 390.0, 429.0),
	(40, 90, 200, 'm', 'H_II', '', 287.0, 375.0, 413.0),
	(41, 0, 7, 'w', 'H_II', '', 176.0, 230.0, 253.0),
	(41, 8, 9, 'w', 'H_II', '', 187.0, 245.0, 270.0),
	(41, 10, 11, 'w', 'H_II', '', 199.0, 260.0, 286.0),
	(41, 12, 13, 'w', 'H_II', '', 210.0, 275.0, 303.0),
	(41, 14, 15, 'w', 'H_II', '', 222.0, 290.0, 319.0),
	(41, 16, 17, 'w', 'H_II', '', 233.0, 305.0, 336.0),
	(41, 18, 19, 'w', 'H_II', '', 310.0, 405.0, 446.0),
	(41, 20, 24, 'w', 'H_II', '', 310.0, 405.0, 446.0),
	(41, 25, 29, 'w', 'H_II', '', 310.0, 405.0, 446.0),
	(41, 30, 34, 'w', 'H_II', '', 298.0, 390.0, 429.0),
	(41, 35, 39, 'w', 'H_II', '', 298.0, 390.0, 429.0),
	(41, 40, 44, 'w', 'H_II', '', 287.0, 375.0, 413.0),
	(41, 45, 49, 'w', 'H_II', '', 275.0, 360.0, 396.0),
	(41, 50, 54, 'w', 'H_II', '', 264.0, 345.0, 380.0),
	(41, 55, 59, 'w', 'H_II', '', 252.0, 330.0, 363.0),
	(41, 60, 64, 'w', 'H_II', '', 241.0, 315.0, 347.0),
	(41, 65, 69, 'w', 'H_II', '', 230.0, 300.0, 330.0),
	(41, 70, 74, 'w', 'H_II', '', 218.0, 285.0, 314.0),
	(41, 75, 79, 'w', 'H_II', '', 207.0, 270.0, 297.0),
	(41, 80, 84, 'w', 'H_II', '', 195.0, 255.0, 281.0),
	(41, 85, 89, 'w', 'H_II', '', 184.0, 240.0, 264.0),
	(41, 90, 200, 'w', 'H_II', '', 172.0, 225.0, 248.0),
	(41, 0, 7, 'm', 'H_II', '', 230.0, 300.0, 330.0),
	(41, 8, 9, 'm', 'H_II', '', 241.0, 315.0, 347.0),
	(41, 10, 11, 'm', 'H_II', '', 252.0, 330.0, 363.0),
	(41, 12, 13, 'm', 'H_II', '', 264.0, 345.0, 380.0),
	(41, 14, 15, 'm', 'H_II', '', 275.0, 360.0, 396.0),
	(41, 16, 17, 'm', 'H_II', '', 287.0, 375.0, 413.0),
	(41, 18, 19, 'm', 'H_II', '', 363.0, 475.0, 523.0),
	(41, 20, 24, 'm', 'H_II', '', 363.0, 475.0, 523.0),
	(41, 25, 29, 'm', 'H_II', '', 432.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'H_II', '', 352.0, 460.0, 506.0),
	(41, 35, 39, 'm', 'H_II', '', 352.0, 460.0, 506.0),
	(41, 40, 44, 'm', 'H_II', '', 340.0, 445.0, 490.0),
	(41, 45, 49, 'm', 'H_II', '', 329.0, 430.0, 473.0),
	(41, 50, 54, 'm', 'H_II', '', 317.0, 415.0, 457.0),
	(41, 55, 59, 'm', 'H_II', '', 306.0, 400.0, 440.0),
	(41, 60, 64, 'm', 'H_II', '', 295.0, 385.0, 424.0),
	(41, 65, 69, 'm', 'H_II', '', 283.0, 370.0, 407.0),
	(41, 70, 74, 'm', 'H_II', '', 272.0, 355.0, 391.0),
	(41, 75, 79, 'm', 'H_II', '', 260.0, 340.0, 374.0),
	(41, 80, 84, 'm', 'H_II', '', 249.0, 325.0, 358.0),
	(41, 85, 89, 'm', 'H_II', '', 237.0, 310.0, 341.0),
	(41, 90, 200, 'm', 'H_II', '', 226.0, 295.0, 325.0),
	(42, 0, 7, 'w', 'H_II', '', 180.0, 235.0, 259.0),
	(42, 8, 9, 'w', 'H_II', '', 191.0, 250.0, 275.0),
	(42, 10, 11, 'w', 'H_II', '', 203.0, 265.0, 292.0),
	(42, 12, 13, 'w', 'H_II', '', 214.0, 280.0, 308.0),
	(42, 14, 15, 'w', 'H_II', '', 226.0, 295.0, 325.0),
	(42, 16, 17, 'w', 'H_II', '', 279.0, 310.0, 341.0),
	(42, 18, 19, 'w', 'H_II', '', 314.0, 410.0, 451.0),
	(42, 20, 24, 'w', 'H_II', '', 314.0, 410.0, 451.0),
	(42, 25, 29, 'w', 'H_II', '', 314.0, 410.0, 451.0),
	(42, 30, 34, 'w', 'H_II', '', 302.0, 395.0, 435.0),
	(42, 35, 39, 'w', 'H_II', '', 302.0, 395.0, 435.0),
	(42, 40, 44, 'w', 'H_II', '', 291.0, 380.0, 418.0),
	(42, 45, 49, 'w', 'H_II', '', 279.0, 365.0, 402.0),
	(42, 50, 54, 'w', 'H_II', '', 268.0, 350.0, 385.0),
	(42, 55, 59, 'w', 'H_II', '', 256.0, 335.0, 369.0),
	(42, 60, 64, 'w', 'H_II', '', 245.0, 320.0, 352.0),
	(42, 65, 69, 'w', 'H_II', '', 233.0, 305.0, 336.0),
	(42, 70, 74, 'w', 'H_II', '', 222.0, 290.0, 319.0),
	(42, 75, 79, 'w', 'H_II', '', 210.0, 275.0, 303.0),
	(42, 80, 84, 'w', 'H_II', '', 199.0, 260.0, 286.0),
	(42, 85, 89, 'w', 'H_II', '', 187.0, 245.0, 270.0),
	(42, 90, 200, 'w', 'H_II', '', 176.0, 230.0, 253.0),
	(42, 0, 7, 'm', 'H_II', '', 233.0, 305.0, 336.0),
	(42, 8, 9, 'm', 'H_II', '', 245.0, 320.0, 352.0),
	(42, 10, 11, 'm', 'H_II', '', 256.0, 335.0, 369.0),
	(42, 12, 13, 'm', 'H_II', '', 268.0, 350.0, 385.0),
	(42, 14, 15, 'm', 'H_II', '', 279.0, 365.0, 402.0),
	(42, 16, 17, 'm', 'H_II', '', 291.0, 380.0, 418.0),
	(42, 18, 19, 'm', 'H_II', '', 367.0, 480.0, 528.0),
	(42, 20, 24, 'm', 'H_II', '', 367.0, 480.0, 528.0),
	(42, 25, 29, 'm', 'H_II', '', 436.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'H_II', '', 356.0, 465.0, 512.0),
	(42, 35, 39, 'm', 'H_II', '', 356.0, 465.0, 512.0),
	(42, 40, 44, 'm', 'H_II', '', 344.0, 450.0, 495.0),
	(42, 45, 49, 'm', 'H_II', '', 333.0, 435.0, 479.0),
	(42, 50, 54, 'm', 'H_II', '', 321.0, 420.0, 462.0),
	(42, 55, 59, 'm', 'H_II', '', 310.0, 405.0, 446.0),
	(42, 60, 64, 'm', 'H_II', '', 298.0, 390.0, 429.0),
	(42, 65, 69, 'm', 'H_II', '', 287.0, 375.0, 413.0),
	(42, 70, 74, 'm', 'H_II', '', 275.0, 360.0, 396.0),
	(42, 75, 79, 'm', 'H_II', '', 264.0, 345.0, 380.0),
	(42, 80, 84, 'm', 'H_II', '', 252.0, 330.0, 363.0),
	(42, 85, 89, 'm', 'H_II', '', 241.0, 315.0, 347.0),
	(42, 90, 200, 'm', 'H_II', '', 230.0, 300.0, 330.0),
	(46, 0, 7, 'w', 'H_II', '', 1.8, 3.6, 4.9),
	(46, 8, 9, 'w', 'H_II', '', 2.9, 4.9, 6.3),
	(46, 10, 11, 'w', 'H_II', '', 3.7, 6.3, 7.6),
	(46, 12, 13, 'w', 'H_II', '', 4.7, 7.1, 8.9),
	(46, 14, 15, 'w', 'H_II', '', 6.7, 9.8, 11.2),
	(46, 16, 17, 'w', 'H_II', '', 8.2, 11.2, 13.0),
	(46, 18, 19, 'w', 'H_II', '', 9.0, 12.3, 13.5),
	(46, 20, 24, 'w', 'H_II', '', 9.2, 12.5, 13.8),
	(46, 25, 29, 'w', 'H_II', '', 9.2, 12.5, 13.8),
	(46, 30, 34, 'w', 'H_II', '', 8.4, 11.5, 12.8),
	(46, 35, 39, 'w', 'H_II', '', 7.9, 11.0, 12.3),
	(46, 40, 44, 'w', 'H_II', '', 7.3, 10.3, 11.5),
	(46, 45, 49, 'w', 'H_II', '', 6.9, 9.8, 11.0),
	(46, 50, 54, 'w', 'H_II', '', 6.0, 9.0, 10.5),
	(46, 55, 59, 'w', 'H_II', '', 5.6, 8.5, 10.0),
	(46, 60, 64, 'w', 'H_II', '', 5.2, 8.0, 9.5),
	(46, 65, 69, 'w', 'H_II', '', 4.7, 7.5, 9.0),
	(46, 70, 74, 'w', 'H_II', '', 4.5, 7.3, 8.8),
	(46, 75, 79, 'w', 'H_II', '', 4.1, 6.8, 8.3),
	(46, 80, 84, 'w', 'H_II', '', 3.7, 6.3, 7.8),
	(46, 85, 89, 'w', 'H_II', '', 3.0, 5.5, 7.0),
	(46, 90, 200, 'w', 'H_II', '', 2.2, 4.5, 6.0),
	(46, 0, 7, 'm', 'H_II', '', 4.1, 6.3, 7.2),
	(46, 8, 9, 'm', 'H_II', '', 6.0, 8.5, 9.9),
	(46, 10, 11, 'm', 'H_II', '', 7.5, 10.8, 12.1),
	(46, 12, 13, 'm', 'H_II', '', 8.9, 12.5, 13.9),
	(46, 14, 15, 'm', 'H_II', '', 10.5, 14.3, 15.7),
	(46, 16, 17, 'm', 'H_II', '', 12.0, 16.1, 17.9),
	(46, 18, 19, 'm', 'H_II', '', 12.4, 17.0, 19.3),
	(46, 20, 24, 'm', 'H_II', '', 13.0, 18.0, 20.0),
	(46, 25, 29, 'm', 'H_II', '', 12.8, 17.8, 19.8),
	(46, 30, 34, 'm', 'H_II', '', 11.8, 16.5, 19.0),
	(46, 35, 39, 'm', 'H_II', '', 11.1, 15.8, 18.3),
	(46, 40, 44, 'm', 'H_II', '', 10.9, 15.5, 18.0),
	(46, 45, 49, 'm', 'H_II', '', 10.5, 15.0, 17.8),
	(46, 50, 54, 'm', 'H_II', '', 9.8, 14.5, 17.3),
	(46, 55, 59, 'm', 'H_II', '', 9.0, 13.5, 16.5),
	(46, 60, 64, 'm', 'H_II', '', 8.6, 13.0, 16.0),
	(46, 65, 69, 'm', 'H_II', '', 7.5, 11.8, 14.3),
	(46, 70, 74, 'm', 'H_II', '', 6.9, 11.0, 13.5),
	(46, 75, 79, 'm', 'H_II', '', 5.8, 9.5, 12.0),
	(46, 80, 84, 'm', 'H_II', '', 5.0, 8.5, 11.0),
	(46, 85, 89, 'm', 'H_II', '', 4.1, 7.3, 9.5),
	(46, 90, 200, 'm', 'H_II', '', 3.5, 6.5, 8.8),
	(48, 0, 7, 'w', 'H_II', '30 m', 20.2, 15.6, 13.9),
	(48, 8, 9, 'w', 'H_II', '30 m', 18.7, 14.5, 12.5),
	(48, 10, 11, 'w', 'H_II', '50 m', 27.8, 22.2, 20.0),
	(48, 12, 13, 'w', 'H_II', '50 m', 26.8, 21.1, 18.7),
	(48, 14, 15, 'w', 'H_II', '100 m', 47.1, 37.4, 34.1),
	(48, 16, 17, 'w', 'H_II', '100 m', 44.5, 35.9, 33.0),
	(48, 18, 19, 'w', 'H_II', '100 m', 46.0, 36.3, 33.7),
	(48, 20, 24, 'w', 'H_II', '100 m', 46.8, 37.0, 34.3),
	(48, 25, 29, 'w', 'H_II', '100 m', 47.8, 37.8, 35.2),
	(48, 30, 34, 'w', 'H_II', '100 m', 49.6, 39.2, 36.1),
	(48, 35, 39, 'w', 'H_II', '100 m', 51.6, 40.9, 37.4),
	(48, 40, 44, 'w', 'H_II', '50 m', 27.8, 21.8, 19.4),
	(48, 45, 49, 'w', 'H_II', '50 m', 29.1, 22.7, 20.0),
	(48, 50, 54, 'w', 'H_II', '50 m', 30.1, 23.5, 20.9),
	(48, 55, 59, 'w', 'H_II', '50 m', 31.4, 24.6, 21.8),
	(48, 60, 64, 'w', 'H_II', '50 m', 31.9, 25.1, 22.4),
	(48, 65, 69, 'w', 'H_II', '50 m', 32.4, 25.5, 22.9),
	(48, 70, 74, 'w', 'H_II', '50 m', 32.9, 26.0, 23.3),
	(48, 75, 79, 'w', 'H_II', '50 m', 34.2, 27.1, 24.4),
	(48, 80, 84, 'w', 'H_II', '50 m', 36.2, 28.8, 26.4),
	(48, 85, 89, 'w', 'H_II', '50 m', 39.2, 31.5, 29.0),
	(48, 90, 200, 'w', 'H_II', '50 m', 43.3, 35.0, 32.6),
	(48, 0, 7, 'm', 'H_II', '30 m', 19.5, 15.0, 13.2),
	(48, 8, 9, 'm', 'H_II', '30 m', 18.2, 14.1, 12.5),
	(48, 10, 11, 'm', 'H_II', '50 m', 26.1, 20.5, 18.5),
	(48, 12, 13, 'm', 'H_II', '50 m', 24.5, 19.6, 17.8),
	(48, 14, 15, 'm', 'H_II', '100 m', 43.0, 33.9, 31.0),
	(48, 16, 17, 'm', 'H_II', '100 m', 41.2, 32.6, 29.7),
	(48, 18, 19, 'm', 'H_II', '100 m', 40.5, 32.1, 29.0),
	(48, 20, 24, 'm', 'H_II', '100 m', 40.0, 31.7, 28.6),
	(48, 25, 29, 'm', 'H_II', '100 m', 41.2, 32.6, 29.3),
	(48, 30, 34, 'm', 'H_II', '100 m', 42.5, 33.2, 29.9),
	(48, 35, 39, 'm', 'H_II', '100 m', 44.5, 35.0, 31.2),
	(48, 40, 44, 'm', 'H_II', '50 m', 24.3, 19.1, 16.9),
	(48, 45, 49, 'm', 'H_II', '50 m', 25.3, 19.6, 17.4),
	(48, 50, 54, 'm', 'H_II', '50 m', 26.1, 20.0, 18.0),
	(48, 55, 59, 'm', 'H_II', '50 m', 26.6, 20.7, 18.7),
	(48, 60, 64, 'm', 'H_II', '50 m', 27.3, 21.3, 19.4),
	(48, 65, 69, 'm', 'H_II', '50 m', 28.3, 22.4, 20.0),
	(48, 70, 74, 'm', 'H_II', '50 m', 29.6, 23.5, 21.1),
	(48, 75, 79, 'm', 'H_II', '50 m', 30.9, 24.6, 22.2),
	(48, 80, 84, 'm', 'H_II', '50 m', 32.9, 26.4, 24.0),
	(48, 85, 89, 'm', 'H_II', '50 m', 35.7, 28.8, 26.4),
	(48, 90, 200, 'm', 'H_II', '50 m', 39.2, 31.9, 29.5),
	(50, 0, 7, 'w', 'H_II', '', 1.45, 1.25, 1.16),
	(50, 8, 9, 'w', 'H_II', '', 1.24, 1.04, 0.55),
	(50, 10, 11, 'w', 'H_II', '', 1.16, 0.57, 0.48),
	(50, 12, 13, 'w', 'H_II', '', 1.04, 0.48, 0.42),
	(50, 14, 15, 'w', 'H_II', '', 0.55, 0.44, 0.38),
	(50, 16, 17, 'w', 'H_II', '', 0.51, 0.4, 0.36),
	(50, 18, 19, 'w', 'H_II', '', 0.49, 0.39, 0.35),
	(50, 20, 24, 'w', 'H_II', '', 0.5, 0.39, 0.35),
	(50, 25, 29, 'w', 'H_II', '', 0.51, 0.4, 0.36),
	(50, 30, 34, 'w', 'H_II', '', 0.53, 0.42, 0.38),
	(50, 35, 39, 'w', 'H_II', '', 0.56, 0.44, 0.39),
	(50, 40, 44, 'w', 'H_II', '', 1.0, 0.45, 0.4),
	(50, 45, 49, 'w', 'H_II', '', 1.03, 0.48, 0.41),
	(50, 50, 54, 'w', 'H_II', '', 1.06, 0.5, 0.42),
	(50, 55, 59, 'w', 'H_II', '', 1.09, 0.52, 0.43),
	(50, 60, 64, 'w', 'H_II', '', 1.12, 0.54, 0.45),
	(50, 65, 69, 'w', 'H_II', '', 1.14, 0.55, 0.45),
	(50, 70, 74, 'w', 'H_II', '', 1.18, 0.57, 0.47),
	(50, 75, 79, 'w', 'H_II', '', 1.2, 0.59, 0.49),
	(50, 80, 84, 'w', 'H_II', '', 1.23, 1.02, 0.51),
	(50, 85, 89, 'w', 'H_II', '', 1.26, 1.04, 0.54),
	(50, 90, 200, 'w', 'H_II', '', 1.32, 1.08, 0.56),
	(50, 0, 7, 'm', 'H_II', '', 1.39, 1.19, 1.1),
	(50, 8, 9, 'm', 'H_II', '', 1.18, 0.59, 0.5),
	(50, 10, 11, 'm', 'H_II', '', 1.12, 0.54, 0.46),
	(50, 12, 13, 'm', 'H_II', '', 1.01, 0.46, 0.4),
	(50, 14, 15, 'm', 'H_II', '', 0.49, 0.38, 0.34),
	(50, 16, 17, 'm', 'H_II', '', 0.45, 0.35, 0.3),
	(50, 18, 19, 'm', 'H_II', '', 0.42, 0.32, 0.27),
	(50, 20, 24, 'm', 'H_II', '', 0.41, 0.31, 0.27),
	(50, 25, 29, 'm', 'H_II', '', 0.43, 0.32, 0.27),
	(50, 30, 34, 'm', 'H_II', '', 0.46, 0.33, 0.27),
	(50, 35, 39, 'm', 'H_II', '', 0.49, 0.36, 0.27),
	(50, 40, 44, 'm', 'H_II', '', 0.54, 0.38, 0.29),
	(50, 45, 49, 'm', 'H_II', '', 0.58, 0.41, 0.3),
	(50, 50, 54, 'm', 'H_II', '', 1.02, 0.43, 0.32),
	(50, 55, 59, 'm', 'H_II', '', 1.06, 0.45, 0.33),
	(50, 60, 64, 'm', 'H_II', '', 1.09, 0.46, 0.34),
	(50, 65, 69, 'm', 'H_II', '', 1.12, 0.48, 0.35),
	(50, 70, 74, 'm', 'H_II', '', 1.14, 0.51, 0.36),
	(50, 75, 79, 'm', 'H_II', '', 1.17, 0.53, 0.38),
	(50, 80, 84, 'm', 'H_II', '', 1.2, 0.56, 0.41),
	(50, 85, 89, 'm', 'H_II', '', 1.24, 0.59, 0.44),
	(50, 90, 200, 'm', 'H_II', '', 1.3, 1.03, 0.48),
	(53, 0, 7, 'w', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'H_II', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'H_II', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'H_II', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'H_II', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(56, 0, 7, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'w', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 0, 7, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'm', 'H_II', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'm', 'H_II', '', 1.0, 2.0, 3.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(7, 0, 7, 'w', 'H_III', '100 m', 16.566666666666666, 12.266666666666667, 10.133333333333333),
	(7, 8, 9, 'w', 'H_III', '100 m', 14.716666666666667, 11.2, 9.466666666666665),
	(7, 10, 11, 'w', 'H_III', '100 m', 13.500000000000002, 10.266666666666667, 8.8),
	(7, 12, 13, 'w', 'H_III', '200 m', 27.3, 20.666666666666664, 17.599999999999998),
	(7, 14, 15, 'w', 'H_III', '200 m', 24.066666666666666, 18.666666666666664, 16.0),
	(7, 16, 17, 'w', 'H_III', '200 m', 21.76666666666667, 16.8, 14.533333333333333),
	(7, 18, 19, 'w', 'H_III', '200 m', 19.31666666666667, 14.816666666666666, 12.883333333333333),
	(7, 20, 24, 'w', 'H_III', '200 m', 18.983333333333334, 14.583333333333332, 12.6),
	(7, 25, 29, 'w', 'H_III', '200 m', 20.533333333333335, 14.766666666666667, 13.066666666666665),
	(7, 30, 34, 'w', 'H_III', '200 m', 23.216666666666665, 16.566666666666666, 13.65),
	(7, 35, 39, 'w', 'H_III', '200 m', 25.76666666666667, 17.916666666666668, 14.233333333333334),
	(7, 40, 44, 'w', 'H_III', '200 m', 27.366666666666664, 19.366666666666664, 14.933333333333334),
	(7, 45, 49, 'w', 'H_III', '200 m', 28.45, 20.3, 15.049999999999999),
	(7, 50, 54, 'w', 'H_III', '100 m', 14.483333333333333, 10.500000000000002, 8.049999999999999),
	(7, 55, 59, 'w', 'H_III', '100 m', 14.966666666666667, 10.733333333333333, 8.333333333333332),
	(7, 60, 64, 'w', 'H_III', '100 m', 15.299999999999999, 10.899999999999999, 8.516666666666667),
	(7, 65, 69, 'w', 'H_III', '100 m', 15.633333333333335, 11.016666666666666, 8.566666666666666),
	(7, 70, 74, 'w', 'H_III', '100 m', 15.966666666666667, 11.25, 8.866666666666665),
	(7, 75, 79, 'w', 'H_III', '50 m', 8.25, 5.833333333333333, 4.55),
	(7, 80, 84, 'w', 'H_III', '50 m', 8.383333333333335, 5.95, 4.733333333333334),
	(7, 85, 89, 'w', 'H_III', '50 m', 8.516666666666667, 6.116666666666667, 4.966666666666667),
	(7, 90, 200, 'w', 'H_III', '50 m', 8.65, 6.2333333333333325, 5.133333333333334),
	(7, 0, 7, 'm', 'H_III', '100 m', 16.566666666666666, 11.733333333333333, 9.866666666666665),
	(7, 8, 9, 'm', 'H_III', '100 m', 14.716666666666667, 10.8, 9.066666666666665),
	(7, 10, 11, 'm', 'H_III', '100 m', 12.883333333333333, 10.133333333333333, 8.266666666666667),
	(7, 12, 13, 'm', 'H_III', '200 m', 24.833333333333332, 18.4, 15.6),
	(7, 14, 15, 'm', 'H_III', '200 m', 22.083333333333336, 16.4, 14.133333333333333),
	(7, 16, 17, 'm', 'H_III', '200 m', 20.233333333333334, 15.466666666666665, 13.333333333333332),
	(7, 18, 19, 'm', 'H_III', '200 m', 18.183333333333334, 13.883333333333333, 11.899999999999999),
	(7, 20, 24, 'm', 'H_III', '200 m', 17.85, 13.65, 11.500000000000002),
	(7, 25, 29, 'm', 'H_III', '200 m', 18.650000000000002, 14.0, 11.899999999999999),
	(7, 30, 34, 'm', 'H_III', '200 m', 20.733333333333334, 15.049999999999999, 12.6),
	(7, 35, 39, 'm', 'H_III', '200 m', 23.216666666666665, 16.8, 13.466666666666665),
	(7, 40, 44, 'm', 'H_III', '200 m', 26.099999999999998, 18.5, 14.299999999999999),
	(7, 45, 49, 'm', 'H_III', '200 m', 27.76666666666667, 19.48333333333333, 14.466666666666665),
	(7, 50, 54, 'm', 'H_III', '100 m', 14.016666666666666, 10.033333333333333, 7.516666666666666),
	(7, 55, 59, 'm', 'H_III', '100 m', 14.350000000000001, 10.2, 7.933333333333333),
	(7, 60, 64, 'm', 'H_III', '100 m', 14.616666666666665, 10.316666666666666, 8.983333333333333),
	(7, 65, 69, 'm', 'H_III', '100 m', 14.833333333333334, 10.55, 8.049999999999999),
	(7, 70, 74, 'm', 'H_III', '100 m', 14.833333333333334, 10.666666666666668, 8.116666666666667),
	(7, 75, 79, 'm', 'H_III', '50 m', 7.583333333333333, 5.366666666666666, 4.250000000000001),
	(7, 80, 84, 'm', 'H_III', '50 m', 7.6499999999999995, 5.483333333333333, 4.316666666666667),
	(7, 85, 89, 'm', 'H_III', '50 m', 7.6499999999999995, 5.6000000000000005, 4.5),
	(7, 90, 200, 'm', 'H_III', '50 m', 7.85, 5.716666666666666, 4.733333333333334),
	(10, 0, 7, 'w', 'H_III', '', 1.3, 2.3, 3.0),
	(10, 8, 9, 'w', 'H_III', '', 1.9, 3.0, 3.8),
	(10, 10, 11, 'w', 'H_III', '', 2.3, 3.8, 4.5),
	(10, 12, 13, 'w', 'H_III', '', 3.2, 4.5, 5.5),
	(10, 0, 7, 'm', 'H_III', '', 2.6, 3.8, 4.3),
	(10, 8, 9, 'm', 'H_III', '', 3.6, 5.0, 5.8),
	(10, 10, 11, 'm', 'H_III', '', 4.5, 6.3, 7.0),
	(11, 14, 15, 'w', 'H_III', '', 4.3, 6.0, 6.8),
	(11, 16, 17, 'w', 'H_III', '', 5.1, 6.8, 7.8),
	(11, 18, 19, 'w', 'H_III', '', 6.0, 8.0, 8.7),
	(11, 20, 24, 'w', 'H_III', '', 6.1, 8.1, 8.9),
	(11, 25, 29, 'w', 'H_III', '', 6.1, 8.1, 8.9),
	(11, 30, 34, 'w', 'H_III', '', 5.6, 7.5, 8.3),
	(11, 35, 39, 'w', 'H_III', '', 5.4, 7.2, 8.0),
	(11, 40, 44, 'w', 'H_III', '', 5.0, 6.8, 7.5),
	(11, 45, 49, 'w', 'H_III', '', 4.7, 6.5, 7.2),
	(11, 50, 54, 'w', 'H_III', '', 4.2, 6.0, 6.9),
	(11, 55, 59, 'w', 'H_III', '', 4.0, 5.7, 6.6),
	(11, 60, 64, 'w', 'H_III', '', 3.7, 5.4, 6.3),
	(11, 65, 69, 'w', 'H_III', '', 3.4, 5.1, 6.0),
	(11, 70, 74, 'w', 'H_III', '', 3.3, 5.0, 5.9),
	(11, 75, 79, 'w', 'H_III', '', 3.1, 4.7, 5.6),
	(11, 80, 84, 'w', 'H_III', '', 2.8, 4.4, 5.3),
	(11, 85, 89, 'w', 'H_III', '', 2.4, 3.9, 4.8),
	(11, 90, 200, 'w', 'H_III', '', 1.9, 3.3, 4.2),
	(11, 12, 13, 'm', 'H_III', '', 5.5, 7.5, 8.3),
	(11, 14, 15, 'm', 'H_III', '', 6.4, 8.5, 9.3),
	(11, 16, 17, 'm', 'H_III', '', 7.2, 9.5, 10.5),
	(11, 18, 19, 'm', 'H_III', '', 8.0, 10.8, 12.2),
	(11, 20, 24, 'm', 'H_III', '', 8.4, 11.4, 12.6),
	(11, 25, 29, 'm', 'H_III', '', 8.3, 11.3, 12.5),
	(11, 30, 34, 'm', 'H_III', '', 7.7, 10.5, 12.0),
	(11, 35, 39, 'm', 'H_III', '', 7.3, 10.1, 11.6),
	(11, 40, 44, 'm', 'H_III', '', 7.1, 9.9, 11.4),
	(11, 45, 49, 'm', 'H_III', '', 6.9, 9.6, 11.3),
	(11, 50, 54, 'm', 'H_III', '', 6.5, 9.3, 11.0),
	(11, 55, 59, 'm', 'H_III', '', 6.0, 8.7, 10.5),
	(11, 60, 64, 'm', 'H_III', '', 5.7, 8.4, 10.2),
	(11, 65, 69, 'm', 'H_III', '', 5.1, 7.7, 9.2),
	(11, 70, 74, 'm', 'H_III', '', 4.7, 7.2, 8.7),
	(11, 75, 79, 'm', 'H_III', '', 4.1, 4.7, 5.6),
	(11, 80, 84, 'm', 'H_III', '', 3.6, 4.4, 5.3),
	(11, 85, 89, 'm', 'H_III', '', 3.1, 3.9, 4.8),
	(11, 90, 200, 'm', 'H_III', '', 2.7, 3.3, 4.2),
	(13, 12, 13, 'w', 'H_III', '2 kg', 1.0, 1.3, 1.4),
	(13, 14, 15, 'w', 'H_III', '2 kg', 1.2, 1.5, 1.6),
	(13, 16, 17, 'w', 'H_III', '2 kg', 1.2, 1.6, 1.7),
	(13, 18, 19, 'w', 'H_III', '2 kg', 1.4, 1.8, 1.9),
	(13, 20, 24, 'w', 'H_III', '2 kg', 1.4, 1.8, 1.9),
	(13, 25, 29, 'w', 'H_III', '2 kg', 1.4, 1.8, 1.9),
	(13, 30, 34, 'w', 'H_III', '2 kg', 1.3, 1.7, 1.8),
	(13, 35, 39, 'w', 'H_III', '2 kg', 1.3, 1.6, 1.8),
	(13, 40, 44, 'w', 'H_III', '2 kg', 1.2, 1.5, 1.6),
	(13, 45, 49, 'w', 'H_III', '2 kg', 1.1, 1.4, 1.6),
	(13, 50, 54, 'w', 'H_III', '2 kg', 1.06, 1.36, 1.56),
	(13, 55, 59, 'w', 'H_III', '2 kg', 1.02, 1.32, 1.52),
	(13, 60, 64, 'w', 'H_III', '2 kg', 0.98, 1.28, 1.48),
	(13, 65, 69, 'w', 'H_III', '2 kg', 0.94, 1.24, 1.44),
	(13, 70, 74, 'w', 'H_III', '2 kg', 0.9, 1.2, 1.4),
	(13, 75, 79, 'w', 'H_III', '2 kg', 0.86, 1.16, 1.36),
	(13, 80, 84, 'w', 'H_III', '2 kg', 0.82, 1.12, 1.32),
	(13, 85, 89, 'w', 'H_III', '2 kg', 0.78, 1.08, 1.28),
	(13, 90, 200, 'w', 'H_III', '2 kg', 0.74, 1.04, 1.24),
	(13, 12, 13, 'm', 'H_III', '2 kg', 1.3, 1.7, 1.8),
	(13, 14, 15, 'm', 'H_III', '2 kg', 1.5, 1.9, 2.0),
	(13, 16, 17, 'm', 'H_III', '2 kg', 1.6, 2.0, 2.1),
	(13, 18, 19, 'm', 'H_III', '2 kg', 1.6, 2.1, 2.2),
	(13, 20, 24, 'm', 'H_III', '2 kg', 1.6, 2.1, 2.3),
	(13, 25, 29, 'm', 'H_III', '2 kg', 1.6, 2.1, 2.2),
	(13, 30, 34, 'm', 'H_III', '2 kg', 1.5, 1.9, 2.1),
	(13, 35, 39, 'm', 'H_III', '2 kg', 1.4, 1.8, 2.0),
	(13, 40, 44, 'm', 'H_III', '2 kg', 1.3, 1.8, 1.9),
	(13, 45, 49, 'm', 'H_III', '2 kg', 1.3, 1.7, 1.9),
	(13, 50, 54, 'm', 'H_III', '2 kg', 1.26, 1.66, 1.86),
	(13, 55, 59, 'm', 'H_III', '2 kg', 1.22, 1.62, 1.82),
	(13, 60, 64, 'm', 'H_III', '2 kg', 1.18, 1.58, 1.78),
	(13, 65, 69, 'm', 'H_III', '2 kg', 1.14, 1.54, 1.74),
	(13, 70, 74, 'm', 'H_III', '2 kg', 1.1, 1.5, 1.7),
	(13, 75, 79, 'm', 'H_III', '2 kg', 1.06, 1.46, 1.66),
	(13, 80, 84, 'm', 'H_III', '2 kg', 1.02, 1.42, 1.62),
	(13, 85, 89, 'm', 'H_III', '2 kg', 0.98, 1.38, 1.58),
	(13, 90, 200, 'm', 'H_III', '2 kg', 0.94, 1.34, 1.54),
	(29, 18, 19, 'w', 'H_III', '', 7.183333333333334, 5.6499999999999995, 5.050000000000001),
	(29, 20, 24, 'w', 'H_III', '', 7.016666666666667, 5.5, 4.9),
	(29, 25, 29, 'w', 'H_III', '', 7.133333333333334, 5.6000000000000005, 5.0),
	(29, 30, 34, 'w', 'H_III', '', 7.416666666666667, 5.85, 5.250000000000001),
	(29, 35, 39, 'w', 'H_III', '', 7.583333333333333, 6.0, 5.4),
	(29, 40, 44, 'w', 'H_III', '', 7.883333333333334, 6.2, 5.55),
	(29, 45, 49, 'w', 'H_III', '', 8.216666666666669, 6.449999999999999, 5.6499999999999995),
	(29, 50, 54, 'w', 'H_III', '', 8.566666666666666, 6.6499999999999995, 5.75),
	(29, 55, 59, 'w', 'H_III', '', 8.916666666666668, 6.85, 5.95),
	(29, 60, 64, 'w', 'H_III', '', 9.15, 7.050000000000001, 6.1499999999999995),
	(29, 65, 69, 'w', 'H_III', '', 9.366666666666667, 7.250000000000001, 6.35),
	(29, 70, 74, 'w', 'H_III', '', 9.55, 7.4, 6.5),
	(29, 75, 79, 'w', 'H_III', '', 9.833333333333334, 7.6499999999999995, 6.75),
	(29, 80, 84, 'w', 'H_III', '', 10.233333333333334, 8.0, 7.1),
	(29, 85, 89, 'w', 'H_III', '', 10.7, 8.4, 7.5),
	(29, 90, 200, 'w', 'H_III', '', 11.216666666666669, 8.85, 7.95),
	(29, 18, 19, 'm', 'H_III', '', 6.1499999999999995, 4.75, 4.1499999999999995),
	(29, 20, 24, 'm', 'H_III', '', 5.983333333333333, 4.6000000000000005, 4.0),
	(29, 25, 29, 'm', 'H_III', '', 6.1, 4.7, 4.1),
	(29, 30, 34, 'm', 'H_III', '', 6.383333333333334, 4.95, 4.35),
	(29, 35, 39, 'm', 'H_III', '', 6.85, 5.2, 4.5),
	(29, 40, 44, 'm', 'H_III', '', 7.250000000000001, 5.55, 4.75),
	(29, 45, 49, 'm', 'H_III', '', 7.6499999999999995, 5.85, 4.95),
	(29, 50, 54, 'm', 'H_III', '', 8.049999999999999, 6.1, 5.2),
	(29, 55, 59, 'm', 'H_III', '', 8.216666666666669, 6.250000000000001, 5.35),
	(29, 60, 64, 'm', 'H_III', '', 8.45, 6.449999999999999, 5.55),
	(29, 65, 69, 'm', 'H_III', '', 8.616666666666665, 6.6000000000000005, 5.7),
	(29, 70, 74, 'm', 'H_III', '', 8.733333333333333, 6.7, 5.800000000000001),
	(29, 75, 79, 'm', 'H_III', '', 8.966666666666667, 6.9, 6.0),
	(29, 80, 84, 'm', 'H_III', '', 9.15, 7.050000000000001, 6.1499999999999995),
	(29, 85, 89, 'm', 'H_III', '', 9.483333333333333, 7.35, 6.449999999999999),
	(29, 90, 200, 'm', 'H_III', '', 10.299999999999999, 8.049999999999999, 7.1499999999999995),
	(34, 0, 7, 'w', 'H_III', '', 5.0, 8.500000000000002, 12.0),
	(34, 8, 9, 'w', 'H_III', '', 7.0, 10.500000000000002, 14.0),
	(34, 10, 11, 'w', 'H_III', '', 10.500000000000002, 14.0, 21.0),
	(34, 12, 13, 'w', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 14, 15, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 16, 17, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 18, 19, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 20, 24, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 25, 29, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 30, 34, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 35, 39, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 40, 44, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 45, 49, 'w', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 50, 54, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 55, 59, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 60, 64, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 65, 69, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 70, 74, 'w', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 75, 79, 'w', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 80, 84, 'w', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 85, 89, 'w', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 90, 200, 'w', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 0, 7, 'm', 'H_III', '', 5.0, 8.500000000000002, 12.0),
	(34, 8, 9, 'm', 'H_III', '', 7.0, 10.500000000000002, 14.0),
	(34, 10, 11, 'm', 'H_III', '', 10.500000000000002, 14.0, 21.0),
	(34, 12, 13, 'm', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 14, 15, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 16, 17, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 18, 19, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 20, 24, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 25, 29, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 30, 34, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 35, 39, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 40, 44, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 45, 49, 'm', 'H_III', '', 31.5, 42.0, 52.49999999999999),
	(34, 50, 54, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 55, 59, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 60, 64, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 65, 69, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 70, 74, 'm', 'H_III', '', 21.0, 28.0, 35.0),
	(34, 75, 79, 'm', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 80, 84, 'm', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 85, 89, 'm', 'H_III', '', 14.0, 21.0, 28.0),
	(34, 90, 200, 'm', 'H_III', '', 14.0, 21.0, 28.0),
	(35, 0, 7, 'w', 'H_III', '1 km', 17.516666666666666, 14.0, 12.500000000000002),
	(35, 8, 9, 'w', 'H_III', '1 km', 15.516666666666667, 12.0, 10.500000000000002),
	(35, 10, 11, 'w', 'H_III', '1,5 km', 29.03333333333333, 21.5, 17.75),
	(35, 12, 13, 'w', 'H_III', '1,5 km', 25.866666666666667, 19.75, 16.75),
	(35, 14, 15, 'w', 'H_III', '1,5 km', 21.85, 16.249999999999996, 14.25),
	(35, 16, 17, 'w', 'H_III', '1,5 km', 18.683333333333334, 14.25, 12.500000000000002),
	(35, 18, 19, 'w', 'H_III', '3 km', 33.06666666666666, 26.0, 23.249999999999996),
	(35, 20, 24, 'w', 'H_III', '3 km', 32.766666666666666, 25.75, 22.75),
	(35, 25, 29, 'w', 'H_III', '3 km', 32.199999999999996, 25.249999999999996, 22.5),
	(35, 30, 34, 'w', 'H_III', '3 km', 32.766666666666666, 25.75, 22.75),
	(35, 35, 39, 'w', 'H_III', '3 km', 34.49999999999999, 26.5, 23.5),
	(35, 40, 44, 'w', 'H_III', '3 km', 36.8, 27.75, 24.75),
	(35, 45, 49, 'w', 'H_III', '3 km', 38.51666666666667, 29.249999999999996, 25.75),
	(35, 50, 54, 'w', 'H_III', '3 km', 39.666666666666664, 30.5, 26.75),
	(35, 55, 59, 'w', 'H_III', '3 km', 41.11666666666667, 31.5, 27.75),
	(35, 60, 64, 'w', 'H_III', '3 km', 42.55, 32.49999999999999, 28.5),
	(35, 65, 69, 'w', 'H_III', '3 km', 43.416666666666664, 33.25, 29.249999999999996),
	(35, 70, 74, 'w', 'H_III', '3 km', 44.849999999999994, 34.25, 30.249999999999996),
	(35, 75, 79, 'w', 'H_III', '3 km', 46.866666666666674, 35.25, 31.5),
	(35, 80, 84, 'w', 'H_III', '3 km', 48.583333333333336, 37.49999999999999, 32.75000000000001),
	(35, 85, 89, 'w', 'H_III', '3 km', 51.46666666666667, 40.0, 34.49999999999999),
	(35, 90, 200, 'w', 'H_III', '3 km', 53.483333333333334, 41.49999999999999, 36.25),
	(35, 0, 7, 'm', 'H_III', '1 km', 17.233333333333334, 13.749999999999998, 12.25),
	(35, 8, 9, 'm', 'H_III', '1 km', 15.233333333333334, 11.749999999999998, 10.25),
	(35, 10, 11, 'm', 'H_III', '1,5 km', 27.883333333333336, 20.5, 16.75),
	(35, 12, 13, 'm', 'H_III', '1,5 km', 24.716666666666665, 18.5, 15.749999999999998),
	(35, 14, 15, 'm', 'H_III', '1,5 km', 18.4, 14.0, 12.0),
	(35, 16, 17, 'm', 'H_III', '1,5 km', 15.516666666666667, 11.749999999999998, 10.25),
	(35, 18, 19, 'm', 'H_III', '3 km', 27.01666666666667, 21.249999999999996, 19.249999999999996),
	(35, 20, 24, 'm', 'H_III', '3 km', 26.733333333333334, 21.0, 18.75),
	(35, 25, 29, 'm', 'H_III', '3 km', 28.75, 22.249999999999996, 19.5),
	(35, 30, 34, 'm', 'H_III', '3 km', 30.76666666666667, 23.5, 20.249999999999996),
	(35, 35, 39, 'm', 'H_III', '3 km', 33.35, 25.0, 20.75),
	(35, 40, 44, 'm', 'H_III', '3 km', 36.233333333333334, 26.0, 21.75),
	(35, 45, 49, 'm', 'H_III', '3 km', 37.95, 27.5, 22.5),
	(35, 50, 54, 'm', 'H_III', '3 km', 39.383333333333326, 28.5, 23.249999999999996),
	(35, 55, 59, 'm', 'H_III', '3 km', 40.53333333333333, 29.249999999999996, 23.75),
	(35, 60, 64, 'm', 'H_III', '3 km', 41.11666666666667, 30.0, 24.0),
	(35, 65, 69, 'm', 'H_III', '3 km', 41.68333333333333, 30.249999999999996, 24.249999999999996),
	(35, 70, 74, 'm', 'H_III', '3 km', 42.26666666666666, 30.75, 24.75),
	(35, 75, 79, 'm', 'H_III', '3 km', 42.833333333333336, 31.5, 25.75),
	(35, 80, 84, 'm', 'H_III', '3 km', 43.7, 32.25, 26.5),
	(35, 85, 89, 'm', 'H_III', '3 km', 44.56666666666667, 33.25, 27.75),
	(35, 90, 200, 'm', 'H_III', '3 km', 45.43333333333333, 34.0, 29.0),
	(43, 0, 7, 'w', 'H_III', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'w', 'H_III', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'w', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'w', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'w', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'w', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'w', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'w', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'w', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 0, 7, 'm', 'H_III', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'm', 'H_III', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'm', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'm', 'H_III', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'm', 'H_III', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'm', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'm', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'm', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'm', 'H_III', '', 10.0, 12.500000000000002, 15.0),
	(46, 0, 7, 'w', 'H_III', '', 0.8, 1.8, 2.5),
	(46, 8, 9, 'w', 'H_III', '', 1.4, 2.5, 3.3),
	(46, 10, 11, 'w', 'H_III', '', 1.8, 3.3, 4.0),
	(46, 12, 13, 'w', 'H_III', '', 2.2, 3.5, 4.5),
	(46, 14, 15, 'w', 'H_III', '', 3.3, 5.0, 5.8),
	(46, 16, 17, 'w', 'H_III', '', 4.1, 5.8, 6.8),
	(46, 18, 19, 'w', 'H_III', '', 5.0, 7.0, 7.7),
	(46, 20, 24, 'w', 'H_III', '', 5.1, 7.1, 7.9),
	(46, 25, 29, 'w', 'H_III', '', 5.1, 7.1, 7.9),
	(46, 30, 34, 'w', 'H_III', '', 4.6, 6.5, 7.3),
	(46, 35, 39, 'w', 'H_III', '', 4.4, 6.2, 7.0),
	(46, 40, 44, 'w', 'H_III', '', 4.0, 5.8, 6.5),
	(46, 45, 49, 'w', 'H_III', '', 3.7, 5.5, 6.2),
	(46, 50, 54, 'w', 'H_III', '', 3.2, 5.0, 5.9),
	(46, 55, 59, 'w', 'H_III', '', 3.0, 4.7, 5.6),
	(46, 60, 64, 'w', 'H_III', '', 2.7, 4.4, 5.3),
	(46, 65, 69, 'w', 'H_III', '', 2.4, 4.1, 5.0),
	(46, 70, 74, 'w', 'H_III', '', 2.3, 4.0, 4.9),
	(46, 75, 79, 'w', 'H_III', '', 2.1, 3.7, 4.6),
	(46, 80, 84, 'w', 'H_III', '', 1.8, 3.4, 4.3),
	(46, 85, 89, 'w', 'H_III', '', 1.4, 2.9, 3.8),
	(46, 90, 200, 'w', 'H_III', '', 0.9, 2.3, 3.2),
	(46, 0, 7, 'm', 'H_III', '', 2.1, 3.3, 3.8),
	(46, 8, 9, 'm', 'H_III', '', 3.1, 4.5, 5.3),
	(46, 10, 11, 'm', 'H_III', '', 4.0, 5.8, 6.5),
	(46, 12, 13, 'm', 'H_III', '', 4.5, 6.5, 7.3),
	(46, 14, 15, 'm', 'H_III', '', 5.4, 7.5, 8.3),
	(46, 16, 17, 'm', 'H_III', '', 6.2, 8.5, 9.5),
	(46, 18, 19, 'm', 'H_III', '', 7.0, 9.8, 11.2),
	(46, 20, 24, 'm', 'H_III', '', 7.4, 10.4, 11.6),
	(46, 25, 29, 'm', 'H_III', '', 7.3, 10.3, 11.5),
	(46, 30, 34, 'm', 'H_III', '', 6.7, 9.5, 11.0),
	(46, 35, 39, 'm', 'H_III', '', 6.3, 9.1, 10.6),
	(46, 40, 44, 'm', 'H_III', '', 6.1, 8.9, 10.4),
	(46, 45, 49, 'm', 'H_III', '', 5.9, 8.6, 10.3),
	(46, 50, 54, 'm', 'H_III', '', 5.5, 8.3, 10.0),
	(46, 55, 59, 'm', 'H_III', '', 5.0, 7.7, 9.5),
	(46, 60, 64, 'm', 'H_III', '', 4.7, 7.4, 9.2),
	(46, 65, 69, 'm', 'H_III', '', 4.1, 6.7, 8.2),
	(46, 70, 74, 'm', 'H_III', '', 3.7, 6.2, 7.7),
	(46, 75, 79, 'm', 'H_III', '', 3.1, 3.7, 4.6),
	(46, 80, 84, 'm', 'H_III', '', 2.6, 3.4, 4.3),
	(46, 85, 89, 'm', 'H_III', '', 2.1, 2.9, 3.8),
	(46, 90, 200, 'm', 'H_III', '', 1.7, 2.3, 3.2),
	(48, 0, 7, 'w', 'H_III', '30 m', 27.6, 21.3, 18.9),
	(48, 8, 9, 'w', 'H_III', '30 m', 25.5, 19.8, 17.1),
	(48, 10, 11, 'w', 'H_III', '50 m', 38.0, 30.3, 27.3),
	(48, 12, 13, 'w', 'H_III', '50 m', 36.6, 28.8, 25.5),
	(48, 14, 15, 'w', 'H_III', '100 m', 55.8, 51.0, 46.5),
	(48, 16, 17, 'w', 'H_III', '100 m', 52.8, 48.9, 45.0),
	(48, 18, 19, 'w', 'H_III', '100 m', 62.8, 49.5, 45.9),
	(48, 20, 24, 'w', 'H_III', '100 m', 63.8, 50.4, 46.8),
	(48, 25, 29, 'w', 'H_III', '100 m', 65.2, 51.6, 48.0),
	(48, 30, 34, 'w', 'H_III', '100 m', 67.6, 53.4, 49.2),
	(48, 35, 39, 'w', 'H_III', '100 m', 70.4, 55.8, 51.0),
	(48, 40, 44, 'w', 'H_III', '50 m', 38.0, 29.7, 26.4),
	(48, 45, 49, 'w', 'H_III', '50 m', 39.7, 30.9, 27.3),
	(48, 50, 54, 'w', 'H_III', '50 m', 41.1, 32.1, 28.5),
	(48, 55, 59, 'w', 'H_III', '50 m', 42.8, 33.6, 29.7),
	(48, 60, 64, 'w', 'H_III', '50 m', 43.5, 34.2, 30.6),
	(48, 65, 69, 'w', 'H_III', '50 m', 44.2, 34.8, 31.2),
	(48, 70, 74, 'w', 'H_III', '50 m', 44.9, 35.4, 31.8),
	(48, 75, 79, 'w', 'H_III', '50 m', 46.6, 36.9, 33.3),
	(48, 80, 84, 'w', 'H_III', '50 m', 49.3, 39.3, 36.0),
	(48, 85, 89, 'w', 'H_III', '50 m', 53.5, 42.9, 39.6),
	(48, 90, 200, 'w', 'H_III', '50 m', 59.0, 47.7, 44.4),
	(48, 0, 7, 'm', 'H_III', '30 m', 26.6, 20.4, 18.0),
	(48, 8, 9, 'm', 'H_III', '30 m', 24.8, 19.2, 17.1),
	(48, 10, 11, 'm', 'H_III', '50 m', 35.5, 27.9, 25.2),
	(48, 12, 13, 'm', 'H_III', '50 m', 33.5, 26.7, 24.3),
	(48, 14, 15, 'm', 'H_III', '100 m', 58.7, 46.2, 42.3),
	(48, 16, 17, 'm', 'H_III', '100 m', 56.2, 44.4, 40.5),
	(48, 18, 19, 'm', 'H_III', '100 m', 55.2, 43.8, 39.6),
	(48, 20, 24, 'm', 'H_III', '100 m', 54.5, 43.2, 39.0),
	(48, 25, 29, 'm', 'H_III', '100 m', 56.2, 44.4, 39.9),
	(48, 30, 34, 'm', 'H_III', '100 m', 58.0, 45.3, 40.8),
	(48, 35, 39, 'm', 'H_III', '100 m', 60.7, 47.7, 42.6),
	(48, 40, 44, 'm', 'H_III', '50 m', 33.1, 26.1, 23.1),
	(48, 45, 49, 'm', 'H_III', '50 m', 34.5, 26.7, 23.7),
	(48, 50, 54, 'm', 'H_III', '50 m', 35.5, 27.3, 24.6),
	(48, 55, 59, 'm', 'H_III', '50 m', 36.2, 28.2, 25.5),
	(48, 60, 64, 'm', 'H_III', '50 m', 37.3, 29.1, 26.4),
	(48, 65, 69, 'm', 'H_III', '50 m', 38.6, 30.6, 27.3),
	(48, 70, 74, 'm', 'H_III', '50 m', 40.4, 32.1, 28.8),
	(48, 75, 79, 'm', 'H_III', '50 m', 42.1, 33.6, 30.3),
	(48, 80, 84, 'm', 'H_III', '50 m', 44.9, 36.0, 32.7),
	(48, 85, 89, 'm', 'H_III', '50 m', 48.6, 39.3, 36.0),
	(48, 90, 200, 'm', 'H_III', '50 m', 53.5, 43.5, 40.2),
	(50, 0, 7, 'w', 'H_III', '', 3.14, 2.33, 2.14),
	(50, 8, 9, 'w', 'H_III', '', 2.54, 2.13, 1.54),
	(50, 10, 11, 'w', 'H_III', '', 2.37, 1.58, 1.39),
	(50, 12, 13, 'w', 'H_III', '', 2.11, 1.39, 1.26),
	(50, 14, 15, 'w', 'H_III', '', 1.54, 1.3, 1.19),
	(50, 16, 17, 'w', 'H_III', '', 1.46, 1.23, 1.14),
	(50, 18, 19, 'w', 'H_III', '', 1.42, 1.21, 1.12),
	(50, 20, 24, 'w', 'H_III', '', 1.44, 1.21, 1.12),
	(50, 25, 29, 'w', 'H_III', '', 1.46, 1.23, 1.14),
	(50, 30, 34, 'w', 'H_III', '', 1.5, 1.26, 1.19),
	(50, 35, 39, 'w', 'H_III', '', 1.57, 1.3, 1.21),
	(50, 40, 44, 'w', 'H_III', '', 2.03, 1.34, 1.23),
	(50, 45, 49, 'w', 'H_III', '', 2.09, 1.39, 1.25),
	(50, 50, 54, 'w', 'H_III', '', 2.16, 1.43, 1.26),
	(50, 55, 59, 'w', 'H_III', '', 2.22, 1.47, 1.28),
	(50, 60, 64, 'w', 'H_III', '', 2.28, 1.51, 1.32),
	(50, 65, 69, 'w', 'H_III', '', 2.33, 1.54, 1.34),
	(50, 70, 74, 'w', 'H_III', '', 2.41, 1.58, 1.38),
	(50, 75, 79, 'w', 'H_III', '', 2.45, 2.02, 1.41),
	(50, 80, 84, 'w', 'H_III', '', 2.52, 2.07, 1.45),
	(50, 85, 89, 'w', 'H_III', '', 2.58, 2.13, 1.51),
	(50, 90, 200, 'w', 'H_III', '', 3.09, 2.2, 1.56),
	(50, 0, 7, 'm', 'H_III', '', 3.01, 2.22, 2.03),
	(50, 8, 9, 'm', 'H_III', '', 2.41, 2.02, 1.43),
	(50, 10, 11, 'm', 'H_III', '', 2.28, 1.52, 1.36),
	(50, 12, 13, 'm', 'H_III', '', 2.05, 1.36, 1.23),
	(50, 14, 15, 'm', 'H_III', '', 1.42, 1.19, 1.1),
	(50, 16, 17, 'm', 'H_III', '', 1.33, 1.12, 1.02),
	(50, 18, 19, 'm', 'H_III', '', 1.27, 1.06, 0.57),
	(50, 20, 24, 'm', 'H_III', '', 1.25, 1.04, 0.55),
	(50, 25, 29, 'm', 'H_III', '', 1.29, 1.06, 0.55),
	(50, 30, 34, 'm', 'H_III', '', 1.35, 1.08, 0.55),
	(50, 35, 39, 'm', 'H_III', '', 1.42, 1.14, 0.57),
	(50, 40, 44, 'm', 'H_III', '', 1.52, 1.19, 1.01),
	(50, 45, 49, 'm', 'H_III', '', 2.01, 1.25, 1.02),
	(50, 50, 54, 'm', 'H_III', '', 2.07, 1.28, 1.06),
	(50, 55, 59, 'm', 'H_III', '', 2.16, 1.32, 1.08),
	(50, 60, 64, 'm', 'H_III', '', 2.22, 1.36, 1.1),
	(50, 65, 69, 'm', 'H_III', '', 2.28, 1.39, 1.12),
	(50, 70, 74, 'm', 'H_III', '', 2.33, 1.45, 1.14),
	(50, 75, 79, 'm', 'H_III', '', 2.39, 1.49, 1.19),
	(50, 80, 84, 'm', 'H_III', '', 2.45, 1.56, 1.25),
	(50, 85, 89, 'm', 'H_III', '', 2.54, 2.02, 1.3),
	(50, 90, 200, 'm', 'H_III', '', 3.05, 2.11, 1.39),
	(53, 0, 7, 'w', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'H_III', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'H_III', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'H_III', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'H_III', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(56, 0, 7, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'w', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 0, 7, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'm', 'H_III', '', 1.0, 2.0, 3.0),
	(58, 0, 7, 'w', 'H_III', '', 5.52, 4.3, 3.5),
	(58, 8, 9, 'w', 'H_III', '', 5.47, 4.21, 3.45),
	(58, 10, 11, 'w', 'H_III', '', 5.31, 4.12, 3.36),
	(58, 12, 13, 'w', 'H_III', '', 5.21, 3.59, 3.23),
	(58, 14, 15, 'w', 'H_III', '', 5.1, 3.54, 3.14),
	(58, 16, 17, 'w', 'H_III', '', 5.0, 3.41, 3.04),
	(58, 0, 7, 'm', 'H_III', '', 5.52, 4.3, 3.5),
	(58, 8, 9, 'm', 'H_III', '', 5.36, 4.12, 3.32),
	(58, 10, 11, 'm', 'H_III', '', 5.16, 3.54, 3.14),
	(58, 12, 13, 'm', 'H_III', '', 4.55, 3.36, 2.56),
	(58, 14, 15, 'm', 'H_III', '', 4.29, 3.18, 2.42),
	(58, 16, 17, 'm', 'H_III', '', 4.14, 3.04, 2.29),
	(59, 0, 7, 'w', 'H_III', '', 0.8, 1.8, 2.5),
	(59, 8, 9, 'w', 'H_III', '', 1.4, 2.5, 3.3),
	(59, 10, 11, 'w', 'H_III', '', 1.8, 3.3, 4.0),
	(59, 12, 13, 'w', 'H_III', '', 2.2, 3.5, 4.5),
	(59, 14, 15, 'w', 'H_III', '', 3.3, 5.0, 5.8),
	(59, 16, 17, 'w', 'H_III', '', 4.1, 5.8, 6.8),
	(59, 18, 19, 'w', 'H_III', '', 5.0, 7.0, 7.7),
	(59, 20, 24, 'w', 'H_III', '', 5.1, 7.1, 7.9),
	(59, 25, 29, 'w', 'H_III', '', 5.1, 7.1, 7.9),
	(59, 30, 34, 'w', 'H_III', '', 4.6, 6.5, 7.3),
	(59, 35, 39, 'w', 'H_III', '', 4.4, 6.2, 7.0),
	(59, 40, 44, 'w', 'H_III', '', 4.0, 5.8, 6.5),
	(59, 45, 49, 'w', 'H_III', '', 3.7, 5.5, 6.2),
	(59, 50, 54, 'w', 'H_III', '', 3.2, 5.0, 5.9),
	(59, 55, 59, 'w', 'H_III', '', 3.0, 4.7, 5.6),
	(59, 60, 64, 'w', 'H_III', '', 2.7, 4.4, 5.3),
	(59, 65, 69, 'w', 'H_III', '', 2.4, 4.1, 5.0),
	(59, 70, 74, 'w', 'H_III', '', 2.3, 4.0, 4.9),
	(59, 75, 79, 'w', 'H_III', '', 2.1, 3.7, 4.6),
	(59, 80, 84, 'w', 'H_III', '', 1.8, 3.4, 4.3),
	(59, 85, 89, 'w', 'H_III', '', 1.4, 2.9, 3.8),
	(59, 90, 200, 'w', 'H_III', '', 0.9, 2.3, 3.2),
	(59, 0, 7, 'm', 'H_III', '', 2.1, 3.3, 3.8),
	(59, 8, 9, 'm', 'H_III', '', 3.1, 4.5, 5.3),
	(59, 10, 11, 'm', 'H_III', '', 4.0, 5.8, 6.5),
	(59, 12, 13, 'm', 'H_III', '', 4.5, 6.5, 7.3),
	(59, 14, 15, 'm', 'H_III', '', 5.4, 7.5, 8.3),
	(59, 16, 17, 'm', 'H_III', '', 6.2, 8.5, 9.5),
	(59, 18, 19, 'm', 'H_III', '', 7.0, 9.8, 11.2),
	(59, 20, 24, 'm', 'H_III', '', 7.4, 10.4, 11.6),
	(59, 25, 29, 'm', 'H_III', '', 7.3, 10.3, 11.5),
	(59, 30, 34, 'm', 'H_III', '', 6.7, 9.5, 11.0),
	(59, 35, 39, 'm', 'H_III', '', 6.3, 9.1, 10.6),
	(59, 40, 44, 'm', 'H_III', '', 6.1, 8.9, 10.4),
	(59, 45, 49, 'm', 'H_III', '', 5.9, 8.6, 10.3),
	(59, 50, 54, 'm', 'H_III', '', 5.5, 8.3, 10.0),
	(59, 55, 59, 'm', 'H_III', '', 5.0, 7.7, 9.5),
	(59, 60, 64, 'm', 'H_III', '', 4.7, 7.4, 9.2),
	(59, 65, 69, 'm', 'H_III', '', 4.1, 6.7, 8.2),
	(59, 70, 74, 'm', 'H_III', '', 3.7, 6.2, 7.7),
	(59, 75, 79, 'm', 'H_III', '', 3.1, 3.7, 4.6),
	(59, 80, 84, 'm', 'H_III', '', 2.6, 3.4, 4.3),
	(59, 85, 89, 'm', 'H_III', '', 2.1, 2.9, 3.8),
	(59, 90, 200, 'm', 'H_III', '', 1.7, 2.3, 3.2),
	(60, 0, 7, 'w', 'H_III', '', 3.33, 2.34, 2.02),
	(60, 8, 9, 'w', 'H_III', '', 3.13, 2.16, 1.52),
	(60, 10, 11, 'w', 'H_III', '', 2.59, 2.06, 1.42),
	(60, 12, 13, 'w', 'H_III', '', 2.41, 1.56, 1.34),
	(60, 14, 15, 'w', 'H_III', '', 2.31, 1.5, 1.26),
	(60, 16, 17, 'w', 'H_III', '', 2.2, 1.42, 1.2),
	(60, 18, 19, 'w', 'H_III', '', 2.15, 1.36, 1.14),
	(60, 20, 24, 'w', 'H_III', '', 2.13, 1.36, 1.14),
	(60, 25, 29, 'w', 'H_III', '', 2.18, 1.4, 1.18),
	(60, 30, 34, 'w', 'H_III', '', 2.29, 1.46, 1.24),
	(60, 35, 39, 'w', 'H_III', '', 2.45, 1.56, 1.28),
	(60, 40, 44, 'w', 'H_III', '', 3.04, 2.06, 1.34),
	(60, 45, 49, 'w', 'H_III', '', 3.22, 2.2, 1.4),
	(60, 50, 54, 'w', 'H_III', '', 3.4, 2.36, 1.52),
	(60, 55, 59, 'w', 'H_III', '', 3.56, 2.5, 2.02),
	(60, 60, 64, 'w', 'H_III', '', 4.1, 2.58, 2.1),
	(60, 65, 69, 'w', 'H_III', '', 4.19, 3.06, 2.18),
	(60, 70, 74, 'w', 'H_III', '', 4.31, 3.12, 2.24),
	(60, 75, 79, 'w', 'H_III', '', 4.4, 3.2, 2.32),
	(60, 80, 84, 'w', 'H_III', '', 4.52, 3.28, 2.4),
	(60, 85, 89, 'w', 'H_III', '', 5.01, 3.34, 2.46),
	(60, 90, 200, 'w', 'H_III', '', 5.05, 3.38, 2.5),
	(60, 0, 7, 'm', 'H_III', '', 3.31, 2.32, 2.0),
	(60, 8, 9, 'm', 'H_III', '', 3.08, 2.12, 1.44),
	(60, 10, 11, 'm', 'H_III', '', 2.45, 1.56, 1.3),
	(60, 12, 13, 'm', 'H_III', '', 2.31, 1.48, 1.24),
	(60, 14, 15, 'm', 'H_III', '', 2.22, 1.42, 1.2),
	(60, 16, 17, 'm', 'H_III', '', 2.15, 1.38, 1.16),
	(60, 18, 19, 'm', 'H_III', '', 2.08, 1.32, 1.1),
	(60, 20, 24, 'm', 'H_III', '', 2.04, 1.28, 1.02),
	(60, 25, 29, 'm', 'H_III', '', 2.13, 1.32, 1.06),
	(60, 30, 34, 'm', 'H_III', '', 2.24, 1.36, 1.08),
	(60, 35, 39, 'm', 'H_III', '', 2.41, 1.46, 1.14),
	(60, 40, 44, 'm', 'H_III', '', 2.57, 1.58, 1.16),
	(60, 45, 49, 'm', 'H_III', '', 3.13, 2.1, 1.22),
	(60, 50, 54, 'm', 'H_III', '', 3.27, 2.2, 1.32),
	(60, 55, 59, 'm', 'H_III', '', 3.45, 2.28, 1.4),
	(60, 60, 64, 'm', 'H_III', '', 3.54, 2.36, 1.48),
	(60, 65, 69, 'm', 'H_III', '', 4.01, 2.42, 1.54),
	(60, 70, 74, 'm', 'H_III', '', 4.13, 2.52, 2.04),
	(60, 75, 79, 'm', 'H_III', '', 4.24, 3.02, 2.14),
	(60, 80, 84, 'm', 'H_III', '', 4.31, 3.12, 2.24),
	(60, 85, 89, 'm', 'H_III', '', 4.33, 3.16, 2.32),
	(60, 90, 200, 'm', 'H_III', '', 4.36, 3.2, 2.4)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(7, 0, 7, 'w', 'H_IV', '100 m', 24.833333333333332, 18.4, 15.2),
	(7, 8, 9, 'w', 'H_IV', '100 m', 22.083333333333336, 16.8, 14.2),
	(7, 10, 11, 'w', 'H_IV', '100 m', 20.233333333333334, 15.4, 13.2),
	(7, 12, 13, 'w', 'H_IV', '200 m', 40.93333333333334, 31.0, 26.4),
	(7, 14, 15, 'w', 'H_IV', '200 m', 36.11666666666667, 28.0, 24.0),
	(7, 16, 17, 'w', 'H_IV', '200 m', 32.666666666666664, 25.200000000000003, 21.8),
	(7, 18, 19, 'w', 'H_IV', '200 m', 30.366666666666664, 23.283333333333335, 20.266666666666666),
	(7, 20, 24, 'w', 'H_IV', '200 m', 29.833333333333332, 22.916666666666668, 19.8),
	(7, 25, 29, 'w', 'H_IV', '200 m', 32.25, 23.183333333333334, 20.533333333333335),
	(7, 30, 34, 'w', 'H_IV', '200 m', 36.46666666666667, 26.03333333333333, 21.45),
	(7, 35, 39, 'w', 'H_IV', '200 m', 40.483333333333334, 28.15, 22.366666666666664),
	(7, 40, 44, 'w', 'H_IV', '200 m', 43.016666666666666, 30.433333333333337, 23.46666666666667),
	(7, 45, 49, 'w', 'H_IV', '200 m', 44.7, 31.9, 23.650000000000002),
	(7, 50, 54, 'w', 'H_IV', '100 m', 22.76666666666667, 16.5, 12.65),
	(7, 55, 59, 'w', 'H_IV', '100 m', 23.5, 16.866666666666667, 13.100000000000001),
	(7, 60, 64, 'w', 'H_IV', '100 m', 24.03333333333333, 17.15, 13.383333333333335),
	(7, 65, 69, 'w', 'H_IV', '100 m', 24.566666666666666, 17.333333333333332, 13.466666666666665),
	(7, 70, 74, 'w', 'H_IV', '100 m', 25.083333333333336, 17.700000000000003, 13.933333333333334),
	(7, 75, 79, 'w', 'H_IV', '50 m', 12.966666666666667, 9.166666666666666, 7.1499999999999995),
	(7, 80, 84, 'w', 'H_IV', '50 m', 13.183333333333332, 9.350000000000001, 7.416666666666667),
	(7, 85, 89, 'w', 'H_IV', '50 m', 13.383333333333335, 9.616666666666665, 7.800000000000001),
	(7, 90, 200, 'w', 'H_IV', '50 m', 13.6, 9.816666666666666, 8.066666666666665),
	(7, 0, 7, 'm', 'H_IV', '100 m', 24.833333333333332, 17.599999999999998, 14.8),
	(7, 8, 9, 'm', 'H_IV', '100 m', 22.083333333333336, 16.200000000000003, 13.6),
	(7, 10, 11, 'm', 'H_IV', '100 m', 19.31666666666667, 15.2, 12.4),
	(7, 12, 13, 'm', 'H_IV', '200 m', 37.26666666666666, 27.599999999999998, 23.4),
	(7, 14, 15, 'm', 'H_IV', '200 m', 33.11666666666667, 24.599999999999998, 21.200000000000003),
	(7, 16, 17, 'm', 'H_IV', '200 m', 30.366666666666664, 23.200000000000003, 20.0),
	(7, 18, 19, 'm', 'H_IV', '200 m', 28.566666666666666, 21.816666666666663, 18.700000000000003),
	(7, 20, 24, 'm', 'H_IV', '200 m', 28.03333333333333, 21.45, 18.066666666666666),
	(7, 25, 29, 'm', 'H_IV', '200 m', 29.3, 22.0, 18.700000000000003),
	(7, 30, 34, 'm', 'H_IV', '200 m', 32.56666666666667, 23.650000000000002, 19.8),
	(7, 35, 39, 'm', 'H_IV', '200 m', 36.46666666666667, 26.4, 21.183333333333334),
	(7, 40, 44, 'm', 'H_IV', '200 m', 41.0, 29.066666666666666, 22.46666666666667),
	(7, 45, 49, 'm', 'H_IV', '200 m', 43.65, 30.616666666666667, 22.733333333333334),
	(7, 50, 54, 'm', 'H_IV', '100 m', 22.03333333333333, 15.766666666666667, 11.833333333333334),
	(7, 55, 59, 'm', 'H_IV', '100 m', 22.566666666666666, 16.05, 12.466666666666665),
	(7, 60, 64, 'm', 'H_IV', '100 m', 22.983333333333334, 16.233333333333334, 12.55),
	(7, 65, 69, 'm', 'H_IV', '100 m', 23.3, 16.599999999999998, 12.65),
	(7, 70, 74, 'm', 'H_IV', '100 m', 23.3, 16.76666666666667, 12.749999999999998),
	(7, 75, 79, 'm', 'H_IV', '50 m', 11.916666666666668, 8.433333333333334, 6.7),
	(7, 80, 84, 'm', 'H_IV', '50 m', 12.016666666666666, 8.616666666666665, 6.783333333333333),
	(7, 85, 89, 'm', 'H_IV', '50 m', 12.016666666666666, 8.8, 7.066666666666666),
	(7, 90, 200, 'm', 'H_IV', '50 m', 12.333333333333332, 8.983333333333333, 7.416666666666667),
	(10, 0, 7, 'w', 'H_IV', '', 1.0, 1.8, 2.4),
	(10, 8, 9, 'w', 'H_IV', '', 1.5, 2.4, 3.0),
	(10, 10, 11, 'w', 'H_IV', '', 1.9, 3.0, 3.6),
	(10, 12, 13, 'w', 'H_IV', '', 2.6, 3.6, 4.4),
	(10, 0, 7, 'm', 'H_IV', '', 2.0, 3.0, 3.4),
	(10, 8, 9, 'm', 'H_IV', '', 2.9, 4.0, 4.6),
	(10, 10, 11, 'm', 'H_IV', '', 3.6, 5.0, 5.6),
	(11, 14, 15, 'w', 'H_IV', '', 3.4, 4.8, 5.4),
	(11, 16, 17, 'w', 'H_IV', '', 4.1, 5.4, 6.2),
	(11, 18, 19, 'w', 'H_IV', '', 5.0, 6.6, 7.3),
	(11, 20, 24, 'w', 'H_IV', '', 5.1, 6.8, 7.4),
	(11, 25, 29, 'w', 'H_IV', '', 5.1, 6.8, 7.4),
	(11, 30, 34, 'w', 'H_IV', '', 4.7, 6.3, 6.9),
	(11, 35, 39, 'w', 'H_IV', '', 4.5, 6.0, 6.6),
	(11, 40, 44, 'w', 'H_IV', '', 4.1, 5.6, 6.3),
	(11, 45, 49, 'w', 'H_IV', '', 3.9, 5.4, 6.0),
	(11, 50, 54, 'w', 'H_IV', '', 3.5, 5.0, 5.8),
	(11, 55, 59, 'w', 'H_IV', '', 3.3, 4.8, 5.5),
	(11, 60, 64, 'w', 'H_IV', '', 3.1, 4.5, 5.3),
	(11, 65, 69, 'w', 'H_IV', '', 2.9, 4.3, 5.0),
	(11, 70, 74, 'w', 'H_IV', '', 2.8, 4.1, 4.9),
	(11, 75, 79, 'w', 'H_IV', '', 2.6, 3.9, 4.6),
	(11, 80, 84, 'w', 'H_IV', '', 2.3, 3.6, 4.4),
	(11, 85, 89, 'w', 'H_IV', '', 2.0, 3.3, 4.0),
	(11, 90, 200, 'w', 'H_IV', '', 1.6, 2.8, 3.5),
	(11, 12, 13, 'm', 'H_IV', '', 4.4, 6.0, 6.6),
	(11, 14, 15, 'm', 'H_IV', '', 5.1, 6.8, 7.4),
	(11, 16, 17, 'm', 'H_IV', '', 5.8, 7.6, 8.4),
	(11, 18, 19, 'm', 'H_IV', '', 6.7, 9.0, 10.1),
	(11, 20, 24, 'm', 'H_IV', '', 7.0, 9.5, 10.5),
	(11, 25, 29, 'm', 'H_IV', '', 6.9, 9.4, 10.4),
	(11, 30, 34, 'm', 'H_IV', '', 6.4, 8.8, 10.0),
	(11, 35, 39, 'm', 'H_IV', '', 6.1, 8.4, 9.6),
	(11, 40, 44, 'm', 'H_IV', '', 6.0, 8.3, 9.5),
	(11, 45, 49, 'm', 'H_IV', '', 5.7, 8.0, 9.4),
	(11, 50, 54, 'm', 'H_IV', '', 5.4, 7.8, 9.1),
	(11, 55, 59, 'm', 'H_IV', '', 5.0, 7.3, 8.8),
	(11, 60, 64, 'm', 'H_IV', '', 4.8, 7.0, 8.5),
	(11, 65, 69, 'm', 'H_IV', '', 4.3, 6.4, 7.6),
	(11, 70, 74, 'm', 'H_IV', '', 3.9, 6.0, 7.3),
	(11, 75, 79, 'm', 'H_IV', '', 3.4, 3.9, 4.6),
	(11, 80, 84, 'm', 'H_IV', '', 3.0, 3.6, 4.4),
	(11, 85, 89, 'm', 'H_IV', '', 2.6, 3.3, 4.0),
	(11, 90, 200, 'm', 'H_IV', '', 2.2, 2.8, 3.5),
	(13, 12, 13, 'w', 'H_IV', '2 kg', 0.6, 0.8, 0.9),
	(13, 14, 15, 'w', 'H_IV', '2 kg', 0.7, 0.9, 1.0),
	(13, 16, 17, 'w', 'H_IV', '2 kg', 0.7, 0.9, 1.0),
	(13, 18, 19, 'w', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 20, 24, 'w', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 25, 29, 'w', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 30, 34, 'w', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 35, 39, 'w', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 40, 44, 'w', 'H_IV', '2 kg', 0.7, 0.9, 1.0),
	(13, 45, 49, 'w', 'H_IV', '2 kg', 0.7, 0.85, 0.9),
	(13, 50, 54, 'w', 'H_IV', '2 kg', 0.66, 0.81, 0.86),
	(13, 55, 59, 'w', 'H_IV', '2 kg', 0.62, 0.77, 0.82),
	(13, 60, 64, 'w', 'H_IV', '2 kg', 0.58, 0.73, 0.78),
	(13, 65, 69, 'w', 'H_IV', '2 kg', 0.54, 0.69, 0.74),
	(13, 70, 74, 'w', 'H_IV', '2 kg', 0.5, 0.65, 0.7),
	(13, 75, 79, 'w', 'H_IV', '2 kg', 0.46, 0.61, 0.66),
	(13, 80, 84, 'w', 'H_IV', '2 kg', 0.42, 0.57, 0.62),
	(13, 85, 89, 'w', 'H_IV', '2 kg', 0.38, 0.53, 0.58),
	(13, 90, 200, 'w', 'H_IV', '2 kg', 0.34, 0.49, 0.54),
	(13, 12, 13, 'm', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 14, 15, 'm', 'H_IV', '2 kg', 0.9, 1.1, 1.2),
	(13, 16, 17, 'm', 'H_IV', '2 kg', 1.0, 1.2, 1.3),
	(13, 18, 19, 'm', 'H_IV', '2 kg', 1.0, 1.2, 1.3),
	(13, 20, 24, 'm', 'H_IV', '2 kg', 1.0, 1.3, 1.4),
	(13, 25, 29, 'm', 'H_IV', '2 kg', 1.0, 1.2, 1.3),
	(13, 30, 34, 'm', 'H_IV', '2 kg', 0.9, 1.1, 1.2),
	(13, 35, 39, 'm', 'H_IV', '2 kg', 0.9, 1.1, 1.2),
	(13, 40, 44, 'm', 'H_IV', '2 kg', 0.8, 1.1, 1.2),
	(13, 45, 49, 'm', 'H_IV', '2 kg', 0.8, 1.0, 1.1),
	(13, 50, 54, 'm', 'H_IV', '2 kg', 0.76, 0.96, 1.06),
	(13, 55, 59, 'm', 'H_IV', '2 kg', 0.72, 0.92, 1.02),
	(13, 60, 64, 'm', 'H_IV', '2 kg', 0.68, 0.88, 0.98),
	(13, 65, 69, 'm', 'H_IV', '2 kg', 0.64, 0.84, 0.94),
	(13, 70, 74, 'm', 'H_IV', '2 kg', 0.6, 0.8, 0.9),
	(13, 75, 79, 'm', 'H_IV', '2 kg', 0.56, 0.76, 0.86),
	(13, 80, 84, 'm', 'H_IV', '2 kg', 0.52, 0.72, 0.82),
	(13, 85, 89, 'm', 'H_IV', '2 kg', 0.48, 0.68, 0.78),
	(13, 90, 200, 'm', 'H_IV', '2 kg', 0.44, 0.64, 0.74),
	(29, 18, 19, 'w', 'H_IV', '', 11.983333333333333, 9.416666666666666, 8.416666666666666),
	(29, 20, 24, 'w', 'H_IV', '', 11.683333333333334, 9.166666666666666, 8.166666666666666),
	(29, 25, 29, 'w', 'H_IV', '', 11.883333333333333, 9.333333333333332, 8.333333333333332),
	(29, 30, 34, 'w', 'H_IV', '', 12.366666666666667, 9.749999999999998, 8.749999999999998),
	(29, 35, 39, 'w', 'H_IV', '', 12.65, 10.0, 9.0),
	(29, 40, 44, 'w', 'H_IV', '', 13.133333333333333, 10.333333333333332, 9.25),
	(29, 45, 49, 'w', 'H_IV', '', 13.7, 10.749999999999998, 9.416666666666666),
	(29, 50, 54, 'w', 'H_IV', '', 14.283333333333333, 11.083333333333334, 9.583333333333332),
	(29, 55, 59, 'w', 'H_IV', '', 14.85, 11.416666666666666, 9.916666666666668),
	(29, 60, 64, 'w', 'H_IV', '', 15.233333333333334, 11.749999999999998, 10.25),
	(29, 65, 69, 'w', 'H_IV', '', 15.616666666666665, 12.083333333333334, 10.583333333333332),
	(29, 70, 74, 'w', 'H_IV', '', 15.899999999999999, 12.333333333333332, 10.833333333333334),
	(29, 75, 79, 'w', 'H_IV', '', 16.383333333333333, 12.749999999999998, 11.25),
	(29, 80, 84, 'w', 'H_IV', '', 17.05, 13.333333333333332, 11.833333333333334),
	(29, 85, 89, 'w', 'H_IV', '', 17.816666666666663, 14.0, 12.500000000000002),
	(29, 90, 200, 'w', 'H_IV', '', 18.683333333333334, 14.749999999999998, 13.25),
	(29, 18, 19, 'm', 'H_IV', '', 10.25, 7.916666666666666, 6.916666666666666),
	(29, 20, 24, 'm', 'H_IV', '', 9.966666666666667, 7.666666666666667, 6.666666666666667),
	(29, 25, 29, 'm', 'H_IV', '', 10.166666666666666, 7.833333333333333, 6.833333333333333),
	(29, 30, 34, 'm', 'H_IV', '', 10.633333333333335, 8.25, 7.250000000000001),
	(29, 35, 39, 'm', 'H_IV', '', 11.4, 8.666666666666668, 7.5),
	(29, 40, 44, 'm', 'H_IV', '', 12.066666666666665, 9.25, 7.916666666666666),
	(29, 45, 49, 'm', 'H_IV', '', 12.749999999999998, 9.749999999999998, 8.25),
	(29, 50, 54, 'm', 'H_IV', '', 13.416666666666666, 10.166666666666666, 8.666666666666668),
	(29, 55, 59, 'm', 'H_IV', '', 13.7, 10.416666666666666, 8.916666666666668),
	(29, 60, 64, 'm', 'H_IV', '', 14.083333333333334, 10.749999999999998, 9.25),
	(29, 65, 69, 'm', 'H_IV', '', 14.366666666666667, 11.0, 9.500000000000002),
	(29, 70, 74, 'm', 'H_IV', '', 14.566666666666666, 11.166666666666666, 9.666666666666668),
	(29, 75, 79, 'm', 'H_IV', '', 14.950000000000001, 11.500000000000002, 10.0),
	(29, 80, 84, 'm', 'H_IV', '', 15.233333333333334, 11.749999999999998, 10.25),
	(29, 85, 89, 'm', 'H_IV', '', 15.816666666666666, 12.25, 10.749999999999998),
	(29, 90, 200, 'm', 'H_IV', '', 17.15, 13.416666666666666, 11.916666666666668),
	(34, 0, 7, 'w', 'H_IV', '', 4.0, 7.0, 10.0),
	(34, 8, 9, 'w', 'H_IV', '', 6.0, 9.0, 12.0),
	(34, 10, 11, 'w', 'H_IV', '', 9.0, 12.0, 18.0),
	(34, 12, 13, 'w', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 14, 15, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 16, 17, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 18, 19, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 20, 24, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 25, 29, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 30, 34, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 35, 39, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 40, 44, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 45, 49, 'w', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 50, 54, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 55, 59, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 60, 64, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 65, 69, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 70, 74, 'w', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 75, 79, 'w', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 80, 84, 'w', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 85, 89, 'w', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 90, 200, 'w', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 0, 7, 'm', 'H_IV', '', 4.0, 7.0, 10.0),
	(34, 8, 9, 'm', 'H_IV', '', 6.0, 9.0, 12.0),
	(34, 10, 11, 'm', 'H_IV', '', 9.0, 12.0, 18.0),
	(34, 12, 13, 'm', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 14, 15, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 16, 17, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 18, 19, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 20, 24, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 25, 29, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 30, 34, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 35, 39, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 40, 44, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 45, 49, 'm', 'H_IV', '', 27.0, 36.0, 45.0),
	(34, 50, 54, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 55, 59, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 60, 64, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 65, 69, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 70, 74, 'm', 'H_IV', '', 18.0, 24.0, 30.0),
	(34, 75, 79, 'm', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 80, 84, 'm', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 85, 89, 'm', 'H_IV', '', 12.0, 18.0, 24.0),
	(34, 90, 200, 'm', 'H_IV', '', 12.0, 18.0, 24.0),
	(35, 0, 7, 'w', 'H_IV', '1 km', 20.633333333333333, 16.4, 14.6),
	(35, 8, 9, 'w', 'H_IV', '1 km', 18.633333333333333, 14.4, 12.6),
	(35, 10, 11, 'w', 'H_IV', '1,5 km', 34.849999999999994, 25.8, 21.3),
	(35, 12, 13, 'w', 'H_IV', '1,5 km', 31.05, 23.700000000000003, 20.099999999999998),
	(35, 14, 15, 'w', 'H_IV', '1,5 km', 26.216666666666665, 19.5, 17.099999999999998),
	(35, 16, 17, 'w', 'H_IV', '1,5 km', 22.416666666666668, 17.099999999999998, 15.0),
	(35, 18, 19, 'w', 'H_IV', '3 km', 39.68333333333333, 31.200000000000003, 27.9),
	(35, 20, 24, 'w', 'H_IV', '3 km', 39.333333333333336, 30.9, 27.3),
	(35, 25, 29, 'w', 'H_IV', '3 km', 38.63333333333334, 30.3, 27.0),
	(35, 30, 34, 'w', 'H_IV', '3 km', 39.333333333333336, 30.9, 27.3),
	(35, 35, 39, 'w', 'H_IV', '3 km', 41.400000000000006, 31.8, 28.200000000000003),
	(35, 40, 44, 'w', 'H_IV', '3 km', 44.16666666666667, 33.3, 29.700000000000003),
	(35, 45, 49, 'w', 'H_IV', '3 km', 46.233333333333334, 35.1, 30.9),
	(35, 50, 54, 'w', 'H_IV', '3 km', 47.61666666666666, 36.6, 32.1),
	(35, 55, 59, 'w', 'H_IV', '3 km', 49.333333333333336, 37.8, 33.3),
	(35, 60, 64, 'w', 'H_IV', '3 km', 51.06666666666666, 39.0, 34.199999999999996),
	(35, 65, 69, 'w', 'H_IV', '3 km', 52.1, 39.9, 35.1),
	(35, 70, 74, 'w', 'H_IV', '3 km', 53.81666666666667, 41.1, 36.3),
	(35, 75, 79, 'w', 'H_IV', '3 km', 56.233333333333334, 42.3, 37.8),
	(35, 80, 84, 'w', 'H_IV', '3 km', 58.3, 45.0, 39.3),
	(35, 85, 89, 'w', 'H_IV', '3 km', 61.75000000000001, 48.0, 41.400000000000006),
	(35, 90, 200, 'w', 'H_IV', '3 km', 64.16666666666666, 49.8, 43.49999999999999),
	(35, 0, 7, 'm', 'H_IV', '1 km', 20.283333333333335, 16.099999999999998, 14.299999999999999),
	(35, 8, 9, 'm', 'H_IV', '1 km', 18.283333333333335, 14.100000000000001, 12.299999999999999),
	(35, 10, 11, 'm', 'H_IV', '1,5 km', 33.46666666666667, 24.599999999999998, 20.099999999999998),
	(35, 12, 13, 'm', 'H_IV', '1,5 km', 29.666666666666664, 22.200000000000003, 18.9),
	(35, 14, 15, 'm', 'H_IV', '1,5 km', 22.083333333333336, 16.8, 14.4),
	(35, 16, 17, 'm', 'H_IV', '1,5 km', 18.633333333333333, 14.100000000000001, 12.299999999999999),
	(35, 18, 19, 'm', 'H_IV', '3 km', 32.43333333333333, 25.5, 23.099999999999998),
	(35, 20, 24, 'm', 'H_IV', '3 km', 32.08333333333333, 25.200000000000003, 22.5),
	(35, 25, 29, 'm', 'H_IV', '3 km', 34.49999999999999, 26.700000000000003, 23.4),
	(35, 30, 34, 'm', 'H_IV', '3 km', 36.916666666666664, 28.200000000000003, 24.3),
	(35, 35, 39, 'm', 'H_IV', '3 km', 40.016666666666666, 30.0, 24.9),
	(35, 40, 44, 'm', 'H_IV', '3 km', 43.46666666666667, 31.200000000000003, 26.099999999999998),
	(35, 45, 49, 'm', 'H_IV', '3 km', 45.53333333333333, 33.0, 27.0),
	(35, 50, 54, 'm', 'H_IV', '3 km', 47.26666666666666, 34.199999999999996, 27.9),
	(35, 55, 59, 'm', 'H_IV', '3 km', 48.65, 35.1, 28.5),
	(35, 60, 64, 'm', 'H_IV', '3 km', 49.333333333333336, 36.0, 28.8),
	(35, 65, 69, 'm', 'H_IV', '3 km', 50.016666666666666, 36.3, 29.099999999999998),
	(35, 70, 74, 'm', 'H_IV', '3 km', 50.71666666666667, 36.9, 29.700000000000003),
	(35, 75, 79, 'm', 'H_IV', '3 km', 51.400000000000006, 37.8, 30.9),
	(35, 80, 84, 'm', 'H_IV', '3 km', 52.43333333333333, 38.7, 31.8),
	(35, 85, 89, 'm', 'H_IV', '3 km', 53.483333333333334, 39.9, 33.3),
	(35, 90, 200, 'm', 'H_IV', '3 km', 54.51666666666667, 40.8, 34.8),
	(43, 0, 7, 'w', 'H_IV', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'w', 'H_IV', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'w', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'w', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'w', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'w', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'w', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'w', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'w', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 0, 7, 'm', 'H_IV', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'm', 'H_IV', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'm', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'm', 'H_IV', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'm', 'H_IV', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'm', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'm', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'm', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'm', 'H_IV', '', 10.0, 12.500000000000002, 15.0),
	(46, 0, 7, 'w', 'H_IV', '', 0.5, 1.3, 1.9),
	(46, 8, 9, 'w', 'H_IV', '', 1.0, 1.9, 2.5),
	(46, 10, 11, 'w', 'H_IV', '', 1.4, 2.5, 3.1),
	(46, 12, 13, 'w', 'H_IV', '', 1.6, 2.6, 3.4),
	(46, 14, 15, 'w', 'H_IV', '', 2.4, 3.8, 4.4),
	(46, 16, 17, 'w', 'H_IV', '', 3.1, 4.4, 5.2),
	(46, 18, 19, 'w', 'H_IV', '', 4.0, 5.6, 6.3),
	(46, 20, 24, 'w', 'H_IV', '', 4.1, 5.8, 6.4),
	(46, 25, 29, 'w', 'H_IV', '', 4.1, 5.8, 6.4),
	(46, 30, 34, 'w', 'H_IV', '', 3.7, 5.3, 5.9),
	(46, 35, 39, 'w', 'H_IV', '', 3.5, 5.0, 5.6),
	(46, 40, 44, 'w', 'H_IV', '', 3.1, 4.6, 5.3),
	(46, 45, 49, 'w', 'H_IV', '', 2.9, 4.4, 5.0),
	(46, 50, 54, 'w', 'H_IV', '', 2.5, 4.0, 4.8),
	(46, 55, 59, 'w', 'H_IV', '', 2.3, 3.8, 4.5),
	(46, 60, 64, 'w', 'H_IV', '', 2.1, 3.5, 4.3),
	(46, 65, 69, 'w', 'H_IV', '', 1.9, 3.3, 4.0),
	(46, 70, 74, 'w', 'H_IV', '', 1.8, 3.1, 3.9),
	(46, 75, 79, 'w', 'H_IV', '', 1.6, 2.9, 3.6),
	(46, 80, 84, 'w', 'H_IV', '', 1.3, 2.6, 3.4),
	(46, 85, 89, 'w', 'H_IV', '', 1.0, 2.3, 3.0),
	(46, 90, 200, 'w', 'H_IV', '', 0.6, 1.8, 2.5),
	(46, 0, 7, 'm', 'H_IV', '', 1.5, 2.5, 2.9),
	(46, 8, 9, 'm', 'H_IV', '', 2.4, 3.5, 4.1),
	(46, 10, 11, 'm', 'H_IV', '', 3.1, 4.5, 5.1),
	(46, 12, 13, 'm', 'H_IV', '', 3.4, 5.0, 5.6),
	(46, 14, 15, 'm', 'H_IV', '', 4.1, 5.8, 6.4),
	(46, 16, 17, 'm', 'H_IV', '', 4.8, 6.6, 7.4),
	(46, 18, 19, 'm', 'H_IV', '', 5.7, 8.0, 9.1),
	(46, 20, 24, 'm', 'H_IV', '', 6.0, 8.5, 9.5),
	(46, 25, 29, 'm', 'H_IV', '', 5.9, 8.4, 9.4),
	(46, 30, 34, 'm', 'H_IV', '', 5.4, 7.8, 9.0),
	(46, 35, 39, 'm', 'H_IV', '', 5.1, 7.4, 8.6),
	(46, 40, 44, 'm', 'H_IV', '', 5.0, 7.3, 8.5),
	(46, 45, 49, 'm', 'H_IV', '', 4.7, 7.0, 8.4),
	(46, 50, 54, 'm', 'H_IV', '', 4.4, 6.8, 8.1),
	(46, 55, 59, 'm', 'H_IV', '', 4.0, 6.3, 7.8),
	(46, 60, 64, 'm', 'H_IV', '', 3.8, 6.0, 7.5),
	(46, 65, 69, 'm', 'H_IV', '', 3.3, 5.4, 6.6),
	(46, 70, 74, 'm', 'H_IV', '', 2.9, 5.0, 6.3),
	(46, 75, 79, 'm', 'H_IV', '', 2.4, 2.9, 3.6),
	(46, 80, 84, 'm', 'H_IV', '', 2.0, 2.6, 3.4),
	(46, 85, 89, 'm', 'H_IV', '', 1.6, 2.3, 3.0),
	(46, 90, 200, 'm', 'H_IV', '', 1.2, 1.8, 2.5),
	(48, 0, 7, 'w', 'H_IV', '30 m', 41.4, 32.0, 28.4),
	(48, 8, 9, 'w', 'H_IV', '30 m', 38.3, 29.7, 25.7),
	(48, 10, 11, 'w', 'H_IV', '50 m', 56.9, 45.5, 41.0),
	(48, 12, 13, 'w', 'H_IV', '50 m', 54.9, 43.2, 38.3),
	(48, 14, 15, 'w', 'H_IV', '100 m', 96.3, 76.5, 69.8),
	(48, 16, 17, 'w', 'H_IV', '100 m', 91.1, 73.4, 67.5),
	(48, 18, 19, 'w', 'H_IV', '100 m', 94.2, 74.3, 68.9),
	(48, 20, 24, 'w', 'H_IV', '100 m', 95.7, 75.6, 70.2),
	(48, 25, 29, 'w', 'H_IV', '100 m', 97.8, 77.4, 72.0),
	(48, 30, 34, 'w', 'H_IV', '100 m', 101.4, 80.1, 73.8),
	(48, 35, 39, 'w', 'H_IV', '100 m', 105.6, 83.7, 76.5),
	(48, 40, 44, 'w', 'H_IV', '50 m', 56.9, 44.6, 39.6),
	(48, 45, 49, 'w', 'H_IV', '50 m', 59.5, 46.4, 41.0),
	(48, 50, 54, 'w', 'H_IV', '50 m', 61.6, 48.2, 42.8),
	(48, 55, 59, 'w', 'H_IV', '50 m', 64.2, 50.4, 44.6),
	(48, 60, 64, 'w', 'H_IV', '50 m', 65.2, 51.3, 45.9),
	(48, 65, 69, 'w', 'H_IV', '50 m', 66.2, 52.2, 46.8),
	(48, 70, 74, 'w', 'H_IV', '50 m', 67.3, 53.1, 47.7),
	(48, 75, 79, 'w', 'H_IV', '50 m', 69.9, 55.4, 50.0),
	(48, 80, 84, 'w', 'H_IV', '50 m', 74.0, 59.0, 54.0),
	(48, 85, 89, 'w', 'H_IV', '50 m', 80.2, 64.4, 59.4),
	(48, 90, 200, 'w', 'H_IV', '50 m', 88.5, 71.6, 66.6),
	(48, 0, 7, 'm', 'H_IV', '30 m', 39.8, 30.6, 27.0),
	(48, 8, 9, 'm', 'H_IV', '30 m', 37.3, 28.8, 25.7),
	(48, 10, 11, 'm', 'H_IV', '50 m', 53.3, 41.9, 37.8),
	(48, 12, 13, 'm', 'H_IV', '50 m', 50.2, 40.1, 36.5),
	(48, 14, 15, 'm', 'H_IV', '100 m', 88.0, 69.3, 63.5),
	(48, 16, 17, 'm', 'H_IV', '100 m', 84.4, 66.6, 60.8),
	(48, 18, 19, 'm', 'H_IV', '100 m', 82.8, 65.7, 59.4),
	(48, 20, 24, 'm', 'H_IV', '100 m', 81.8, 64.8, 58.5),
	(48, 25, 29, 'm', 'H_IV', '100 m', 84.4, 66.6, 59.9),
	(48, 30, 34, 'm', 'H_IV', '100 m', 86.9, 68.0, 61.2),
	(48, 35, 39, 'm', 'H_IV', '100 m', 91.1, 71.6, 63.9),
	(48, 40, 44, 'm', 'H_IV', '50 m', 49.7, 39.2, 34.7),
	(48, 45, 49, 'm', 'H_IV', '50 m', 51.8, 40.1, 35.6),
	(48, 50, 54, 'm', 'H_IV', '50 m', 53.3, 41.0, 36.9),
	(48, 55, 59, 'm', 'H_IV', '50 m', 54.3, 42.3, 38.3),
	(48, 60, 64, 'm', 'H_IV', '50 m', 55.9, 43.7, 39.6),
	(48, 65, 69, 'm', 'H_IV', '50 m', 58.0, 45.9, 41.0),
	(48, 70, 74, 'm', 'H_IV', '50 m', 60.5, 48.2, 43.2),
	(48, 75, 79, 'm', 'H_IV', '50 m', 63.1, 50.4, 45.5),
	(48, 80, 84, 'm', 'H_IV', '50 m', 67.3, 54.0, 49.1),
	(48, 85, 89, 'm', 'H_IV', '50 m', 73.0, 59.0, 54.0),
	(48, 90, 200, 'm', 'H_IV', '50 m', 80.2, 65.3, 60.3),
	(50, 0, 7, 'w', 'H_IV', '', 3.59, 3.07, 2.44),
	(50, 8, 9, 'w', 'H_IV', '', 3.39, 2.47, 2.24),
	(50, 10, 11, 'w', 'H_IV', '', 3.17, 2.28, 2.05),
	(50, 12, 13, 'w', 'H_IV', '', 2.45, 2.05, 1.49),
	(50, 14, 15, 'w', 'H_IV', '', 2.24, 1.53, 1.39),
	(50, 16, 17, 'w', 'H_IV', '', 2.13, 1.44, 1.33),
	(50, 18, 19, 'w', 'H_IV', '', 2.08, 1.42, 1.3),
	(50, 20, 24, 'w', 'H_IV', '', 2.11, 1.42, 1.3),
	(50, 25, 29, 'w', 'H_IV', '', 2.13, 1.44, 1.33),
	(50, 30, 34, 'w', 'H_IV', '', 2.19, 1.49, 1.39),
	(50, 35, 39, 'w', 'H_IV', '', 2.27, 1.53, 1.42),
	(50, 40, 44, 'w', 'H_IV', '', 2.35, 1.58, 1.44),
	(50, 45, 49, 'w', 'H_IV', '', 2.43, 2.05, 1.46),
	(50, 50, 54, 'w', 'H_IV', '', 2.51, 2.1, 1.49),
	(50, 55, 59, 'w', 'H_IV', '', 2.59, 2.14, 1.51),
	(50, 60, 64, 'w', 'H_IV', '', 3.07, 2.19, 1.56),
	(50, 65, 69, 'w', 'H_IV', '', 3.12, 2.24, 1.58),
	(50, 70, 74, 'w', 'H_IV', '', 3.23, 2.28, 2.03),
	(50, 75, 79, 'w', 'H_IV', '', 3.28, 2.33, 2.07),
	(50, 80, 84, 'w', 'H_IV', '', 3.36, 2.4, 2.12),
	(50, 85, 89, 'w', 'H_IV', '', 3.44, 2.47, 2.19),
	(50, 90, 200, 'w', 'H_IV', '', 3.57, 2.56, 2.26),
	(50, 0, 7, 'm', 'H_IV', '', 3.43, 2.53, 2.3),
	(50, 8, 9, 'm', 'H_IV', '', 3.23, 2.33, 2.1),
	(50, 10, 11, 'm', 'H_IV', '', 3.07, 2.21, 2.0),
	(50, 12, 13, 'm', 'H_IV', '', 2.37, 2.0, 1.44),
	(50, 14, 15, 'm', 'H_IV', '', 2.08, 1.39, 1.28),
	(50, 16, 17, 'm', 'H_IV', '', 1.57, 1.3, 1.19),
	(50, 18, 19, 'm', 'H_IV', '', 1.49, 1.23, 1.12),
	(50, 20, 24, 'm', 'H_IV', '', 1.46, 1.21, 1.09),
	(50, 25, 29, 'm', 'H_IV', '', 1.52, 1.23, 1.09),
	(50, 30, 34, 'm', 'H_IV', '', 2.0, 1.26, 1.09),
	(50, 35, 39, 'm', 'H_IV', '', 2.08, 1.33, 1.12),
	(50, 40, 44, 'm', 'H_IV', '', 2.21, 1.39, 1.16),
	(50, 45, 49, 'm', 'H_IV', '', 2.32, 1.46, 1.19),
	(50, 50, 54, 'm', 'H_IV', '', 2.4, 1.51, 1.23),
	(50, 55, 59, 'm', 'H_IV', '', 2.51, 1.56, 1.26),
	(50, 60, 64, 'm', 'H_IV', '', 2.59, 2.0, 1.28),
	(50, 65, 69, 'm', 'H_IV', '', 3.07, 2.05, 1.3),
	(50, 70, 74, 'm', 'H_IV', '', 3.12, 2.12, 1.33),
	(50, 75, 79, 'm', 'H_IV', '', 3.2, 2.17, 1.39),
	(50, 80, 84, 'm', 'H_IV', '', 3.28, 2.26, 1.46),
	(50, 85, 89, 'm', 'H_IV', '', 3.39, 2.33, 1.53),
	(50, 90, 200, 'm', 'H_IV', '', 3.52, 2.45, 2.05),
	(53, 0, 7, 'w', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'H_IV', '1,5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'H_IV', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'H_IV', '2 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'H_IV', '2 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(56, 0, 7, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'w', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 0, 7, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 8, 9, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 10, 11, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 12, 13, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 14, 15, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 16, 17, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 18, 19, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 20, 24, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 25, 29, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 30, 34, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 35, 39, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 40, 44, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 45, 49, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 50, 54, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 55, 59, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 60, 64, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 65, 69, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 70, 74, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 75, 79, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 80, 84, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 85, 89, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(56, 90, 200, 'm', 'H_IV', '', 1.0, 2.0, 3.0),
	(58, 0, 7, 'w', 'H_IV', '', 7.1, 5.3, 4.41),
	(58, 8, 9, 'w', 'H_IV', '', 7.04, 5.19, 4.35),
	(58, 10, 11, 'w', 'H_IV', '', 6.45, 5.08, 4.24),
	(58, 12, 13, 'w', 'H_IV', '', 6.32, 4.52, 4.08),
	(58, 14, 15, 'w', 'H_IV', '', 6.19, 4.46, 3.57),
	(58, 16, 17, 'w', 'H_IV', '', 6.07, 4.3, 3.46),
	(58, 0, 7, 'm', 'H_IV', '', 7.1, 5.3, 4.41),
	(58, 8, 9, 'm', 'H_IV', '', 6.51, 5.08, 4.19),
	(58, 10, 11, 'm', 'H_IV', '', 6.26, 4.46, 3.57),
	(58, 12, 13, 'm', 'H_IV', '', 6.01, 4.24, 3.35),
	(58, 14, 15, 'm', 'H_IV', '', 5.29, 4.02, 3.18),
	(58, 16, 17, 'm', 'H_IV', '', 5.1, 3.46, 3.02),
	(59, 0, 7, 'w', 'H_IV', '', 0.5, 1.3, 1.9),
	(59, 8, 9, 'w', 'H_IV', '', 1.0, 1.9, 2.5),
	(59, 10, 11, 'w', 'H_IV', '', 1.4, 2.5, 3.1),
	(59, 12, 13, 'w', 'H_IV', '', 1.6, 2.6, 3.4),
	(59, 14, 15, 'w', 'H_IV', '', 2.4, 3.8, 4.4),
	(59, 16, 17, 'w', 'H_IV', '', 3.1, 4.4, 5.2),
	(59, 18, 19, 'w', 'H_IV', '', 4.0, 5.6, 6.3),
	(59, 20, 24, 'w', 'H_IV', '', 4.1, 5.8, 6.4),
	(59, 25, 29, 'w', 'H_IV', '', 4.1, 5.8, 6.4),
	(59, 30, 34, 'w', 'H_IV', '', 3.7, 5.3, 5.9),
	(59, 35, 39, 'w', 'H_IV', '', 3.5, 5.0, 5.6),
	(59, 40, 44, 'w', 'H_IV', '', 3.1, 4.6, 5.3),
	(59, 45, 49, 'w', 'H_IV', '', 2.9, 4.4, 5.0),
	(59, 50, 54, 'w', 'H_IV', '', 2.5, 4.0, 4.8),
	(59, 55, 59, 'w', 'H_IV', '', 2.3, 3.8, 4.5),
	(59, 60, 64, 'w', 'H_IV', '', 2.1, 3.5, 4.3),
	(59, 65, 69, 'w', 'H_IV', '', 1.9, 3.3, 4.0),
	(59, 70, 74, 'w', 'H_IV', '', 1.8, 3.1, 3.9),
	(59, 75, 79, 'w', 'H_IV', '', 1.6, 2.9, 3.6),
	(59, 80, 84, 'w', 'H_IV', '', 1.3, 2.6, 3.4),
	(59, 85, 89, 'w', 'H_IV', '', 1.0, 2.3, 3.0),
	(59, 90, 200, 'w', 'H_IV', '', 0.6, 1.8, 2.5),
	(59, 0, 7, 'm', 'H_IV', '', 1.5, 2.5, 2.9),
	(59, 8, 9, 'm', 'H_IV', '', 2.4, 3.5, 4.1),
	(59, 10, 11, 'm', 'H_IV', '', 3.1, 4.5, 5.1),
	(59, 12, 13, 'm', 'H_IV', '', 3.4, 5.0, 5.6),
	(59, 14, 15, 'm', 'H_IV', '', 4.1, 5.8, 6.4),
	(59, 16, 17, 'm', 'H_IV', '', 4.8, 6.6, 7.4),
	(59, 18, 19, 'm', 'H_IV', '', 5.7, 8.0, 9.1),
	(59, 20, 24, 'm', 'H_IV', '', 6.0, 8.5, 9.5),
	(59, 25, 29, 'm', 'H_IV', '', 5.9, 8.4, 9.4),
	(59, 30, 34, 'm', 'H_IV', '', 5.4, 7.8, 9.0),
	(59, 35, 39, 'm', 'H_IV', '', 5.1, 7.4, 8.6),
	(59, 40, 44, 'm', 'H_IV', '', 5.0, 7.3, 8.5),
	(59, 45, 49, 'm', 'H_IV', '', 4.7, 7.0, 8.4),
	(59, 50, 54, 'm', 'H_IV', '', 4.4, 6.8, 8.1),
	(59, 55, 59, 'm', 'H_IV', '', 4.0, 6.3, 7.8),
	(59, 60, 64, 'm', 'H_IV', '', 3.8, 6.0, 7.5),
	(59, 65, 69, 'm', 'H_IV', '', 3.3, 5.4, 6.6),
	(59, 70, 74, 'm', 'H_IV', '', 2.9, 5.0, 6.3),
	(59, 75, 79, 'm', 'H_IV', '', 2.4, 2.9, 3.6),
	(59, 80, 84, 'm', 'H_IV', '', 2.0, 2.6, 3.4),
	(59, 85, 89, 'm', 'H_IV', '', 1.6, 2.3, 3.0),
	(59, 90, 200, 'm', 'H_IV', '', 1.2, 1.8, 2.5),
	(60, 0, 7, 'w', 'H_IV', '', 5.2, 3.51, 3.03),
	(60, 8, 9, 'w', 'H_IV', '', 4.49, 3.24, 2.48),
	(60, 10, 11, 'w', 'H_IV', '', 4.29, 3.09, 2.33),
	(60, 12, 13, 'w', 'H_IV', '', 4.01, 2.54, 2.21),
	(60, 14, 15, 'w', 'H_IV', '', 3.47, 2.45, 2.09),
	(60, 16, 17, 'w', 'H_IV', '', 3.3, 2.33, 2.0),
	(60, 18, 19, 'w', 'H_IV', '', 3.23, 2.24, 1.51),
	(60, 20, 24, 'w', 'H_IV', '', 3.2, 2.24, 1.51),
	(60, 25, 29, 'w', 'H_IV', '', 3.27, 2.3, 1.57),
	(60, 30, 34, 'w', 'H_IV', '', 3.44, 2.39, 2.06),
	(60, 35, 39, 'w', 'H_IV', '', 4.08, 2.54, 2.12),
	(60, 40, 44, 'w', 'H_IV', '', 4.36, 3.09, 2.21),
	(60, 45, 49, 'w', 'H_IV', '', 5.03, 3.3, 2.3),
	(60, 50, 54, 'w', 'H_IV', '', 5.31, 3.54, 2.48),
	(60, 55, 59, 'w', 'H_IV', '', 5.55, 4.15, 3.03),
	(60, 60, 64, 'w', 'H_IV', '', 6.16, 4.27, 3.15),
	(60, 65, 69, 'w', 'H_IV', '', 6.29, 4.39, 3.27),
	(60, 70, 74, 'w', 'H_IV', '', 6.47, 4.48, 3.36),
	(60, 75, 79, 'w', 'H_IV', '', 7.0, 5.0, 3.48),
	(60, 80, 84, 'w', 'H_IV', '', 7.18, 5.12, 4.0),
	(60, 85, 89, 'w', 'H_IV', '', 7.31, 5.21, 4.09),
	(60, 90, 200, 'w', 'H_IV', '', 7.38, 5.27, 4.15),
	(60, 0, 7, 'm', 'H_IV', '', 5.17, 3.48, 3.0),
	(60, 8, 9, 'm', 'H_IV', '', 4.42, 3.18, 2.36),
	(60, 10, 11, 'm', 'H_IV', '', 4.08, 2.54, 2.15),
	(60, 12, 13, 'm', 'H_IV', '', 3.47, 2.42, 2.06),
	(60, 14, 15, 'm', 'H_IV', '', 3.33, 2.33, 2.0),
	(60, 16, 17, 'm', 'H_IV', '', 3.23, 2.27, 1.54),
	(60, 18, 19, 'm', 'H_IV', '', 3.13, 2.18, 1.45),
	(60, 20, 24, 'm', 'H_IV', '', 3.06, 2.12, 1.33),
	(60, 25, 29, 'm', 'H_IV', '', 3.2, 2.18, 1.39),
	(60, 30, 34, 'm', 'H_IV', '', 3.37, 2.24, 1.42),
	(60, 35, 39, 'm', 'H_IV', '', 4.01, 2.39, 1.51),
	(60, 40, 44, 'm', 'H_IV', '', 4.25, 2.57, 1.54),
	(60, 45, 49, 'm', 'H_IV', '', 4.49, 3.15, 2.03),
	(60, 50, 54, 'm', 'H_IV', '', 5.1, 3.3, 2.18),
	(60, 55, 59, 'm', 'H_IV', '', 5.38, 3.42, 2.3),
	(60, 60, 64, 'm', 'H_IV', '', 5.51, 3.54, 2.42),
	(60, 65, 69, 'm', 'H_IV', '', 6.02, 4.03, 2.51),
	(60, 70, 74, 'm', 'H_IV', '', 6.19, 4.18, 3.06),
	(60, 75, 79, 'm', 'H_IV', '', 6.36, 4.33, 3.21),
	(60, 80, 84, 'm', 'H_IV', '', 6.47, 4.48, 3.36),
	(60, 85, 89, 'm', 'H_IV', '', 6.5, 4.54, 3.48),
	(60, 90, 200, 'm', 'H_IV', '', 6.54, 5.0, 4.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'I', '', 10.2, 9.0, 7.6499999999999995),
	(1, 8, 9, 'w', 'I', '', 10.049999999999999, 8.7, 7.5),
	(1, 10, 11, 'w', 'I', '', 9.6, 8.4, 7.2),
	(1, 12, 13, 'w', 'I', '', 9.299999999999999, 7.95, 6.75),
	(1, 14, 15, 'w', 'I', '', 9.0, 7.800000000000001, 6.449999999999999),
	(1, 16, 17, 'w', 'I', '', 8.7, 7.35, 6.1499999999999995),
	(1, 0, 7, 'm', 'I', '', 10.2, 9.0, 7.6499999999999995),
	(1, 8, 9, 'm', 'I', '', 9.749999999999998, 8.4, 7.050000000000001),
	(1, 10, 11, 'm', 'I', '', 9.15, 7.800000000000001, 6.449999999999999),
	(1, 12, 13, 'm', 'I', '', 8.55, 7.2, 5.85),
	(1, 14, 15, 'm', 'I', '', 7.800000000000001, 6.6000000000000005, 5.4),
	(1, 16, 17, 'm', 'I', '', 7.35, 6.1499999999999995, 4.95),
	(4, 8, 9, 'w', 'I', '2,5 km', 17.01666666666667, 15.116666666666667, 13.233333333333334),
	(4, 10, 11, 'w', 'I', '5 km', 31.816666666666663, 27.083333333333336, 22.366666666666664),
	(4, 12, 13, 'w', 'I', '5 km', 28.35, 24.883333333333336, 21.099999999999998),
	(4, 14, 15, 'w', 'I', '5 km', 23.93333333333333, 20.48333333333333, 17.95),
	(4, 16, 17, 'w', 'I', '5 km', 20.48333333333333, 17.95, 15.749999999999998),
	(4, 18, 19, 'w', 'I', '10 km', 36.233333333333334, 32.766666666666666, 29.3),
	(4, 20, 24, 'w', 'I', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 25, 29, 'w', 'I', '10 km', 35.28333333333334, 31.816666666666663, 28.35),
	(4, 30, 34, 'w', 'I', '10 km', 35.916666666666664, 32.45, 28.666666666666664),
	(4, 35, 39, 'w', 'I', '10 km', 37.8, 33.383333333333326, 29.616666666666667),
	(4, 40, 44, 'w', 'I', '10 km', 40.31666666666666, 34.96666666666666, 31.183333333333334),
	(4, 45, 49, 'w', 'I', '10 km', 42.21666666666667, 36.849999999999994, 32.45),
	(4, 50, 54, 'w', 'I', '10 km', 43.46666666666667, 38.43333333333333, 33.7),
	(4, 55, 59, 'w', 'I', '10 km', 45.050000000000004, 39.68333333333333, 34.96666666666666),
	(4, 60, 64, 'w', 'I', '10 km', 46.61666666666666, 40.95, 35.916666666666664),
	(4, 65, 69, 'w', 'I', '10 km', 47.56666666666667, 41.9, 36.849999999999994),
	(4, 70, 74, 'w', 'I', '10 km', 49.13333333333333, 43.150000000000006, 38.11666666666667),
	(4, 75, 79, 'w', 'I', '10 km', 51.35, 44.416666666666664, 39.68333333333333),
	(4, 80, 84, 'w', 'I', '10 km', 53.233333333333334, 47.25, 41.26666666666666),
	(4, 85, 89, 'w', 'I', '10 km', 56.383333333333326, 50.400000000000006, 43.46666666666667),
	(4, 90, 200, 'w', 'I', '10 km', 58.583333333333336, 52.28333333333334, 45.68333333333333),
	(4, 8, 9, 'm', 'I', '2,5 km', 16.700000000000003, 14.8, 12.916666666666668),
	(4, 10, 11, 'm', 'I', '5 km', 30.549999999999997, 25.833333333333332, 21.099999999999998),
	(4, 12, 13, 'm', 'I', '5 km', 27.083333333333336, 23.31666666666667, 19.85),
	(4, 14, 15, 'm', 'I', '5 km', 20.166666666666668, 17.633333333333333, 15.116666666666667),
	(4, 16, 17, 'm', 'I', '5 km', 17.01666666666667, 14.8, 12.916666666666668),
	(4, 18, 19, 'm', 'I', '10 km', 29.616666666666667, 26.78333333333333, 24.249999999999996),
	(4, 20, 24, 'm', 'I', '10 km', 29.3, 26.46666666666667, 23.616666666666667),
	(4, 25, 29, 'm', 'I', '10 km', 31.5, 28.03333333333333, 24.566666666666666),
	(4, 30, 34, 'm', 'I', '10 km', 33.7, 29.616666666666667, 25.516666666666666),
	(4, 35, 39, 'm', 'I', '10 km', 36.53333333333333, 31.5, 26.15),
	(4, 40, 44, 'm', 'I', '10 km', 39.68333333333333, 32.766666666666666, 27.4),
	(4, 45, 49, 'm', 'I', '10 km', 41.583333333333336, 34.65, 28.35),
	(4, 50, 54, 'm', 'I', '10 km', 43.150000000000006, 35.916666666666664, 29.3),
	(4, 55, 59, 'm', 'I', '10 km', 44.416666666666664, 36.849999999999994, 29.93333333333333),
	(4, 60, 64, 'm', 'I', '10 km', 45.050000000000004, 37.8, 30.233333333333334),
	(4, 65, 69, 'm', 'I', '10 km', 45.68333333333333, 38.11666666666667, 30.549999999999997),
	(4, 70, 74, 'm', 'I', '10 km', 46.3, 38.75000000000001, 31.183333333333334),
	(4, 75, 79, 'm', 'I', '10 km', 46.93333333333334, 39.68333333333333, 32.45),
	(4, 80, 84, 'm', 'I', '10 km', 47.88333333333333, 40.63333333333334, 33.383333333333326),
	(4, 85, 89, 'm', 'I', '10 km', 48.833333333333336, 41.9, 34.96666666666666),
	(4, 90, 200, 'm', 'I', '10 km', 49.766666666666666, 42.833333333333336, 36.53333333333333),
	(7, 0, 7, 'w', 'I', '200 m', 12.6, 10.733333333333333, 8.866666666666665),
	(7, 8, 9, 'w', 'I', '200 m', 11.2, 9.8, 8.283333333333333),
	(7, 10, 11, 'w', 'I', '200 m', 10.266666666666667, 8.983333333333333, 7.7),
	(7, 12, 13, 'w', 'I', '400 m', 20.76666666666667, 18.083333333333336, 15.4),
	(7, 14, 15, 'w', 'I', '400 m', 18.31666666666667, 16.333333333333332, 14.0),
	(7, 16, 17, 'w', 'I', '400 m', 16.566666666666666, 14.7, 12.716666666666667),
	(7, 18, 19, 'w', 'I', '800 m', 33.6, 29.633333333333333, 25.78333333333333),
	(7, 20, 24, 'w', 'I', '800 m', 33.016666666666666, 29.166666666666668, 25.200000000000003),
	(7, 25, 29, 'w', 'I', '800 m', 35.7, 29.516666666666666, 26.13333333333333),
	(7, 30, 34, 'w', 'I', '800 m', 40.36666666666667, 33.13333333333333, 27.3),
	(7, 35, 39, 'w', 'I', '800 m', 44.8, 35.81666666666667, 28.46666666666667),
	(7, 40, 44, 'w', 'I', '800 m', 47.6, 38.73333333333333, 29.866666666666667),
	(7, 45, 49, 'w', 'I', '800 m', 49.46666666666667, 40.6, 30.099999999999998),
	(7, 50, 54, 'w', 'I', '400 m', 25.200000000000003, 21.0, 16.099999999999998),
	(7, 55, 59, 'w', 'I', '400 m', 26.01666666666667, 21.46666666666667, 16.683333333333334),
	(7, 60, 64, 'w', 'I', '400 m', 26.599999999999998, 21.816666666666663, 17.03333333333333),
	(7, 65, 69, 'w', 'I', '400 m', 27.183333333333334, 22.05, 17.15),
	(7, 70, 74, 'w', 'I', '400 m', 27.76666666666667, 22.516666666666666, 17.733333333333334),
	(7, 75, 79, 'w', 'I', '200 m', 14.350000000000001, 11.666666666666668, 9.100000000000001),
	(7, 80, 84, 'w', 'I', '200 m', 14.583333333333332, 11.899999999999999, 9.45),
	(7, 85, 89, 'w', 'I', '200 m', 14.816666666666666, 12.25, 9.916666666666668),
	(7, 90, 200, 'w', 'I', '200 m', 15.049999999999999, 12.483333333333333, 10.266666666666667),
	(7, 0, 7, 'm', 'I', '200 m', 12.6, 10.266666666666667, 8.633333333333335),
	(7, 8, 9, 'm', 'I', '200 m', 11.2, 9.45, 7.933333333333333),
	(7, 10, 11, 'm', 'I', '200 m', 9.8, 8.866666666666665, 7.2333333333333325),
	(7, 12, 13, 'm', 'I', '400 m', 18.9, 16.099999999999998, 13.65),
	(7, 14, 15, 'm', 'I', '400 m', 16.8, 14.350000000000001, 12.366666666666667),
	(7, 16, 17, 'm', 'I', '400 m', 15.4, 13.533333333333333, 11.666666666666668),
	(7, 18, 19, 'm', 'I', '800 m', 31.616666666666667, 27.76666666666667, 23.8),
	(7, 20, 24, 'm', 'I', '800 m', 31.03333333333333, 27.3, 22.983333333333334),
	(7, 25, 29, 'm', 'I', '800 m', 32.43333333333333, 28.0, 23.8),
	(7, 30, 34, 'm', 'I', '800 m', 36.050000000000004, 30.099999999999998, 25.200000000000003),
	(7, 35, 39, 'm', 'I', '800 m', 40.36666666666667, 33.6, 26.95),
	(7, 40, 44, 'm', 'I', '800 m', 45.383333333333326, 36.98333333333334, 28.583333333333336),
	(7, 45, 49, 'm', 'I', '800 m', 48.3, 38.96666666666666, 28.93333333333333),
	(7, 50, 54, 'm', 'I', '400 m', 24.383333333333333, 20.066666666666666, 15.049999999999999),
	(7, 55, 59, 'm', 'I', '400 m', 24.966666666666665, 20.416666666666668, 15.866666666666665),
	(7, 60, 64, 'm', 'I', '400 m', 25.433333333333337, 20.650000000000002, 15.983333333333333),
	(7, 65, 69, 'm', 'I', '400 m', 25.78333333333333, 21.116666666666667, 16.099999999999998),
	(7, 70, 74, 'm', 'I', '400 m', 25.78333333333333, 21.35, 16.216666666666665),
	(7, 75, 79, 'm', 'I', '200 m', 13.183333333333332, 10.733333333333333, 8.516666666666667),
	(7, 80, 84, 'm', 'I', '200 m', 13.299999999999999, 10.966666666666667, 8.633333333333335),
	(7, 85, 89, 'm', 'I', '200 m', 13.299999999999999, 11.2, 8.983333333333333),
	(7, 90, 200, 'm', 'I', '200 m', 13.65, 11.433333333333334, 9.45),
	(10, 0, 7, 'w', 'I', '', 3.6, 5.4, 7.2),
	(10, 8, 9, 'w', 'I', '', 5.4, 7.2, 9.0),
	(10, 10, 11, 'w', 'I', '', 6.6, 9.0, 10.8),
	(10, 0, 7, 'm', 'I', '', 7.2, 9.0, 10.2),
	(10, 8, 9, 'm', 'I', '', 10.2, 12.0, 13.8),
	(10, 10, 11, 'm', 'I', '', 12.6, 15.0, 16.8),
	(11, 12, 13, 'w', 'I', '', 9.0, 10.8, 13.2),
	(11, 14, 15, 'w', 'I', '', 12.0, 14.4, 16.2),
	(11, 16, 17, 'w', 'I', '', 14.4, 16.2, 18.6),
	(11, 12, 13, 'm', 'I', '', 15.6, 18.0, 19.8),
	(11, 14, 15, 'm', 'I', '', 18.0, 20.4, 22.2),
	(11, 16, 17, 'm', 'I', '', 20.4, 22.8, 25.2),
	(12, 0, 7, 'w', 'I', '1 kg', 3.0, 3.3, 3.75),
	(12, 8, 9, 'w', 'I', '1 kg', 3.25, 3.55, 4.0),
	(12, 10, 11, 'w', 'I', '1 kg', 3.5, 3.8, 4.25),
	(12, 12, 13, 'w', 'I', '1 kg', 3.75, 4.05, 4.5),
	(12, 14, 15, 'w', 'I', '1 kg', 4.0, 4.3, 4.75),
	(12, 16, 17, 'w', 'I', '1 kg', 4.25, 4.55, 5.0),
	(12, 18, 19, 'w', 'I', '2 kg', 4.5, 4.8, 5.25),
	(12, 20, 24, 'w', 'I', '2 kg', 4.5, 4.8, 5.25),
	(12, 25, 29, 'w', 'I', '2 kg', 4.2, 4.65, 5.1),
	(12, 30, 34, 'w', 'I', '2 kg', 3.9, 4.5, 5.1),
	(12, 35, 39, 'w', 'I', '2 kg', 3.6, 4.35, 4.95),
	(12, 40, 44, 'w', 'I', '2 kg', 3.15, 4.05, 4.95),
	(12, 45, 49, 'w', 'I', '2 kg', 2.85, 3.9, 4.8),
	(12, 50, 54, 'w', 'I', '2 kg', 2.55, 3.6, 4.65),
	(12, 55, 59, 'w', 'I', '2 kg', 2.4, 3.45, 4.5),
	(12, 60, 64, 'w', 'I', '2 kg', 2.25, 3.3, 4.35),
	(12, 65, 69, 'w', 'I', '2 kg', 2.1, 3.15, 4.2),
	(12, 70, 74, 'w', 'I', '2 kg', 1.95, 3.0, 4.05),
	(12, 75, 79, 'w', 'I', '2 kg', 1.95, 2.85, 3.9),
	(12, 80, 84, 'w', 'I', '2 kg', 1.8, 2.85, 3.75),
	(12, 85, 89, 'w', 'I', '2 kg', 1.8, 2.7, 3.6),
	(12, 90, 200, 'w', 'I', '2 kg', 1.65, 2.55, 3.3),
	(12, 0, 7, 'm', 'I', '1 kg', 4.65, 5.1, 5.55),
	(12, 8, 9, 'm', 'I', '1 kg', 4.9, 5.35, 5.8),
	(12, 10, 11, 'm', 'I', '1 kg', 5.15, 5.6, 6.05),
	(12, 12, 13, 'm', 'I', '1 kg', 5.4, 5.85, 6.3),
	(12, 14, 15, 'm', 'I', '1 kg', 5.65, 6.1, 6.55),
	(12, 16, 17, 'm', 'I', '1 kg', 5.9, 6.35, 6.8),
	(12, 18, 19, 'm', 'I', '2 kg', 6.15, 6.6, 7.05),
	(12, 20, 24, 'm', 'I', '2 kg', 6.15, 6.75, 7.2),
	(12, 25, 29, 'm', 'I', '2 kg', 5.85, 6.45, 7.05),
	(12, 30, 34, 'm', 'I', '2 kg', 5.4, 6.15, 6.9),
	(12, 35, 39, 'm', 'I', '2 kg', 4.95, 5.85, 6.75),
	(12, 40, 44, 'm', 'I', '2 kg', 4.65, 5.55, 6.45),
	(12, 45, 49, 'm', 'I', '2 kg', 4.2, 5.25, 6.3),
	(12, 50, 54, 'm', 'I', '2 kg', 3.9, 5.1, 6.15),
	(12, 55, 59, 'm', 'I', '2 kg', 3.6, 4.95, 6.0),
	(12, 60, 64, 'm', 'I', '2 kg', 3.45, 4.65, 5.85),
	(12, 65, 69, 'm', 'I', '2 kg', 3.15, 4.35, 5.55),
	(12, 70, 74, 'm', 'I', '2 kg', 3.0, 4.2, 5.4),
	(12, 75, 79, 'm', 'I', '2 kg', 2.7, 3.9, 5.1),
	(12, 80, 84, 'm', 'I', '2 kg', 2.55, 3.75, 4.95),
	(12, 85, 89, 'm', 'I', '2 kg', 2.4, 3.6, 4.8),
	(12, 90, 200, 'm', 'I', '2 kg', 2.1, 3.3, 4.5),
	(13, 12, 13, 'w', 'I', '2 kg', 2.85, 3.15, 3.45),
	(13, 14, 15, 'w', 'I', '3 kg', 3.3, 3.6, 3.9),
	(13, 16, 17, 'w', 'I', '3 kg', 3.45, 3.75, 4.05),
	(13, 18, 19, 'w', 'I', '4 kg', 4.55, 4.9, 5.25),
	(13, 20, 24, 'w', 'I', '4 kg', 4.55, 4.9, 5.25),
	(13, 25, 29, 'w', 'I', '4 kg', 4.55, 4.9, 5.25),
	(13, 30, 34, 'w', 'I', '4 kg', 4.38, 4.73, 5.08),
	(13, 35, 39, 'w', 'I', '4 kg', 4.2, 4.55, 4.9),
	(13, 40, 44, 'w', 'I', '4 kg', 3.85, 4.2, 4.55),
	(13, 45, 49, 'w', 'I', '4 kg', 3.68, 4.03, 4.38),
	(13, 50, 54, 'w', 'I', '3 kg', 3.68, 4.2, 4.9),
	(13, 55, 59, 'w', 'I', '3 kg', 3.5, 4.03, 4.55),
	(13, 60, 64, 'w', 'I', '3 kg', 3.33, 3.85, 4.38),
	(13, 65, 69, 'w', 'I', '3 kg', 3.15, 3.68, 4.38),
	(13, 70, 74, 'w', 'I', '3 kg', 2.98, 3.5, 4.2),
	(13, 75, 79, 'w', 'I', '2 kg', 2.98, 3.68, 4.38),
	(13, 80, 84, 'w', 'I', '2 kg', 2.8, 3.5, 4.03),
	(13, 85, 89, 'w', 'I', '2 kg', 2.63, 3.15, 3.85),
	(13, 90, 200, 'w', 'I', '2 kg', 2.28, 2.98, 3.5),
	(13, 12, 13, 'm', 'I', '3 kg', 3.75, 4.05, 4.35),
	(13, 14, 15, 'm', 'I', '4 kg', 4.2, 4.5, 4.8),
	(13, 16, 17, 'm', 'I', '5 kg', 4.5, 4.8, 5.1),
	(13, 18, 19, 'm', 'I', '6 kg', 5.43, 5.78, 6.13),
	(13, 20, 24, 'm', 'I', '7,26 kg', 5.43, 5.95, 6.3),
	(13, 25, 29, 'm', 'I', '7,26 kg', 5.25, 5.78, 6.13),
	(13, 30, 34, 'm', 'I', '7,26 kg', 4.9, 5.43, 5.78),
	(13, 35, 39, 'm', 'I', '7,26 kg', 4.73, 5.08, 5.6),
	(13, 40, 44, 'm', 'I', '7,26 kg', 4.38, 4.9, 5.43),
	(13, 45, 49, 'm', 'I', '7,26 kg', 4.2, 4.73, 5.25),
	(13, 50, 54, 'm', 'I', '6 kg', 4.38, 4.9, 5.6),
	(13, 55, 59, 'm', 'I', '6 kg', 4.2, 4.73, 5.25),
	(13, 60, 64, 'm', 'I', '5 kg', 4.2, 4.9, 5.6),
	(13, 65, 69, 'm', 'I', '5 kg', 4.03, 4.73, 5.25),
	(13, 70, 74, 'm', 'I', '4 kg', 4.2, 4.73, 5.43),
	(13, 75, 79, 'm', 'I', '4 kg', 4.03, 4.55, 5.25),
	(13, 80, 84, 'm', 'I', '3 kg', 3.85, 4.38, 5.08),
	(13, 85, 89, 'm', 'I', '3 kg', 3.5, 4.2, 4.73),
	(13, 90, 200, 'm', 'I', '3 kg', 3.15, 3.68, 4.38),
	(15, 0, 7, 'w', 'I', '', 0.63, 0.75, 0.84),
	(15, 8, 9, 'w', 'I', '', 0.69, 0.78, 0.9),
	(15, 10, 11, 'w', 'I', '', 0.78, 0.87, 0.99),
	(15, 12, 13, 'w', 'I', '', 0.84, 0.96, 1.08),
	(15, 14, 15, 'w', 'I', '', 0.93, 1.02, 1.14),
	(15, 16, 17, 'w', 'I', '', 0.99, 1.08, 1.2),
	(15, 18, 19, 'w', 'I', '', 0.99, 1.11, 1.23),
	(15, 20, 24, 'w', 'I', '', 0.96, 1.08, 1.2),
	(15, 25, 29, 'w', 'I', '', 0.9, 1.02, 1.17),
	(15, 30, 34, 'w', 'I', '', 0.81, 0.96, 1.11),
	(15, 35, 39, 'w', 'I', '', 0.75, 0.9, 1.08),
	(15, 40, 44, 'w', 'I', '', 0.69, 0.84, 0.99),
	(15, 45, 49, 'w', 'I', '', 0.66, 0.81, 0.96),
	(15, 50, 54, 'w', 'I', '', 0.6, 0.78, 0.93),
	(15, 55, 59, 'w', 'I', '', 0.57, 0.72, 0.87),
	(15, 60, 64, 'w', 'I', '', 0.57, 0.72, 0.87),
	(15, 65, 69, 'w', 'I', '', 0.54, 0.69, 0.84),
	(15, 70, 74, 'w', 'I', '', 0.54, 0.69, 0.81),
	(15, 75, 79, 'w', 'I', '', 0.54, 0.69, 0.81),
	(15, 80, 84, 'w', 'I', '', 0.54, 0.66, 0.78),
	(15, 85, 89, 'w', 'I', '', 0.51, 0.63, 0.75),
	(15, 90, 200, 'w', 'I', '', 0.48, 0.6, 0.72),
	(15, 0, 7, 'm', 'I', '', 0.69, 0.81, 0.9),
	(15, 8, 9, 'm', 'I', '', 0.78, 0.9, 0.99),
	(15, 10, 11, 'm', 'I', '', 0.9, 1.02, 1.11),
	(15, 12, 13, 'm', 'I', '', 1.02, 1.14, 1.23),
	(15, 14, 15, 'm', 'I', '', 1.14, 1.23, 1.35),
	(15, 16, 17, 'm', 'I', '', 1.23, 1.32, 1.44),
	(15, 18, 19, 'm', 'I', '', 1.26, 1.38, 1.5),
	(15, 20, 24, 'm', 'I', '', 1.26, 1.38, 1.5),
	(15, 25, 29, 'm', 'I', '', 1.23, 1.35, 1.47),
	(15, 30, 34, 'm', 'I', '', 1.11, 1.26, 1.41),
	(15, 35, 39, 'm', 'I', '', 0.99, 1.17, 1.35),
	(15, 40, 44, 'm', 'I', '', 0.93, 1.11, 1.29),
	(15, 45, 49, 'm', 'I', '', 0.87, 1.05, 1.23),
	(15, 50, 54, 'm', 'I', '', 0.84, 1.02, 1.2),
	(15, 55, 59, 'm', 'I', '', 0.81, 0.99, 1.17),
	(15, 60, 64, 'm', 'I', '', 0.78, 0.96, 1.14),
	(15, 65, 69, 'm', 'I', '', 0.78, 0.96, 1.14),
	(15, 70, 74, 'm', 'I', '', 0.75, 0.93, 1.11),
	(15, 75, 79, 'm', 'I', '', 0.72, 0.9, 1.08),
	(15, 80, 84, 'm', 'I', '', 0.69, 0.87, 1.05),
	(15, 85, 89, 'm', 'I', '', 0.6, 0.78, 0.96),
	(15, 90, 200, 'm', 'I', '', 0.54, 0.72, 0.9),
	(17, 0, 7, 'w', 'I', '30 m', 11.2, 9.9, 8.8),
	(17, 8, 9, 'w', 'I', '30 m', 10.4, 9.2, 8.0),
	(17, 10, 11, 'w', 'I', '50 m', 15.4, 14.1, 12.7),
	(17, 12, 13, 'w', 'I', '50 m', 14.8, 13.4, 11.9),
	(17, 14, 15, 'w', 'I', '100 m', 26.0, 23.8, 21.7),
	(17, 16, 17, 'w', 'I', '100 m', 24.6, 22.8, 21.0),
	(17, 18, 19, 'w', 'I', '100 m', 25.5, 23.1, 21.4),
	(17, 20, 24, 'w', 'I', '100 m', 25.9, 23.5, 21.8),
	(17, 25, 29, 'w', 'I', '100 m', 26.5, 24.1, 22.4),
	(17, 30, 34, 'w', 'I', '100 m', 27.4, 24.9, 23.0),
	(17, 35, 39, 'w', 'I', '100 m', 28.6, 26.0, 23.8),
	(17, 40, 44, 'w', 'I', '50 m', 15.4, 13.9, 12.3),
	(17, 45, 49, 'w', 'I', '50 m', 16.1, 14.4, 12.7),
	(17, 50, 54, 'w', 'I', '50 m', 16.7, 15.0, 13.3),
	(17, 55, 59, 'w', 'I', '50 m', 17.4, 15.7, 13.9),
	(17, 60, 64, 'w', 'I', '50 m', 17.6, 16.0, 14.3),
	(17, 65, 69, 'w', 'I', '50 m', 17.9, 16.2, 14.6),
	(17, 70, 74, 'w', 'I', '50 m', 18.2, 16.5, 14.8),
	(17, 75, 79, 'w', 'I', '50 m', 18.9, 17.2, 15.5),
	(17, 80, 84, 'w', 'I', '50 m', 20.0, 18.3, 16.8),
	(17, 85, 89, 'w', 'I', '50 m', 21.7, 20.0, 18.5),
	(17, 90, 200, 'w', 'I', '50 m', 23.9, 22.3, 20.7),
	(17, 0, 7, 'm', 'I', '30 m', 10.8, 9.5, 8.4),
	(17, 8, 9, 'm', 'I', '30 m', 10.1, 9.0, 8.0),
	(17, 10, 11, 'm', 'I', '50 m', 14.4, 13.0, 11.8),
	(17, 12, 13, 'm', 'I', '50 m', 13.6, 12.5, 11.3),
	(17, 14, 15, 'm', 'I', '100 m', 23.8, 21.6, 19.7),
	(17, 16, 17, 'm', 'I', '100 m', 22.8, 20.7, 18.9),
	(17, 18, 19, 'm', 'I', '100 m', 22.4, 20.4, 18.5),
	(17, 20, 24, 'm', 'I', '100 m', 22.1, 20.2, 18.2),
	(17, 25, 29, 'm', 'I', '100 m', 22.8, 20.7, 18.6),
	(17, 30, 34, 'm', 'I', '100 m', 23.5, 21.1, 19.0),
	(17, 35, 39, 'm', 'I', '100 m', 24.6, 22.3, 19.9),
	(17, 40, 44, 'm', 'I', '50 m', 13.4, 12.2, 10.8),
	(17, 45, 49, 'm', 'I', '50 m', 14.0, 12.5, 11.1),
	(17, 50, 54, 'm', 'I', '50 m', 14.4, 12.7, 11.5),
	(17, 55, 59, 'm', 'I', '50 m', 14.7, 13.2, 11.9),
	(17, 60, 64, 'm', 'I', '50 m', 15.1, 13.6, 12.3),
	(17, 65, 69, 'm', 'I', '50 m', 15.7, 14.3, 12.7),
	(17, 70, 74, 'm', 'I', '50 m', 16.4, 15.0, 13.4),
	(17, 75, 79, 'm', 'I', '50 m', 17.1, 15.7, 14.1),
	(17, 80, 84, 'm', 'I', '50 m', 18.2, 16.8, 15.3),
	(17, 85, 89, 'm', 'I', '50 m', 19.7, 18.3, 16.8),
	(17, 90, 200, 'm', 'I', '50 m', 21.7, 20.3, 18.8),
	(18, 0, 7, 'w', 'I', '', 65.1, 53.9, 42.7),
	(18, 8, 9, 'w', 'I', '', 58.8, 47.6, 39.2),
	(18, 10, 11, 'w', 'I', '', 54.6, 44.1, 35.7),
	(18, 12, 13, 'w', 'I', '', 49.0, 40.6, 32.9),
	(18, 14, 15, 'w', 'I', '', 46.2, 38.5, 30.1),
	(18, 16, 17, 'w', 'I', '', 42.7, 35.7, 28.0),
	(18, 18, 19, 'w', 'I', '', 41.3, 33.6, 25.9),
	(18, 20, 24, 'w', 'I', '', 40.6, 33.6, 25.9),
	(18, 25, 29, 'w', 'I', '', 42.0, 35.0, 27.3),
	(18, 30, 34, 'w', 'I', '', 45.5, 37.1, 29.4),
	(18, 35, 39, 'w', 'I', '', 50.4, 40.6, 30.8),
	(18, 40, 44, 'w', 'I', '', 56.0, 44.1, 32.9),
	(18, 45, 49, 'w', 'I', '', 61.6, 49.0, 35.0),
	(18, 50, 54, 'w', 'I', '', 67.2, 54.6, 39.2),
	(18, 55, 59, 'w', 'I', '', 72.1, 59.5, 42.7),
	(18, 60, 64, 'w', 'I', '', 76.3, 62.3, 45.5),
	(18, 65, 69, 'w', 'I', '', 79.1, 65.1, 48.3),
	(18, 70, 74, 'w', 'I', '', 82.6, 67.2, 50.4),
	(18, 75, 79, 'w', 'I', '', 85.4, 70.0, 53.2),
	(18, 80, 84, 'w', 'I', '', 88.9, 72.8, 56.0),
	(18, 85, 89, 'w', 'I', '', 91.7, 74.9, 58.1),
	(18, 90, 200, 'w', 'I', '', 93.1, 76.3, 59.5),
	(18, 0, 7, 'm', 'I', '', 64.4, 53.2, 42.0),
	(18, 8, 9, 'm', 'I', '', 57.4, 46.2, 36.4),
	(18, 10, 11, 'm', 'I', '', 50.4, 40.6, 31.5),
	(18, 12, 13, 'm', 'I', '', 46.2, 37.8, 29.4),
	(18, 14, 15, 'm', 'I', '', 43.4, 35.7, 28.0),
	(18, 16, 17, 'm', 'I', '', 41.3, 34.3, 26.6),
	(18, 18, 19, 'm', 'I', '', 39.2, 32.2, 24.5),
	(18, 20, 24, 'm', 'I', '', 37.8, 30.8, 21.7),
	(18, 25, 29, 'm', 'I', '', 40.6, 32.2, 23.1),
	(18, 30, 34, 'm', 'I', '', 44.1, 33.6, 23.8),
	(18, 35, 39, 'm', 'I', '', 49.0, 37.1, 25.9),
	(18, 40, 44, 'm', 'I', '', 53.9, 41.3, 26.6),
	(18, 45, 49, 'm', 'I', '', 58.8, 45.5, 28.7),
	(18, 50, 54, 'm', 'I', '', 63.0, 49.0, 32.2),
	(18, 55, 59, 'm', 'I', '', 68.6, 51.8, 35.0),
	(18, 60, 64, 'm', 'I', '', 71.4, 54.6, 37.8),
	(18, 65, 69, 'm', 'I', '', 73.5, 56.7, 39.9),
	(18, 70, 74, 'm', 'I', '', 77.0, 60.2, 43.4),
	(18, 75, 79, 'm', 'I', '', 80.5, 63.7, 46.9),
	(18, 80, 84, 'm', 'I', '', 82.6, 67.2, 50.4),
	(18, 85, 89, 'm', 'I', '', 83.3, 68.6, 53.2),
	(18, 90, 200, 'm', 'I', '', 84.0, 70.0, 56.0),
	(19, 8, 9, 'w', 'I', '', 57.4, 50.4, 43.4),
	(19, 10, 11, 'w', 'I', '', 51.8, 44.8, 37.8),
	(19, 12, 13, 'w', 'I', '', 43.4, 37.8, 32.9),
	(19, 14, 15, 'w', 'I', '', 37.8, 34.3, 30.1),
	(19, 16, 17, 'w', 'I', '', 35.0, 31.5, 28.0),
	(19, 18, 19, 'w', 'I', '', 33.6, 30.8, 27.3),
	(19, 20, 24, 'w', 'I', '', 34.3, 30.8, 27.3),
	(19, 25, 29, 'w', 'I', '', 35.0, 31.5, 28.0),
	(19, 30, 34, 'w', 'I', '', 36.4, 32.9, 30.1),
	(19, 35, 39, 'w', 'I', '', 38.5, 34.3, 30.8),
	(19, 40, 44, 'w', 'I', '', 40.6, 35.7, 31.5),
	(19, 45, 49, 'w', 'I', '', 42.7, 37.8, 32.2),
	(19, 50, 54, 'w', 'I', '', 44.8, 39.2, 32.9),
	(19, 55, 59, 'w', 'I', '', 46.9, 40.6, 33.6),
	(19, 60, 64, 'w', 'I', '', 49.0, 42.0, 35.0),
	(19, 65, 69, 'w', 'I', '', 50.4, 43.4, 35.7),
	(19, 70, 74, 'w', 'I', '', 53.2, 44.8, 37.1),
	(19, 75, 79, 'w', 'I', '', 54.6, 46.2, 38.5),
	(19, 80, 84, 'w', 'I', '', 56.7, 48.3, 39.9),
	(19, 85, 89, 'w', 'I', '', 58.8, 50.4, 42.0),
	(19, 90, 200, 'w', 'I', '', 62.3, 53.2, 44.1),
	(19, 8, 9, 'm', 'I', '', 53.2, 46.2, 39.2),
	(19, 10, 11, 'm', 'I', '', 49.0, 42.7, 36.4),
	(19, 12, 13, 'm', 'I', '', 41.3, 36.4, 31.5),
	(19, 14, 15, 'm', 'I', '', 33.6, 30.1, 26.6),
	(19, 16, 17, 'm', 'I', '', 30.8, 27.3, 23.8),
	(19, 18, 19, 'm', 'I', '', 28.7, 25.2, 21.7),
	(19, 20, 24, 'm', 'I', '', 28.0, 24.5, 21.0),
	(19, 25, 29, 'm', 'I', '', 29.4, 25.2, 21.0),
	(19, 30, 34, 'm', 'I', '', 31.5, 25.9, 21.0),
	(19, 35, 39, 'm', 'I', '', 33.6, 28.0, 21.7),
	(19, 40, 44, 'm', 'I', '', 37.1, 30.1, 23.1),
	(19, 45, 49, 'm', 'I', '', 39.9, 32.2, 23.8),
	(19, 50, 54, 'm', 'I', '', 42.0, 33.6, 25.2),
	(19, 55, 59, 'm', 'I', '', 44.8, 35.0, 25.9),
	(19, 60, 64, 'm', 'I', '', 46.9, 36.4, 26.6),
	(19, 65, 69, 'm', 'I', '', 49.0, 37.8, 27.3),
	(19, 70, 74, 'm', 'I', '', 50.4, 39.9, 28.0),
	(19, 75, 79, 'm', 'I', '', 52.5, 41.3, 30.1),
	(19, 80, 84, 'm', 'I', '', 54.6, 44.1, 32.2),
	(19, 85, 89, 'm', 'I', '', 57.4, 46.2, 34.3),
	(19, 90, 200, 'm', 'I', '', 60.9, 49.7, 37.8),
	(21, 10, 11, 'w', 'I', '', 0.48, 0.54, 0.6),
	(21, 12, 13, 'w', 'I', '', 0.54, 0.6, 0.66),
	(21, 14, 15, 'w', 'I', '', 0.57, 0.63, 0.69),
	(21, 16, 17, 'w', 'I', '', 0.63, 0.69, 0.75),
	(21, 18, 19, 'w', 'I', '', 0.66, 0.72, 0.78),
	(21, 20, 24, 'w', 'I', '', 0.66, 0.72, 0.78),
	(21, 25, 29, 'w', 'I', '', 0.63, 0.69, 0.75),
	(21, 30, 34, 'w', 'I', '', 0.6, 0.66, 0.72),
	(21, 35, 39, 'w', 'I', '', 0.57, 0.63, 0.69),
	(21, 40, 44, 'w', 'I', '', 0.54, 0.6, 0.66),
	(21, 45, 49, 'w', 'I', '', 0.54, 0.6, 0.66),
	(21, 50, 54, 'w', 'I', '', 0.51, 0.57, 0.63),
	(21, 55, 59, 'w', 'I', '', 0.48, 0.54, 0.6),
	(21, 60, 64, 'w', 'I', '', 0.45, 0.51, 0.57),
	(21, 65, 69, 'w', 'I', '', 0.45, 0.51, 0.57),
	(21, 70, 74, 'w', 'I', '', 0.42, 0.48, 0.54),
	(21, 75, 79, 'w', 'I', '', 0.39, 0.45, 0.51),
	(21, 80, 84, 'w', 'I', '', 0.39, 0.45, 0.51),
	(21, 85, 89, 'w', 'I', '', 0.36, 0.42, 0.48),
	(21, 90, 200, 'w', 'I', '', 0.33, 0.36, 0.39),
	(21, 10, 11, 'm', 'I', '', 0.51, 0.57, 0.63),
	(21, 12, 13, 'm', 'I', '', 0.57, 0.63, 0.69),
	(21, 14, 15, 'm', 'I', '', 0.66, 0.72, 0.78),
	(21, 16, 17, 'm', 'I', '', 0.72, 0.78, 0.84),
	(21, 18, 19, 'm', 'I', '', 0.78, 0.84, 0.9),
	(21, 20, 24, 'm', 'I', '', 0.81, 0.87, 0.93),
	(21, 25, 29, 'm', 'I', '', 0.78, 0.84, 0.9),
	(21, 30, 34, 'm', 'I', '', 0.78, 0.84, 0.9),
	(21, 35, 39, 'm', 'I', '', 0.75, 0.81, 0.87),
	(21, 40, 44, 'm', 'I', '', 0.72, 0.78, 0.84),
	(21, 45, 49, 'm', 'I', '', 0.69, 0.75, 0.81),
	(21, 50, 54, 'm', 'I', '', 0.63, 0.69, 0.75),
	(21, 55, 59, 'm', 'I', '', 0.6, 0.66, 0.72),
	(21, 60, 64, 'm', 'I', '', 0.57, 0.63, 0.69),
	(21, 65, 69, 'm', 'I', '', 0.51, 0.6, 0.66),
	(21, 70, 74, 'm', 'I', '', 0.48, 0.57, 0.63),
	(21, 75, 79, 'm', 'I', '', 0.45, 0.54, 0.6),
	(21, 80, 84, 'm', 'I', '', 0.45, 0.51, 0.57),
	(21, 85, 89, 'm', 'I', '', 0.42, 0.48, 0.54),
	(21, 90, 200, 'm', 'I', '', 0.39, 0.45, 0.51),
	(23, 0, 7, 'w', 'I', '', 0.98, 1.16, 1.34),
	(23, 8, 9, 'w', 'I', '', 1.18, 1.36, 1.54),
	(23, 10, 11, 'w', 'I', '', 1.38, 1.56, 1.74),
	(23, 12, 13, 'w', 'I', '', 1.68, 1.86, 2.04),
	(23, 14, 15, 'w', 'I', '', 1.92, 2.1, 2.28),
	(23, 16, 17, 'w', 'I', '', 2.04, 2.22, 2.4),
	(23, 18, 19, 'w', 'I', '', 2.04, 2.22, 2.4),
	(23, 20, 24, 'w', 'I', '', 2.04, 2.22, 2.4),
	(23, 25, 29, 'w', 'I', '', 1.98, 2.16, 2.34),
	(23, 30, 34, 'w', 'I', '', 1.92, 2.1, 2.28),
	(23, 35, 39, 'w', 'I', '', 1.86, 2.04, 2.22),
	(23, 40, 44, 'w', 'I', '', 1.8, 1.98, 2.16),
	(23, 45, 49, 'w', 'I', '', 1.68, 1.92, 2.1),
	(23, 50, 54, 'w', 'I', '', 1.56, 1.8, 2.04),
	(23, 55, 59, 'w', 'I', '', 1.5, 1.74, 1.98),
	(23, 60, 64, 'w', 'I', '', 1.44, 1.68, 1.92),
	(23, 65, 69, 'w', 'I', '', 1.38, 1.62, 1.86),
	(23, 70, 74, 'w', 'I', '', 1.26, 1.5, 1.74),
	(23, 75, 79, 'w', 'I', '', 1.08, 1.32, 1.56),
	(23, 80, 84, 'w', 'I', '', 0.96, 1.2, 1.44),
	(23, 85, 89, 'w', 'I', '', 0.78, 1.02, 1.26),
	(23, 90, 200, 'w', 'I', '', 0.66, 0.9, 1.14),
	(23, 0, 7, 'm', 'I', '', 1.16, 1.34, 1.52),
	(23, 8, 9, 'm', 'I', '', 1.36, 1.54, 1.72),
	(23, 10, 11, 'm', 'I', '', 1.56, 1.74, 1.92),
	(23, 12, 13, 'm', 'I', '', 1.92, 2.1, 2.28),
	(23, 14, 15, 'm', 'I', '', 2.28, 2.46, 2.64),
	(23, 16, 17, 'm', 'I', '', 2.58, 2.76, 2.94),
	(23, 18, 19, 'm', 'I', '', 2.7, 2.88, 3.06),
	(23, 20, 24, 'm', 'I', '', 2.64, 2.82, 3.0),
	(23, 25, 29, 'm', 'I', '', 2.58, 2.76, 2.94),
	(23, 30, 34, 'm', 'I', '', 2.52, 2.7, 2.88),
	(23, 35, 39, 'm', 'I', '', 2.46, 2.64, 2.82),
	(23, 40, 44, 'm', 'I', '', 2.34, 2.58, 2.76),
	(23, 45, 49, 'm', 'I', '', 2.22, 2.46, 2.7),
	(23, 50, 54, 'm', 'I', '', 2.16, 2.4, 2.64),
	(23, 55, 59, 'm', 'I', '', 2.04, 2.28, 2.52),
	(23, 60, 64, 'm', 'I', '', 1.92, 2.16, 2.4),
	(23, 65, 69, 'm', 'I', '', 1.74, 1.98, 2.22),
	(23, 70, 74, 'm', 'I', '', 1.62, 1.86, 2.1),
	(23, 75, 79, 'm', 'I', '', 1.44, 1.74, 1.98),
	(23, 80, 84, 'm', 'I', '', 1.26, 1.56, 1.86),
	(23, 85, 89, 'm', 'I', '', 1.14, 1.44, 1.74),
	(23, 90, 200, 'm', 'I', '', 0.96, 1.26, 1.56),
	(25, 12, 13, 'w', 'I', '', 10.2, 11.7, 13.2),
	(25, 14, 15, 'w', 'I', '', 11.7, 13.5, 15.3),
	(25, 16, 17, 'w', 'I', '', 13.2, 15.0, 16.8),
	(25, 18, 19, 'w', 'I', '', 14.1, 15.9, 17.4),
	(25, 20, 24, 'w', 'I', '', 14.4, 16.2, 17.7),
	(25, 25, 29, 'w', 'I', '', 14.4, 16.2, 17.7),
	(25, 30, 34, 'w', 'I', '', 13.2, 15.0, 16.5),
	(25, 35, 39, 'w', 'I', '', 12.6, 14.4, 15.9),
	(25, 40, 44, 'w', 'I', '', 11.7, 13.5, 15.0),
	(25, 45, 49, 'w', 'I', '', 11.1, 12.9, 14.4),
	(25, 50, 54, 'w', 'I', '', 9.9, 12.0, 13.8),
	(25, 55, 59, 'w', 'I', '', 9.3, 11.4, 13.2),
	(25, 60, 64, 'w', 'I', '', 8.7, 10.8, 12.6),
	(25, 65, 69, 'w', 'I', '', 8.1, 10.2, 12.0),
	(25, 70, 74, 'w', 'I', '', 7.8, 9.9, 11.7),
	(25, 75, 79, 'w', 'I', '', 7.2, 9.3, 11.1),
	(25, 80, 84, 'w', 'I', '', 6.6, 8.7, 10.5),
	(25, 85, 89, 'w', 'I', '', 5.7, 7.8, 9.6),
	(25, 90, 200, 'w', 'I', '', 4.5, 6.6, 8.4),
	(25, 12, 13, 'm', 'I', '', 11.7, 14.4, 16.5),
	(25, 14, 15, 'm', 'I', '', 14.1, 16.8, 19.2),
	(25, 16, 17, 'm', 'I', '', 16.5, 19.2, 21.9),
	(25, 18, 19, 'm', 'I', '', 18.9, 21.6, 24.3),
	(25, 20, 24, 'm', 'I', '', 19.8, 22.8, 25.2),
	(25, 25, 29, 'm', 'I', '', 19.5, 22.5, 24.9),
	(25, 30, 34, 'm', 'I', '', 18.0, 21.0, 24.0),
	(25, 35, 39, 'm', 'I', '', 17.1, 20.1, 23.1),
	(25, 40, 44, 'm', 'I', '', 16.8, 19.8, 22.8),
	(25, 45, 49, 'm', 'I', '', 16.2, 19.2, 22.5),
	(25, 50, 54, 'm', 'I', '', 15.3, 18.6, 21.9),
	(25, 55, 59, 'm', 'I', '', 14.1, 17.4, 21.0),
	(25, 60, 64, 'm', 'I', '', 13.5, 16.8, 20.4),
	(25, 65, 69, 'm', 'I', '', 12.0, 15.3, 18.3),
	(25, 70, 74, 'm', 'I', '', 11.1, 14.4, 17.4),
	(25, 75, 79, 'm', 'I', '', 9.6, 12.6, 15.6),
	(25, 80, 84, 'm', 'I', '', 8.4, 11.4, 14.4),
	(25, 85, 89, 'm', 'I', '', 7.2, 9.9, 12.6),
	(25, 90, 200, 'm', 'I', '', 6.3, 9.0, 11.7),
	(32, 18, 19, 'w', 'I', '', 16.866666666666667, 15.25, 13.633333333333335),
	(32, 20, 24, 'w', 'I', '', 16.46666666666667, 14.85, 13.233333333333334),
	(32, 25, 29, 'w', 'I', '', 16.733333333333334, 15.116666666666667, 13.500000000000002),
	(32, 30, 34, 'w', 'I', '', 17.416666666666668, 15.8, 14.166666666666666),
	(32, 35, 39, 'w', 'I', '', 17.816666666666663, 16.200000000000003, 14.583333333333332),
	(32, 40, 44, 'w', 'I', '', 18.5, 16.733333333333334, 14.983333333333333),
	(32, 45, 49, 'w', 'I', '', 19.3, 17.416666666666668, 15.25),
	(32, 50, 54, 'w', 'I', '', 20.116666666666667, 17.95, 15.533333333333333),
	(32, 55, 59, 'w', 'I', '', 20.93333333333333, 18.5, 16.066666666666666),
	(32, 60, 64, 'w', 'I', '', 21.46666666666667, 19.03333333333333, 16.599999999999998),
	(32, 65, 69, 'w', 'I', '', 22.0, 19.583333333333336, 17.15),
	(32, 70, 74, 'w', 'I', '', 22.416666666666668, 19.983333333333334, 17.549999999999997),
	(32, 75, 79, 'w', 'I', '', 23.083333333333336, 20.650000000000002, 18.233333333333334),
	(32, 80, 84, 'w', 'I', '', 24.03333333333333, 21.599999999999998, 19.166666666666668),
	(32, 85, 89, 'w', 'I', '', 25.116666666666667, 22.683333333333334, 20.249999999999996),
	(32, 90, 200, 'w', 'I', '', 26.333333333333332, 23.9, 21.46666666666667),
	(32, 18, 19, 'm', 'I', '', 14.45, 12.833333333333334, 11.2),
	(32, 20, 24, 'm', 'I', '', 14.033333333333333, 12.416666666666666, 10.8),
	(32, 25, 29, 'm', 'I', '', 14.316666666666666, 12.683333333333334, 11.066666666666665),
	(32, 30, 34, 'm', 'I', '', 14.983333333333333, 13.366666666666667, 11.749999999999998),
	(32, 35, 39, 'm', 'I', '', 16.066666666666666, 14.033333333333333, 12.15),
	(32, 40, 44, 'm', 'I', '', 17.01666666666667, 14.983333333333333, 12.833333333333334),
	(32, 45, 49, 'm', 'I', '', 17.95, 15.8, 13.366666666666667),
	(32, 50, 54, 'm', 'I', '', 18.9, 16.46666666666667, 14.033333333333333),
	(32, 55, 59, 'm', 'I', '', 19.3, 16.866666666666667, 14.45),
	(32, 60, 64, 'm', 'I', '', 19.85, 17.416666666666668, 14.983333333333333),
	(32, 65, 69, 'm', 'I', '', 20.249999999999996, 17.816666666666663, 15.383333333333335),
	(32, 70, 74, 'm', 'I', '', 20.516666666666666, 18.083333333333336, 15.666666666666668),
	(32, 75, 79, 'm', 'I', '', 21.066666666666666, 18.633333333333333, 16.200000000000003),
	(32, 80, 84, 'm', 'I', '', 21.46666666666667, 19.03333333333333, 16.599999999999998),
	(32, 85, 89, 'm', 'I', '', 22.266666666666666, 19.85, 17.416666666666668),
	(32, 90, 200, 'm', 'I', '', 24.166666666666668, 21.733333333333334, 19.3),
	(33, 0, 7, 'w', 'I', 'auch als Wandern/Walking möglich', 5.6000000000000005, 8.4, 11.899999999999999),
	(33, 8, 9, 'w', 'I', 'auch als Wandern/Walking möglich', 7.0, 10.500000000000002, 14.0),
	(33, 10, 11, 'w', 'I', 'auch als Wandern/Walking möglich', 10.500000000000002, 14.0, 21.0),
	(33, 12, 13, 'w', 'I', 'auch als Wandern/Walking möglich', 14.0, 21.0, 28.0),
	(33, 14, 15, 'w', 'I', 'auch als Wandern/Walking möglich', 21.0, 28.0, 35.0),
	(33, 16, 17, 'w', 'I', 'auch als Wandern/Walking möglich', 31.5, 42.0, 52.49999999999999),
	(33, 0, 7, 'm', 'I', 'auch als Wandern/Walking möglich', 7.0, 10.500000000000002, 14.0),
	(33, 8, 9, 'm', 'I', 'auch als Wandern/Walking möglich', 8.4, 11.899999999999999, 16.099999999999998),
	(33, 10, 11, 'm', 'I', 'auch als Wandern/Walking möglich', 11.899999999999999, 17.5, 24.5),
	(33, 12, 13, 'm', 'I', 'auch als Wandern/Walking möglich', 17.5, 24.5, 31.5),
	(33, 14, 15, 'm', 'I', 'auch als Wandern/Walking möglich', 24.5, 31.5, 42.0),
	(33, 16, 17, 'm', 'I', 'auch als Wandern/Walking möglich', 38.49999999999999, 49.0, 63.0),
	(38, 18, 19, 'w', 'I', '', 51.43333333333333, 48.833333333333336, 45.88333333333333),
	(38, 20, 24, 'w', 'I', '', 49.21666666666667, 46.61666666666666, 44.03333333333334),
	(38, 25, 29, 'w', 'I', '', 49.583333333333336, 46.98333333333334, 44.400000000000006),
	(38, 30, 34, 'w', 'I', '', 49.95, 47.36666666666667, 44.7),
	(38, 35, 39, 'w', 'I', '', 51.8, 48.1, 44.95),
	(38, 40, 44, 'w', 'I', '', 54.016666666666666, 49.583333333333336, 45.13333333333333),
	(38, 45, 49, 'w', 'I', '', 55.866666666666674, 51.06666666666666, 45.88333333333333),
	(38, 50, 54, 'w', 'I', '', 57.71666666666667, 52.53333333333333, 47.36666666666667),
	(38, 55, 59, 'w', 'I', '', 59.199999999999996, 54.016666666666666, 48.833333333333336),
	(38, 60, 64, 'w', 'I', '', 61.050000000000004, 55.13333333333333, 49.95),
	(38, 65, 69, 'w', 'I', '', 62.35, 56.61666666666666, 51.8),
	(38, 70, 74, 'w', 'I', '', 65.30000000000001, 58.46666666666667, 53.28333333333334),
	(38, 75, 79, 'w', 'I', '', 68.44999999999999, 60.31666666666666, 55.13333333333333),
	(38, 80, 84, 'w', 'I', '', 72.88333333333334, 63.08333333333333, 57.35),
	(38, 85, 89, 'w', 'I', '', 76.96666666666667, 66.85000000000001, 60.68333333333333),
	(38, 90, 200, 'w', 'I', '', 81.65, 71.03333333333333, 64.38333333333334),
	(38, 18, 19, 'm', 'I', '', 43.28333333333334, 40.333333333333336, 37.36666666666667),
	(38, 20, 24, 'm', 'I', '', 42.18333333333333, 39.21666666666667, 36.26666666666666),
	(38, 25, 29, 'm', 'I', '', 43.28333333333334, 40.333333333333336, 37.36666666666667),
	(38, 30, 34, 'm', 'I', '', 46.25, 42.18333333333333, 37.73333333333333),
	(38, 35, 39, 'm', 'I', '', 48.1, 43.28333333333334, 39.583333333333336),
	(38, 40, 44, 'm', 'I', '', 48.833333333333336, 44.766666666666666, 39.96666666666666),
	(38, 45, 49, 'm', 'I', '', 50.68333333333333, 46.25, 40.7),
	(38, 50, 54, 'm', 'I', '', 52.53333333333333, 47.36666666666667, 42.55),
	(38, 55, 59, 'm', 'I', '', 54.016666666666666, 48.1, 43.666666666666664),
	(38, 60, 64, 'm', 'I', '', 56.050000000000004, 49.95, 44.766666666666666),
	(38, 65, 69, 'm', 'I', '', 57.849999999999994, 51.43333333333333, 45.88333333333333),
	(38, 70, 74, 'm', 'I', '', 60.31666666666666, 53.28333333333334, 48.1),
	(38, 75, 79, 'm', 'I', '', 63.766666666666666, 56.050000000000004, 53.28333333333334),
	(38, 80, 84, 'm', 'I', '', 67.71666666666668, 59.016666666666666, 53.28333333333334),
	(38, 85, 89, 'm', 'I', '', 71.03333333333333, 62.35, 55.866666666666674),
	(38, 90, 200, 'm', 'I', '', 76.03333333333333, 66.10000000000001, 59.199999999999996),
	(39, 0, 7, 'w', 'I', '', 133.0, 148.0, 162.0),
	(39, 8, 9, 'w', 'I', '', 144.0, 160.0, 176.0),
	(39, 10, 11, 'w', 'I', '', 155.0, 173.0, 190.0),
	(39, 12, 13, 'w', 'I', '', 167.0, 185.0, 204.0),
	(39, 14, 15, 'w', 'I', '', 178.0, 198.0, 217.0),
	(39, 16, 17, 'w', 'I', '', 189.0, 210.0, 231.0),
	(39, 18, 19, 'w', 'I', '', 279.0, 310.0, 341.0),
	(39, 20, 24, 'w', 'I', '', 279.0, 310.0, 341.0),
	(39, 25, 29, 'w', 'I', '', 279.0, 310.0, 341.0),
	(39, 30, 34, 'w', 'I', '', 268.0, 298.0, 327.0),
	(39, 35, 39, 'w', 'I', '', 268.0, 298.0, 327.0),
	(39, 40, 44, 'w', 'I', '', 257.0, 285.0, 314.0),
	(39, 45, 49, 'w', 'I', '', 245.0, 273.0, 300.0),
	(39, 50, 54, 'w', 'I', '', 234.0, 260.0, 286.0),
	(39, 55, 59, 'w', 'I', '', 223.0, 248.0, 272.0),
	(39, 60, 64, 'w', 'I', '', 212.0, 235.0, 259.0),
	(39, 65, 69, 'w', 'I', '', 200.0, 223.0, 245.0),
	(39, 70, 74, 'w', 'I', '', 189.0, 210.0, 231.0),
	(39, 75, 79, 'w', 'I', '', 178.0, 198.0, 217.0),
	(39, 80, 84, 'w', 'I', '', 167.0, 185.0, 204.0),
	(39, 85, 89, 'w', 'I', '', 155.0, 173.0, 190.0),
	(39, 90, 200, 'w', 'I', '', 144.0, 160.0, 176.0),
	(39, 0, 7, 'm', 'I', '', 191.0, 213.0, 234.0),
	(39, 8, 9, 'm', 'I', '', 203.0, 225.0, 248.0),
	(39, 10, 11, 'm', 'I', '', 214.0, 238.0, 261.0),
	(39, 12, 13, 'm', 'I', '', 225.0, 250.0, 275.0),
	(39, 14, 15, 'm', 'I', '', 236.0, 263.0, 289.0),
	(39, 16, 17, 'm', 'I', '', 248.0, 275.0, 303.0),
	(39, 18, 19, 'm', 'I', '', 338.0, 375.0, 413.0),
	(39, 20, 24, 'm', 'I', '', 338.0, 375.0, 413.0),
	(39, 25, 29, 'm', 'I', '', 338.0, 375.0, 413.0),
	(39, 30, 34, 'm', 'I', '', 326.0, 363.0, 399.0),
	(39, 35, 39, 'm', 'I', '', 326.0, 363.0, 399.0),
	(39, 40, 44, 'm', 'I', '', 315.0, 350.0, 385.0),
	(39, 45, 49, 'm', 'I', '', 304.0, 338.0, 371.0),
	(39, 50, 54, 'm', 'I', '', 293.0, 325.0, 358.0),
	(39, 55, 59, 'm', 'I', '', 281.0, 313.0, 344.0),
	(39, 60, 64, 'm', 'I', '', 270.0, 300.0, 330.0),
	(39, 65, 69, 'm', 'I', '', 259.0, 288.0, 316.0),
	(39, 70, 74, 'm', 'I', '', 248.0, 275.0, 303.0),
	(39, 75, 79, 'm', 'I', '', 236.0, 263.0, 289.0),
	(39, 80, 84, 'm', 'I', '', 225.0, 250.0, 275.0),
	(39, 85, 89, 'm', 'I', '', 214.0, 238.0, 261.0),
	(39, 90, 200, 'm', 'I', '', 203.0, 225.0, 248.0),
	(40, 0, 7, 'w', 'I', '', 293.0, 325.0, 358.0),
	(40, 8, 9, 'w', 'I', '', 306.0, 340.0, 374.0),
	(40, 10, 11, 'w', 'I', '', 320.0, 355.0, 391.0),
	(40, 12, 13, 'w', 'I', '', 333.0, 370.0, 407.0),
	(40, 14, 15, 'w', 'I', '', 347.0, 385.0, 424.0),
	(40, 16, 17, 'w', 'I', '', 360.0, 400.0, 440.0),
	(40, 18, 19, 'w', 'I', '', 450.0, 500.0, 550.0),
	(40, 20, 24, 'w', 'I', '', 450.0, 500.0, 550.0),
	(40, 25, 29, 'w', 'I', '', 450.0, 500.0, 550.0),
	(40, 30, 34, 'w', 'I', '', 437.0, 485.0, 534.0),
	(40, 35, 39, 'w', 'I', '', 437.0, 485.0, 534.0),
	(40, 40, 44, 'w', 'I', '', 423.0, 470.0, 517.0),
	(40, 45, 49, 'w', 'I', '', 410.0, 455.0, 501.0),
	(40, 50, 54, 'w', 'I', '', 396.0, 440.0, 484.0),
	(40, 55, 59, 'w', 'I', '', 383.0, 425.0, 468.0),
	(40, 60, 64, 'w', 'I', '', 369.0, 410.0, 451.0),
	(40, 65, 69, 'w', 'I', '', 356.0, 395.0, 435.0),
	(40, 70, 74, 'w', 'I', '', 342.0, 380.0, 418.0),
	(40, 75, 79, 'w', 'I', '', 329.0, 365.0, 402.0),
	(40, 80, 84, 'w', 'I', '', 315.0, 350.0, 385.0),
	(40, 85, 89, 'w', 'I', '', 302.0, 335.0, 369.0),
	(40, 90, 200, 'w', 'I', '', 288.0, 320.0, 352.0),
	(40, 0, 7, 'm', 'I', '', 360.0, 400.0, 440.0),
	(40, 8, 9, 'm', 'I', '', 374.0, 415.0, 457.0),
	(40, 10, 11, 'm', 'I', '', 387.0, 430.0, 473.0),
	(40, 12, 13, 'm', 'I', '', 401.0, 445.0, 490.0),
	(40, 14, 15, 'm', 'I', '', 414.0, 460.0, 506.0),
	(40, 16, 17, 'm', 'I', '', 428.0, 475.0, 523.0),
	(40, 18, 19, 'm', 'I', '', 518.0, 575.0, 633.0),
	(40, 20, 24, 'm', 'I', '', 518.0, 575.0, 633.0),
	(40, 25, 29, 'm', 'I', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'I', '', 504.0, 560.0, 616.0),
	(40, 35, 39, 'm', 'I', '', 504.0, 560.0, 616.0),
	(40, 40, 44, 'm', 'I', '', 491.0, 545.0, 600.0),
	(40, 45, 49, 'm', 'I', '', 477.0, 530.0, 583.0),
	(40, 50, 54, 'm', 'I', '', 464.0, 515.0, 567.0),
	(40, 55, 59, 'm', 'I', '', 450.0, 500.0, 550.0),
	(40, 60, 64, 'm', 'I', '', 437.0, 485.0, 534.0),
	(40, 65, 69, 'm', 'I', '', 423.0, 470.0, 517.0),
	(40, 70, 74, 'm', 'I', '', 410.0, 455.0, 501.0),
	(40, 75, 79, 'm', 'I', '', 396.0, 440.0, 484.0),
	(40, 80, 84, 'm', 'I', '', 383.0, 425.0, 468.0),
	(40, 85, 89, 'm', 'I', '', 369.0, 410.0, 451.0),
	(40, 90, 200, 'm', 'I', '', 356.0, 395.0, 435.0),
	(41, 0, 7, 'w', 'I', '', 225.0, 250.0, 275.0),
	(41, 8, 9, 'w', 'I', '', 239.0, 265.0, 292.0),
	(41, 10, 11, 'w', 'I', '', 252.0, 280.0, 308.0),
	(41, 12, 13, 'w', 'I', '', 266.0, 295.0, 325.0),
	(41, 14, 15, 'w', 'I', '', 279.0, 310.0, 341.0),
	(41, 16, 17, 'w', 'I', '', 293.0, 325.0, 358.0),
	(41, 18, 19, 'w', 'I', '', 383.0, 425.0, 468.0),
	(41, 20, 24, 'w', 'I', '', 383.0, 425.0, 468.0),
	(41, 25, 29, 'w', 'I', '', 383.0, 425.0, 468.0),
	(41, 30, 34, 'w', 'I', '', 369.0, 410.0, 451.0),
	(41, 35, 39, 'w', 'I', '', 369.0, 410.0, 451.0),
	(41, 40, 44, 'w', 'I', '', 356.0, 395.0, 435.0),
	(41, 45, 49, 'w', 'I', '', 342.0, 380.0, 418.0),
	(41, 50, 54, 'w', 'I', '', 329.0, 365.0, 402.0),
	(41, 55, 59, 'w', 'I', '', 315.0, 350.0, 385.0),
	(41, 60, 64, 'w', 'I', '', 302.0, 335.0, 369.0),
	(41, 65, 69, 'w', 'I', '', 288.0, 320.0, 352.0),
	(41, 70, 74, 'w', 'I', '', 275.0, 305.0, 336.0),
	(41, 75, 79, 'w', 'I', '', 261.0, 290.0, 319.0),
	(41, 80, 84, 'w', 'I', '', 248.0, 275.0, 303.0),
	(41, 85, 89, 'w', 'I', '', 234.0, 260.0, 286.0),
	(41, 90, 200, 'w', 'I', '', 221.0, 245.0, 270.0),
	(41, 0, 7, 'm', 'I', '', 288.0, 320.0, 352.0),
	(41, 8, 9, 'm', 'I', '', 302.0, 335.0, 369.0),
	(41, 10, 11, 'm', 'I', '', 315.0, 350.0, 385.0),
	(41, 12, 13, 'm', 'I', '', 329.0, 365.0, 402.0),
	(41, 14, 15, 'm', 'I', '', 342.0, 380.0, 418.0),
	(41, 16, 17, 'm', 'I', '', 356.0, 395.0, 435.0),
	(41, 18, 19, 'm', 'I', '', 446.0, 495.0, 545.0),
	(41, 20, 24, 'm', 'I', '', 446.0, 495.0, 545.0),
	(41, 25, 29, 'm', 'I', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'I', '', 432.0, 480.0, 528.0),
	(41, 35, 39, 'm', 'I', '', 432.0, 480.0, 528.0),
	(41, 40, 44, 'm', 'I', '', 419.0, 465.0, 512.0),
	(41, 45, 49, 'm', 'I', '', 405.0, 450.0, 495.0),
	(41, 50, 54, 'm', 'I', '', 392.0, 435.0, 479.0),
	(41, 55, 59, 'm', 'I', '', 378.0, 420.0, 462.0),
	(41, 60, 64, 'm', 'I', '', 365.0, 405.0, 446.0),
	(41, 65, 69, 'm', 'I', '', 351.0, 390.0, 429.0),
	(41, 70, 74, 'm', 'I', '', 338.0, 375.0, 413.0),
	(41, 75, 79, 'm', 'I', '', 324.0, 360.0, 396.0),
	(41, 80, 84, 'm', 'I', '', 311.0, 345.0, 380.0),
	(41, 85, 89, 'm', 'I', '', 297.0, 330.0, 363.0),
	(41, 90, 200, 'm', 'I', '', 284.0, 315.0, 347.0),
	(42, 0, 7, 'w', 'I', '', 230.0, 255.0, 281.0),
	(42, 8, 9, 'w', 'I', '', 243.0, 270.0, 297.0),
	(42, 10, 11, 'w', 'I', '', 257.0, 285.0, 314.0),
	(42, 12, 13, 'w', 'I', '', 270.0, 300.0, 330.0),
	(42, 14, 15, 'w', 'I', '', 284.0, 315.0, 347.0),
	(42, 16, 17, 'w', 'I', '', 297.0, 330.0, 363.0),
	(42, 18, 19, 'w', 'I', '', 387.0, 430.0, 473.0),
	(42, 20, 24, 'w', 'I', '', 387.0, 430.0, 473.0),
	(42, 25, 29, 'w', 'I', '', 387.0, 430.0, 473.0),
	(42, 30, 34, 'w', 'I', '', 374.0, 415.0, 457.0),
	(42, 35, 39, 'w', 'I', '', 374.0, 415.0, 457.0),
	(42, 40, 44, 'w', 'I', '', 360.0, 400.0, 440.0),
	(42, 45, 49, 'w', 'I', '', 347.0, 385.0, 424.0),
	(42, 50, 54, 'w', 'I', '', 333.0, 370.0, 407.0),
	(42, 55, 59, 'w', 'I', '', 320.0, 355.0, 391.0),
	(42, 60, 64, 'w', 'I', '', 306.0, 340.0, 374.0),
	(42, 65, 69, 'w', 'I', '', 293.0, 325.0, 358.0),
	(42, 70, 74, 'w', 'I', '', 279.0, 310.0, 341.0),
	(42, 75, 79, 'w', 'I', '', 266.0, 295.0, 325.0),
	(42, 80, 84, 'w', 'I', '', 252.0, 280.0, 308.0),
	(42, 85, 89, 'w', 'I', '', 239.0, 265.0, 292.0),
	(42, 90, 200, 'w', 'I', '', 225.0, 250.0, 275.0),
	(42, 0, 7, 'm', 'I', '', 293.0, 325.0, 358.0),
	(42, 8, 9, 'm', 'I', '', 306.0, 340.0, 374.0),
	(42, 10, 11, 'm', 'I', '', 320.0, 355.0, 391.0),
	(42, 12, 13, 'm', 'I', '', 333.0, 370.0, 407.0),
	(42, 14, 15, 'm', 'I', '', 347.0, 385.0, 424.0),
	(42, 16, 17, 'm', 'I', '', 360.0, 400.0, 440.0),
	(42, 18, 19, 'm', 'I', '', 450.0, 500.0, 550.0),
	(42, 20, 24, 'm', 'I', '', 450.0, 500.0, 550.0),
	(42, 25, 29, 'm', 'I', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'I', '', 437.0, 485.0, 534.0),
	(42, 35, 39, 'm', 'I', '', 437.0, 485.0, 534.0),
	(42, 40, 44, 'm', 'I', '', 423.0, 470.0, 517.0),
	(42, 45, 49, 'm', 'I', '', 410.0, 455.0, 501.0),
	(42, 50, 54, 'm', 'I', '', 396.0, 440.0, 484.0),
	(42, 55, 59, 'm', 'I', '', 383.0, 425.0, 468.0),
	(42, 60, 64, 'm', 'I', '', 369.0, 410.0, 451.0),
	(42, 65, 69, 'm', 'I', '', 356.0, 395.0, 435.0),
	(42, 70, 74, 'm', 'I', '', 342.0, 380.0, 418.0),
	(42, 75, 79, 'm', 'I', '', 329.0, 365.0, 402.0),
	(42, 80, 84, 'm', 'I', '', 315.0, 350.0, 385.0),
	(42, 85, 89, 'm', 'I', '', 302.0, 335.0, 369.0),
	(42, 90, 200, 'm', 'I', '', 288.0, 320.0, 352.0),
	(43, 0, 7, 'w', 'I', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'w', 'I', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'w', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'w', 'I', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'w', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'w', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'w', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'w', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'w', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 0, 7, 'm', 'I', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'm', 'I', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'm', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'm', 'I', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'm', 'I', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'm', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'm', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'm', 'I', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'm', 'I', '', 10.0, 12.500000000000002, 15.0),
	(53, 0, 7, 'w', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'I', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'I', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'I', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'I', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'I', '', 7.0, 9.0, 13.0),
	(57, 8, 9, 'w', 'I', '', 11.0, 13.0, 16.0),
	(57, 10, 11, 'w', 'I', '', 16.0, 18.0, 22.0),
	(57, 0, 7, 'm', 'I', '', 9.0, 11.0, 14.0),
	(57, 8, 9, 'm', 'I', '', 13.0, 16.0, 20.0),
	(57, 10, 11, 'm', 'I', '', 20.0, 23.0, 27.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(4, 8, 9, 'w', 'J', '1 km', 13.500000000000002, 12.0, 10.500000000000002),
	(4, 10, 11, 'w', 'J', '2 km', 25.249999999999996, 21.5, 17.75),
	(4, 12, 13, 'w', 'J', '2 km', 22.5, 19.75, 16.75),
	(4, 14, 15, 'w', 'J', '2 km', 19.0, 16.249999999999996, 14.25),
	(4, 16, 17, 'w', 'J', '2 km', 16.249999999999996, 14.25, 12.500000000000002),
	(4, 18, 19, 'w', 'J', '5 km', 28.75, 26.0, 23.249999999999996),
	(4, 20, 24, 'w', 'J', '5 km', 28.5, 25.75, 22.75),
	(4, 25, 29, 'w', 'J', '5 km', 28.0, 25.249999999999996, 22.5),
	(4, 30, 34, 'w', 'J', '5 km', 28.5, 25.75, 22.75),
	(4, 35, 39, 'w', 'J', '5 km', 30.0, 26.5, 23.5),
	(4, 40, 44, 'w', 'J', '5 km', 32.0, 27.75, 24.75),
	(4, 45, 49, 'w', 'J', '5 km', 33.49999999999999, 29.249999999999996, 25.75),
	(4, 50, 54, 'w', 'J', '5 km', 34.49999999999999, 30.5, 26.75),
	(4, 55, 59, 'w', 'J', '5 km', 35.75000000000001, 31.5, 27.75),
	(4, 60, 64, 'w', 'J', '5 km', 37.0, 32.49999999999999, 28.5),
	(4, 65, 69, 'w', 'J', '5 km', 37.75000000000001, 33.25, 29.249999999999996),
	(4, 70, 74, 'w', 'J', '5 km', 39.0, 34.25, 30.249999999999996),
	(4, 75, 79, 'w', 'J', '5 km', 40.75000000000001, 35.25, 31.5),
	(4, 80, 84, 'w', 'J', '5 km', 42.25, 37.49999999999999, 32.75000000000001),
	(4, 85, 89, 'w', 'J', '5 km', 44.75000000000001, 40.0, 34.49999999999999),
	(4, 90, 200, 'w', 'J', '5 km', 46.49999999999999, 41.49999999999999, 36.25),
	(4, 8, 9, 'm', 'J', '1 km', 13.25, 11.749999999999998, 10.25),
	(4, 10, 11, 'm', 'J', '2 km', 24.249999999999996, 20.5, 16.75),
	(4, 12, 13, 'm', 'J', '2 km', 21.5, 18.5, 15.749999999999998),
	(4, 14, 15, 'm', 'J', '2 km', 16.0, 14.0, 12.0),
	(4, 16, 17, 'm', 'J', '2 km', 13.500000000000002, 11.749999999999998, 10.25),
	(4, 18, 19, 'm', 'J', '5 km', 23.5, 21.249999999999996, 19.249999999999996),
	(4, 20, 24, 'm', 'J', '5 km', 23.249999999999996, 21.0, 18.75),
	(4, 25, 29, 'm', 'J', '5 km', 25.0, 22.249999999999996, 19.5),
	(4, 30, 34, 'm', 'J', '5 km', 26.75, 23.5, 20.249999999999996),
	(4, 35, 39, 'm', 'J', '5 km', 29.0, 25.0, 20.75),
	(4, 40, 44, 'm', 'J', '5 km', 31.5, 26.0, 21.75),
	(4, 45, 49, 'm', 'J', '5 km', 33.0, 27.5, 22.5),
	(4, 50, 54, 'm', 'J', '5 km', 34.25, 28.5, 23.249999999999996),
	(4, 55, 59, 'm', 'J', '5 km', 35.25, 29.249999999999996, 23.75),
	(4, 60, 64, 'm', 'J', '5 km', 35.75000000000001, 30.0, 24.0),
	(4, 65, 69, 'm', 'J', '5 km', 36.25, 30.249999999999996, 24.249999999999996),
	(4, 70, 74, 'm', 'J', '5 km', 36.75000000000001, 30.75, 24.75),
	(4, 75, 79, 'm', 'J', '5 km', 37.25, 31.5, 25.75),
	(4, 80, 84, 'm', 'J', '5 km', 38.0, 32.25, 26.5),
	(4, 85, 89, 'm', 'J', '5 km', 38.75000000000001, 33.25, 27.75),
	(4, 90, 200, 'm', 'J', '5 km', 39.49999999999999, 34.0, 29.0),
	(7, 0, 7, 'w', 'J', '200 m', 14.4, 12.266666666666667, 10.133333333333333),
	(7, 8, 9, 'w', 'J', '200 m', 12.8, 11.2, 9.466666666666665),
	(7, 10, 11, 'w', 'J', '200 m', 11.733333333333333, 10.266666666666667, 8.8),
	(7, 12, 13, 'w', 'J', '400 m', 23.733333333333334, 20.666666666666664, 17.599999999999998),
	(7, 14, 15, 'w', 'J', '400 m', 20.93333333333333, 18.666666666666664, 16.0),
	(7, 16, 17, 'w', 'J', '400 m', 18.93333333333333, 16.8, 14.533333333333333),
	(7, 18, 19, 'w', 'J', '400 m', 16.31666666666667, 14.4, 12.516666666666667),
	(7, 20, 24, 'w', 'J', '400 m', 16.03333333333333, 14.166666666666666, 12.233333333333334),
	(7, 25, 29, 'w', 'J', '400 m', 17.333333333333332, 14.333333333333332, 12.7),
	(7, 30, 34, 'w', 'J', '400 m', 19.599999999999998, 16.099999999999998, 13.266666666666667),
	(7, 35, 39, 'w', 'J', '400 m', 21.76666666666667, 17.4, 13.833333333333334),
	(7, 40, 44, 'w', 'J', '400 m', 23.116666666666667, 18.816666666666663, 14.500000000000002),
	(7, 45, 49, 'w', 'J', '400 m', 24.03333333333333, 19.716666666666665, 14.616666666666665),
	(7, 50, 54, 'w', 'J', '200 m', 12.233333333333334, 10.2, 7.816666666666667),
	(7, 55, 59, 'w', 'J', '200 m', 12.633333333333335, 10.433333333333334, 8.100000000000001),
	(7, 60, 64, 'w', 'J', '200 m', 12.916666666666668, 10.6, 8.266666666666667),
	(7, 65, 69, 'w', 'J', '200 m', 13.2, 10.716666666666667, 8.333333333333332),
	(7, 70, 74, 'w', 'J', '200 m', 13.483333333333333, 10.933333333333334, 8.616666666666665),
	(7, 75, 79, 'w', 'J', '100 m', 6.966666666666667, 5.666666666666667, 4.416666666666667),
	(7, 80, 84, 'w', 'J', '100 m', 7.083333333333333, 5.783333333333333, 4.583333333333333),
	(7, 85, 89, 'w', 'J', '100 m', 7.2, 5.95, 4.816666666666667),
	(7, 90, 200, 'w', 'J', '100 m', 7.316666666666667, 6.066666666666666, 4.983333333333333),
	(7, 0, 7, 'm', 'J', '200 m', 14.4, 11.733333333333333, 9.866666666666665),
	(7, 8, 9, 'm', 'J', '200 m', 12.8, 10.8, 9.066666666666665),
	(7, 10, 11, 'm', 'J', '200 m', 11.2, 10.133333333333333, 8.266666666666667),
	(7, 12, 13, 'm', 'J', '400 m', 21.599999999999998, 18.4, 15.6),
	(7, 14, 15, 'm', 'J', '400 m', 19.200000000000003, 16.4, 14.133333333333333),
	(7, 16, 17, 'm', 'J', '400 m', 17.599999999999998, 15.466666666666665, 13.333333333333332),
	(7, 18, 19, 'm', 'J', '400 m', 15.350000000000001, 13.483333333333333, 11.566666666666666),
	(7, 20, 24, 'm', 'J', '400 m', 15.066666666666665, 13.266666666666667, 11.166666666666666),
	(7, 25, 29, 'm', 'J', '400 m', 15.749999999999998, 13.6, 11.566666666666666),
	(7, 30, 34, 'm', 'J', '400 m', 17.516666666666666, 14.616666666666665, 12.233333333333334),
	(7, 35, 39, 'm', 'J', '400 m', 19.599999999999998, 16.31666666666667, 13.083333333333334),
	(7, 40, 44, 'm', 'J', '400 m', 22.05, 17.966666666666665, 13.883333333333333),
	(7, 45, 49, 'm', 'J', '400 m', 23.46666666666667, 18.93333333333333, 14.049999999999999),
	(7, 50, 54, 'm', 'J', '200 m', 11.85, 9.749999999999998, 7.316666666666667),
	(7, 55, 59, 'm', 'J', '200 m', 12.133333333333333, 9.916666666666668, 7.7),
	(7, 60, 64, 'm', 'J', '200 m', 12.350000000000001, 10.033333333333333, 7.766666666666667),
	(7, 65, 69, 'm', 'J', '200 m', 12.516666666666667, 10.25, 7.816666666666667),
	(7, 70, 74, 'm', 'J', '200 m', 12.516666666666667, 10.366666666666667, 7.883333333333334),
	(7, 75, 79, 'm', 'J', '100 m', 6.4, 5.216666666666667, 4.133333333333334),
	(7, 80, 84, 'm', 'J', '100 m', 6.466666666666667, 5.333333333333334, 4.2),
	(7, 85, 89, 'm', 'J', '100 m', 6.466666666666667, 5.433333333333333, 4.366666666666666),
	(7, 90, 200, 'm', 'J', '100 m', 6.633333333333333, 5.55, 4.583333333333333),
	(8, 18, 19, 'w', 'J', '3 km', 49.35, 46.866666666666674, 44.016666666666666),
	(8, 20, 24, 'w', 'J', '3 km', 47.21666666666667, 44.73333333333333, 42.25),
	(8, 25, 29, 'w', 'J', '3 km', 47.56666666666667, 45.08333333333333, 42.6),
	(8, 30, 34, 'w', 'J', '3 km', 47.93333333333334, 45.43333333333333, 42.9),
	(8, 35, 39, 'w', 'J', '3 km', 49.7, 46.150000000000006, 43.13333333333333),
	(8, 40, 44, 'w', 'J', '3 km', 51.833333333333336, 47.56666666666667, 43.31666666666666),
	(8, 45, 49, 'w', 'J', '3 km', 53.6, 48.98333333333334, 44.016666666666666),
	(8, 50, 54, 'w', 'J', '3 km', 55.383333333333326, 50.416666666666664, 45.43333333333333),
	(8, 55, 59, 'w', 'J', '3 km', 56.8, 51.833333333333336, 46.866666666666674),
	(8, 60, 64, 'w', 'J', '3 km', 58.56666666666667, 52.9, 47.93333333333334),
	(8, 65, 69, 'w', 'J', '3 km', 59.81666666666667, 54.31666666666666, 49.7),
	(8, 70, 74, 'w', 'J', '3 km', 62.65, 56.08333333333333, 51.11666666666667),
	(8, 75, 79, 'w', 'J', '3 km', 65.68333333333332, 57.866666666666674, 52.9),
	(8, 80, 84, 'w', 'J', '3 km', 69.93333333333334, 60.53333333333333, 55.03333333333334),
	(8, 85, 89, 'w', 'J', '3 km', 73.83333333333333, 64.13333333333333, 58.21666666666667),
	(8, 90, 200, 'w', 'J', '3 km', 78.33333333333334, 68.16666666666666, 61.766666666666666),
	(8, 18, 19, 'm', 'J', '3 km', 41.53333333333333, 38.7, 35.849999999999994),
	(8, 20, 24, 'm', 'J', '3 km', 40.46666666666667, 37.63333333333334, 34.78333333333333),
	(8, 25, 29, 'm', 'J', '3 km', 41.53333333333333, 38.7, 35.849999999999994),
	(8, 30, 34, 'm', 'J', '3 km', 44.383333333333326, 40.46666666666667, 36.21666666666667),
	(8, 35, 39, 'm', 'J', '3 km', 46.150000000000006, 41.53333333333333, 37.98333333333334),
	(8, 40, 44, 'm', 'J', '3 km', 46.866666666666674, 42.95, 38.333333333333336),
	(8, 45, 49, 'm', 'J', '3 km', 48.63333333333334, 44.383333333333326, 39.050000000000004),
	(8, 50, 54, 'm', 'J', '3 km', 50.416666666666664, 45.43333333333333, 40.833333333333336),
	(8, 55, 59, 'm', 'J', '3 km', 51.833333333333336, 46.150000000000006, 41.88333333333333),
	(8, 60, 64, 'm', 'J', '3 km', 53.78333333333333, 47.93333333333334, 42.95),
	(8, 65, 69, 'm', 'J', '3 km', 55.49999999999999, 49.35, 44.016666666666666),
	(8, 70, 74, 'm', 'J', '3 km', 57.866666666666674, 51.11666666666667, 46.150000000000006),
	(8, 75, 79, 'm', 'J', '3 km', 61.18333333333333, 53.78333333333333, 51.11666666666667),
	(8, 80, 84, 'm', 'J', '3 km', 64.96666666666667, 56.61666666666666, 51.11666666666667),
	(8, 85, 89, 'm', 'J', '3 km', 68.16666666666666, 59.81666666666667, 53.6),
	(8, 90, 200, 'm', 'J', '3 km', 72.94999999999999, 63.43333333333333, 56.8),
	(10, 0, 7, 'w', 'J', '', 1.8, 2.7, 3.6),
	(10, 8, 9, 'w', 'J', '', 2.7, 3.6, 4.5),
	(10, 10, 11, 'w', 'J', '', 3.3, 4.5, 5.4),
	(10, 0, 7, 'm', 'J', '', 3.6, 4.5, 5.1),
	(10, 8, 9, 'm', 'J', '', 5.1, 6.0, 6.9),
	(10, 10, 11, 'm', 'J', '', 6.3, 7.5, 8.4),
	(11, 12, 13, 'w', 'J', '', 4.5, 5.4, 6.6),
	(11, 14, 15, 'w', 'J', '', 6.0, 7.2, 8.1),
	(11, 16, 17, 'w', 'J', '', 7.2, 8.1, 9.3),
	(11, 12, 13, 'm', 'J', '', 7.8, 9.0, 9.9),
	(11, 14, 15, 'm', 'J', '', 9.0, 10.2, 11.1),
	(11, 16, 17, 'm', 'J', '', 10.2, 11.4, 12.6),
	(12, 0, 7, 'w', 'J', '1 kg', 3.0, 3.3, 3.75),
	(12, 8, 9, 'w', 'J', '1 kg', 3.25, 3.55, 4.0),
	(12, 10, 11, 'w', 'J', '1 kg', 3.5, 3.8, 4.25),
	(12, 12, 13, 'w', 'J', '1 kg', 3.75, 4.05, 4.5),
	(12, 14, 15, 'w', 'J', '1 kg', 4.0, 4.3, 4.75),
	(12, 16, 17, 'w', 'J', '1 kg', 4.25, 4.55, 5.0),
	(12, 18, 19, 'w', 'J', '1 kg', 4.5, 4.8, 5.25),
	(12, 20, 24, 'w', 'J', '1 kg', 4.5, 4.8, 5.25),
	(12, 25, 29, 'w', 'J', '1 kg', 4.2, 4.65, 5.1),
	(12, 30, 34, 'w', 'J', '1 kg', 3.9, 4.5, 5.1),
	(12, 35, 39, 'w', 'J', '1 kg', 3.6, 4.35, 4.95),
	(12, 40, 44, 'w', 'J', '1 kg', 3.15, 4.05, 4.95),
	(12, 45, 49, 'w', 'J', '1 kg', 2.85, 3.9, 4.8),
	(12, 50, 54, 'w', 'J', '1 kg', 2.55, 3.6, 4.65),
	(12, 55, 59, 'w', 'J', '1 kg', 2.4, 3.45, 4.5),
	(12, 60, 64, 'w', 'J', '1 kg', 2.25, 3.3, 4.35),
	(12, 65, 69, 'w', 'J', '1 kg', 2.1, 3.15, 4.2),
	(12, 70, 74, 'w', 'J', '1 kg', 1.95, 3.0, 4.05),
	(12, 75, 79, 'w', 'J', '1 kg', 1.95, 2.85, 3.9),
	(12, 80, 84, 'w', 'J', '1 kg', 1.8, 2.85, 3.75),
	(12, 85, 89, 'w', 'J', '1 kg', 1.8, 2.7, 3.6),
	(12, 90, 200, 'w', 'J', '1 kg', 1.65, 2.55, 3.3),
	(12, 0, 7, 'm', 'J', '1 kg', 4.65, 5.1, 5.55),
	(12, 8, 9, 'm', 'J', '1 kg', 4.9, 5.35, 5.8),
	(12, 10, 11, 'm', 'J', '1 kg', 5.15, 5.6, 6.05),
	(12, 12, 13, 'm', 'J', '1 kg', 5.4, 5.85, 6.3),
	(12, 14, 15, 'm', 'J', '1 kg', 5.65, 6.1, 6.55),
	(12, 16, 17, 'm', 'J', '1 kg', 5.9, 6.35, 6.8),
	(12, 18, 19, 'm', 'J', '1 kg', 6.15, 6.6, 7.05),
	(12, 20, 24, 'm', 'J', '1 kg', 6.15, 6.75, 7.2),
	(12, 25, 29, 'm', 'J', '1 kg', 5.85, 6.45, 7.05),
	(12, 30, 34, 'm', 'J', '1 kg', 5.4, 6.15, 6.9),
	(12, 35, 39, 'm', 'J', '1 kg', 4.95, 5.85, 6.75),
	(12, 40, 44, 'm', 'J', '1 kg', 4.65, 5.55, 6.45),
	(12, 45, 49, 'm', 'J', '1 kg', 4.2, 5.25, 6.3),
	(12, 50, 54, 'm', 'J', '1 kg', 3.9, 5.1, 6.15),
	(12, 55, 59, 'm', 'J', '1 kg', 3.6, 4.95, 6.0),
	(12, 60, 64, 'm', 'J', '1 kg', 3.45, 4.65, 5.85),
	(12, 65, 69, 'm', 'J', '1 kg', 3.15, 4.35, 5.55),
	(12, 70, 74, 'm', 'J', '1 kg', 3.0, 4.2, 5.4),
	(12, 75, 79, 'm', 'J', '1 kg', 2.7, 3.9, 5.1),
	(12, 80, 84, 'm', 'J', '1 kg', 2.55, 3.75, 4.95),
	(12, 85, 89, 'm', 'J', '1 kg', 2.4, 3.6, 4.8),
	(12, 90, 200, 'm', 'J', '1 kg', 2.1, 3.3, 4.5),
	(13, 12, 13, 'w', 'J', '2 kg', 1.43, 1.58, 1.73),
	(13, 14, 15, 'w', 'J', '2 kg', 1.65, 1.8, 1.95),
	(13, 16, 17, 'w', 'J', '2 kg', 1.73, 1.88, 2.03),
	(13, 18, 19, 'w', 'J', '3 kg', 3.25, 3.5, 3.75),
	(13, 20, 24, 'w', 'J', '3 kg', 3.25, 3.5, 3.75),
	(13, 25, 29, 'w', 'J', '3 kg', 3.25, 3.5, 3.75),
	(13, 30, 34, 'w', 'J', '3 kg', 3.13, 3.38, 3.63),
	(13, 35, 39, 'w', 'J', '3 kg', 3.0, 3.25, 3.5),
	(13, 40, 44, 'w', 'J', '3 kg', 2.75, 3.0, 3.25),
	(13, 45, 49, 'w', 'J', '3 kg', 2.63, 2.88, 3.13),
	(13, 50, 54, 'w', 'J', '3 kg', 2.55, 2.85, 3.1),
	(13, 55, 59, 'w', 'J', '3 kg', 2.5, 2.8, 3.07),
	(13, 60, 64, 'w', 'J', '3 kg', 2.38, 2.75, 3.04),
	(13, 65, 69, 'w', 'J', '3 kg', 2.25, 2.63, 3.04),
	(13, 70, 74, 'w', 'J', '3 kg', 2.13, 2.5, 3.0),
	(13, 75, 79, 'w', 'J', '2 kg', 2.13, 2.63, 3.13),
	(13, 80, 84, 'w', 'J', '2 kg', 2.0, 2.5, 2.88),
	(13, 85, 89, 'w', 'J', '2 kg', 1.88, 2.25, 2.75),
	(13, 90, 200, 'w', 'J', '2 kg', 1.63, 2.13, 2.5),
	(13, 12, 13, 'm', 'J', '3 kg', 1.88, 2.03, 2.18),
	(13, 14, 15, 'm', 'J', '3 kg', 2.1, 2.25, 2.4),
	(13, 16, 17, 'm', 'J', '3 kg', 2.25, 2.4, 2.55),
	(13, 18, 19, 'm', 'J', '4 kg', 3.88, 4.13, 4.38),
	(13, 20, 24, 'm', 'J', '4 kg', 3.88, 4.25, 4.5),
	(13, 25, 29, 'm', 'J', '4 kg', 3.75, 4.13, 4.38),
	(13, 30, 34, 'm', 'J', '4 kg', 3.5, 3.88, 4.13),
	(13, 35, 39, 'm', 'J', '4 kg', 3.38, 3.63, 4.0),
	(13, 40, 44, 'm', 'J', '4 kg', 3.13, 3.5, 3.88),
	(13, 45, 49, 'm', 'J', '4 kg', 3.0, 3.38, 3.75),
	(13, 50, 54, 'm', 'J', '4 kg', 2.95, 3.35, 3.7),
	(13, 55, 59, 'm', 'J', '4 kg', 2.9, 3.3, 3.65),
	(13, 60, 64, 'm', 'J', '3 kg', 3.0, 3.5, 4.0),
	(13, 65, 69, 'm', 'J', '3 kg', 2.95, 3.45, 3.95),
	(13, 70, 74, 'm', 'J', '3 kg', 2.9, 3.35, 3.85),
	(13, 75, 79, 'm', 'J', '3 kg', 2.88, 3.25, 3.75),
	(13, 80, 84, 'm', 'J', '3 kg', 2.75, 3.13, 3.63),
	(13, 85, 89, 'm', 'J', '3 kg', 2.5, 3.0, 3.38),
	(13, 90, 200, 'm', 'J', '3 kg', 2.25, 2.63, 3.13),
	(15, 0, 7, 'w', 'J', '', 0.32, 0.38, 0.42),
	(15, 8, 9, 'w', 'J', '', 0.35, 0.39, 0.45),
	(15, 10, 11, 'w', 'J', '', 0.39, 0.44, 0.5),
	(15, 12, 13, 'w', 'J', '', 0.42, 0.48, 0.54),
	(15, 14, 15, 'w', 'J', '', 0.47, 0.51, 0.57),
	(15, 16, 17, 'w', 'J', '', 0.5, 0.54, 0.6),
	(15, 18, 19, 'w', 'J', '', 0.83, 0.93, 1.03),
	(15, 20, 24, 'w', 'J', '', 0.8, 0.9, 1.0),
	(15, 25, 29, 'w', 'J', '', 0.75, 0.85, 0.98),
	(15, 30, 34, 'w', 'J', '', 0.68, 0.8, 0.93),
	(15, 35, 39, 'w', 'J', '', 0.63, 0.75, 0.9),
	(15, 40, 44, 'w', 'J', '', 0.58, 0.7, 0.83),
	(15, 45, 49, 'w', 'J', '', 0.55, 0.68, 0.8),
	(15, 50, 54, 'w', 'J', '', 0.5, 0.65, 0.78),
	(15, 55, 59, 'w', 'J', '', 0.48, 0.6, 0.73),
	(15, 60, 64, 'w', 'J', '', 0.48, 0.6, 0.73),
	(15, 65, 69, 'w', 'J', '', 0.45, 0.58, 0.7),
	(15, 70, 74, 'w', 'J', '', 0.45, 0.58, 0.68),
	(15, 75, 79, 'w', 'J', '', 0.45, 0.58, 0.68),
	(15, 80, 84, 'w', 'J', '', 0.45, 0.55, 0.65),
	(15, 85, 89, 'w', 'J', '', 0.43, 0.53, 0.63),
	(15, 90, 200, 'w', 'J', '', 0.4, 0.5, 0.6),
	(15, 0, 7, 'm', 'J', '', 0.35, 0.41, 0.45),
	(15, 8, 9, 'm', 'J', '', 0.39, 0.45, 0.5),
	(15, 10, 11, 'm', 'J', '', 0.45, 0.51, 0.56),
	(15, 12, 13, 'm', 'J', '', 0.51, 0.57, 0.62),
	(15, 14, 15, 'm', 'J', '', 0.57, 0.62, 0.68),
	(15, 16, 17, 'm', 'J', '', 0.62, 0.66, 0.72),
	(15, 18, 19, 'm', 'J', '', 1.05, 1.15, 1.25),
	(15, 20, 24, 'm', 'J', '', 1.05, 1.15, 1.25),
	(15, 25, 29, 'm', 'J', '', 1.03, 1.13, 1.23),
	(15, 30, 34, 'm', 'J', '', 0.93, 1.05, 1.18),
	(15, 35, 39, 'm', 'J', '', 0.83, 0.98, 1.13),
	(15, 40, 44, 'm', 'J', '', 0.78, 0.93, 1.08),
	(15, 45, 49, 'm', 'J', '', 0.73, 0.88, 1.03),
	(15, 50, 54, 'm', 'J', '', 0.7, 0.85, 1.0),
	(15, 55, 59, 'm', 'J', '', 0.68, 0.83, 0.98),
	(15, 60, 64, 'm', 'J', '', 0.65, 0.8, 0.95),
	(15, 65, 69, 'm', 'J', '', 0.65, 0.8, 0.95),
	(15, 70, 74, 'm', 'J', '', 0.63, 0.78, 0.93),
	(15, 75, 79, 'm', 'J', '', 0.6, 0.75, 0.9),
	(15, 80, 84, 'm', 'J', '', 0.58, 0.73, 0.88),
	(15, 85, 89, 'm', 'J', '', 0.5, 0.65, 0.8),
	(15, 90, 200, 'm', 'J', '', 0.45, 0.6, 0.75),
	(17, 0, 7, 'w', 'J', '30 m', 12.8, 11.4, 10.1),
	(17, 8, 9, 'w', 'J', '30 m', 11.8, 10.6, 9.1),
	(17, 10, 11, 'w', 'J', '50 m', 17.6, 16.2, 14.6),
	(17, 12, 13, 'w', 'J', '50 m', 17.0, 15.4, 13.6),
	(17, 14, 15, 'w', 'J', '100 m', 29.8, 27.2, 24.8),
	(17, 16, 17, 'w', 'J', '100 m', 28.2, 26.1, 24.0),
	(17, 18, 19, 'w', 'J', '100 m', 27.3, 24.8, 23.0),
	(17, 20, 24, 'w', 'J', '100 m', 27.8, 25.2, 23.4),
	(17, 25, 29, 'w', 'J', '100 m', 28.4, 25.8, 24.0),
	(17, 30, 34, 'w', 'J', '100 m', 29.4, 26.7, 24.6),
	(17, 35, 39, 'w', 'J', '100 m', 30.6, 27.9, 25.5),
	(17, 40, 44, 'w', 'J', '50 m', 16.5, 14.9, 13.2),
	(17, 45, 49, 'w', 'J', '50 m', 17.3, 15.5, 13.7),
	(17, 50, 54, 'w', 'J', '50 m', 17.9, 16.1, 14.3),
	(17, 55, 59, 'w', 'J', '50 m', 18.6, 16.8, 14.9),
	(17, 60, 64, 'w', 'J', '50 m', 18.9, 17.1, 15.3),
	(17, 65, 69, 'w', 'J', '50 m', 19.2, 17.4, 15.6),
	(17, 70, 74, 'w', 'J', '50 m', 19.5, 17.7, 15.9),
	(17, 75, 79, 'w', 'J', '50 m', 20.3, 18.5, 16.7),
	(17, 80, 84, 'w', 'J', '50 m', 21.5, 19.7, 18.0),
	(17, 85, 89, 'w', 'J', '50 m', 23.3, 21.5, 19.8),
	(17, 90, 200, 'w', 'J', '50 m', 25.7, 23.9, 22.2),
	(17, 0, 7, 'm', 'J', '30 m', 12.3, 10.9, 9.6),
	(17, 8, 9, 'm', 'J', '30 m', 11.5, 10.2, 9.1),
	(17, 10, 11, 'm', 'J', '50 m', 16.5, 14.9, 13.4),
	(17, 12, 13, 'm', 'J', '50 m', 15.5, 14.2, 13.0),
	(17, 14, 15, 'm', 'J', '100 m', 27.2, 24.6, 22.6),
	(17, 16, 17, 'm', 'J', '100 m', 26.1, 23.7, 21.6),
	(17, 18, 19, 'm', 'J', '100 m', 24.0, 21.9, 19.8),
	(17, 20, 24, 'm', 'J', '100 m', 23.7, 21.6, 19.5),
	(17, 25, 29, 'm', 'J', '100 m', 24.5, 22.2, 20.0),
	(17, 30, 34, 'm', 'J', '100 m', 25.2, 22.7, 20.4),
	(17, 35, 39, 'm', 'J', '100 m', 26.4, 23.9, 21.3),
	(17, 40, 44, 'm', 'J', '50 m', 14.4, 13.1, 11.6),
	(17, 45, 49, 'm', 'J', '50 m', 15.0, 13.4, 11.9),
	(17, 50, 54, 'm', 'J', '50 m', 15.5, 13.7, 12.3),
	(17, 55, 59, 'm', 'J', '50 m', 15.8, 14.1, 12.8),
	(17, 60, 64, 'm', 'J', '50 m', 16.2, 14.6, 13.2),
	(17, 65, 69, 'm', 'J', '50 m', 16.8, 15.3, 13.7),
	(17, 70, 74, 'm', 'J', '50 m', 17.6, 16.1, 14.4),
	(17, 75, 79, 'm', 'J', '50 m', 18.3, 16.8, 15.2),
	(17, 80, 84, 'm', 'J', '50 m', 19.5, 18.0, 16.4),
	(17, 85, 89, 'm', 'J', '50 m', 21.2, 19.7, 18.0),
	(17, 90, 200, 'm', 'J', '50 m', 23.3, 21.8, 20.1),
	(18, 0, 7, 'w', 'J', '', 74.4, 61.6, 48.8),
	(18, 8, 9, 'w', 'J', '', 67.2, 54.4, 44.8),
	(18, 10, 11, 'w', 'J', '', 62.4, 50.4, 40.8),
	(18, 12, 13, 'w', 'J', '', 56.0, 46.4, 37.6),
	(18, 14, 15, 'w', 'J', '', 52.8, 44.0, 34.4),
	(18, 16, 17, 'w', 'J', '', 48.8, 40.8, 32.0),
	(18, 18, 19, 'w', 'J', '', 44.3, 36.0, 27.8),
	(18, 20, 24, 'w', 'J', '', 43.5, 36.0, 27.8),
	(18, 25, 29, 'w', 'J', '', 45.0, 37.5, 29.3),
	(18, 30, 34, 'w', 'J', '', 48.8, 39.8, 31.5),
	(18, 35, 39, 'w', 'J', '', 54.0, 43.5, 33.0),
	(18, 40, 44, 'w', 'J', '', 60.0, 47.3, 35.3),
	(18, 45, 49, 'w', 'J', '', 66.0, 52.5, 37.5),
	(18, 50, 54, 'w', 'J', '', 72.0, 58.5, 42.0),
	(18, 55, 59, 'w', 'J', '', 77.3, 63.8, 45.8),
	(18, 60, 64, 'w', 'J', '', 81.8, 66.8, 48.8),
	(18, 65, 69, 'w', 'J', '', 84.8, 69.8, 51.8),
	(18, 70, 74, 'w', 'J', '', 88.5, 72.0, 54.0),
	(18, 75, 79, 'w', 'J', '', 91.5, 75.0, 57.0),
	(18, 80, 84, 'w', 'J', '', 95.3, 78.0, 60.0),
	(18, 85, 89, 'w', 'J', '', 98.3, 80.3, 62.3),
	(18, 90, 200, 'w', 'J', '', 99.8, 81.8, 63.8),
	(18, 0, 7, 'm', 'J', '', 73.6, 60.8, 48.0),
	(18, 8, 9, 'm', 'J', '', 65.6, 52.8, 41.6),
	(18, 10, 11, 'm', 'J', '', 57.6, 46.4, 36.0),
	(18, 12, 13, 'm', 'J', '', 52.8, 43.2, 33.6),
	(18, 14, 15, 'm', 'J', '', 49.6, 40.8, 32.0),
	(18, 16, 17, 'm', 'J', '', 47.2, 39.2, 30.4),
	(18, 18, 19, 'm', 'J', '', 42.0, 34.5, 26.3),
	(18, 20, 24, 'm', 'J', '', 40.5, 33.0, 23.3),
	(18, 25, 29, 'm', 'J', '', 43.5, 34.5, 24.8),
	(18, 30, 34, 'm', 'J', '', 47.3, 36.0, 25.5),
	(18, 35, 39, 'm', 'J', '', 52.5, 39.8, 27.8),
	(18, 40, 44, 'm', 'J', '', 57.8, 44.3, 28.5),
	(18, 45, 49, 'm', 'J', '', 63.0, 48.8, 30.8),
	(18, 50, 54, 'm', 'J', '', 67.5, 52.5, 34.5),
	(18, 55, 59, 'm', 'J', '', 73.5, 55.5, 37.5),
	(18, 60, 64, 'm', 'J', '', 76.5, 58.5, 40.5),
	(18, 65, 69, 'm', 'J', '', 78.8, 60.8, 42.8),
	(18, 70, 74, 'm', 'J', '', 82.5, 64.5, 46.5),
	(18, 75, 79, 'm', 'J', '', 86.3, 68.3, 50.3),
	(18, 80, 84, 'm', 'J', '', 88.5, 72.0, 54.0),
	(18, 85, 89, 'm', 'J', '', 89.3, 73.5, 57.0),
	(18, 90, 200, 'm', 'J', '', 90.0, 75.0, 60.0),
	(19, 8, 9, 'w', 'J', '', 65.6, 57.6, 49.6),
	(19, 10, 11, 'w', 'J', '', 59.2, 51.2, 43.2),
	(19, 12, 13, 'w', 'J', '', 49.6, 43.2, 37.6),
	(19, 14, 15, 'w', 'J', '', 43.2, 39.2, 34.4),
	(19, 16, 17, 'w', 'J', '', 40.0, 36.0, 32.0),
	(19, 18, 19, 'w', 'J', '', 38.4, 35.2, 31.2),
	(19, 20, 24, 'w', 'J', '', 39.2, 35.2, 31.2),
	(19, 25, 29, 'w', 'J', '', 40.0, 36.0, 32.0),
	(19, 30, 34, 'w', 'J', '', 41.6, 37.6, 34.4),
	(19, 35, 39, 'w', 'J', '', 44.0, 39.2, 35.2),
	(19, 40, 44, 'w', 'J', '', 46.4, 40.8, 36.0),
	(19, 45, 49, 'w', 'J', '', 48.8, 43.2, 36.8),
	(19, 50, 54, 'w', 'J', '', 51.2, 44.8, 37.6),
	(19, 55, 59, 'w', 'J', '', 53.6, 46.4, 38.4),
	(19, 60, 64, 'w', 'J', '', 56.0, 48.0, 40.0),
	(19, 65, 69, 'w', 'J', '', 57.6, 49.6, 40.8),
	(19, 70, 74, 'w', 'J', '', 60.8, 51.2, 42.4),
	(19, 75, 79, 'w', 'J', '', 62.4, 52.8, 44.0),
	(19, 80, 84, 'w', 'J', '', 64.8, 55.2, 45.6),
	(19, 85, 89, 'w', 'J', '', 67.2, 57.6, 48.0),
	(19, 90, 200, 'w', 'J', '', 71.2, 60.8, 50.4),
	(19, 8, 9, 'm', 'J', '', 60.8, 52.8, 44.8),
	(19, 10, 11, 'm', 'J', '', 56.0, 48.8, 41.6),
	(19, 12, 13, 'm', 'J', '', 47.2, 41.6, 36.0),
	(19, 14, 15, 'm', 'J', '', 38.4, 34.4, 30.4),
	(19, 16, 17, 'm', 'J', '', 35.2, 31.2, 27.2),
	(19, 18, 19, 'm', 'J', '', 32.8, 28.8, 24.8),
	(19, 20, 24, 'm', 'J', '', 32.0, 28.0, 24.0),
	(19, 25, 29, 'm', 'J', '', 33.6, 28.8, 24.0),
	(19, 30, 34, 'm', 'J', '', 36.0, 29.6, 24.0),
	(19, 35, 39, 'm', 'J', '', 38.4, 32.0, 24.8),
	(19, 40, 44, 'm', 'J', '', 42.4, 34.4, 26.4),
	(19, 45, 49, 'm', 'J', '', 45.6, 36.8, 27.2),
	(19, 50, 54, 'm', 'J', '', 48.0, 38.4, 28.8),
	(19, 55, 59, 'm', 'J', '', 51.2, 40.0, 29.6),
	(19, 60, 64, 'm', 'J', '', 53.6, 41.6, 30.4),
	(19, 65, 69, 'm', 'J', '', 56.0, 43.2, 31.2),
	(19, 70, 74, 'm', 'J', '', 57.6, 45.6, 32.0),
	(19, 75, 79, 'm', 'J', '', 60.0, 47.2, 34.4),
	(19, 80, 84, 'm', 'J', '', 62.4, 50.4, 36.8),
	(19, 85, 89, 'm', 'J', '', 65.6, 52.8, 39.2),
	(19, 90, 200, 'm', 'J', '', 69.6, 56.8, 43.2),
	(23, 0, 7, 'w', 'J', '', 0.29, 0.38, 0.47),
	(23, 8, 9, 'w', 'J', '', 0.49, 0.58, 0.67),
	(23, 10, 11, 'w', 'J', '', 0.69, 0.78, 0.87),
	(23, 12, 13, 'w', 'J', '', 0.84, 0.93, 1.02),
	(23, 14, 15, 'w', 'J', '', 0.96, 1.05, 1.14),
	(23, 16, 17, 'w', 'J', '', 1.02, 1.11, 1.2),
	(23, 18, 19, 'w', 'J', '', 1.7, 1.85, 2.0),
	(23, 20, 24, 'w', 'J', '', 1.7, 1.85, 2.0),
	(23, 25, 29, 'w', 'J', '', 1.65, 1.8, 1.95),
	(23, 30, 34, 'w', 'J', '', 1.6, 1.75, 1.9),
	(23, 35, 39, 'w', 'J', '', 1.55, 1.7, 1.85),
	(23, 40, 44, 'w', 'J', '', 1.5, 1.65, 1.8),
	(23, 45, 49, 'w', 'J', '', 1.4, 1.6, 1.75),
	(23, 50, 54, 'w', 'J', '', 1.3, 1.5, 1.7),
	(23, 55, 59, 'w', 'J', '', 1.25, 1.45, 1.65),
	(23, 60, 64, 'w', 'J', '', 1.2, 1.4, 1.6),
	(23, 65, 69, 'w', 'J', '', 1.15, 1.35, 1.55),
	(23, 70, 74, 'w', 'J', '', 1.05, 1.25, 1.45),
	(23, 75, 79, 'w', 'J', '', 0.9, 1.1, 1.3),
	(23, 80, 84, 'w', 'J', '', 0.8, 1.0, 1.2),
	(23, 85, 89, 'w', 'J', '', 0.65, 0.85, 1.05),
	(23, 90, 200, 'w', 'J', '', 0.55, 0.75, 0.95),
	(23, 0, 7, 'm', 'J', '', 0.38, 0.47, 0.56),
	(23, 8, 9, 'm', 'J', '', 0.58, 0.67, 0.76),
	(23, 10, 11, 'm', 'J', '', 0.78, 0.87, 0.96),
	(23, 12, 13, 'm', 'J', '', 0.96, 1.05, 1.14),
	(23, 14, 15, 'm', 'J', '', 1.14, 1.23, 1.32),
	(23, 16, 17, 'm', 'J', '', 1.29, 1.38, 1.47),
	(23, 18, 19, 'm', 'J', '', 2.25, 2.4, 2.55),
	(23, 20, 24, 'm', 'J', '', 2.2, 2.35, 2.5),
	(23, 25, 29, 'm', 'J', '', 2.15, 2.3, 2.45),
	(23, 30, 34, 'm', 'J', '', 2.1, 2.25, 2.4),
	(23, 35, 39, 'm', 'J', '', 2.05, 2.2, 2.35),
	(23, 40, 44, 'm', 'J', '', 1.95, 2.15, 2.3),
	(23, 45, 49, 'm', 'J', '', 1.85, 2.05, 2.25),
	(23, 50, 54, 'm', 'J', '', 1.8, 2.0, 2.2),
	(23, 55, 59, 'm', 'J', '', 1.7, 1.9, 2.1),
	(23, 60, 64, 'm', 'J', '', 1.6, 1.8, 2.0),
	(23, 65, 69, 'm', 'J', '', 1.45, 1.65, 1.85),
	(23, 70, 74, 'm', 'J', '', 1.35, 1.55, 1.75),
	(23, 75, 79, 'm', 'J', '', 1.2, 1.45, 1.65),
	(23, 80, 84, 'm', 'J', '', 1.05, 1.3, 1.55),
	(23, 85, 89, 'm', 'J', '', 0.95, 1.2, 1.45),
	(23, 90, 200, 'm', 'J', '', 0.8, 1.05, 1.3),
	(25, 12, 13, 'w', 'J', '', 5.1, 5.85, 6.6),
	(25, 14, 15, 'w', 'J', '', 5.85, 6.75, 7.65),
	(25, 16, 17, 'w', 'J', '', 6.6, 7.5, 8.4),
	(25, 18, 19, 'w', 'J', '', 9.4, 10.6, 11.6),
	(25, 20, 24, 'w', 'J', '', 9.6, 10.8, 11.8),
	(25, 25, 29, 'w', 'J', '', 9.6, 10.8, 11.8),
	(25, 30, 34, 'w', 'J', '', 8.8, 10.0, 11.0),
	(25, 35, 39, 'w', 'J', '', 8.4, 9.6, 10.6),
	(25, 40, 44, 'w', 'J', '', 7.8, 9.0, 10.0),
	(25, 45, 49, 'w', 'J', '', 7.4, 8.6, 9.6),
	(25, 50, 54, 'w', 'J', '', 6.6, 8.0, 9.2),
	(25, 55, 59, 'w', 'J', '', 6.2, 7.6, 8.8),
	(25, 60, 64, 'w', 'J', '', 5.8, 7.2, 8.4),
	(25, 65, 69, 'w', 'J', '', 5.4, 6.8, 8.0),
	(25, 70, 74, 'w', 'J', '', 5.2, 6.6, 7.8),
	(25, 75, 79, 'w', 'J', '', 4.8, 6.2, 7.4),
	(25, 80, 84, 'w', 'J', '', 4.4, 5.8, 7.0),
	(25, 85, 89, 'w', 'J', '', 3.8, 5.2, 6.4),
	(25, 90, 200, 'w', 'J', '', 3.0, 4.4, 5.6),
	(25, 12, 13, 'm', 'J', '', 5.85, 7.2, 8.25),
	(25, 14, 15, 'm', 'J', '', 7.05, 8.4, 9.6),
	(25, 16, 17, 'm', 'J', '', 8.25, 9.6, 10.95),
	(25, 18, 19, 'm', 'J', '', 12.6, 14.4, 16.2),
	(25, 20, 24, 'm', 'J', '', 13.2, 15.2, 16.8),
	(25, 25, 29, 'm', 'J', '', 13.0, 15.0, 16.6),
	(25, 30, 34, 'm', 'J', '', 12.0, 14.0, 16.0),
	(25, 35, 39, 'm', 'J', '', 11.4, 13.4, 15.4),
	(25, 40, 44, 'm', 'J', '', 11.2, 13.2, 15.2),
	(25, 45, 49, 'm', 'J', '', 10.8, 12.8, 15.0),
	(25, 50, 54, 'm', 'J', '', 10.2, 12.4, 14.6),
	(25, 55, 59, 'm', 'J', '', 9.4, 11.6, 14.0),
	(25, 60, 64, 'm', 'J', '', 9.0, 11.2, 13.6),
	(25, 65, 69, 'm', 'J', '', 8.0, 10.2, 12.2),
	(25, 70, 74, 'm', 'J', '', 7.4, 9.6, 11.6),
	(25, 75, 79, 'm', 'J', '', 6.4, 8.4, 10.4),
	(25, 80, 84, 'm', 'J', '', 5.6, 7.6, 9.6),
	(25, 85, 89, 'm', 'J', '', 4.8, 6.6, 8.4),
	(25, 90, 200, 'm', 'J', '', 4.2, 6.0, 7.8),
	(33, 0, 7, 'w', 'J', '', 2.4000000000000004, 3.5999999999999996, 5.1),
	(33, 8, 9, 'w', 'J', '', 3.0, 4.5, 6.0),
	(33, 10, 11, 'w', 'J', '', 4.5, 6.0, 9.0),
	(33, 12, 13, 'w', 'J', '', 6.0, 9.0, 12.0),
	(33, 14, 15, 'w', 'J', '', 9.0, 12.0, 15.0),
	(33, 16, 17, 'w', 'J', '', 13.500000000000002, 18.0, 22.5),
	(33, 0, 7, 'm', 'J', '', 3.0, 4.5, 6.0),
	(33, 8, 9, 'm', 'J', '', 3.5999999999999996, 5.1, 6.9),
	(33, 10, 11, 'm', 'J', '', 5.1, 7.5, 10.500000000000002),
	(33, 12, 13, 'm', 'J', '', 7.5, 10.500000000000002, 13.500000000000002),
	(33, 14, 15, 'm', 'J', '', 10.500000000000002, 13.500000000000002, 18.0),
	(33, 16, 17, 'm', 'J', '', 16.5, 21.0, 27.0),
	(39, 0, 7, 'w', 'J', '', 88.0, 98.0, 107.0),
	(39, 8, 9, 'w', 'J', '', 99.0, 110.0, 121.0),
	(39, 10, 11, 'w', 'J', '', 110.0, 123.0, 135.0),
	(39, 12, 13, 'w', 'J', '', 122.0, 135.0, 149.0),
	(39, 14, 15, 'w', 'J', '', 133.0, 148.0, 162.0),
	(39, 16, 17, 'w', 'J', '', 144.0, 160.0, 176.0),
	(39, 18, 19, 'w', 'J', '', 234.0, 260.0, 286.0),
	(39, 20, 24, 'w', 'J', '', 234.0, 260.0, 286.0),
	(39, 25, 29, 'w', 'J', '', 234.0, 260.0, 286.0),
	(39, 30, 34, 'w', 'J', '', 223.0, 248.0, 272.0),
	(39, 35, 39, 'w', 'J', '', 223.0, 248.0, 272.0),
	(39, 40, 44, 'w', 'J', '', 212.0, 235.0, 259.0),
	(39, 45, 49, 'w', 'J', '', 200.0, 223.0, 245.0),
	(39, 50, 54, 'w', 'J', '', 189.0, 210.0, 231.0),
	(39, 55, 59, 'w', 'J', '', 178.0, 198.0, 217.0),
	(39, 60, 64, 'w', 'J', '', 167.0, 185.0, 204.0),
	(39, 65, 69, 'w', 'J', '', 155.0, 173.0, 190.0),
	(39, 70, 74, 'w', 'J', '', 144.0, 160.0, 176.0),
	(39, 75, 79, 'w', 'J', '', 133.0, 148.0, 162.0),
	(39, 80, 84, 'w', 'J', '', 122.0, 135.0, 149.0),
	(39, 85, 89, 'w', 'J', '', 110.0, 123.0, 135.0),
	(39, 90, 200, 'w', 'J', '', 99.0, 110.0, 121.0),
	(39, 0, 7, 'm', 'J', '', 146.0, 163.0, 179.0),
	(39, 8, 9, 'm', 'J', '', 158.0, 175.0, 193.0),
	(39, 10, 11, 'm', 'J', '', 169.0, 188.0, 206.0),
	(39, 12, 13, 'm', 'J', '', 180.0, 200.0, 220.0),
	(39, 14, 15, 'm', 'J', '', 191.0, 213.0, 234.0),
	(39, 16, 17, 'm', 'J', '', 203.0, 225.0, 248.0),
	(39, 18, 19, 'm', 'J', '', 293.0, 325.0, 358.0),
	(39, 20, 24, 'm', 'J', '', 293.0, 325.0, 358.0),
	(39, 25, 29, 'm', 'J', '', 293.0, 325.0, 358.0),
	(39, 30, 34, 'm', 'J', '', 281.0, 313.0, 344.0),
	(39, 35, 39, 'm', 'J', '', 281.0, 313.0, 344.0),
	(39, 40, 44, 'm', 'J', '', 270.0, 300.0, 330.0),
	(39, 45, 49, 'm', 'J', '', 259.0, 288.0, 316.0),
	(39, 50, 54, 'm', 'J', '', 248.0, 275.0, 303.0),
	(39, 55, 59, 'm', 'J', '', 236.0, 263.0, 289.0),
	(39, 60, 64, 'm', 'J', '', 225.0, 250.0, 275.0),
	(39, 65, 69, 'm', 'J', '', 214.0, 238.0, 261.0),
	(39, 70, 74, 'm', 'J', '', 203.0, 225.0, 248.0),
	(39, 75, 79, 'm', 'J', '', 191.0, 213.0, 234.0),
	(39, 80, 84, 'm', 'J', '', 180.0, 200.0, 220.0),
	(39, 85, 89, 'm', 'J', '', 169.0, 188.0, 206.0),
	(39, 90, 200, 'm', 'J', '', 158.0, 175.0, 193.0),
	(40, 0, 7, 'w', 'J', '', 248.0, 275.0, 303.0),
	(40, 8, 9, 'w', 'J', '', 261.0, 290.0, 319.0),
	(40, 10, 11, 'w', 'J', '', 275.0, 305.0, 336.0),
	(40, 12, 13, 'w', 'J', '', 288.0, 320.0, 352.0),
	(40, 14, 15, 'w', 'J', '', 302.0, 335.0, 369.0),
	(40, 16, 17, 'w', 'J', '', 315.0, 350.0, 385.0),
	(40, 18, 19, 'w', 'J', '', 405.0, 450.0, 495.0),
	(40, 20, 24, 'w', 'J', '', 405.0, 450.0, 495.0),
	(40, 25, 29, 'w', 'J', '', 405.0, 450.0, 495.0),
	(40, 30, 34, 'w', 'J', '', 392.0, 435.0, 479.0),
	(40, 35, 39, 'w', 'J', '', 392.0, 435.0, 479.0),
	(40, 40, 44, 'w', 'J', '', 378.0, 420.0, 462.0),
	(40, 45, 49, 'w', 'J', '', 365.0, 405.0, 446.0),
	(40, 50, 54, 'w', 'J', '', 351.0, 390.0, 429.0),
	(40, 55, 59, 'w', 'J', '', 338.0, 375.0, 413.0),
	(40, 60, 64, 'w', 'J', '', 324.0, 360.0, 396.0),
	(40, 65, 69, 'w', 'J', '', 311.0, 345.0, 380.0),
	(40, 70, 74, 'w', 'J', '', 297.0, 330.0, 363.0),
	(40, 75, 79, 'w', 'J', '', 284.0, 315.0, 347.0),
	(40, 80, 84, 'w', 'J', '', 270.0, 300.0, 330.0),
	(40, 85, 89, 'w', 'J', '', 257.0, 285.0, 314.0),
	(40, 90, 200, 'w', 'J', '', 243.0, 270.0, 297.0),
	(40, 0, 7, 'm', 'J', '', 315.0, 350.0, 385.0),
	(40, 8, 9, 'm', 'J', '', 329.0, 365.0, 402.0),
	(40, 10, 11, 'm', 'J', '', 342.0, 380.0, 418.0),
	(40, 12, 13, 'm', 'J', '', 356.0, 395.0, 435.0),
	(40, 14, 15, 'm', 'J', '', 369.0, 410.0, 451.0),
	(40, 16, 17, 'm', 'J', '', 383.0, 425.0, 468.0),
	(40, 18, 19, 'm', 'J', '', 473.0, 525.0, 578.0),
	(40, 20, 24, 'm', 'J', '', 473.0, 525.0, 578.0),
	(40, 25, 29, 'm', 'J', '', 581.0, 645.0, 710.0),
	(40, 30, 34, 'm', 'J', '', 459.0, 510.0, 561.0),
	(40, 35, 39, 'm', 'J', '', 459.0, 510.0, 561.0),
	(40, 40, 44, 'm', 'J', '', 446.0, 495.0, 545.0),
	(40, 45, 49, 'm', 'J', '', 432.0, 480.0, 528.0),
	(40, 50, 54, 'm', 'J', '', 419.0, 465.0, 512.0),
	(40, 55, 59, 'm', 'J', '', 405.0, 450.0, 495.0),
	(40, 60, 64, 'm', 'J', '', 392.0, 435.0, 479.0),
	(40, 65, 69, 'm', 'J', '', 378.0, 420.0, 462.0),
	(40, 70, 74, 'm', 'J', '', 365.0, 405.0, 446.0),
	(40, 75, 79, 'm', 'J', '', 351.0, 390.0, 429.0),
	(40, 80, 84, 'm', 'J', '', 338.0, 375.0, 413.0),
	(40, 85, 89, 'm', 'J', '', 324.0, 360.0, 396.0),
	(40, 90, 200, 'm', 'J', '', 311.0, 345.0, 380.0),
	(41, 0, 7, 'w', 'J', '', 180.0, 200.0, 220.0),
	(41, 8, 9, 'w', 'J', '', 194.0, 215.0, 237.0),
	(41, 10, 11, 'w', 'J', '', 207.0, 230.0, 253.0),
	(41, 12, 13, 'w', 'J', '', 221.0, 245.0, 270.0),
	(41, 14, 15, 'w', 'J', '', 234.0, 260.0, 286.0),
	(41, 16, 17, 'w', 'J', '', 248.0, 275.0, 303.0),
	(41, 18, 19, 'w', 'J', '', 338.0, 375.0, 413.0),
	(41, 20, 24, 'w', 'J', '', 338.0, 375.0, 413.0),
	(41, 25, 29, 'w', 'J', '', 338.0, 375.0, 413.0),
	(41, 30, 34, 'w', 'J', '', 324.0, 360.0, 396.0),
	(41, 35, 39, 'w', 'J', '', 324.0, 360.0, 396.0),
	(41, 40, 44, 'w', 'J', '', 311.0, 345.0, 380.0),
	(41, 45, 49, 'w', 'J', '', 297.0, 330.0, 363.0),
	(41, 50, 54, 'w', 'J', '', 284.0, 315.0, 347.0),
	(41, 55, 59, 'w', 'J', '', 270.0, 300.0, 330.0),
	(41, 60, 64, 'w', 'J', '', 257.0, 285.0, 314.0),
	(41, 65, 69, 'w', 'J', '', 243.0, 270.0, 297.0),
	(41, 70, 74, 'w', 'J', '', 230.0, 255.0, 281.0),
	(41, 75, 79, 'w', 'J', '', 216.0, 240.0, 264.0),
	(41, 80, 84, 'w', 'J', '', 203.0, 225.0, 248.0),
	(41, 85, 89, 'w', 'J', '', 189.0, 210.0, 231.0),
	(41, 90, 200, 'w', 'J', '', 176.0, 195.0, 215.0),
	(41, 0, 7, 'm', 'J', '', 243.0, 270.0, 297.0),
	(41, 8, 9, 'm', 'J', '', 257.0, 285.0, 314.0),
	(41, 10, 11, 'm', 'J', '', 270.0, 300.0, 330.0),
	(41, 12, 13, 'm', 'J', '', 284.0, 315.0, 347.0),
	(41, 14, 15, 'm', 'J', '', 297.0, 330.0, 363.0),
	(41, 16, 17, 'm', 'J', '', 311.0, 345.0, 380.0),
	(41, 18, 19, 'm', 'J', '', 401.0, 445.0, 490.0),
	(41, 20, 24, 'm', 'J', '', 401.0, 445.0, 490.0),
	(41, 25, 29, 'm', 'J', '', 509.0, 565.0, 622.0),
	(41, 30, 34, 'm', 'J', '', 387.0, 430.0, 473.0),
	(41, 35, 39, 'm', 'J', '', 387.0, 430.0, 473.0),
	(41, 40, 44, 'm', 'J', '', 374.0, 415.0, 457.0),
	(41, 45, 49, 'm', 'J', '', 360.0, 400.0, 440.0),
	(41, 50, 54, 'm', 'J', '', 347.0, 385.0, 424.0),
	(41, 55, 59, 'm', 'J', '', 333.0, 370.0, 407.0),
	(41, 60, 64, 'm', 'J', '', 320.0, 355.0, 391.0),
	(41, 65, 69, 'm', 'J', '', 306.0, 340.0, 374.0),
	(41, 70, 74, 'm', 'J', '', 293.0, 325.0, 358.0),
	(41, 75, 79, 'm', 'J', '', 279.0, 310.0, 341.0),
	(41, 80, 84, 'm', 'J', '', 266.0, 295.0, 325.0),
	(41, 85, 89, 'm', 'J', '', 252.0, 280.0, 308.0),
	(41, 90, 200, 'm', 'J', '', 239.0, 265.0, 292.0),
	(42, 0, 7, 'w', 'J', '', 185.0, 205.0, 226.0),
	(42, 8, 9, 'w', 'J', '', 198.0, 220.0, 242.0),
	(42, 10, 11, 'w', 'J', '', 212.0, 235.0, 259.0),
	(42, 12, 13, 'w', 'J', '', 225.0, 250.0, 275.0),
	(42, 14, 15, 'w', 'J', '', 239.0, 265.0, 292.0),
	(42, 16, 17, 'w', 'J', '', 252.0, 280.0, 308.0),
	(42, 18, 19, 'w', 'J', '', 342.0, 380.0, 418.0),
	(42, 20, 24, 'w', 'J', '', 342.0, 380.0, 418.0),
	(42, 25, 29, 'w', 'J', '', 342.0, 380.0, 418.0),
	(42, 30, 34, 'w', 'J', '', 329.0, 365.0, 402.0),
	(42, 35, 39, 'w', 'J', '', 329.0, 365.0, 402.0),
	(42, 40, 44, 'w', 'J', '', 315.0, 350.0, 385.0),
	(42, 45, 49, 'w', 'J', '', 302.0, 335.0, 369.0),
	(42, 50, 54, 'w', 'J', '', 288.0, 320.0, 352.0),
	(42, 55, 59, 'w', 'J', '', 275.0, 305.0, 336.0),
	(42, 60, 64, 'w', 'J', '', 261.0, 290.0, 319.0),
	(42, 65, 69, 'w', 'J', '', 248.0, 275.0, 303.0),
	(42, 70, 74, 'w', 'J', '', 234.0, 260.0, 286.0),
	(42, 75, 79, 'w', 'J', '', 221.0, 245.0, 270.0),
	(42, 80, 84, 'w', 'J', '', 207.0, 230.0, 253.0),
	(42, 85, 89, 'w', 'J', '', 194.0, 215.0, 237.0),
	(42, 90, 200, 'w', 'J', '', 180.0, 200.0, 220.0),
	(42, 0, 7, 'm', 'J', '', 248.0, 275.0, 303.0),
	(42, 8, 9, 'm', 'J', '', 261.0, 290.0, 319.0),
	(42, 10, 11, 'm', 'J', '', 275.0, 305.0, 336.0),
	(42, 12, 13, 'm', 'J', '', 288.0, 320.0, 352.0),
	(42, 14, 15, 'm', 'J', '', 302.0, 335.0, 369.0),
	(42, 16, 17, 'm', 'J', '', 315.0, 350.0, 385.0),
	(42, 18, 19, 'm', 'J', '', 405.0, 450.0, 495.0),
	(42, 20, 24, 'm', 'J', '', 405.0, 450.0, 495.0),
	(42, 25, 29, 'm', 'J', '', 513.0, 570.0, 627.0),
	(42, 30, 34, 'm', 'J', '', 392.0, 435.0, 479.0),
	(42, 35, 39, 'm', 'J', '', 392.0, 435.0, 479.0),
	(42, 40, 44, 'm', 'J', '', 378.0, 420.0, 462.0),
	(42, 45, 49, 'm', 'J', '', 365.0, 405.0, 446.0),
	(42, 50, 54, 'm', 'J', '', 351.0, 390.0, 429.0),
	(42, 55, 59, 'm', 'J', '', 338.0, 375.0, 413.0),
	(42, 60, 64, 'm', 'J', '', 324.0, 360.0, 396.0),
	(42, 65, 69, 'm', 'J', '', 311.0, 345.0, 380.0),
	(42, 70, 74, 'm', 'J', '', 297.0, 330.0, 363.0),
	(42, 75, 79, 'm', 'J', '', 284.0, 315.0, 347.0),
	(42, 80, 84, 'm', 'J', '', 270.0, 300.0, 330.0),
	(42, 85, 89, 'm', 'J', '', 257.0, 285.0, 314.0),
	(42, 90, 200, 'm', 'J', '', 243.0, 270.0, 297.0),
	(43, 0, 7, 'w', 'J', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'w', 'J', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'w', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'w', 'J', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'w', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'w', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'w', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'w', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'w', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 0, 7, 'm', 'J', '', 5.0, 7.5, 10.0),
	(43, 8, 9, 'm', 'J', '', 7.5, 10.0, 12.500000000000002),
	(43, 10, 11, 'm', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 12, 13, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 14, 15, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 16, 17, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 18, 19, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 20, 24, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 25, 29, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 30, 34, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 35, 39, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 40, 44, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 45, 49, 'm', 'J', '', 15.0, 17.5, 20.0),
	(43, 50, 54, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 55, 59, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 60, 64, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 65, 69, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 70, 74, 'm', 'J', '', 12.500000000000002, 15.0, 17.5),
	(43, 75, 79, 'm', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 80, 84, 'm', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 85, 89, 'm', 'J', '', 10.0, 12.500000000000002, 15.0),
	(43, 90, 200, 'm', 'J', '', 10.0, 12.500000000000002, 15.0),
	(44, 12, 13, 'w', 'J', '', 2.42, 2.68, 2.93),
	(44, 14, 15, 'w', 'J', '', 2.81, 3.06, 3.32),
	(44, 16, 17, 'w', 'J', '', 2.93, 3.19, 3.44),
	(44, 18, 19, 'w', 'J', '', 5.53, 5.95, 6.38),
	(44, 20, 24, 'w', 'J', '', 5.53, 5.95, 6.38),
	(44, 25, 29, 'w', 'J', '', 5.53, 5.95, 6.38),
	(44, 30, 34, 'w', 'J', '', 5.31, 5.74, 6.16),
	(44, 35, 39, 'w', 'J', '', 5.1, 5.53, 5.95),
	(44, 40, 44, 'w', 'J', '', 4.68, 5.1, 5.53),
	(44, 45, 49, 'w', 'J', '', 4.46, 4.89, 5.31),
	(44, 50, 54, 'w', 'J', '', 4.33, 4.85, 5.27),
	(44, 55, 59, 'w', 'J', '', 4.25, 4.75, 5.22),
	(44, 60, 64, 'w', 'J', '', 4.04, 4.68, 5.16),
	(44, 65, 69, 'w', 'J', '', 3.83, 4.46, 5.16),
	(44, 70, 74, 'w', 'J', '', 3.61, 4.25, 5.1),
	(44, 75, 79, 'w', 'J', '', 3.61, 4.46, 5.31),
	(44, 80, 84, 'w', 'J', '', 3.4, 4.25, 4.89),
	(44, 85, 89, 'w', 'J', '', 3.19, 3.83, 4.68),
	(44, 90, 200, 'w', 'J', '', 2.76, 3.61, 4.25),
	(44, 12, 13, 'm', 'J', '', 3.19, 3.44, 3.7),
	(44, 14, 15, 'm', 'J', '', 3.57, 3.83, 4.08),
	(44, 16, 17, 'm', 'J', '', 3.83, 4.08, 4.34),
	(44, 18, 19, 'm', 'J', '', 6.59, 7.01, 7.44),
	(44, 20, 24, 'm', 'J', '', 6.59, 7.23, 7.65),
	(44, 25, 29, 'm', 'J', '', 6.38, 7.01, 7.44),
	(44, 30, 34, 'm', 'J', '', 5.95, 6.59, 7.01),
	(44, 35, 39, 'm', 'J', '', 5.74, 6.16, 6.8),
	(44, 40, 44, 'm', 'J', '', 5.31, 5.95, 6.59),
	(44, 45, 49, 'm', 'J', '', 5.1, 5.74, 6.38),
	(44, 50, 54, 'm', 'J', '', 5.01, 5.7, 6.29),
	(44, 55, 59, 'm', 'J', '', 4.93, 5.6, 6.21),
	(44, 60, 64, 'm', 'J', '', 5.1, 5.95, 6.8),
	(44, 65, 69, 'm', 'J', '', 5.01, 5.86, 6.72),
	(44, 70, 74, 'm', 'J', '', 4.93, 5.69, 6.54),
	(44, 75, 79, 'm', 'J', '', 4.89, 5.53, 6.38),
	(44, 80, 84, 'm', 'J', '', 4.68, 5.31, 6.16),
	(44, 85, 89, 'm', 'J', '', 4.25, 5.1, 5.74),
	(44, 90, 200, 'm', 'J', '', 3.83, 4.46, 5.31),
	(53, 0, 7, 'w', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'w', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'w', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'w', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'w', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'w', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'w', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'w', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'w', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'w', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'w', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'w', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'w', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'w', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 0, 7, 'm', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 8, 9, 'm', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 10, 11, 'm', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 12, 13, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 14, 15, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 16, 17, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 18, 19, 'm', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 20, 24, 'm', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 25, 29, 'm', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 30, 34, 'm', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 35, 39, 'm', 'J', '7 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 40, 44, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 45, 49, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 50, 54, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 55, 59, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 60, 64, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 65, 69, 'm', 'J', '5 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 70, 74, 'm', 'J', '3 m Abstand Kreismitte', 10.0, 15.0, 20.0),
	(53, 75, 79, 'm', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 80, 84, 'm', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 85, 89, 'm', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(53, 90, 200, 'm', 'J', '3 m Abstand zur Kreismitte', 10.0, 15.0, 20.0),
	(57, 0, 7, 'w', 'J', '', 5.0, 6.0, 8.0),
	(57, 8, 9, 'w', 'J', '', 7.0, 8.0, 11.0),
	(57, 10, 11, 'w', 'J', '', 11.0, 12.0, 14.0),
	(57, 0, 7, 'm', 'J', '', 6.0, 7.0, 10.0),
	(57, 8, 9, 'm', 'J', '', 8.0, 11.0, 13.0),
	(57, 10, 11, 'm', 'J', '', 13.0, 16.0, 18.0)
;
INSERT INTO Punkte(DNr, Alter_Von, Alter_Bis, Geschl, BehinderungsKlasse, Zusatz, Sollwert1, Sollwert2, Sollwert3) VALUES
	(1, 0, 7, 'w', 'NONE', '', 5.666666666666667, 5.0, 4.250000000000001),
	(1, 8, 9, 'w', 'NONE', '', 5.583333333333333, 4.833333333333333, 4.166666666666666),
	(1, 10, 11, 'w', 'NONE', '', 5.333333333333334, 4.666666666666667, 4.0),
	(1, 12, 13, 'w', 'NONE', '', 5.166666666666666, 4.416666666666667, 3.7500000000000004),
	(1, 14, 15, 'w', 'NONE', '', 5.0, 4.333333333333334, 3.5833333333333335),
	(1, 16, 17, 'w', 'NONE', '', 4.833333333333333, 4.083333333333333, 3.4166666666666665),
	(1, 0, 7, 'm', 'NONE', '', 5.666666666666667, 5.0, 4.250000000000001),
	(1, 8, 9, 'm', 'NONE', '', 5.416666666666667, 4.666666666666667, 3.9166666666666665),
	(1, 10, 11, 'm', 'NONE', '', 5.083333333333333, 4.333333333333334, 3.5833333333333335),
	(1, 12, 13, 'm', 'NONE', '', 4.75, 4.0, 3.25),
	(1, 14, 15, 'm', 'NONE', '', 4.333333333333334, 3.6666666666666665, 3.0),
	(1, 16, 17, 'm', 'NONE', '', 4.083333333333333, 3.4166666666666665, 2.7500000000000004),
	(3, 0, 7, 'w', 'NONE', '', 8.0, 12.0, 17.0),
	(3, 8, 9, 'w', 'NONE', '', 10.0, 15.0, 20.0),
	(3, 10, 11, 'w', 'NONE', '', 15.0, 20.0, 30.0),
	(3, 12, 13, 'w', 'NONE', '', 20.0, 30.0, 40.0),
	(3, 14, 15, 'w', 'NONE', '', 30.0, 40.0, 50.0),
	(3, 16, 17, 'w', 'NONE', '', 45.0, 60.0, 75.0),
	(3, 0, 7, 'm', 'NONE', '', 10.0, 15.0, 20.0),
	(3, 8, 9, 'm', 'NONE', '', 12.0, 17.0, 23.0),
	(3, 10, 11, 'm', 'NONE', '', 17.0, 25.0, 35.0),
	(3, 12, 13, 'm', 'NONE', '', 25.0, 35.0, 45.0),
	(3, 14, 15, 'm', 'NONE', '', 35.0, 45.0, 60.0),
	(3, 16, 17, 'm', 'NONE', '', 55.0, 70.0, 90.0),
	(4, 8, 9, 'w', 'NONE', '5 km', 27.0, 24.0, 21.0),
	(4, 10, 11, 'w', 'NONE', '10 km', 50.49999999999999, 43.0, 35.49999999999999),
	(4, 12, 13, 'w', 'NONE', '10 km', 45.0, 39.49999999999999, 33.49999999999999),
	(4, 14, 15, 'w', 'NONE', '10 km', 38.0, 32.49999999999999, 28.5),
	(4, 16, 17, 'w', 'NONE', '10 km', 32.49999999999999, 28.5, 25.0),
	(4, 18, 19, 'w', 'NONE', '20 km', 57.49999999999999, 52.0, 46.49999999999999),
	(4, 20, 24, 'w', 'NONE', '20 km', 57.0, 51.49999999999999, 45.49999999999999),
	(4, 25, 29, 'w', 'NONE', '20 km', 56.0, 50.49999999999999, 45.0),
	(4, 30, 34, 'w', 'NONE', '20 km', 57.0, 51.49999999999999, 45.49999999999999),
	(4, 35, 39, 'w', 'NONE', '20 km', 60.0, 53.0, 47.0),
	(4, 40, 44, 'w', 'NONE', '20 km', 64.0, 55.49999999999999, 49.49999999999999),
	(4, 45, 49, 'w', 'NONE', '20 km', 67.0, 58.49999999999999, 51.49999999999999),
	(4, 50, 54, 'w', 'NONE', '20 km', 69.0, 61.0, 53.49999999999999),
	(4, 55, 59, 'w', 'NONE', '20 km', 71.5, 63.0, 55.49999999999999),
	(4, 60, 64, 'w', 'NONE', '20 km', 74.0, 65.0, 57.0),
	(4, 65, 69, 'w', 'NONE', '20 km', 75.5, 66.5, 58.49999999999999),
	(4, 70, 74, 'w', 'NONE', '20 km', 78.0, 68.5, 60.49999999999999),
	(4, 75, 79, 'w', 'NONE', '20 km', 81.5, 70.5, 63.0),
	(4, 80, 84, 'w', 'NONE', '20 km', 84.5, 75.0, 65.5),
	(4, 85, 89, 'w', 'NONE', '20 km', 89.5, 80.0, 69.0),
	(4, 90, 200, 'w', 'NONE', '20 km', 93.0, 83.0, 72.5),
	(4, 8, 9, 'm', 'NONE', '5 km', 26.5, 23.5, 20.5),
	(4, 10, 11, 'm', 'NONE', '10 km', 48.49999999999999, 41.0, 33.49999999999999),
	(4, 12, 13, 'm', 'NONE', '10 km', 43.0, 37.0, 31.5),
	(4, 14, 15, 'm', 'NONE', '10 km', 32.0, 28.0, 24.0),
	(4, 16, 17, 'm', 'NONE', '10 km', 27.0, 23.5, 20.5),
	(4, 18, 19, 'm', 'NONE', '20 km', 47.0, 42.49999999999999, 38.49999999999999),
	(4, 20, 24, 'm', 'NONE', '20 km', 46.49999999999999, 42.0, 37.49999999999999),
	(4, 25, 29, 'm', 'NONE', '20 km', 50.0, 44.49999999999999, 39.0),
	(4, 30, 34, 'm', 'NONE', '20 km', 53.49999999999999, 47.0, 40.49999999999999),
	(4, 35, 39, 'm', 'NONE', '20 km', 58.0, 50.0, 41.49999999999999),
	(4, 40, 44, 'm', 'NONE', '20 km', 63.0, 52.0, 43.49999999999999),
	(4, 45, 49, 'm', 'NONE', '20 km', 66.0, 55.0, 45.0),
	(4, 50, 54, 'm', 'NONE', '20 km', 68.5, 57.0, 46.49999999999999),
	(4, 55, 59, 'm', 'NONE', '20 km', 70.5, 58.49999999999999, 47.49999999999999),
	(4, 60, 64, 'm', 'NONE', '20 km', 71.5, 60.0, 48.0),
	(4, 65, 69, 'm', 'NONE', '20 km', 72.5, 60.49999999999999, 48.49999999999999),
	(4, 70, 74, 'm', 'NONE', '20 km', 73.5, 61.49999999999999, 49.49999999999999),
	(4, 75, 79, 'm', 'NONE', '20 km', 74.5, 63.0, 51.49999999999999),
	(4, 80, 84, 'm', 'NONE', '20 km', 76.0, 64.5, 53.0),
	(4, 85, 89, 'm', 'NONE', '20 km', 77.5, 66.5, 55.49999999999999),
	(4, 90, 200, 'm', 'NONE', '20 km', 79.0, 68.0, 58.0),
	(5, 18, 19, 'w', 'NONE', '', 20.833333333333332, 18.833333333333332, 16.833333333333332),
	(5, 20, 24, 'w', 'NONE', '', 20.333333333333332, 18.333333333333332, 16.333333333333332),
	(5, 25, 29, 'w', 'NONE', '', 20.666666666666664, 18.666666666666664, 16.666666666666664),
	(5, 30, 34, 'w', 'NONE', '', 21.5, 19.5, 17.5),
	(5, 35, 39, 'w', 'NONE', '', 22.0, 20.0, 18.0),
	(5, 40, 44, 'w', 'NONE', '', 22.833333333333332, 20.666666666666664, 18.5),
	(5, 45, 49, 'w', 'NONE', '', 23.833333333333332, 21.5, 18.833333333333332),
	(5, 50, 54, 'w', 'NONE', '', 24.833333333333332, 22.166666666666668, 19.166666666666668),
	(5, 55, 59, 'w', 'NONE', '', 25.833333333333332, 22.833333333333332, 19.833333333333332),
	(5, 60, 64, 'w', 'NONE', '', 26.5, 23.5, 20.5),
	(5, 65, 69, 'w', 'NONE', '', 27.166666666666668, 24.166666666666668, 21.166666666666668),
	(5, 70, 74, 'w', 'NONE', '', 27.666666666666664, 24.666666666666664, 21.666666666666664),
	(5, 75, 79, 'w', 'NONE', '', 28.5, 25.5, 22.5),
	(5, 80, 84, 'w', 'NONE', '', 29.666666666666664, 26.666666666666664, 23.666666666666664),
	(5, 85, 89, 'w', 'NONE', '', 31.0, 28.0, 25.0),
	(5, 90, 200, 'w', 'NONE', '', 32.49999999999999, 29.5, 26.5),
	(5, 18, 19, 'm', 'NONE', '', 17.833333333333332, 15.833333333333334, 13.833333333333334),
	(5, 20, 24, 'm', 'NONE', '', 17.333333333333332, 15.333333333333332, 13.333333333333332),
	(5, 25, 29, 'm', 'NONE', '', 17.666666666666664, 15.666666666666668, 13.666666666666668),
	(5, 30, 34, 'm', 'NONE', '', 18.5, 16.5, 14.500000000000002),
	(5, 35, 39, 'm', 'NONE', '', 19.833333333333332, 17.333333333333332, 15.0),
	(5, 40, 44, 'm', 'NONE', '', 21.0, 18.5, 15.833333333333334),
	(5, 45, 49, 'm', 'NONE', '', 22.166666666666668, 19.5, 16.5),
	(5, 50, 54, 'm', 'NONE', '', 23.333333333333332, 20.333333333333332, 17.333333333333332),
	(5, 55, 59, 'm', 'NONE', '', 23.833333333333332, 20.833333333333332, 17.833333333333332),
	(5, 60, 64, 'm', 'NONE', '', 24.5, 21.5, 18.5),
	(5, 65, 69, 'm', 'NONE', '', 25.0, 22.0, 19.0),
	(5, 70, 74, 'm', 'NONE', '', 25.333333333333332, 22.333333333333332, 19.333333333333332),
	(5, 75, 79, 'm', 'NONE', '', 26.0, 23.0, 20.0),
	(5, 80, 84, 'm', 'NONE', '', 26.5, 23.5, 20.5),
	(5, 85, 89, 'm', 'NONE', '', 27.5, 24.5, 21.5),
	(5, 90, 200, 'm', 'NONE', '', 29.833333333333332, 26.833333333333332, 23.833333333333332),
	(6, 18, 19, 'w', 'NONE', '', 84.66666666666667, 78.66666666666667, 72.66666666666667),
	(6, 20, 24, 'w', 'NONE', '', 83.5, 76.83333333333333, 71.5),
	(6, 25, 29, 'w', 'NONE', '', 83.5, 76.83333333333333, 71.0),
	(6, 30, 34, 'w', 'NONE', '', 84.16666666666666, 78.0, 71.33333333333334),
	(6, 35, 39, 'w', 'NONE', '', 87.66666666666667, 79.5, 71.5),
	(6, 40, 44, 'w', 'NONE', '', 91.33333333333334, 81.33333333333334, 71.66666666666667),
	(6, 45, 49, 'w', 'NONE', '', 95.33333333333334, 83.16666666666666, 72.83333333333333),
	(6, 50, 54, 'w', 'NONE', '', 97.66666666666667, 85.5, 74.0),
	(6, 55, 59, 'w', 'NONE', '', 100.16666666666666, 88.16666666666666, 76.16666666666666),
	(6, 60, 64, 'w', 'NONE', '', 102.83333333333333, 90.83333333333333, 78.83333333333333),
	(6, 65, 69, 'w', 'NONE', '', 105.66666666666667, 93.66666666666667, 81.66666666666667),
	(6, 70, 74, 'w', 'NONE', '', 109.5, 97.5, 85.5),
	(6, 75, 79, 'w', 'NONE', '', 115.33333333333334, 103.33333333333334, 91.33333333333334),
	(6, 80, 84, 'w', 'NONE', '', 122.33333333333334, 110.33333333333334, 98.33333333333334),
	(6, 85, 89, 'w', 'NONE', '', 129.16666666666666, 117.16666666666666, 105.16666666666666),
	(6, 90, 200, 'w', 'NONE', '', 136.50000000000003, 124.5, 112.5),
	(6, 18, 19, 'm', 'NONE', '', 63.333333333333336, 57.333333333333336, 51.333333333333336),
	(6, 20, 24, 'm', 'NONE', '', 62.49999999999999, 56.49999999999999, 50.0),
	(6, 25, 29, 'm', 'NONE', '', 66.0, 59.333333333333336, 52.0),
	(6, 30, 34, 'm', 'NONE', '', 69.66666666666667, 61.16666666666667, 54.833333333333336),
	(6, 35, 39, 'm', 'NONE', '', 74.16666666666666, 65.5, 56.833333333333336),
	(6, 40, 44, 'm', 'NONE', '', 78.83333333333333, 69.5, 60.16666666666667),
	(6, 45, 49, 'm', 'NONE', '', 83.66666666666667, 73.16666666666666, 63.49999999999999),
	(6, 50, 54, 'm', 'NONE', '', 88.33333333333334, 76.66666666666667, 65.5),
	(6, 55, 59, 'm', 'NONE', '', 91.5, 79.66666666666667, 67.66666666666667),
	(6, 60, 64, 'm', 'NONE', '', 94.66666666666667, 82.66666666666667, 70.66666666666667),
	(6, 65, 69, 'm', 'NONE', '', 98.0, 86.0, 74.0),
	(6, 70, 74, 'm', 'NONE', '', 102.16666666666666, 90.16666666666666, 78.16666666666666),
	(6, 75, 79, 'm', 'NONE', '', 107.33333333333334, 95.33333333333334, 83.33333333333334),
	(6, 80, 84, 'm', 'NONE', '', 113.16666666666666, 101.16666666666666, 89.16666666666666),
	(6, 85, 89, 'm', 'NONE', '', 120.16666666666666, 108.16666666666666, 96.16666666666666),
	(6, 90, 200, 'm', 'NONE', '', 127.66666666666667, 115.66666666666667, 103.66666666666667),
	(7, 0, 7, 'w', 'NONE', '200 m', 9.0, 7.666666666666667, 6.333333333333334),
	(7, 8, 9, 'w', 'NONE', '200 m', 8.0, 7.0, 5.916666666666666),
	(7, 10, 11, 'w', 'NONE', '200 m', 7.333333333333334, 6.416666666666667, 5.5),
	(7, 12, 13, 'w', 'NONE', '400 m', 14.833333333333334, 12.916666666666668, 11.0),
	(7, 14, 15, 'w', 'NONE', '400 m', 13.083333333333334, 11.666666666666668, 10.0),
	(7, 16, 17, 'w', 'NONE', '400 m', 11.833333333333334, 10.500000000000002, 9.083333333333334),
	(7, 18, 19, 'w', 'NONE', '800 m', 24.0, 21.166666666666668, 18.416666666666668),
	(7, 20, 24, 'w', 'NONE', '800 m', 23.583333333333336, 20.833333333333332, 18.0),
	(7, 25, 29, 'w', 'NONE', '800 m', 25.5, 21.083333333333336, 18.666666666666664),
	(7, 30, 34, 'w', 'NONE', '800 m', 28.833333333333332, 23.666666666666664, 19.5),
	(7, 35, 39, 'w', 'NONE', '800 m', 32.0, 25.583333333333336, 20.333333333333332),
	(7, 40, 44, 'w', 'NONE', '800 m', 34.0, 27.666666666666664, 21.333333333333332),
	(7, 45, 49, 'w', 'NONE', '800 m', 35.333333333333336, 29.0, 21.5),
	(7, 50, 54, 'w', 'NONE', '400 m', 18.0, 15.0, 11.500000000000002),
	(7, 55, 59, 'w', 'NONE', '400 m', 18.583333333333336, 15.333333333333332, 11.916666666666668),
	(7, 60, 64, 'w', 'NONE', '400 m', 19.0, 15.583333333333332, 12.166666666666666),
	(7, 65, 69, 'w', 'NONE', '400 m', 19.416666666666668, 15.749999999999998, 12.25),
	(7, 70, 74, 'w', 'NONE', '400 m', 19.833333333333332, 16.083333333333336, 12.666666666666668),
	(7, 75, 79, 'w', 'NONE', '200 m', 10.25, 8.333333333333332, 6.5),
	(7, 80, 84, 'w', 'NONE', '200 m', 10.416666666666666, 8.500000000000002, 6.75),
	(7, 85, 89, 'w', 'NONE', '200 m', 10.583333333333332, 8.749999999999998, 7.083333333333333),
	(7, 90, 200, 'w', 'NONE', '200 m', 10.749999999999998, 8.916666666666668, 7.333333333333334),
	(7, 0, 7, 'm', 'NONE', '200 m', 9.0, 7.333333333333334, 6.166666666666666),
	(7, 8, 9, 'm', 'NONE', '200 m', 8.0, 6.75, 5.666666666666667),
	(7, 10, 11, 'm', 'NONE', '200 m', 7.0, 6.333333333333334, 5.166666666666666),
	(7, 12, 13, 'm', 'NONE', '400 m', 13.500000000000002, 11.500000000000002, 9.749999999999998),
	(7, 14, 15, 'm', 'NONE', '400 m', 12.0, 10.25, 8.833333333333334),
	(7, 16, 17, 'm', 'NONE', '400 m', 11.0, 9.666666666666668, 8.333333333333332),
	(7, 18, 19, 'm', 'NONE', '800 m', 22.583333333333336, 19.833333333333332, 17.0),
	(7, 20, 24, 'm', 'NONE', '800 m', 22.166666666666668, 19.5, 16.416666666666668),
	(7, 25, 29, 'm', 'NONE', '800 m', 23.166666666666668, 20.0, 17.0),
	(7, 30, 34, 'm', 'NONE', '800 m', 25.75, 21.5, 18.0),
	(7, 35, 39, 'm', 'NONE', '800 m', 28.833333333333332, 24.0, 19.249999999999996),
	(7, 40, 44, 'm', 'NONE', '800 m', 32.416666666666664, 26.416666666666668, 20.416666666666668),
	(7, 45, 49, 'm', 'NONE', '800 m', 34.49999999999999, 27.833333333333332, 20.666666666666664),
	(7, 50, 54, 'm', 'NONE', '400 m', 17.416666666666668, 14.333333333333332, 10.749999999999998),
	(7, 55, 59, 'm', 'NONE', '400 m', 17.833333333333332, 14.583333333333332, 11.333333333333332),
	(7, 60, 64, 'm', 'NONE', '400 m', 18.166666666666668, 14.749999999999998, 11.416666666666666),
	(7, 65, 69, 'm', 'NONE', '400 m', 18.416666666666668, 15.083333333333334, 11.500000000000002),
	(7, 70, 74, 'm', 'NONE', '400 m', 18.416666666666668, 15.25, 11.583333333333332),
	(7, 75, 79, 'm', 'NONE', '200 m', 9.416666666666666, 7.666666666666667, 6.083333333333333),
	(7, 80, 84, 'm', 'NONE', '200 m', 9.500000000000002, 7.833333333333333, 6.166666666666666),
	(7, 85, 89, 'm', 'NONE', '200 m', 9.500000000000002, 8.0, 6.416666666666667),
	(7, 90, 200, 'm', 'NONE', '200 m', 9.749999999999998, 8.166666666666666, 6.75),
	(8, 18, 19, 'w', 'NONE', '7,5 km', 69.5, 66.0, 62.0),
	(8, 20, 24, 'w', 'NONE', '7,5 km', 66.5, 63.0, 60.0),
	(8, 25, 29, 'w', 'NONE', '7,5 km', 67.0, 63.49999999999999, 60.0),
	(8, 30, 34, 'w', 'NONE', '7,5 km', 67.5, 64.0, 61.0),
	(8, 35, 39, 'w', 'NONE', '7,5 km', 70.0, 65.0, 61.49999999999999),
	(8, 40, 44, 'w', 'NONE', '7,5 km', 73.0, 67.0, 62.0),
	(8, 45, 49, 'w', 'NONE', '7,5 km', 75.5, 69.0, 63.0),
	(8, 50, 54, 'w', 'NONE', '7,5 km', 78.0, 71.0, 64.0),
	(8, 55, 59, 'w', 'NONE', '7,5 km', 80.0, 73.0, 66.0),
	(8, 60, 64, 'w', 'NONE', '7,5 km', 82.5, 74.5, 67.5),
	(8, 65, 69, 'w', 'NONE', '7,5 km', 84.25000000000001, 76.5, 70.0),
	(8, 70, 74, 'w', 'NONE', '7,5 km', 88.25000000000001, 79.0, 72.0),
	(8, 75, 79, 'w', 'NONE', '7,5 km', 92.5, 81.5, 74.5),
	(8, 80, 84, 'w', 'NONE', '7,5 km', 98.5, 85.25000000000001, 77.5),
	(8, 85, 89, 'w', 'NONE', '7,5 km', 104.0, 90.33333333333334, 82.0),
	(8, 90, 200, 'w', 'NONE', '7,5 km', 110.35, 96.0, 87.0),
	(8, 18, 19, 'm', 'NONE', '7,5 km', 58.49999999999999, 54.49999999999999, 50.49999999999999),
	(8, 20, 24, 'm', 'NONE', '7,5 km', 57.0, 53.0, 49.0),
	(8, 25, 29, 'm', 'NONE', '7,5 km', 58.49999999999999, 54.49999999999999, 50.49999999999999),
	(8, 30, 34, 'm', 'NONE', '7,5 km', 62.49999999999999, 57.0, 51.0),
	(8, 35, 39, 'm', 'NONE', '7,5 km', 65.0, 58.49999999999999, 53.49999999999999),
	(8, 40, 44, 'm', 'NONE', '7,5 km', 66.0, 60.49999999999999, 54.0),
	(8, 45, 49, 'm', 'NONE', '7,5 km', 68.5, 62.49999999999999, 55.0),
	(8, 50, 54, 'm', 'NONE', '7,5 km', 71.0, 64.0, 57.49999999999999),
	(8, 55, 59, 'm', 'NONE', '7,5 km', 73.0, 65.0, 59.0),
	(8, 60, 64, 'm', 'NONE', '7,5 km', 75.75, 67.5, 60.49999999999999),
	(8, 65, 69, 'm', 'NONE', '7,5 km', 78.16666666666666, 69.5, 62.0),
	(8, 70, 74, 'm', 'NONE', '7,5 km', 81.5, 72.0, 65.0),
	(8, 75, 79, 'm', 'NONE', '7,5 km', 86.16666666666666, 75.75, 67.5),
	(8, 80, 84, 'm', 'NONE', '7,5 km', 91.5, 79.75, 72.0),
	(8, 85, 89, 'm', 'NONE', '7,5 km', 96.0, 84.25000000000001, 75.5),
	(8, 90, 200, 'm', 'NONE', '7,5 km', 102.75, 89.33333333333334, 80.0),
	(10, 0, 7, 'w', 'NONE', '', 6.0, 9.0, 12.0),
	(10, 8, 9, 'w', 'NONE', '', 9.0, 12.0, 15.0),
	(10, 10, 11, 'w', 'NONE', '', 11.0, 15.0, 18.0),
	(10, 12, 13, 'w', 'NONE', '', 15.0, 18.0, 22.0),
	(10, 0, 7, 'm', 'NONE', '', 12.0, 15.0, 17.0),
	(10, 8, 9, 'm', 'NONE', '', 17.0, 20.0, 23.0),
	(10, 10, 11, 'm', 'NONE', '', 21.0, 25.0, 28.0),
	(11, 14, 15, 'w', 'NONE', '', 20.0, 24.0, 27.0),
	(11, 16, 17, 'w', 'NONE', '', 24.0, 27.0, 31.0),
	(11, 12, 13, 'm', 'NONE', '', 26.0, 30.0, 33.0),
	(11, 14, 15, 'm', 'NONE', '', 30.0, 34.0, 37.0),
	(11, 16, 17, 'm', 'NONE', '', 34.0, 38.0, 42.0),
	(12, 0, 7, 'w', 'NONE', '1 kg', 2.5, 3.5, 4.5),
	(12, 8, 9, 'w', 'NONE', '1 kg', 3.0, 4.0, 5.0),
	(12, 10, 11, 'w', 'NONE', '1 kg', 5.0, 6.0, 7.0),
	(12, 18, 19, 'w', 'NONE', '2 kg', 8.0, 9.0, 10.0),
	(12, 20, 24, 'w', 'NONE', '2 kg', 8.0, 9.0, 10.0),
	(12, 25, 29, 'w', 'NONE', '2 kg', 8.0, 9.0, 10.0),
	(12, 30, 34, 'w', 'NONE', '2 kg', 7.5, 8.5, 9.5),
	(12, 35, 39, 'w', 'NONE', '2 kg', 7.0, 8.5, 9.5),
	(12, 40, 44, 'w', 'NONE', '2 kg', 6.5, 8.5, 9.5),
	(12, 45, 49, 'w', 'NONE', '2 kg', 6.0, 8.5, 9.5),
	(12, 50, 54, 'w', 'NONE', '2 kg', 5.5, 7.5, 9.0),
	(12, 55, 59, 'w', 'NONE', '2 kg', 5.5, 7.5, 9.0),
	(12, 60, 64, 'w', 'NONE', '2 kg', 5.0, 7.0, 8.5),
	(12, 65, 69, 'w', 'NONE', '2 kg', 5.0, 7.0, 8.5),
	(12, 70, 74, 'w', 'NONE', '2 kg', 4.5, 6.5, 7.5),
	(12, 75, 79, 'w', 'NONE', '2 kg', 4.5, 6.5, 7.5),
	(12, 80, 84, 'w', 'NONE', '2 kg', 4.0, 5.5, 6.5),
	(12, 85, 89, 'w', 'NONE', '2 kg', 3.5, 4.5, 5.5),
	(12, 90, 200, 'w', 'NONE', '2 kg', 3.0, 4.0, 5.0),
	(12, 0, 7, 'm', 'NONE', '1 kg', 2.5, 3.5, 4.5),
	(12, 8, 9, 'm', 'NONE', '1 kg', 3.0, 4.0, 5.0),
	(12, 10, 11, 'm', 'NONE', '1 kg', 5.5, 6.5, 7.5),
	(12, 18, 19, 'm', 'NONE', '2 kg', 11.0, 13.0, 14.0),
	(12, 20, 24, 'm', 'NONE', '2 kg', 11.0, 13.5, 14.5),
	(12, 25, 29, 'm', 'NONE', '2 kg', 10.5, 13.0, 14.5),
	(12, 30, 34, 'm', 'NONE', '2 kg', 10.0, 13.0, 14.0),
	(12, 35, 39, 'm', 'NONE', '2 kg', 9.5, 12.5, 14.0),
	(12, 40, 44, 'm', 'NONE', '2 kg', 9.0, 12.0, 13.5),
	(12, 45, 49, 'm', 'NONE', '2 kg', 8.0, 11.5, 13.5),
	(12, 50, 54, 'm', 'NONE', '2 kg', 7.5, 11.0, 13.0),
	(12, 55, 59, 'm', 'NONE', '2 kg', 7.0, 10.5, 12.5),
	(12, 60, 64, 'm', 'NONE', '2 kg', 6.5, 10.0, 12.5),
	(12, 65, 69, 'm', 'NONE', '2 kg', 6.0, 9.5, 11.5),
	(12, 70, 74, 'm', 'NONE', '2 kg', 6.0, 9.0, 10.5),
	(12, 75, 79, 'm', 'NONE', '2 kg', 6.0, 8.5, 10.0),
	(12, 80, 84, 'm', 'NONE', '2 kg', 5.5, 8.0, 9.5),
	(12, 85, 89, 'm', 'NONE', '2 kg', 5.0, 7.5, 9.0),
	(12, 90, 200, 'm', 'NONE', '2 kg', 4.5, 6.5, 8.0),
	(13, 12, 13, 'w', 'NONE', '3 kg', 4.75, 5.25, 5.75),
	(13, 14, 15, 'w', 'NONE', '3 kg', 5.5, 6.0, 6.5),
	(13, 16, 17, 'w', 'NONE', '3 kg', 5.75, 6.25, 6.75),
	(13, 18, 19, 'w', 'NONE', '4 kg', 6.5, 7.0, 7.5),
	(13, 20, 24, 'w', 'NONE', '4 kg', 6.5, 7.0, 7.5),
	(13, 25, 29, 'w', 'NONE', '4 kg', 6.5, 7.0, 7.5),
	(13, 30, 34, 'w', 'NONE', '4 kg', 6.25, 6.75, 7.25),
	(13, 35, 39, 'w', 'NONE', '4 kg', 6.0, 6.5, 7.0),
	(13, 40, 44, 'w', 'NONE', '4 kg', 5.5, 6.0, 6.5),
	(13, 45, 49, 'w', 'NONE', '4 kg', 5.25, 5.75, 6.25),
	(13, 50, 54, 'w', 'NONE', '3 kg', 5.25, 6.0, 7.0),
	(13, 55, 59, 'w', 'NONE', '3 kg', 5.0, 5.75, 6.5),
	(13, 60, 64, 'w', 'NONE', '3 kg', 4.75, 5.5, 6.25),
	(13, 65, 69, 'w', 'NONE', '3 kg', 4.5, 5.25, 6.15),
	(13, 70, 74, 'w', 'NONE', '3 kg', 4.25, 5.0, 6.0),
	(13, 75, 79, 'w', 'NONE', '2 kg', 4.25, 5.25, 6.25),
	(13, 80, 84, 'w', 'NONE', '2 kg', 4.0, 5.0, 5.75),
	(13, 85, 89, 'w', 'NONE', '2 kg', 3.75, 4.5, 5.5),
	(13, 90, 200, 'w', 'NONE', '2 kg', 3.25, 4.25, 5.0),
	(13, 12, 13, 'm', 'NONE', '3 kg', 6.25, 6.75, 7.25),
	(13, 14, 15, 'm', 'NONE', '4 kg', 7.0, 7.5, 8.0),
	(13, 16, 17, 'm', 'NONE', '5 kg', 7.5, 8.0, 8.5),
	(13, 18, 19, 'm', 'NONE', '6 kg', 7.75, 8.25, 8.75),
	(13, 20, 24, 'm', 'NONE', '7,26 kg', 7.75, 8.5, 9.0),
	(13, 25, 29, 'm', 'NONE', '7,26 kg', 7.5, 8.25, 8.75),
	(13, 30, 34, 'm', 'NONE', '7,26 kg', 7.0, 7.75, 8.25),
	(13, 35, 39, 'm', 'NONE', '7,26 kg', 6.75, 7.25, 8.0),
	(13, 40, 44, 'm', 'NONE', '7,26 kg', 6.25, 7.0, 7.75),
	(13, 45, 49, 'm', 'NONE', '7,26 kg', 6.0, 6.75, 7.5),
	(13, 50, 54, 'm', 'NONE', '6 kg', 6.25, 7.0, 8.0),
	(13, 55, 59, 'm', 'NONE', '6 kg', 6.0, 6.75, 7.5),
	(13, 60, 64, 'm', 'NONE', '5 kg', 6.0, 7.0, 8.0),
	(13, 65, 69, 'm', 'NONE', '5 kg', 5.75, 6.75, 7.5),
	(13, 70, 74, 'm', 'NONE', '4 kg', 6.0, 6.75, 7.75),
	(13, 75, 79, 'm', 'NONE', '4 kg', 5.75, 6.5, 7.5),
	(13, 80, 84, 'm', 'NONE', '3 kg', 5.5, 6.25, 7.25),
	(13, 85, 89, 'm', 'NONE', '3 kg', 5.0, 6.0, 6.75),
	(13, 90, 200, 'm', 'NONE', '3 kg', 4.5, 5.25, 6.25),
	(14, 18, 19, 'w', 'NONE', '5 kg', 10.65, 11.25, 11.85),
	(14, 20, 24, 'w', 'NONE', '5 kg', 10.8, 11.4, 12.0),
	(14, 25, 29, 'w', 'NONE', '5 kg', 10.1, 10.7, 11.35),
	(14, 30, 34, 'w', 'NONE', '5 kg', 9.5, 10.15, 10.7),
	(14, 35, 39, 'w', 'NONE', '5 kg', 9.0, 9.5, 10.2),
	(14, 40, 44, 'w', 'NONE', '5 kg', 8.6, 9.2, 9.85),
	(14, 45, 49, 'w', 'NONE', '5 kg', 8.3, 8.95, 9.7),
	(14, 50, 54, 'w', 'NONE', '3 kg', 9.8, 10.6, 11.4),
	(14, 55, 59, 'w', 'NONE', '3 kg', 9.4, 10.3, 11.1),
	(14, 60, 64, 'w', 'NONE', '3 kg', 9.05, 9.9, 10.7),
	(14, 65, 69, 'w', 'NONE', '3 kg', 8.5, 9.4, 10.2),
	(14, 70, 74, 'w', 'NONE', '3 kg', 7.9, 8.8, 9.6),
	(14, 75, 79, 'w', 'NONE', '3 kg', 7.4, 8.3, 9.1),
	(14, 80, 84, 'w', 'NONE', '3 kg', 6.9, 7.8, 8.6),
	(14, 85, 89, 'w', 'NONE', '3 kg', 6.45, 7.35, 8.15),
	(14, 90, 200, 'w', 'NONE', '3 kg', 6.1, 7.0, 7.8),
	(14, 18, 19, 'm', 'NONE', '10 kg', 9.3, 10.1, 10.95),
	(14, 20, 24, 'm', 'NONE', '15 kg', 7.7, 8.65, 9.55),
	(14, 25, 29, 'm', 'NONE', '15 kg', 7.45, 8.45, 9.45),
	(14, 30, 34, 'm', 'NONE', '15 kg', 7.1, 8.15, 9.15),
	(14, 35, 39, 'm', 'NONE', '15 kg', 6.75, 7.75, 8.8),
	(14, 40, 44, 'm', 'NONE', '15 kg', 6.1, 7.4, 8.65),
	(14, 45, 49, 'm', 'NONE', '15 kg', 5.5, 7.05, 8.6),
	(14, 50, 54, 'm', 'NONE', '10 kg', 7.95, 9.25, 10.55),
	(14, 55, 59, 'm', 'NONE', '10 kg', 7.75, 9.05, 10.35),
	(14, 60, 64, 'm', 'NONE', '7,5 kg', 7.65, 8.95, 10.25),
	(14, 65, 69, 'm', 'NONE', '7,5 kg', 7.25, 8.55, 9.85),
	(14, 70, 74, 'm', 'NONE', '5 kg', 9.4, 10.7, 12.0),
	(14, 75, 79, 'm', 'NONE', '5 kg', 9.2, 10.5, 11.8),
	(14, 80, 84, 'm', 'NONE', '3 kg', 9.0, 10.3, 11.6),
	(14, 85, 89, 'm', 'NONE', '3 kg', 8.8, 10.1, 11.4),
	(14, 90, 200, 'm', 'NONE', '3 kg', 8.4, 9.7, 11.0),
	(15, 0, 7, 'w', 'NONE', '', 1.05, 1.25, 1.4),
	(15, 8, 9, 'w', 'NONE', '', 1.15, 1.3, 1.5),
	(15, 10, 11, 'w', 'NONE', '', 1.3, 1.45, 1.65),
	(15, 12, 13, 'w', 'NONE', '', 1.4, 1.6, 1.8),
	(15, 14, 15, 'w', 'NONE', '', 1.55, 1.7, 1.9),
	(15, 16, 17, 'w', 'NONE', '', 1.65, 1.8, 2.0),
	(15, 18, 19, 'w', 'NONE', '', 1.65, 1.85, 2.05),
	(15, 20, 24, 'w', 'NONE', '', 1.6, 1.8, 2.0),
	(15, 25, 29, 'w', 'NONE', '', 1.5, 1.7, 1.95),
	(15, 30, 34, 'w', 'NONE', '', 1.35, 1.6, 1.85),
	(15, 35, 39, 'w', 'NONE', '', 1.25, 1.5, 1.8),
	(15, 40, 44, 'w', 'NONE', '', 1.15, 1.4, 1.65),
	(15, 45, 49, 'w', 'NONE', '', 1.1, 1.35, 1.6),
	(15, 50, 54, 'w', 'NONE', '', 1.0, 1.3, 1.55),
	(15, 55, 59, 'w', 'NONE', '', 0.95, 1.25, 1.5),
	(15, 60, 64, 'w', 'NONE', '', 0.95, 1.2, 1.45),
	(15, 65, 69, 'w', 'NONE', '', 0.9, 1.15, 1.4),
	(15, 70, 74, 'w', 'NONE', '', 0.9, 1.15, 1.35),
	(15, 75, 79, 'w', 'NONE', '', 0.9, 1.15, 1.35),
	(15, 80, 84, 'w', 'NONE', '', 0.85, 1.1, 1.3),
	(15, 85, 89, 'w', 'NONE', '', 0.85, 1.05, 1.25),
	(15, 90, 200, 'w', 'NONE', '', 0.8, 1.0, 1.2),
	(15, 0, 7, 'm', 'NONE', '', 1.15, 1.35, 1.5),
	(15, 8, 9, 'm', 'NONE', '', 1.3, 1.5, 1.65),
	(15, 10, 11, 'm', 'NONE', '', 1.5, 1.7, 1.85),
	(15, 12, 13, 'm', 'NONE', '', 1.7, 1.9, 2.05),
	(15, 14, 15, 'm', 'NONE', '', 1.9, 2.05, 2.25),
	(15, 16, 17, 'm', 'NONE', '', 2.05, 2.2, 2.4),
	(15, 18, 19, 'm', 'NONE', '', 2.1, 2.3, 2.5),
	(15, 20, 24, 'm', 'NONE', '', 2.1, 2.3, 2.5),
	(15, 25, 29, 'm', 'NONE', '', 2.05, 2.25, 2.45),
	(15, 30, 34, 'm', 'NONE', '', 1.85, 2.1, 2.35),
	(15, 35, 39, 'm', 'NONE', '', 1.65, 1.95, 2.25),
	(15, 40, 44, 'm', 'NONE', '', 1.55, 1.85, 2.15),
	(15, 45, 49, 'm', 'NONE', '', 1.45, 1.75, 2.05),
	(15, 50, 54, 'm', 'NONE', '', 1.4, 1.7, 2.0),
	(15, 55, 59, 'm', 'NONE', '', 1.35, 1.65, 1.95),
	(15, 60, 64, 'm', 'NONE', '', 1.3, 1.6, 1.9),
	(15, 65, 69, 'm', 'NONE', '', 1.3, 1.6, 1.9),
	(15, 70, 74, 'm', 'NONE', '', 1.25, 1.55, 1.85),
	(15, 75, 79, 'm', 'NONE', '', 1.2, 1.5, 1.8),
	(15, 80, 84, 'm', 'NONE', '', 1.15, 1.45, 1.75),
	(15, 85, 89, 'm', 'NONE', '', 1.0, 1.3, 1.6),
	(15, 90, 200, 'm', 'NONE', '', 0.9, 1.2, 1.5),
	(16, 0, 7, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 8, 9, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 10, 11, 'w', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 12, 13, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 14, 15, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 16, 17, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 18, 19, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 20, 24, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 25, 29, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 30, 34, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 35, 39, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 40, 44, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 45, 49, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 50, 54, 'w', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 55, 59, 'w', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 60, 64, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 65, 69, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 70, 74, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 75, 79, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 80, 84, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 85, 89, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 90, 200, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 0, 7, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 8, 9, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 10, 11, 'm', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 12, 13, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 14, 15, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 16, 17, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 18, 19, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 20, 24, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 25, 29, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 30, 34, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 35, 39, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 40, 44, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 45, 49, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(16, 50, 54, 'm', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 55, 59, 'm', 'NONE', 'Barren', 1.0, 2.0, 3.0),
	(16, 60, 64, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 65, 69, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 70, 74, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 75, 79, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 80, 84, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 85, 89, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(16, 90, 200, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(17, 0, 7, 'w', 'NONE', '30 m', 8.0, 7.1, 6.3),
	(17, 8, 9, 'w', 'NONE', '30 m', 7.4, 6.6, 5.7),
	(17, 10, 11, 'w', 'NONE', '50 m', 11.0, 10.1, 9.1),
	(17, 12, 13, 'w', 'NONE', '50 m', 10.6, 9.6, 8.5),
	(17, 14, 15, 'w', 'NONE', '100 m', 18.6, 17.0, 15.5),
	(17, 16, 17, 'w', 'NONE', '100 m', 17.6, 16.3, 15.0),
	(17, 18, 19, 'w', 'NONE', '100 m', 18.2, 16.5, 15.3),
	(17, 20, 24, 'w', 'NONE', '100 m', 18.5, 16.8, 15.6),
	(17, 25, 29, 'w', 'NONE', '100 m', 18.9, 17.2, 16.0),
	(17, 30, 34, 'w', 'NONE', '100 m', 19.6, 17.8, 16.4),
	(17, 35, 39, 'w', 'NONE', '100 m', 20.4, 18.6, 17.0),
	(17, 40, 44, 'w', 'NONE', '50 m', 11.0, 9.9, 8.8),
	(17, 45, 49, 'w', 'NONE', '50 m', 11.5, 10.3, 9.1),
	(17, 50, 54, 'w', 'NONE', '50 m', 11.9, 10.7, 9.5),
	(17, 55, 59, 'w', 'NONE', '50 m', 12.4, 11.2, 9.9),
	(17, 60, 64, 'w', 'NONE', '50 m', 12.6, 11.4, 10.2),
	(17, 65, 69, 'w', 'NONE', '50 m', 12.8, 11.6, 10.4),
	(17, 70, 74, 'w', 'NONE', '50 m', 13.0, 11.8, 10.6),
	(17, 75, 79, 'w', 'NONE', '50 m', 13.5, 12.3, 11.1),
	(17, 80, 84, 'w', 'NONE', '50 m', 14.3, 13.1, 12.0),
	(17, 85, 89, 'w', 'NONE', '50 m', 15.5, 14.3, 13.2),
	(17, 90, 200, 'w', 'NONE', '50 m', 17.1, 15.9, 14.8),
	(17, 0, 7, 'm', 'NONE', '30 m', 7.7, 6.8, 6.0),
	(17, 8, 9, 'm', 'NONE', '30 m', 7.2, 6.4, 5.7),
	(17, 10, 11, 'm', 'NONE', '50 m', 10.3, 9.3, 8.4),
	(17, 12, 13, 'm', 'NONE', '50 m', 9.7, 8.9, 8.1),
	(17, 14, 15, 'm', 'NONE', '100 m', 17.0, 15.4, 14.1),
	(17, 16, 17, 'm', 'NONE', '100 m', 16.3, 14.8, 13.5),
	(17, 18, 19, 'm', 'NONE', '100 m', 16.0, 14.6, 13.2),
	(17, 20, 24, 'm', 'NONE', '100 m', 15.8, 14.4, 13.0),
	(17, 25, 29, 'm', 'NONE', '100 m', 16.3, 14.8, 13.3),
	(17, 30, 34, 'm', 'NONE', '100 m', 16.8, 15.1, 13.6),
	(17, 35, 39, 'm', 'NONE', '100 m', 17.6, 15.9, 14.2),
	(17, 40, 44, 'm', 'NONE', '50 m', 9.6, 8.7, 7.7),
	(17, 45, 49, 'm', 'NONE', '50 m', 10.0, 8.9, 7.9),
	(17, 50, 54, 'm', 'NONE', '50 m', 10.3, 9.1, 8.2),
	(17, 55, 59, 'm', 'NONE', '50 m', 10.5, 9.4, 8.5),
	(17, 60, 64, 'm', 'NONE', '50 m', 10.8, 9.7, 8.8),
	(17, 65, 69, 'm', 'NONE', '50 m', 11.2, 10.2, 9.1),
	(17, 70, 74, 'm', 'NONE', '50 m', 11.7, 10.7, 9.6),
	(17, 75, 79, 'm', 'NONE', '50 m', 12.2, 11.2, 10.1),
	(17, 80, 84, 'm', 'NONE', '50 m', 13.0, 12.0, 10.9),
	(17, 85, 89, 'm', 'NONE', '50 m', 14.1, 13.1, 12.0),
	(17, 90, 200, 'm', 'NONE', '50 m', 15.5, 14.5, 13.4),
	(18, 0, 7, 'w', 'NONE', '', 46.5, 38.5, 30.5),
	(18, 8, 9, 'w', 'NONE', '', 42.0, 34.0, 28.0),
	(18, 10, 11, 'w', 'NONE', '', 39.0, 31.5, 25.5),
	(18, 12, 13, 'w', 'NONE', '', 35.0, 29.0, 23.5),
	(18, 14, 15, 'w', 'NONE', '', 33.0, 27.5, 21.5),
	(18, 16, 17, 'w', 'NONE', '', 30.5, 25.5, 20.0),
	(18, 18, 19, 'w', 'NONE', '', 29.5, 24.0, 18.5),
	(18, 20, 24, 'w', 'NONE', '', 29.0, 24.0, 18.5),
	(18, 25, 29, 'w', 'NONE', '', 30.0, 25.0, 19.5),
	(18, 30, 34, 'w', 'NONE', '', 32.5, 26.5, 21.0),
	(18, 35, 39, 'w', 'NONE', '', 36.0, 29.0, 22.0),
	(18, 40, 44, 'w', 'NONE', '', 40.0, 31.5, 23.5),
	(18, 45, 49, 'w', 'NONE', '', 44.0, 35.0, 25.0),
	(18, 50, 54, 'w', 'NONE', '', 48.0, 39.0, 28.0),
	(18, 55, 59, 'w', 'NONE', '', 51.5, 42.5, 30.5),
	(18, 60, 64, 'w', 'NONE', '', 54.5, 44.5, 32.5),
	(18, 65, 69, 'w', 'NONE', '', 56.5, 46.5, 34.5),
	(18, 70, 74, 'w', 'NONE', '', 59.0, 48.0, 36.0),
	(18, 75, 79, 'w', 'NONE', '', 61.0, 50.0, 38.0),
	(18, 80, 84, 'w', 'NONE', '', 63.5, 52.0, 40.0),
	(18, 85, 89, 'w', 'NONE', '', 65.5, 53.5, 41.5),
	(18, 90, 200, 'w', 'NONE', '', 66.5, 54.5, 42.5),
	(18, 0, 7, 'm', 'NONE', '', 46.0, 38.0, 30.0),
	(18, 8, 9, 'm', 'NONE', '', 41.0, 33.0, 26.0),
	(18, 10, 11, 'm', 'NONE', '', 36.0, 29.0, 22.5),
	(18, 12, 13, 'm', 'NONE', '', 33.0, 27.0, 21.0),
	(18, 14, 15, 'm', 'NONE', '', 31.0, 25.5, 20.0),
	(18, 16, 17, 'm', 'NONE', '', 29.5, 24.5, 19.0),
	(18, 18, 19, 'm', 'NONE', '', 28.0, 23.0, 17.5),
	(18, 20, 24, 'm', 'NONE', '', 27.0, 22.0, 15.5),
	(18, 25, 29, 'm', 'NONE', '', 29.0, 23.0, 16.5),
	(18, 30, 34, 'm', 'NONE', '', 31.5, 24.0, 17.0),
	(18, 35, 39, 'm', 'NONE', '', 35.0, 26.5, 18.5),
	(18, 40, 44, 'm', 'NONE', '', 38.5, 29.5, 19.0),
	(18, 45, 49, 'm', 'NONE', '', 42.0, 32.5, 20.5),
	(18, 50, 54, 'm', 'NONE', '', 45.0, 35.0, 23.0),
	(18, 55, 59, 'm', 'NONE', '', 49.0, 37.0, 25.0),
	(18, 60, 64, 'm', 'NONE', '', 51.0, 39.0, 27.0),
	(18, 65, 69, 'm', 'NONE', '', 52.5, 40.5, 28.5),
	(18, 70, 74, 'm', 'NONE', '', 55.0, 43.0, 31.0),
	(18, 75, 79, 'm', 'NONE', '', 57.5, 45.5, 33.5),
	(18, 80, 84, 'm', 'NONE', '', 59.0, 48.0, 36.0),
	(18, 85, 89, 'm', 'NONE', '', 59.5, 49.0, 38.0),
	(18, 90, 200, 'm', 'NONE', '', 60.0, 50.0, 40.0),
	(19, 8, 9, 'w', 'NONE', '', 41.0, 36.0, 31.0),
	(19, 10, 11, 'w', 'NONE', '', 37.0, 32.0, 27.0),
	(19, 12, 13, 'w', 'NONE', '', 31.0, 27.0, 23.5),
	(19, 14, 15, 'w', 'NONE', '', 27.0, 24.5, 21.5),
	(19, 16, 17, 'w', 'NONE', '', 25.0, 22.5, 20.0),
	(19, 18, 19, 'w', 'NONE', '', 24.0, 22.0, 19.5),
	(19, 20, 24, 'w', 'NONE', '', 24.5, 22.0, 19.5),
	(19, 25, 29, 'w', 'NONE', '', 25.0, 22.5, 20.0),
	(19, 30, 34, 'w', 'NONE', '', 26.0, 23.5, 21.5),
	(19, 35, 39, 'w', 'NONE', '', 27.5, 24.5, 22.0),
	(19, 40, 44, 'w', 'NONE', '', 29.0, 25.5, 22.5),
	(19, 45, 49, 'w', 'NONE', '', 30.5, 27.0, 23.0),
	(19, 50, 54, 'w', 'NONE', '', 32.0, 28.0, 23.5),
	(19, 55, 59, 'w', 'NONE', '', 33.5, 29.0, 24.0),
	(19, 60, 64, 'w', 'NONE', '', 35.0, 30.0, 25.0),
	(19, 65, 69, 'w', 'NONE', '', 36.0, 31.0, 25.5),
	(19, 70, 74, 'w', 'NONE', '', 38.0, 32.0, 26.5),
	(19, 75, 79, 'w', 'NONE', '', 39.0, 33.0, 27.5),
	(19, 80, 84, 'w', 'NONE', '', 40.5, 34.5, 28.5),
	(19, 85, 89, 'w', 'NONE', '', 42.0, 36.0, 30.0),
	(19, 90, 200, 'w', 'NONE', '', 44.5, 38.0, 31.5),
	(19, 8, 9, 'm', 'NONE', '', 38.0, 33.0, 28.0),
	(19, 10, 11, 'm', 'NONE', '', 35.0, 30.5, 26.0),
	(19, 12, 13, 'm', 'NONE', '', 29.5, 26.0, 22.5),
	(19, 14, 15, 'm', 'NONE', '', 24.0, 21.5, 19.0),
	(19, 16, 17, 'm', 'NONE', '', 22.0, 19.5, 17.0),
	(19, 18, 19, 'm', 'NONE', '', 20.5, 18.0, 15.5),
	(19, 20, 24, 'm', 'NONE', '', 20.0, 17.5, 15.0),
	(19, 25, 29, 'm', 'NONE', '', 21.0, 18.0, 15.0),
	(19, 30, 34, 'm', 'NONE', '', 22.5, 18.5, 15.0),
	(19, 35, 39, 'm', 'NONE', '', 24.0, 20.0, 15.5),
	(19, 40, 44, 'm', 'NONE', '', 26.5, 21.5, 16.5),
	(19, 45, 49, 'm', 'NONE', '', 28.5, 23.0, 17.0),
	(19, 50, 54, 'm', 'NONE', '', 30.0, 24.0, 18.0),
	(19, 55, 59, 'm', 'NONE', '', 32.0, 25.0, 18.5),
	(19, 60, 64, 'm', 'NONE', '', 33.5, 26.0, 19.0),
	(19, 65, 69, 'm', 'NONE', '', 35.0, 27.0, 19.5),
	(19, 70, 74, 'm', 'NONE', '', 36.0, 28.5, 20.0),
	(19, 75, 79, 'm', 'NONE', '', 37.5, 29.5, 21.5),
	(19, 80, 84, 'm', 'NONE', '', 39.0, 31.5, 23.0),
	(19, 85, 89, 'm', 'NONE', '', 41.0, 33.0, 24.5),
	(19, 90, 200, 'm', 'NONE', '', 43.5, 35.5, 27.0),
	(20, 0, 7, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 8, 9, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 10, 11, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 12, 13, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 14, 15, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 16, 17, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 18, 19, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 20, 24, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 25, 29, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 30, 34, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 35, 39, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 40, 44, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 45, 49, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 50, 54, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 55, 59, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 60, 64, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 65, 69, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 70, 74, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 75, 79, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 80, 84, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 85, 89, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 90, 200, 'w', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 0, 7, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 8, 9, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 10, 11, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 12, 13, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 14, 15, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 16, 17, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 18, 19, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 20, 24, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 25, 29, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 30, 34, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 35, 39, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 40, 44, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 45, 49, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 50, 54, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 55, 59, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 60, 64, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 65, 69, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(20, 70, 74, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 75, 79, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 80, 84, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 85, 89, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(20, 90, 200, 'm', 'NONE', 'Sprung', 1.0, 2.0, 3.0),
	(21, 10, 11, 'w', 'NONE', '', 0.8, 0.9, 1.0),
	(21, 12, 13, 'w', 'NONE', '', 0.9, 1.0, 1.1),
	(21, 14, 15, 'w', 'NONE', '', 0.95, 1.05, 1.15),
	(21, 16, 17, 'w', 'NONE', '', 1.05, 1.15, 1.25),
	(21, 18, 19, 'w', 'NONE', '', 1.1, 1.2, 1.3),
	(21, 20, 24, 'w', 'NONE', '', 1.1, 1.2, 1.3),
	(21, 25, 29, 'w', 'NONE', '', 1.05, 1.15, 1.25),
	(21, 30, 34, 'w', 'NONE', '', 1.0, 1.1, 1.2),
	(21, 35, 39, 'w', 'NONE', '', 0.95, 1.05, 1.15),
	(21, 40, 44, 'w', 'NONE', '', 0.9, 1.0, 1.1),
	(21, 45, 49, 'w', 'NONE', '', 0.9, 1.0, 1.1),
	(21, 50, 54, 'w', 'NONE', '', 0.85, 0.95, 1.05),
	(21, 55, 59, 'w', 'NONE', '', 0.8, 0.9, 1.0),
	(21, 60, 64, 'w', 'NONE', '', 0.75, 0.85, 0.95),
	(21, 65, 69, 'w', 'NONE', '', 0.75, 0.85, 0.95),
	(21, 70, 74, 'w', 'NONE', '', 0.7, 0.8, 0.9),
	(21, 75, 79, 'w', 'NONE', '', 0.65, 0.75, 0.85),
	(21, 80, 84, 'w', 'NONE', '', 0.65, 0.75, 0.85),
	(21, 85, 89, 'w', 'NONE', '', 0.6, 0.7, 0.8),
	(21, 90, 200, 'w', 'NONE', '', 0.55, 0.6, 0.65),
	(21, 10, 11, 'm', 'NONE', '', 0.85, 0.95, 1.05),
	(21, 12, 13, 'm', 'NONE', '', 0.95, 1.05, 1.15),
	(21, 14, 15, 'm', 'NONE', '', 1.1, 1.2, 1.3),
	(21, 16, 17, 'm', 'NONE', '', 1.2, 1.3, 1.4),
	(21, 18, 19, 'm', 'NONE', '', 1.3, 1.4, 1.5),
	(21, 20, 24, 'm', 'NONE', '', 1.35, 1.45, 1.55),
	(21, 25, 29, 'm', 'NONE', '', 1.3, 1.4, 1.5),
	(21, 30, 34, 'm', 'NONE', '', 1.3, 1.4, 1.5),
	(21, 35, 39, 'm', 'NONE', '', 1.25, 1.35, 1.45),
	(21, 40, 44, 'm', 'NONE', '', 1.2, 1.3, 1.4),
	(21, 45, 49, 'm', 'NONE', '', 1.15, 1.25, 1.35),
	(21, 50, 54, 'm', 'NONE', '', 1.05, 1.15, 1.25),
	(21, 55, 59, 'm', 'NONE', '', 1.0, 1.1, 1.2),
	(21, 60, 64, 'm', 'NONE', '', 0.95, 1.05, 1.15),
	(21, 65, 69, 'm', 'NONE', '', 0.85, 1.0, 1.1),
	(21, 70, 74, 'm', 'NONE', '', 0.8, 0.95, 1.05),
	(21, 75, 79, 'm', 'NONE', '', 0.75, 0.9, 1.0),
	(21, 80, 84, 'm', 'NONE', '', 0.75, 0.85, 0.95),
	(21, 85, 89, 'm', 'NONE', '', 0.7, 0.8, 0.9),
	(21, 90, 200, 'm', 'NONE', '', 0.65, 0.75, 0.85),
	(22, 0, 7, 'w', 'NONE', '', 18.0, 21.0, 24.0),
	(22, 8, 9, 'w', 'NONE', '', 24.0, 27.0, 30.0),
	(22, 0, 7, 'm', 'NONE', '', 18.0, 21.0, 24.0),
	(22, 8, 9, 'm', 'NONE', '', 27.0, 30.0, 33.0),
	(23, 10, 11, 'w', 'NONE', '', 2.3, 2.6, 2.9),
	(23, 12, 13, 'w', 'NONE', '', 2.8, 3.1, 3.4),
	(23, 14, 15, 'w', 'NONE', '', 3.2, 3.5, 3.8),
	(23, 16, 17, 'w', 'NONE', '', 3.4, 3.7, 4.0),
	(23, 18, 19, 'w', 'NONE', '', 3.4, 3.7, 4.0),
	(23, 20, 24, 'w', 'NONE', '', 3.4, 3.7, 4.0),
	(23, 25, 29, 'w', 'NONE', '', 3.3, 3.6, 3.9),
	(23, 30, 34, 'w', 'NONE', '', 3.2, 3.5, 3.8),
	(23, 35, 39, 'w', 'NONE', '', 3.1, 3.4, 3.7),
	(23, 40, 44, 'w', 'NONE', '', 3.0, 3.3, 3.6),
	(23, 45, 49, 'w', 'NONE', '', 2.8, 3.2, 3.5),
	(23, 50, 54, 'w', 'NONE', '', 2.6, 3.0, 3.4),
	(23, 55, 59, 'w', 'NONE', '', 2.5, 2.9, 3.3),
	(23, 60, 64, 'w', 'NONE', '', 2.4, 2.8, 3.2),
	(23, 65, 69, 'w', 'NONE', '', 2.3, 2.7, 3.1),
	(23, 70, 74, 'w', 'NONE', '', 2.1, 2.5, 2.9),
	(23, 75, 79, 'w', 'NONE', '', 1.8, 2.2, 2.6),
	(23, 80, 84, 'w', 'NONE', '', 1.6, 2.0, 2.4),
	(23, 85, 89, 'w', 'NONE', '', 1.3, 1.7, 2.1),
	(23, 90, 200, 'w', 'NONE', '', 1.1, 1.5, 1.9),
	(23, 10, 11, 'm', 'NONE', '', 2.6, 2.9, 3.2),
	(23, 12, 13, 'm', 'NONE', '', 3.2, 3.5, 3.8),
	(23, 14, 15, 'm', 'NONE', '', 3.8, 4.1, 4.4),
	(23, 16, 17, 'm', 'NONE', '', 4.3, 4.6, 4.9),
	(23, 18, 19, 'm', 'NONE', '', 4.5, 4.8, 5.1),
	(23, 20, 24, 'm', 'NONE', '', 4.4, 4.7, 5.0),
	(23, 25, 29, 'm', 'NONE', '', 4.3, 4.6, 4.9),
	(23, 30, 34, 'm', 'NONE', '', 4.2, 4.5, 4.8),
	(23, 35, 39, 'm', 'NONE', '', 4.1, 4.4, 4.7),
	(23, 40, 44, 'm', 'NONE', '', 3.9, 4.3, 4.6),
	(23, 45, 49, 'm', 'NONE', '', 3.7, 4.1, 4.5),
	(23, 50, 54, 'm', 'NONE', '', 3.6, 4.0, 4.4),
	(23, 55, 59, 'm', 'NONE', '', 3.4, 3.8, 4.2),
	(23, 60, 64, 'm', 'NONE', '', 3.2, 3.6, 4.0),
	(23, 65, 69, 'm', 'NONE', '', 2.9, 3.3, 3.7),
	(23, 70, 74, 'm', 'NONE', '', 2.7, 3.1, 3.5),
	(23, 75, 79, 'm', 'NONE', '', 2.4, 2.9, 3.3),
	(23, 80, 84, 'm', 'NONE', '', 2.1, 2.6, 3.1),
	(23, 85, 89, 'm', 'NONE', '', 1.9, 2.4, 2.9),
	(23, 90, 200, 'm', 'NONE', '', 1.6, 2.1, 2.6),
	(25, 12, 13, 'w', 'NONE', '', 17.0, 19.5, 22.0),
	(25, 14, 15, 'w', 'NONE', '', 19.5, 22.5, 25.5),
	(25, 16, 17, 'w', 'NONE', '', 22.0, 25.0, 28.0),
	(25, 18, 19, 'w', 'NONE', '', 23.5, 26.5, 29.0),
	(25, 20, 24, 'w', 'NONE', '', 24.0, 27.0, 29.5),
	(25, 25, 29, 'w', 'NONE', '', 24.0, 27.0, 29.5),
	(25, 30, 34, 'w', 'NONE', '', 22.0, 25.0, 27.5),
	(25, 35, 39, 'w', 'NONE', '', 21.0, 24.0, 26.5),
	(25, 40, 44, 'w', 'NONE', '', 19.5, 22.5, 25.0),
	(25, 45, 49, 'w', 'NONE', '', 18.5, 21.5, 24.0),
	(25, 50, 54, 'w', 'NONE', '', 16.5, 20.0, 23.0),
	(25, 55, 59, 'w', 'NONE', '', 15.5, 19.0, 22.0),
	(25, 60, 64, 'w', 'NONE', '', 14.5, 18.0, 21.0),
	(25, 65, 69, 'w', 'NONE', '', 13.5, 17.0, 20.0),
	(25, 70, 74, 'w', 'NONE', '', 13.0, 16.5, 19.5),
	(25, 75, 79, 'w', 'NONE', '', 12.0, 15.5, 18.5),
	(25, 80, 84, 'w', 'NONE', '', 11.0, 14.5, 17.5),
	(25, 85, 89, 'w', 'NONE', '', 9.5, 13.0, 16.0),
	(25, 90, 200, 'w', 'NONE', '', 7.5, 11.0, 14.0),
	(25, 12, 13, 'm', 'NONE', '', 19.5, 24.0, 27.5),
	(25, 14, 15, 'm', 'NONE', '', 23.5, 28.0, 32.0),
	(25, 16, 17, 'm', 'NONE', '', 27.5, 32.0, 36.5),
	(25, 18, 19, 'm', 'NONE', '', 31.5, 36.0, 40.5),
	(25, 20, 24, 'm', 'NONE', '', 33.0, 38.0, 42.0),
	(25, 25, 29, 'm', 'NONE', '', 32.5, 37.5, 41.5),
	(25, 30, 34, 'm', 'NONE', '', 30.0, 35.0, 40.0),
	(25, 35, 39, 'm', 'NONE', '', 28.5, 33.5, 38.5),
	(25, 40, 44, 'm', 'NONE', '', 28.0, 33.0, 38.0),
	(25, 45, 49, 'm', 'NONE', '', 27.0, 32.0, 37.5),
	(25, 50, 54, 'm', 'NONE', '', 25.5, 31.0, 36.5),
	(25, 55, 59, 'm', 'NONE', '', 23.5, 29.0, 35.0),
	(25, 60, 64, 'm', 'NONE', '', 22.5, 28.0, 34.0),
	(25, 65, 69, 'm', 'NONE', '', 20.0, 25.5, 30.5),
	(25, 70, 74, 'm', 'NONE', '', 18.5, 24.0, 29.0),
	(25, 75, 79, 'm', 'NONE', '', 16.0, 21.0, 26.0),
	(25, 80, 84, 'm', 'NONE', '', 14.0, 19.0, 24.0),
	(25, 85, 89, 'm', 'NONE', '', 12.0, 16.5, 21.0),
	(25, 90, 200, 'm', 'NONE', '', 10.5, 15.0, 19.5),
	(26, 0, 7, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 10.0, 15.0, 25.0),
	(26, 8, 9, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 10.0, 15.0, 25.0),
	(26, 10, 11, 'w', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 20.0, 30.0, 40.0),
	(26, 12, 13, 'w', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 14, 15, 'w', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 16, 17, 'w', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 18, 19, 'w', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 20, 24, 'w', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 25, 29, 'w', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 30, 34, 'w', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 35, 39, 'w', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 40, 44, 'w', 'NONE', 'Laufschritt ohne Zwischensprung', 40.0, 60.0, 80.0),
	(26, 45, 49, 'w', 'NONE', 'Laufschritt ohne Zwischensprung', 40.0, 60.0, 80.0),
	(26, 50, 54, 'w', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 55, 59, 'w', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 60, 64, 'w', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 65, 69, 'w', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 70, 74, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 8.0, 14.0, 18.0),
	(26, 75, 79, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 8.0, 14.0, 18.0),
	(26, 80, 84, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 6.0, 10.0, 12.0),
	(26, 85, 89, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 6.0, 10.0, 12.0),
	(26, 90, 200, 'w', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 4.0, 6.0, 8.0),
	(26, 0, 7, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 10.0, 15.0, 25.0),
	(26, 8, 9, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 10.0, 15.0, 25.0),
	(26, 10, 11, 'm', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 20.0, 30.0, 40.0),
	(26, 12, 13, 'm', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 14, 15, 'm', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 16, 17, 'm', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 18, 19, 'm', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 20, 24, 'm', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 25, 29, 'm', 'NONE', 'Doppeldurchschlag', 5.0, 10.0, 15.0),
	(26, 30, 34, 'm', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 35, 39, 'm', 'NONE', 'Kreuzdurchschlag ohne Zwischensprung', 10.0, 15.0, 20.0),
	(26, 40, 44, 'm', 'NONE', 'Laufschritt ohne Zwischensprung', 40.0, 60.0, 80.0),
	(26, 45, 49, 'm', 'NONE', 'Laufschritt ohne Zwischensprung', 40.0, 60.0, 80.0),
	(26, 50, 54, 'm', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 55, 59, 'm', 'NONE', 'Grundsprung rückwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 60, 64, 'm', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 65, 69, 'm', 'NONE', 'Grundsprung vorwärts ohne Zwischensprung', 10.0, 20.0, 30.0),
	(26, 70, 74, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 8.0, 14.0, 18.0),
	(26, 75, 79, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 8.0, 14.0, 18.0),
	(26, 80, 84, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 6.0, 10.0, 12.0),
	(26, 85, 89, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 6.0, 10.0, 12.0),
	(26, 90, 200, 'm', 'NONE', 'Grundsprung vorwärts oder Galoppschritt', 4.0, 6.0, 8.0),
	(27, 0, 7, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 8, 9, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 10, 11, 'w', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 12, 13, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 14, 15, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 16, 17, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 18, 19, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 20, 24, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 25, 29, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 30, 34, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 35, 39, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 40, 44, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 45, 49, 'w', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 50, 54, 'w', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 55, 59, 'w', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 60, 64, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 65, 69, 'w', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 70, 74, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 75, 79, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 80, 84, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 85, 89, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 90, 200, 'w', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 0, 7, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 8, 9, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 10, 11, 'm', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 12, 13, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 14, 15, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 16, 17, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 18, 19, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 20, 24, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 25, 29, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 30, 34, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 35, 39, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 40, 44, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 45, 49, 'm', 'NONE', 'Boden', 1.0, 2.0, 3.0),
	(27, 50, 54, 'm', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 55, 59, 'm', 'NONE', 'Ringe', 1.0, 2.0, 3.0),
	(27, 60, 64, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 65, 69, 'm', 'NONE', 'Reck', 1.0, 2.0, 3.0),
	(27, 70, 74, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 75, 79, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 80, 84, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 85, 89, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(27, 90, 200, 'm', 'NONE', 'Schwebebalken', 1.0, 2.0, 3.0),
	(57, 0, 7, 'w', 'NONE', '', 12.0, 15.0, 21.0),
	(57, 8, 9, 'w', 'NONE', '', 18.0, 21.0, 27.0),
	(57, 10, 11, 'w', 'NONE', '', 27.0, 30.0, 36.0),
	(57, 0, 7, 'm', 'NONE', '', 15.0, 18.0, 24.0),
	(57, 8, 9, 'm', 'NONE', '', 21.0, 27.0, 33.0),
	(57, 10, 11, 'm', 'NONE', '', 33.0, 39.0, 45.0),
	(61, 18, 19, 'w', 'NONE', '', 8.0, 12.0, 17.0),
	(61, 20, 24, 'w', 'NONE', '', 8.0, 11.0, 17.0),
	(61, 25, 29, 'w', 'NONE', '', 8.0, 11.0, 16.0),
	(61, 30, 34, 'w', 'NONE', '', 7.0, 10.0, 16.0),
	(61, 35, 39, 'w', 'NONE', '', 7.0, 10.0, 15.0),
	(61, 40, 44, 'w', 'NONE', '', 6.0, 9.0, 14.0),
	(61, 45, 49, 'w', 'NONE', '', 6.0, 9.0, 14.0),
	(61, 50, 54, 'w', 'NONE', '', 5.0, 8.0, 13.0),
	(61, 55, 59, 'w', 'NONE', '', 5.0, 8.0, 12.0),
	(61, 60, 64, 'w', 'NONE', '', 5.0, 8.0, 12.0),
	(61, 65, 69, 'w', 'NONE', '', 4.0, 7.0, 12.0),
	(61, 70, 74, 'w', 'NONE', '', 4.0, 7.0, 11.0),
	(61, 75, 79, 'w', 'NONE', '', 4.0, 7.0, 11.0),
	(61, 80, 84, 'w', 'NONE', '', 3.0, 7.0, 10.0),
	(61, 85, 89, 'w', 'NONE', '', 3.0, 6.0, 10.0),
	(61, 90, 200, 'w', 'NONE', '', 3.0, 5.0, 8.0),
	(61, 18, 19, 'm', 'NONE', '', 23.0, 33.0, 47.0),
	(61, 20, 24, 'm', 'NONE', '', 23.0, 33.0, 47.0),
	(61, 25, 29, 'm', 'NONE', '', 22.0, 32.0, 46.0),
	(61, 30, 34, 'm', 'NONE', '', 21.0, 31.0, 44.0),
	(61, 35, 39, 'm', 'NONE', '', 19.0, 29.0, 42.0),
	(61, 40, 44, 'm', 'NONE', '', 17.0, 26.0, 39.0),
	(61, 45, 49, 'm', 'NONE', '', 15.0, 24.0, 35.0),
	(61, 50, 54, 'm', 'NONE', '', 13.0, 22.0, 33.0),
	(61, 55, 59, 'm', 'NONE', '', 11.0, 19.0, 29.0),
	(61, 60, 64, 'm', 'NONE', '', 10.0, 18.0, 27.0),
	(61, 65, 69, 'm', 'NONE', '', 9.0, 17.0, 26.0),
	(61, 70, 74, 'm', 'NONE', '', 9.0, 16.0, 25.0),
	(61, 75, 79, 'm', 'NONE', '', 9.0, 16.0, 25.0),
	(61, 80, 84, 'm', 'NONE', '', 7.0, 14.0, 23.0),
	(61, 85, 89, 'm', 'NONE', '', 7.0, 12.0, 21.0),
	(61, 90, 200, 'm', 'NONE', '', 6.0, 11.0, 20.0),
	(62, 18, 19, 'w', 'NONE', '', 32.0, 41.0, 52.0),
	(62, 20, 24, 'w', 'NONE', '', 32.0, 41.0, 53.0),
	(62, 25, 29, 'w', 'NONE', '', 31.0, 41.0, 52.0),
	(62, 30, 34, 'w', 'NONE', '', 29.0, 39.0, 50.0),
	(62, 35, 39, 'w', 'NONE', '', 27.0, 37.0, 48.0),
	(62, 40, 44, 'w', 'NONE', '', 24.0, 34.0, 45.0),
	(62, 45, 49, 'w', 'NONE', '', 22.0, 31.0, 41.0),
	(62, 50, 54, 'w', 'NONE', '', 19.0, 28.0, 38.0),
	(62, 55, 59, 'w', 'NONE', '', 16.0, 25.0, 35.0),
	(62, 60, 64, 'w', 'NONE', '', 13.0, 22.0, 32.0),
	(62, 65, 69, 'w', 'NONE', '', 11.0, 20.0, 30.0),
	(62, 70, 74, 'w', 'NONE', '', 10.0, 18.0, 28.0),
	(62, 75, 79, 'w', 'NONE', '', 9.0, 18.0, 28.0),
	(62, 80, 84, 'w', 'NONE', '', 8.0, 16.0, 26.0),
	(62, 85, 89, 'w', 'NONE', '', 7.0, 14.0, 24.0),
	(62, 90, 200, 'w', 'NONE', '', 5.0, 12.0, 23.0),
	(62, 18, 19, 'm', 'NONE', '', 38.0, 49.0, 62.0),
	(62, 20, 24, 'm', 'NONE', '', 37.0, 48.0, 62.0),
	(62, 25, 29, 'm', 'NONE', '', 36.0, 47.0, 61.0),
	(62, 30, 34, 'm', 'NONE', '', 34.0, 46.0, 59.0),
	(62, 35, 39, 'm', 'NONE', '', 32.0, 43.0, 57.0),
	(62, 40, 44, 'm', 'NONE', '', 29.0, 41.0, 54.0),
	(62, 45, 49, 'm', 'NONE', '', 27.0, 38.0, 51.0),
	(62, 50, 54, 'm', 'NONE', '', 24.0, 35.0, 48.0),
	(62, 55, 59, 'm', 'NONE', '', 21.0, 32.0, 45.0),
	(62, 60, 64, 'm', 'NONE', '', 18.0, 29.0, 42.0),
	(62, 65, 69, 'm', 'NONE', '', 15.0, 26.0, 39.0),
	(62, 70, 74, 'm', 'NONE', '', 12.0, 23.0, 36.0),
	(62, 75, 79, 'm', 'NONE', '', 10.0, 20.0, 33.0),
	(62, 80, 84, 'm', 'NONE', '', 7.0, 18.0, 31.0),
	(62, 85, 89, 'm', 'NONE', '', 5.0, 16.0, 29.0),
	(62, 90, 200, 'm', 'NONE', '', 3.0, 14.0, 27.0),
	(63, 18, 19, 'w', 'NONE', '', 16.0, 21.0, 27.0),
	(63, 20, 24, 'w', 'NONE', '', 16.0, 21.0, 27.0),
	(63, 25, 29, 'w', 'NONE', '', 15.0, 20.0, 27.0),
	(63, 30, 34, 'w', 'NONE', '', 14.0, 20.0, 26.0),
	(63, 35, 39, 'w', 'NONE', '', 13.0, 19.0, 25.0),
	(63, 40, 44, 'w', 'NONE', '', 12.0, 18.0, 24.0),
	(63, 45, 49, 'w', 'NONE', '', 11.0, 17.0, 23.0),
	(63, 50, 54, 'w', 'NONE', '', 10.0, 15.0, 21.0),
	(63, 55, 59, 'w', 'NONE', '', 9.0, 14.0, 20.0),
	(63, 60, 64, 'w', 'NONE', '', 8.0, 13.0, 19.0),
	(63, 65, 69, 'w', 'NONE', '', 7.0, 12.0, 18.0),
	(63, 70, 74, 'w', 'NONE', '', 6.0, 11.0, 17.0),
	(63, 75, 79, 'w', 'NONE', '', 5.0, 10.0, 16.0),
	(63, 80, 84, 'w', 'NONE', '', 4.0, 9.0, 15.0),
	(63, 85, 89, 'w', 'NONE', '', 3.0, 8.0, 14.0),
	(63, 90, 200, 'w', 'NONE', '', 3.0, 7.0, 13.0),
	(63, 18, 19, 'm', 'NONE', '', 29.0, 38.0, 49.0),
	(63, 20, 24, 'm', 'NONE', '', 29.0, 39.0, 50.0),
	(63, 25, 29, 'm', 'NONE', '', 28.0, 38.0, 50.0),
	(63, 30, 34, 'm', 'NONE', '', 27.0, 37.0, 48.0),
	(63, 35, 39, 'm', 'NONE', '', 25.0, 35.0, 46.0),
	(63, 40, 44, 'm', 'NONE', '', 22.0, 32.0, 44.0),
	(63, 45, 49, 'm', 'NONE', '', 20.0, 29.0, 41.0),
	(63, 50, 54, 'm', 'NONE', '', 17.0, 27.0, 38.0),
	(63, 55, 59, 'm', 'NONE', '', 14.0, 24.0, 35.0),
	(63, 60, 64, 'm', 'NONE', '', 12.0, 21.0, 32.0),
	(63, 65, 69, 'm', 'NONE', '', 10.0, 19.0, 30.0),
	(63, 70, 74, 'm', 'NONE', '', 9.0, 18.0, 29.0),
	(63, 75, 79, 'm', 'NONE', '', 8.0, 16.0, 27.0),
	(63, 80, 84, 'm', 'NONE', '', 7.0, 15.0, 25.0),
	(63, 85, 89, 'm', 'NONE', '', 6.0, 13.0, 22.0),
	(63, 90, 200, 'm', 'NONE', '', 5.0, 10.0, 19.0),
	(64, 18, 19, 'w', 'NONE', '', 1.0, 3.0, 6.0),
	(64, 20, 24, 'w', 'NONE', '', 1.0, 4.0, 6.0),
	(64, 25, 29, 'w', 'NONE', '', 1.0, 4.0, 6.0),
	(64, 30, 34, 'w', 'NONE', '', 1.0, 4.0, 6.0),
	(64, 35, 39, 'w', 'NONE', '', 1.0, 3.0, 6.0),
	(64, 40, 44, 'w', 'NONE', '', 1.0, 3.0, 6.0),
	(64, 45, 49, 'w', 'NONE', '', 1.0, 2.0, 5.0),
	(64, 50, 54, 'w', 'NONE', '', 1.0, 2.0, 5.0),
	(64, 55, 59, 'w', 'NONE', '', 1.0, 2.0, 4.0),
	(64, 60, 64, 'w', 'NONE', '', 1.0, 2.0, 4.0),
	(64, 65, 69, 'w', 'NONE', '', 1.0, 2.0, 4.0),
	(64, 70, 74, 'w', 'NONE', '', 1.0, 2.0, 4.0),
	(64, 75, 79, 'w', 'NONE', '', 1.0, 2.0, 3.0),
	(64, 80, 84, 'w', 'NONE', '', 1.0, 2.0, 3.0),
	(64, 85, 89, 'w', 'NONE', '', null, 1.0, 2.0),
	(64, 90, 200, 'w', 'NONE', '', null, 1.0, 2.0),
	(64, 18, 19, 'm', 'NONE', '', 5.0, 11.0, 15.0),
	(64, 20, 24, 'm', 'NONE', '', 5.0, 12.0, 16.0),
	(64, 25, 29, 'm', 'NONE', '', 5.0, 12.0, 16.0),
	(64, 30, 34, 'm', 'NONE', '', 5.0, 11.0, 15.0),
	(64, 35, 39, 'm', 'NONE', '', 4.0, 10.0, 14.0),
	(64, 40, 44, 'm', 'NONE', '', 2.0, 9.0, 13.0),
	(64, 45, 49, 'm', 'NONE', '', 1.0, 7.0, 11.0),
	(64, 50, 54, 'm', 'NONE', '', 1.0, 6.0, 10.0),
	(64, 55, 59, 'm', 'NONE', '', 1.0, 4.0, 9.0),
	(64, 60, 64, 'm', 'NONE', '', 1.0, 4.0, 8.0),
	(64, 65, 69, 'm', 'NONE', '', 1.0, 3.0, 8.0),
	(64, 70, 74, 'm', 'NONE', '', 1.0, 3.0, 7.0),
	(64, 75, 79, 'm', 'NONE', '', 1.0, 2.0, 6.0),
	(64, 80, 84, 'm', 'NONE', '', 1.0, 2.0, 5.0),
	(64, 85, 89, 'm', 'NONE', '', null, 1.0, 3.0),
	(64, 90, 200, 'm', 'NONE', '', null, 1.0, 3.0)
;

INSERT INTO Verbandsabzeichen(AName, Abkuerzung, DGNr, Schwimm) VALUES
	('Deutsches Radsportabzeichen ab Silber', 'Deutsches Radsportabzeichen ab Silber', 1, false),
    ('Deutsches Schwimmabzeichen Gold', 'Deutsches Schwimmabzeichen Gold', 1, true),
	('Deutscher Rettungsschwimmpass', 'Deutscher Rettungsschwimmpass', 1, true),
	('Junior-Retter', 'Junior-Retter', 1, true),
    ('Jugendfahrtenabzeichen', 'Jugendfahrtenabzeichen', 1, false),
	('Fahrtenabzeichen für Erwachsene', 'Fahrtenabzeichen für Erwachsene', 1, false),
	('Deutsches Duathlonabzeichen', 'Deutsches Duathlonabzeichen', 1, false),
	('Deutsches Triathlonabzeichen', 'Deutsches Triathlonabzeichen', 1, true),
	('Deutsches Triathlon Jugendabzeichen', 'Deutsches Triathlon Jugendabzeichen', 1, false),
    ('Laufabzeichen Stufe 4-5', 'Laufabzeichen Stufe 4-5', 1, false),
	('Marathonabzeichen', 'Marathonabzeichen', 1, false),
	('Walking-/Nordic Walking-Abzeichen Stufe 3', 'Walking-/Nordic Walking-Abzeichen Stufe 3', 1, false),
	('Deutsches Fünfkampfabzeichen', 'Deutsches Fünfkampfabzeichen', 1, true),
	('Leistungsabzeichen Flossenschwimmen', 'Leistungsabzeichen Flossenschwimmen', 1, false),
	('Wanderfahrerabzeichen', 'Wanderfahrerabzeichen', 1, false),
	('Skate-Abzeichen ab Stufe 3', 'Skate-Abzeichen Stufe 3', 1, false),
    ('Skate-Abzeichen ab Stufe 5', 'Skate-Abzeichen Stufe 5', 1, false),
    ('Langhantel-Leistungsabzeichen', 'Langhantel-Leistungsabzeichen', 2, false),
    ('Segelflug Leistungsabzeichen ab Silber', 'Segelflug Leistungsabzeichen ab Silber', 4, false),
	('Badminton Spielabzeichen(6-17jährige) Gold', 'Badminton Spielabzeichen(6-17jährige) Gold', 4, false),
	('Badminton Sportabzeichen(Erwachsene) Gold', 'Badminton Sportabzeichen(Erwachsene) Gold', 4, false),
	('Fußball-Abzeichen ab Silber', 'Fußball-Abzeichen ab Silber', 4, false),
	('Schnupper-Abzeichen ab Silber', 'Schnupper-Abzeichen ab Silber', 4, false),
	('Schulfußball-Abzeichen ab Silber', 'Schulfußball-Abzeichen ab Silber', 4, false),
	('Schulfußball-Schnupper-Abzeichen ab Silber', 'Schulfußball-Schnupper-Abzeichen ab Silber', 4, false),
	('Kindergolfabzeichen', 'Kindergolfabzeichen', 4, false),
	('JJ-Jugendsportabzeichen', 'JJ-Jugendsportabzeichen', 4, false),
	('DJJV-Sportabzeichen', 'DJJV-Sportabzeichen', 4, false),
	('Judo-Abzeichen', 'Judo-Abzeichen', 4, false),
    ('Bundeskegelsportabzeichen Gold', 'Bundeskegelsportabzeichen Gold', 4, false),
	('Kinderleichtathletik-Abzeichen Stufe II', 'Kinderleichtathletik-Abzeichen Stufe II', 4, false),
    ('Mehrkampfabzeichen', 'Mehrkampfabzeichen', 4, false),
	('Minigolfsportabzeichen Stufe Gold', 'Minigolfsportabzeichen Stufe Gold', 4, false),
	('Boule-Sportabzeichen', 'Boule-Sportabzeichen', 4, false),
	('Reitabzeichen 5 (RA 5)', 'Deutsches Reitabzeichen', 4, false),
	('FN-Sportabzeichen Reiten', 'FN-Sportabzeichen Reiten', 4, false),
    ('Leistungsabzeichen des DSB', 'Leistungsabzeichen des DSB', 4, false),
	('Taekwondo Sportabzeichen ab Silber', 'Taekwondo Sportabzeichen ab Silber', 4, false),
	('Kindertanzabzeichen', 'Kindertanzabzeichen', 4, false),
	('Deutsches Tanz-Sportabzeichen', 'Deutsches Tanz-Sportabzeichen', 4, false),
	('Tennis-Sportabzeichen', 'Tennis-Sportabzeichen', 4, false),
    ('Tischtennissportabzeichen ab GUT', 'Tischtennissportabzeichen ab GUT', 4, false),
	('Kinderturn-Abzeichen Gold', 'Kinderturn-Abzeichen Gold', 4, false),
	('Deutsches Gymnastikabzeichen', 'Deutsches Gymnastikabzeichen', 4, false),
	('Geräteturnabzeichen', 'Geräteturnabzeichen', 4, false),
    ('Deutsches Rope-Skipping Abzeichen (6-9jährige)', 'Deutsches Rope-Skipping Abzeichen (6-9jährige)', 4, false),
    ('Deutsches Rope-Skipping Abzeichen (10jährige)', 'Deutsches Rope-Skipping Abzeichen (10jährige)', 4, false),
    ('Deutsches Rope-Skipping Abzeichen ab Silber', 'Deutsches Rope-Skipping Abzeichen ab Silber', 4, false),
	('Petanque-Leistungsabzeichen', 'Petanque-Leistungsabzeichen', 4, false)
;

INSERT INTO ABZART(AbzArtNr, AbzArtName) VALUES
	(1, 'Bronze'),
	(2, 'Bronze Wiederh. o. Abz.'),
	(3, 'Silber'),
	(4, 'Silber Wiederh. o. Abz.'),
	(5, 'Gold'),
	(6, 'Gold Wiederh. o. Abz.'),
	(7, 'Gold mit Zahl 5'),
	(8, 'Gold mit Zahl 10'),
	(9, 'Gold mit Zahl 15'),
	(10, 'Gold mit Zahl 20'),
	(11, 'Gold mit Zahl 25'),
	(12, 'Gold mit Zahl 30'),
	(13, 'Gold mit Zahl 35'),
	(14, 'Gold mit Zahl 40'),
	(15, 'Gold mit Zahl 45'),
	(16, 'Gold mit Zahl 50'),
	(17, 'Gold mit Zahl 55'),
	(18, 'Gold mit Zahl 60'),
	(19, 'Gold mit Zahl 65'),
	(20, 'Gold mit Zahl 70'),
	(21, 'Gold mit Zahl 75'),
	(22, 'Gold mit Zahl 80'),
	(23, 'Gold mit Zahl 85'),
	(24, 'Gold mit Zahl 90'),
	(25, ''),
	(104, 'Gold mit Zahl 4'),
	(105, 'Gold mit Zahl 5'),
	(106, 'Gold mit Zahl 6'),
	(107, 'Gold mit Zahl 7'),
	(108, 'Gold mit Zahl 8'),
	(109, 'Gold mit Zahl 9'),
	(110, 'Gold mit Zahl 10'),
	(111, 'Gold mit Zahl 11'),
	(112, 'Gold mit Zahl 12'),
	(200, 'Abzeichen mit Zahl')
;

INSERT INTO PruefArt(PruefArtNr, PruefArtName, PruefArtKuerzel) VALUES
	(1, 'Schülersportabzeichen', 'Schüler'),
	(2, 'Jugendsportabzeichen', 'Jugend'),
	(3, 'Deutsches Sportabzeichen', 'Erwachsen'),
	(4, 'Minisportabzeichen', 'Mini'),
	(5, 'Europ. Jugendsportabzeichen', 'Europ. Jugend'),
	(6, 'Familiensportabzeichen', 'Familien'),
	(7, 'Deutsches Sportabzeichen Jugend', 'SpA Jugend')
;

INSERT INTO tblFilter(FName, Alter_Von, Alter_Bis, Geschlecht, Aktiv, Selektion) VALUES
	('', -1, -1, 'a', NULL, NULL),
	('Aktive', -1, -1, 'a', TRUE, NULL),
	('Inaktive', -1, -1, 'a', FALSE, NULL)
;

INSERT INTO tblEinstellungen(einst_key, einst_value) VALUES
	('version', '4.25.00'),
    ('saison', '2024')
;